/******************************************************************************
 *                                                                            *
 * Copyright (C) 2018 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *****************************************************************************
 * Originally developed and contributed by Ittiam Systems Pvt. Ltd, Bangalore
*/
#include "ixheaac_type_def.h"
#include "ixheaac_constants.h"
#include "ixheaacd_mps_struct_def.h"
#include "ixheaacd_bitbuffer.h"
#include "ixheaacd_common_rom.h"
#include "ixheaacd_sbrdecsettings.h"
#include "ixheaacd_sbr_scale.h"
#include "ixheaacd_env_extr_part.h"
#include "ixheaacd_sbr_rom.h"
#include "ixheaacd_hybrid.h"
#include "ixheaacd_ps_dec.h"
#include "ixheaacd_config.h"
#include "ixheaacd_qmf_dec.h"
#include "ixheaacd_mps_polyphase.h"
#include "ixheaacd_mps_res_rom.h"
#include "ixheaacd_mps_aac_struct.h"
#include "ixheaacd_mps_dec.h"
#include "ixheaacd_mps_huff_tab.h"

const ia_huff_cld_nodes_struct ixheaacd_huff_cld_nodes = {
    {{{{-1, 1},   {-2, 2},   {-3, 3},   {-4, 4},    {-5, 5},    {-6, 6},   {-7, 7},   {-8, 8},
       {-9, 9},   {-10, 10}, {-11, 11}, {-12, 12},  {-13, 13},  {15, 14},  {-14, 16}, {-15, 17},
       {-16, 18}, {-17, 19}, {-18, 20}, {-19, 21},  {-20, -21}, {-23, 22}, {-22, 23}, {-24, 24},
       {-25, 25}, {27, 26},  {29, 28},  {-30, -31}, {-28, -29}, {-26, -27}}},
     {{{-1, 1},   {-2, 2},   {-3, 3},   {-4, 4},    {-5, 5},    {-6, 6},   {-7, 7},   {9, 8},
       {-8, 10},  {-9, 11},  {-10, 12}, {-11, 13},  {-12, 14},  {-13, 15}, {-14, 16}, {-15, 17},
       {-16, 18}, {-17, 19}, {-18, 20}, {-19, -20}, {-21, 21},  {-22, 22}, {-23, 23}, {25, 24},
       {-24, 26}, {-25, 27}, {29, 28},  {-26, -31}, {-29, -30}, {-27, -28}}},
     {{{-1, 1},   {-2, 2},   {-3, 3},   {-4, 4},    {-5, 5},    {-6, 6},   {-7, 7},   {9, 8},
       {-8, 10},  {-9, 11},  {-10, 12}, {-11, 13},  {-12, 14},  {-13, 15}, {-14, 16}, {-15, 17},
       {-16, 18}, {-17, 19}, {-18, 20}, {-19, -20}, {-21, 21},  {-22, 22}, {-23, 23}, {25, 24},
       {-24, 26}, {-25, 27}, {29, 28},  {-26, -31}, {-29, -30}, {-27, -28}}}},
    {{{{{2, 1},
        {-1, -52},
        {4, 3},
        {-2, 5},
        {-51, 6},
        {-17, -18},
        {8, 7},
        {10, 9},
        {-3, -36},
        {-19, 11},
        {-35, -50},
        {-34, 12},
        {-4, 13},
        {-33, 14},
        {-20, -49}},
       {{2, 1},    {4, 3},    {-86, 5},   {7, 6},    {9, 8},     {-1, -2},   {-85, 10},
        {-18, 11}, {-17, 12}, {14, 13},   {-70, 15}, {17, 16},   {-19, -69}, {-84, 18},
        {-3, 19},  {21, 20},  {-34, -68}, {-20, 22}, {-35, 23},  {-83, 24},  {-33, 25},
        {-4, 26},  {-53, 27}, {-54, -67}, {-36, 28}, {-21, -52}, {-82, 29},  {-5, -50},
        {-51, 30}, {-38, 31}, {-37, -49}, {-6, 32},  {-66, 33},  {-65, 34},  {-22, -81}},
       {{2, 1},      {4, 3},     {-120, 5},   {7, 6},     {9, 8},     {11, 10},    {-1, 12},
        {-18, -119}, {-2, 13},   {15, 14},    {-17, 16},  {-104, 17}, {19, 18},    {-19, 20},
        {-103, 21},  {-118, 22}, {24, 23},    {-3, 25},   {27, 26},   {-34, 28},   {-102, 29},
        {-20, 30},   {-35, 31},  {33, 32},    {-117, 34}, {-33, 35},  {-88, 36},   {-4, 37},
        {-87, 38},   {40, 39},   {-36, -101}, {-86, 41},  {-21, -37}, {-85, -100}, {-52, 42},
        {-22, 43},   {-116, 44}, {-50, 45},   {47, 46},   {-5, -51},  {-115, 48},  {-70, 49},
        {-84, 50},   {-38, -49}, {-72, -99},  {-53, 51},  {-69, -71}, {-23, 52},   {-6, -67},
        {-114, 53},  {-7, 54},   {-66, -68},  {-55, 55},  {57, 56},   {-54, -65},  {-8, -56},
        {-82, -83},  {59, 58},   {-39, -40},  {-81, 60},  {-98, 61},  {-97, 62},   {-24, -113}},
       {{2, 1},       {4, 3},      {6, 5},      {-154, 7},   {9, 8},       {11, 10},
        {13, 12},     {15, 14},    {-18, 16},   {-153, 17},  {-1, -2},     {19, 18},
        {-138, 20},   {-17, 21},   {23, 22},    {25, 24},    {-19, -137},  {27, 26},
        {-152, 28},   {30, 29},    {-3, -34},   {32, 31},    {34, 33},     {36, 35},
        {-136, 37},   {-35, 38},   {-20, 39},   {-122, 40},  {-151, 41},   {-33, 42},
        {-121, 43},   {45, 44},    {47, 46},    {-4, 48},    {-36, -120},  {-135, 49},
        {51, 50},     {-21, 52},   {54, 53},    {56, 55},    {-50, -150},  {58, 57},
        {-51, 59},    {61, 60},    {-119, 62},  {-52, 63},   {-5, 64},     {-37, 65},
        {-117, -134}, {-39, -54},  {-22, 66},   {-106, 67},  {-69, -102},  {-132, 68},
        {-105, 69},   {-49, 70},   {-149, 71},  {-24, -104}, {73, 72},     {-53, 74},
        {-38, -118},  {-103, 75},  {-6, 76},    {-66, -87},  {-133, -147}, {-23, 77},
        {-67, 78},    {-68, -86},  {-70, -101}, {-40, -148}, {-116, 79},   {-55, 80},
        {-84, -131},  {82, 81},    {-89, -90},  {-7, -25},   {-85, -88},   {-65, 83},
        {-72, -146},  {85, 84},    {-9, -71},   {-83, 86},   {-82, 87},    {-8, 88},
        {-100, 89},   {-74, -99},  {-73, 90},   {-10, -81},  {-56, 91},    {-57, -98},
        {93, 92},     {-58, -114}, {-97, -115}, {95, 94},    {-41, 96},    {-42, 97},
        {-26, -129},  {-113, 98},  {-130, -145}}},
      {{{-1, 1},
        {-52, 2},
        {-17, 3},
        {5, 4},
        {-36, 6},
        {-33, 7},
        {-2, -18},
        {-20, 8},
        {10, 9},
        {-34, -49},
        {-51, 11},
        {-35, 12},
        {-19, 13},
        {-3, 14},
        {-4, -50}},
       {{2, 1},    {4, 3},     {-86, 5},  {-1, 6},    {-17, 7},   {-70, 8},  {10, 9},
        {-18, 11}, {-33, 12},  {-54, 13}, {-2, 14},   {-34, 15},  {-38, 16}, {-49, 17},
        {-85, 18}, {-50, 19},  {-69, 20}, {-53, -65}, {-22, 21},  {-66, 22}, {-19, 23},
        {-37, 24}, {-35, -81}, {-3, 25},  {-51, 26},  {-68, -84}, {-52, 27}, {29, 28},
        {-20, 30}, {-4, -36},  {-83, 31}, {-67, 32},  {-21, 33},  {-5, 34},  {-6, -82}},
       {{2, 1},      {4, 3},     {6, 5},     {-120, 7}, {-17, 8},   {-1, -104},   {10, 9},
        {12, 11},    {-18, 13},  {-33, -88}, {15, 14},  {17, 16},   {-2, 18},     {-34, 19},
        {-72, 20},   {-49, 21},  {-119, 22}, {-50, 23}, {-103, 24}, {-56, 25},    {-65, 26},
        {28, 27},    {-40, -87}, {-66, 29},  {-82, 30}, {32, 31},   {-19, -81},   {-71, 33},
        {-97, 34},   {-35, -55}, {-24, 35},  {37, 36},  {-3, -98},  {-51, 38},    {-67, 39},
        {-39, -118}, {-113, 40}, {-102, 41}, {-86, 42}, {-70, -83}, {44, 43},     {-20, -54},
        {-52, 45},   {-36, 46},  {-4, 47},   {-68, 48}, {-85, 49},  {-101, -117}, {-69, 50},
        {52, 51},    {-21, -37}, {-53, 53},  {55, 54},  {-5, -100}, {-116, 56},   {-84, 57},
        {-38, 58},   {-22, -99}, {-115, 59}, {-6, 60},  {-23, 61},  {-7, 62},     {-114, 0}},
       {{2, 1},      {4, 3},     {6, 5},       {-154, 7},    {9, 8},      {-17, 10},
        {-138, 11},  {-1, 12},   {14, 13},     {16, 15},     {-33, -122}, {-18, 17},
        {19, 18},    {-34, 20},  {-2, 21},     {-106, 22},   {-49, 23},   {25, 24},
        {-50, 26},   {-153, 27}, {-90, 28},    {-137, 29},   {-65, 30},   {32, 31},
        {-66, 33},   {-121, 34}, {-74, 35},    {-81, 36},    {38, 37},    {-42, 39},
        {-82, 40},   {-105, 41}, {-19, -114},  {-58, 42},    {-35, 43},   {-97, 44},
        {46, 45},    {-129, 47}, {-26, -89},   {-57, -98},   {-51, 48},   {-3, 49},
        {-113, 50},  {-130, 51}, {-152, 52},   {-67, -73},   {-99, -136}, {-145, 53},
        {-120, 54},  {-41, 55},  {-83, 56},    {-72, 57},    {-104, 58},  {-115, 59},
        {-20, 60},   {62, 61},   {-36, -88},   {-84, 63},    {-52, -56},  {65, 64},
        {-4, -87},   {-68, 66},  {-151, 67},   {-100, -135}, {69, 68},    {-69, -119},
        {-103, 70},  {-71, 71},  {73, 72},     {-21, 74},    {-85, 75},   {-37, -53},
        {-86, 76},   {78, 77},   {-102, -150}, {-5, 79},     {-134, 80},  {-118, 81},
        {-54, -117}, {83, 82},   {-38, -70},   {-22, 84},    {-6, 85},    {87, 86},
        {-55, 88},   {-101, 89}, {-133, -149}, {-24, -39},   {91, 90},    {-132, 92},
        {-23, 93},   {-7, 94},   {-147, -148}, {-116, -131}, {-25, 95},   {-40, 0},
        {0, 0},      {0, 0},     {0, 0}}}},
     {{{{-1, 1},
        {-52, 2},
        {-17, 3},
        {5, 4},
        {-2, -36},
        {-18, 6},
        {8, 7},
        {-51, 9},
        {-33, 10},
        {-34, 11},
        {-20, -35},
        {-19, 12},
        {-3, 13},
        {-49, 14},
        {-4, -50}},
       {{2, 1},    {-86, 3},   {-1, 4},   {-17, 5},   {7, 6},     {-70, 8},  {-2, -18},
        {10, 9},   {12, 11},   {-85, 13}, {-33, 14},  {-34, -54}, {16, 15},  {-69, 17},
        {19, 18},  {-50, -53}, {-19, 20}, {-38, 21},  {-35, -49}, {-3, 22},  {24, 23},
        {-68, 25}, {-84, 26},  {-65, 27}, {-51, -66}, {-22, -37}, {-52, 28}, {-20, 29},
        {-36, 30}, {-81, 31},  {-4, -83}, {-67, 32},  {-21, 33},  {-5, 34},  {-6, -82}},
       {{2, 1},      {-120, 3},   {-1, 4},   {6, 5},     {-17, 7},    {-104, 8},   {-18, 9},
        {-2, 10},    {12, 11},    {14, 13},  {-119, 15}, {-33, 16},   {-34, -88},  {-103, 17},
        {19, 18},    {21, 20},    {23, 22},  {25, 24},   {-19, -72},  {-50, 26},   {-49, 27},
        {-87, 28},   {30, 29},    {32, 31},  {-3, -35},  {34, 33},    {-56, 35},   {-65, -66},
        {-40, 36},   {-82, -118}, {-71, 37}, {-55, 38},  {-67, -102}, {-51, 39},   {-70, 40},
        {42, 41},    {-81, 43},   {-86, 44}, {-52, -97}, {-98, 45},   {-24, -39},  {-20, 46},
        {-54, -83},  {-36, 47},   {-85, 48}, {-68, 49},  {-4, 50},    {-69, -113}, {-117, 51},
        {-37, -101}, {-53, 52},   {-21, 53}, {55, 54},   {-84, -100}, {-5, 56},    {-116, 57},
        {-22, 58},   {-38, -115}, {60, 59},  {-6, -99},  {-23, 61},   {-114, 62},  {-7, -8}},
       {{2, 1},       {-154, 3},   {5, 4},      {-1, 6},      {8, 7},      {-17, 9},
        {-138, 10},   {-18, 11},   {-2, 12},    {14, 13},     {16, 15},    {-153, 17},
        {-34, 18},    {-33, -122}, {20, 19},    {22, 21},     {-137, 23},  {25, 24},
        {27, 26},     {-106, 28},  {30, 29},    {-50, 31},    {-19, 32},   {-49, -121},
        {34, 33},     {36, 35},    {-35, 37},   {-90, 38},    {-66, 39},   {-3, 40},
        {42, 41},     {-65, 43},   {-105, 44},  {46, 45},     {-74, 47},   {-51, 48},
        {-82, -152},  {-136, 49},  {-81, 50},   {-42, -89},   {-114, 51},  {53, 52},
        {-57, -58},   {-120, 54},  {-98, 55},   {-67, 56},    {-97, 57},   {59, 58},
        {-99, 60},    {-73, -104}, {-72, 61},   {-113, 62},   {-20, -83},  {-84, -130},
        {-36, 63},    {-26, 64},   {-41, 65},   {-52, -129},  {-87, -88},  {67, 66},
        {-115, 68},   {-68, 69},   {-56, -69},  {-4, -100},   {-151, 70},  {-135, 71},
        {-103, -119}, {73, 72},    {-71, -145}, {-102, 74},   {76, 75},    {-53, -85},
        {-37, 77},    {-21, -86},  {79, 78},    {-5, 80},     {-54, -134}, {-150, 81},
        {-118, 82},   {-70, 83},   {-117, 84},  {-22, -38},   {-101, 85},  {-55, 86},
        {-149, 87},   {-39, 88},   {-133, 89},  {-6, 90},     {-116, 91},  {-24, 92},
        {-7, -132},   {-23, 93},   {-40, 94},   {-131, -148}, {-25, 95},   {-147, 96},
        {-146, 97},   {-8, 0},     {0, 0}}},
      {{{-1, 1},
        {-52, 2},
        {4, 3},
        {-2, 5},
        {-17, 6},
        {-18, 7},
        {-36, -51},
        {9, 8},
        {-35, 10},
        {-34, 11},
        {-19, -33},
        {-3, 12},
        {-20, 13},
        {-50, 14},
        {-4, -49}},
       {{2, 1},     {-86, 3},  {5, 4},     {-1, 6},    {8, 7},    {-17, -18}, {-2, 9},
        {-70, 10},  {-85, 11}, {13, 12},   {-69, 14},  {-34, 15}, {17, 16},   {-19, 18},
        {-33, -35}, {-54, 19}, {-53, 20},  {-3, 21},   {-68, 22}, {-84, 23},  {-50, 24},
        {-52, 25},  {-51, 26}, {-20, -36}, {-49, 27},  {-38, 28}, {-37, 29},  {-4, -83},
        {-67, 30},  {-66, 31}, {-21, 32},  {-22, -65}, {-5, 33},  {-82, 34},  {-6, -81}},
       {{2, 1},     {4, 3},     {-120, 5},   {7, 6},      {9, 8},     {-1, 10},   {-18, 11},
        {-17, 12},  {-2, -104}, {-119, 13},  {15, 14},    {-103, 16}, {18, 17},   {-34, 19},
        {-19, 20},  {22, 21},   {-35, 23},   {-33, 24},   {-88, 25},  {-87, 26},  {28, 27},
        {-3, -102}, {-86, 29},  {-52, -118}, {31, 30},    {-50, 32},  {-51, 33},  {-70, 34},
        {-36, 35},  {-85, 36},  {-20, 37},   {39, 38},    {-69, -71}, {-72, 40},  {-49, -67},
        {42, 41},   {-68, 43},  {-4, -101},  {-53, -117}, {-37, 44},  {-66, 45},  {-55, 46},
        {48, 47},   {-54, 49},  {-21, 50},   {-84, -100}, {-56, -65}, {52, 51},   {-82, -83},
        {54, 53},   {-5, -116}, {-22, 55},   {-38, 56},   {-39, -40}, {58, 57},   {-81, -115},
        {-98, -99}, {-6, 59},   {-23, 60},   {-24, 61},   {-7, -97},  {-114, 62}, {-8, -113}},
       {{2, 1},      {4, 3},      {-154, 5},  {7, 6},      {9, 8},      {11, 10},
        {-1, 12},    {-18, 13},   {-17, 14},  {-2, -138},  {16, 15},    {-153, 17},
        {-137, 18},  {20, 19},    {22, 21},   {-34, 23},   {-19, 24},   {-35, 25},
        {27, 26},    {29, 28},    {-121, 30}, {-120, 31},  {-136, 32},  {-33, -122},
        {34, 33},    {-152, 35},  {-3, 36},   {-51, 37},   {-52, 38},   {-69, 39},
        {-36, 40},   {-50, 41},   {43, 42},   {-20, 44},   {-104, 45},  {-103, 46},
        {-87, 47},   {-119, 48},  {-105, 49}, {-86, 50},   {-102, 51},  {-106, 52},
        {-49, -135}, {-68, 53},   {55, 54},   {-53, 56},   {-67, -151}, {-4, 57},
        {-84, 58},   {-85, 59},   {-66, 60},  {-37, 61},   {-70, 62},   {-54, -88},
        {-21, 63},   {65, 64},    {-89, 66},  {-118, 67},  {-72, 68},   {-90, 69},
        {-71, 70},   {-65, -134}, {-150, 71}, {-83, 72},   {-5, 73},    {-101, -117},
        {-82, 74},   {76, 75},    {-99, 77},  {-38, 78},   {-100, 79},  {-22, 80},
        {-73, 81},   {-39, -74},  {83, 82},   {-55, -81},  {-57, 84},   {-133, -149},
        {-56, 85},   {-6, 86},    {-98, 87},  {-132, 88},  {-23, 89},   {-114, 90},
        {-116, 91},  {-58, -115}, {-24, 92},  {-97, -148}, {-40, -41},  {-7, -42},
        {-147, 93},  {95, 94},    {-131, 96}, {-8, -130},  {-25, -113}, {-9, 97},
        {-26, -129}, {-146, 98},  {-10, -145}}}},
     {{{{-1, 1},
        {-52, 2},
        {-17, 3},
        {5, 4},
        {-36, 6},
        {-33, 7},
        {-2, -18},
        {-20, 8},
        {10, 9},
        {-34, -49},
        {-51, 11},
        {-35, 12},
        {-19, 13},
        {-3, 14},
        {-4, -50}},
       {{2, 1},    {4, 3},     {-86, 5},  {-1, 6},    {-17, 7},   {-70, 8},  {10, 9},
        {-18, 11}, {-33, 12},  {-54, 13}, {-2, 14},   {-34, 15},  {-38, 16}, {-49, 17},
        {-85, 18}, {-50, 19},  {-69, 20}, {-53, -65}, {-22, 21},  {-66, 22}, {-19, 23},
        {-37, 24}, {-35, -81}, {-3, 25},  {-51, 26},  {-68, -84}, {-52, 27}, {29, 28},
        {-20, 30}, {-4, -36},  {-83, 31}, {-67, 32},  {-21, 33},  {-5, 34},  {-6, -82}},
       {{2, 1},      {4, 3},     {6, 5},     {-120, 7}, {-17, 8},   {-1, -104},   {10, 9},
        {12, 11},    {-18, 13},  {-33, -88}, {15, 14},  {17, 16},   {-2, 18},     {-34, 19},
        {-72, 20},   {-49, 21},  {-119, 22}, {-50, 23}, {-103, 24}, {-56, 25},    {-65, 26},
        {28, 27},    {-40, -87}, {-66, 29},  {-82, 30}, {32, 31},   {-19, -81},   {-71, 33},
        {-97, 34},   {-35, -55}, {-24, 35},  {37, 36},  {-3, -98},  {-51, 38},    {-67, 39},
        {-39, -118}, {-113, 40}, {-102, 41}, {-86, 42}, {-70, -83}, {44, 43},     {-20, -54},
        {-52, 45},   {-36, 46},  {-4, 47},   {-68, 48}, {-85, 49},  {-101, -117}, {-69, 50},
        {52, 51},    {-21, -37}, {-53, 53},  {55, 54},  {-5, -100}, {-116, 56},   {-84, 57},
        {-38, 58},   {-22, -99}, {-115, 59}, {-6, 60},  {-23, 61},  {-7, 62},     {-114, 0}},
       {{2, 1},      {4, 3},     {6, 5},       {-154, 7},    {9, 8},      {-17, 10},
        {-138, 11},  {-1, 12},   {14, 13},     {16, 15},     {-33, -122}, {-18, 17},
        {19, 18},    {-34, 20},  {-2, 21},     {-106, 22},   {-49, 23},   {25, 24},
        {-50, 26},   {-153, 27}, {-90, 28},    {-137, 29},   {-65, 30},   {32, 31},
        {-66, 33},   {-121, 34}, {-74, 35},    {-81, 36},    {38, 37},    {-42, 39},
        {-82, 40},   {-105, 41}, {-19, -114},  {-58, 42},    {-35, 43},   {-97, 44},
        {46, 45},    {-129, 47}, {-26, -89},   {-57, -98},   {-51, 48},   {-3, 49},
        {-113, 50},  {-130, 51}, {-152, 52},   {-67, -73},   {-99, -136}, {-145, 53},
        {-120, 54},  {-41, 55},  {-83, 56},    {-72, 57},    {-104, 58},  {-115, 59},
        {-20, 60},   {62, 61},   {-36, -88},   {-84, 63},    {-52, -56},  {65, 64},
        {-4, -87},   {-68, 66},  {-151, 67},   {-100, -135}, {69, 68},    {-69, -119},
        {-103, 70},  {-71, 71},  {73, 72},     {-21, 74},    {-85, 75},   {-37, -53},
        {-86, 76},   {78, 77},   {-102, -150}, {-5, 79},     {-134, 80},  {-118, 81},
        {-54, -117}, {83, 82},   {-38, -70},   {-22, 84},    {-6, 85},    {87, 86},
        {-55, 88},   {-101, 89}, {-133, -149}, {-24, -39},   {91, 90},    {-132, 92},
        {-23, 93},   {-7, 94},   {-147, -148}, {-116, -131}, {-25, 95},   {-40, 0},
        {0, 0},      {0, 0},     {0, 0}}},
      {{{-1, 1},
        {-52, 2},
        {-17, 3},
        {5, 4},
        {-36, 6},
        {-33, 7},
        {-2, -18},
        {-20, 8},
        {10, 9},
        {-34, -49},
        {-51, 11},
        {-35, 12},
        {-19, 13},
        {-3, 14},
        {-4, -50}},
       {{2, 1},    {4, 3},     {-86, 5},  {-1, 6},    {-17, 7},   {-70, 8},  {10, 9},
        {-18, 11}, {-33, 12},  {-54, 13}, {-2, 14},   {-34, 15},  {-38, 16}, {-49, 17},
        {-85, 18}, {-50, 19},  {-69, 20}, {-53, -65}, {-22, 21},  {-66, 22}, {-19, 23},
        {-37, 24}, {-35, -81}, {-3, 25},  {-51, 26},  {-68, -84}, {-52, 27}, {29, 28},
        {-20, 30}, {-4, -36},  {-83, 31}, {-67, 32},  {-21, 33},  {-5, 34},  {-6, -82}},
       {{2, 1},      {4, 3},     {6, 5},     {-120, 7}, {-17, 8},   {-1, -104},   {10, 9},
        {12, 11},    {-18, 13},  {-33, -88}, {15, 14},  {17, 16},   {-2, 18},     {-34, 19},
        {-72, 20},   {-49, 21},  {-119, 22}, {-50, 23}, {-103, 24}, {-56, 25},    {-65, 26},
        {28, 27},    {-40, -87}, {-66, 29},  {-82, 30}, {32, 31},   {-19, -81},   {-71, 33},
        {-97, 34},   {-35, -55}, {-24, 35},  {37, 36},  {-3, -98},  {-51, 38},    {-67, 39},
        {-39, -118}, {-113, 40}, {-102, 41}, {-86, 42}, {-70, -83}, {44, 43},     {-20, -54},
        {-52, 45},   {-36, 46},  {-4, 47},   {-68, 48}, {-85, 49},  {-101, -117}, {-69, 50},
        {52, 51},    {-21, -37}, {-53, 53},  {55, 54},  {-5, -100}, {-116, 56},   {-84, 57},
        {-38, 58},   {-22, -99}, {-115, 59}, {-6, 60},  {-23, 61},  {-7, 62},     {-114, 0}},
       {{2, 1},      {4, 3},     {6, 5},       {-154, 7},    {9, 8},      {-17, 10},
        {-138, 11},  {-1, 12},   {14, 13},     {16, 15},     {-33, -122}, {-18, 17},
        {19, 18},    {-34, 20},  {-2, 21},     {-106, 22},   {-49, 23},   {25, 24},
        {-50, 26},   {-153, 27}, {-90, 28},    {-137, 29},   {-65, 30},   {32, 31},
        {-66, 33},   {-121, 34}, {-74, 35},    {-81, 36},    {38, 37},    {-42, 39},
        {-82, 40},   {-105, 41}, {-19, -114},  {-58, 42},    {-35, 43},   {-97, 44},
        {46, 45},    {-129, 47}, {-26, -89},   {-57, -98},   {-51, 48},   {-3, 49},
        {-113, 50},  {-130, 51}, {-152, 52},   {-67, -73},   {-99, -136}, {-145, 53},
        {-120, 54},  {-41, 55},  {-83, 56},    {-72, 57},    {-104, 58},  {-115, 59},
        {-20, 60},   {62, 61},   {-36, -88},   {-84, 63},    {-52, -56},  {65, 64},
        {-4, -87},   {-68, 66},  {-151, 67},   {-100, -135}, {69, 68},    {-69, -119},
        {-103, 70},  {-71, 71},  {73, 72},     {-21, 74},    {-85, 75},   {-37, -53},
        {-86, 76},   {78, 77},   {-102, -150}, {-5, 79},     {-134, 80},  {-118, 81},
        {-54, -117}, {83, 82},   {-38, -70},   {-22, 84},    {-6, 85},    {87, 86},
        {-55, 88},   {-101, 89}, {-133, -149}, {-24, -39},   {91, 90},    {-132, 92},
        {-23, 93},   {-7, 94},   {-147, -148}, {-116, -131}, {-25, 95},   {-40, 0},
        {0, 0},      {0, 0},     {0, 0}}}}}};

const ia_huff_icc_nodes_struct ixheaacd_huff_icc_nodes = {
    {{{{-1, 1}, {-2, 2}, {-3, 3}, {-4, 4}, {-5, 5}, {-6, 6}, {-7, -8}}},
     {{{-1, 1}, {-2, 2}, {-3, 3}, {-4, 4}, {-5, 5}, {-6, 6}, {-7, -8}}},
     {{{-1, 1}, {-2, 2}, {-3, 3}, {-4, 4}, {-5, 5}, {-6, 6}, {-7, -8}}}},
    {{{{{-1, 1}, {-18, 2}, {-2, -17}},
       {{2, 1},
        {-1, -52},
        {-2, 3},
        {5, 4},
        {-51, 6},
        {-18, 7},
        {-17, 8},
        {-3, 9},
        {-36, 10},
        {-19, -50},
        {-35, 11},
        {-4, 12},
        {-34, 13},
        {-33, 14},
        {-20, -49}},
       {{2, 1},    {-86, 3},   {-1, 4},    {6, 5},     {-2, 7},   {-85, 8},  {-18, 9},
        {11, 10},  {-17, 12},  {14, 13},   {-70, 15},  {-3, -19}, {-69, 16}, {-84, 17},
        {-68, 18}, {-20, -35}, {-34, -83}, {20, 19},   {-4, 21},  {-33, 22}, {-5, 23},
        {-53, 24}, {-36, -52}, {-67, 25},  {-21, -82}, {-54, 26}, {-6, 27},  {-51, 28},
        {-50, 29}, {-49, 30},  {-37, 31},  {-38, 0},   {0, 0},    {0, 0},    {0, 0}},
       {{2, 1},     {4, 3},     {-1, -120},  {6, 5},    {8, 7},     {-18, 9},   {-2, 10},
        {12, 11},   {14, 13},   {-17, -119}, {16, 15},  {-103, 17}, {-104, 18}, {-52, 19},
        {21, 20},   {-69, 22},  {24, 23},    {-3, -35}, {-19, 25},  {-34, -85}, {27, 26},
        {-86, 28},  {-118, 29}, {-37, 30},   {32, 31},  {-102, 33}, {-20, -22}, {-4, -117},
        {-87, 34},  {-100, 35}, {-33, -36},  {37, 36},  {-70, -88}, {-101, 38}, {-5, 39},
        {-51, -53}, {-50, 40},  {-115, 41},  {-21, 42}, {-116, 43}, {-38, 44},  {-23, -84},
        {-49, -99}, {46, 45},   {-6, -114},  {-7, -72}, {-71, 47},  {-8, 0},    {0, 0},
        {0, 0},     {0, 0},     {0, 0},      {0, 0},    {0, 0},     {0, 0},     {0, 0},
        {0, 0},     {0, 0},     {0, 0},      {0, 0},    {0, 0},     {0, 0},     {0, 0}}},
      {{{-1, 1}, {-18, 2}, {-2, -17}},
       {{2, 1},
        {-1, -52},
        {-17, 3},
        {5, 4},
        {-36, 6},
        {-2, 7},
        {-18, -33},
        {9, 8},
        {-20, 10},
        {-34, -51},
        {-49, 11},
        {-35, 12},
        {-19, 13},
        {-3, 14},
        {-4, -50}},
       {{2, 1},    {-86, 3},  {-1, 4},   {-17, 5},   {7, 6},    {-70, 8},   {-33, 9},
        {-18, 10}, {-2, 11},  {-54, 12}, {-49, 13},  {-38, 14}, {-34, -65}, {-85, 15},
        {-50, 16}, {-69, 17}, {-22, 18}, {-53, 19},  {21, 20},  {-19, -81}, {-66, 22},
        {-3, -35}, {24, 23},  {-37, 25}, {-68, -84}, {-51, 26}, {28, 27},   {-20, -52},
        {30, 29},  {-4, -36}, {-83, 31}, {-67, 32},  {-82, 33}, {-21, 34},  {-5, -6}},
       {{2, 1},      {-1, 3},     {-120, 4},   {-17, 5},   {7, 6},     {-104, 8},  {-33, 9},
        {11, 10},    {13, 12},    {-49, 14},   {-88, 15},  {-18, -97}, {-65, 16},  {-40, 17},
        {-2, -72},   {19, 18},    {-113, 20},  {-34, 21},  {-56, -81}, {23, 22},   {-50, 24},
        {-82, -119}, {-24, -103}, {26, 25},    {28, 27},   {30, 29},   {-55, -87}, {-66, 31},
        {33, 32},    {-98, 34},   {-35, -67},  {-19, 35},  {-70, 36},  {-71, 37},  {-51, -52},
        {-3, 38},    {40, 39},    {-86, -118}, {42, 41},   {-39, -69}, {-54, -83}, {44, 43},
        {-102, 45},  {-101, 46},  {-68, -85},  {-36, -53}, {-5, 0},    {0, 0},     {0, 0},
        {0, 0},      {0, 0},      {0, 0},      {0, 0},     {0, 0},     {0, 0},     {0, 0},
        {0, 0},      {0, 0},      {0, 0},      {0, 0},     {0, 0},     {0, 0},     {0, 0}}}},
     {{{{-1, 1}, {-18, 2}, {-2, -17}},
       {{-52, 1},
        {-1, 2},
        {4, 3},
        {-2, -17},
        {-18, 5},
        {-36, 6},
        {-51, 7},
        {9, 8},
        {-33, 10},
        {-34, 11},
        {-35, 12},
        {-19, -20},
        {-3, 13},
        {-49, 14},
        {-4, -50}},
       {{-1, 1},   {-86, 2},  {4, 3},     {-17, 5},  {-2, 6},   {-18, 7},   {-70, 8},
        {-85, 9},  {11, 10},  {13, 12},   {-33, 14}, {16, 15},  {-34, -54}, {-69, 17},
        {-38, 18}, {-50, 19}, {-35, -53}, {-49, 20}, {-19, 21}, {-3, 22},   {-65, 23},
        {-68, 24}, {-22, 25}, {-81, -84}, {-66, 26}, {-37, 27}, {-20, -51}, {29, 28},
        {-52, 30}, {-4, -83}, {-36, 31},  {-67, 32}, {-5, 33},  {-82, 34},  {-21, 0}},
       {{-1, 1},    {-120, 2},  {4, 3},     {-17, 5},   {-2, 6},    {8, 7},     {-18, 9},
        {-104, 10}, {12, 11},   {14, 13},   {16, 15},   {-119, 17}, {-81, 18},  {20, 19},
        {-33, 21},  {-88, 22},  {-103, 23}, {-34, 24},  {-56, 25},  {-72, 26},  {-49, 27},
        {-82, 28},  {-50, 29},  {-65, 30},  {-55, -87}, {-19, 31},  {-67, 32},  {-35, -40},
        {34, 33},   {-52, -71}, {-66, 35},  {-70, 36},  {38, 37},   {-51, -97}, {-86, -102},
        {-3, 39},   {-118, 40}, {42, 41},   {-24, -85}, {-54, 43},  {-39, 44},  {-98, -113},
        {-36, -37}, {-20, -69}, {-4, 45},   {-5, 46},   {-21, 0},   {0, 0},     {0, 0},
        {0, 0},     {0, 0},     {0, 0},     {0, 0},     {0, 0},     {0, 0},     {0, 0},
        {0, 0},     {0, 0},     {0, 0},     {0, 0},     {0, 0},     {0, 0},     {0, 0}}},
      {{{-1, 1}, {-18, 2}, {-2, -17}},
       {{-52, 1},
        {-1, 2},
        {4, 3},
        {-2, 5},
        {-17, -18},
        {-51, 6},
        {-36, 7},
        {9, 8},
        {-35, 10},
        {-3, 11},
        {-19, -34},
        {-33, 12},
        {-50, 13},
        {-20, 14},
        {-4, -49}},
       {{2, 1},     {-86, 3},   {-1, 4},   {6, 5},     {-18, 7},  {-2, -17}, {9, 8},
        {-70, 10},  {-69, -85}, {-35, 11}, {13, 12},   {-34, 14}, {-19, 15}, {-53, 16},
        {-68, 17},  {-33, 18},  {-3, -52}, {20, 19},   {-54, 21}, {-84, 22}, {-50, 23},
        {-20, -51}, {-36, 24},  {26, 25},  {-83, 27},  {-4, -38}, {-49, 28}, {-37, 29},
        {-67, 30},  {-5, 31},   {-21, 32}, {-65, -66}, {-82, 33}, {-22, 34}, {-6, -81}},
       {{2, 1},     {-1, -120}, {4, 3},     {6, 5},      {-18, 7},   {9, 8},      {-17, 10},
        {-2, 11},   {-103, 12}, {-52, 13},  {-35, -104}, {-119, 14}, {16, 15},    {-69, -86},
        {18, 17},   {-34, 19},  {-19, 20},  {22, 21},    {-70, 23},  {-87, 24},   {-102, 25},
        {-85, 26},  {-33, 27},  {-36, 28},  {-3, 29},    {-88, 30},  {-51, 31},   {-118, 32},
        {34, 33},   {-68, 35},  {-53, 36},  {-67, 37},   {-20, 38},  {-101, 39},  {-50, 40},
        {42, 41},   {-37, 43},  {-116, 44}, {-117, 45},  {-49, 46},  {-21, -100}, {48, 47},
        {-55, -71}, {-4, 49},   {-22, -84}, {-115, 50},  {-66, -82}, {-72, 51},   {-5, -6},
        {-54, 52},  {-38, 53},  {-83, 54},  {-40, 55},   {-39, 56},  {-99, 57},   {-23, -56},
        {-7, 58},   {-65, -97}, {-8, 0},    {0, 0},      {0, 0},     {0, 0},      {0, 0}}}},
     {{{{-1, 1}, {-18, 2}, {-2, -17}},
       {{2, 1},
        {-1, -52},
        {-17, 3},
        {5, 4},
        {-36, 6},
        {-2, 7},
        {-18, -33},
        {9, 8},
        {-20, 10},
        {-34, -51},
        {-49, 11},
        {-35, 12},
        {-19, 13},
        {-3, 14},
        {-4, -50}},
       {{2, 1},    {-86, 3},  {-1, 4},   {-17, 5},   {7, 6},    {-70, 8},   {-33, 9},
        {-18, 10}, {-2, 11},  {-54, 12}, {-49, 13},  {-38, 14}, {-34, -65}, {-85, 15},
        {-50, 16}, {-69, 17}, {-22, 18}, {-53, 19},  {21, 20},  {-19, -81}, {-66, 22},
        {-3, -35}, {24, 23},  {-37, 25}, {-68, -84}, {-51, 26}, {28, 27},   {-20, -52},
        {30, 29},  {-4, -36}, {-83, 31}, {-67, 32},  {-82, 33}, {-21, 34},  {-5, -6}},
       {{2, 1},      {-1, 3},     {-120, 4},   {-17, 5},   {7, 6},     {-104, 8},  {-33, 9},
        {11, 10},    {13, 12},    {-49, 14},   {-88, 15},  {-18, -97}, {-65, 16},  {-40, 17},
        {-2, -72},   {19, 18},    {-113, 20},  {-34, 21},  {-56, -81}, {23, 22},   {-50, 24},
        {-82, -119}, {-24, -103}, {26, 25},    {28, 27},   {30, 29},   {-55, -87}, {-66, 31},
        {33, 32},    {-98, 34},   {-35, -67},  {-19, 35},  {-70, 36},  {-71, 37},  {-51, -52},
        {-3, 38},    {40, 39},    {-86, -118}, {42, 41},   {-39, -69}, {-54, -83}, {44, 43},
        {-102, 45},  {-101, 46},  {-68, -85},  {-36, -53}, {-5, 0},    {0, 0},     {0, 0},
        {0, 0},      {0, 0},      {0, 0},      {0, 0},     {0, 0},     {0, 0},     {0, 0},
        {0, 0},      {0, 0},      {0, 0},      {0, 0},     {0, 0},     {0, 0},     {0, 0}}},
      {{{-1, 1}, {-18, 2}, {-2, -17}},
       {{2, 1},
        {-1, -52},
        {-17, 3},
        {5, 4},
        {-36, 6},
        {-2, 7},
        {-18, -33},
        {9, 8},
        {-20, 10},
        {-34, -51},
        {-49, 11},
        {-35, 12},
        {-19, 13},
        {-3, 14},
        {-4, -50}},
       {{2, 1},    {-86, 3},  {-1, 4},   {-17, 5},   {7, 6},    {-70, 8},   {-33, 9},
        {-18, 10}, {-2, 11},  {-54, 12}, {-49, 13},  {-38, 14}, {-34, -65}, {-85, 15},
        {-50, 16}, {-69, 17}, {-22, 18}, {-53, 19},  {21, 20},  {-19, -81}, {-66, 22},
        {-3, -35}, {24, 23},  {-37, 25}, {-68, -84}, {-51, 26}, {28, 27},   {-20, -52},
        {30, 29},  {-4, -36}, {-83, 31}, {-67, 32},  {-82, 33}, {-21, 34},  {-5, -6}},
       {{2, 1},      {-1, 3},     {-120, 4},   {-17, 5},   {7, 6},     {-104, 8},  {-33, 9},
        {11, 10},    {13, 12},    {-49, 14},   {-88, 15},  {-18, -97}, {-65, 16},  {-40, 17},
        {-2, -72},   {19, 18},    {-113, 20},  {-34, 21},  {-56, -81}, {23, 22},   {-50, 24},
        {-82, -119}, {-24, -103}, {26, 25},    {28, 27},   {30, 29},   {-55, -87}, {-66, 31},
        {33, 32},    {-98, 34},   {-35, -67},  {-19, 35},  {-70, 36},  {-71, 37},  {-51, -52},
        {-3, 38},    {40, 39},    {-86, -118}, {42, 41},   {-39, -69}, {-54, -83}, {44, 43},
        {-102, 45},  {-101, 46},  {-68, -85},  {-36, -53}, {-5, 0},    {0, 0},     {0, 0},
        {0, 0},      {0, 0},      {0, 0},      {0, 0},     {0, 0},     {0, 0},     {0, 0},
        {0, 0},      {0, 0},      {0, 0},      {0, 0},     {0, 0},     {0, 0},     {0, 0}}}}}};

const ia_huff_ipd_nodes_struct ixheaacd_huff_ipd_nodes = {
    {{{-1, 1}, {-8, 2}, {-2, 3}, {5, 4}, {-7, 6}, {-3, -5}, {-4, -6}}},
    {{{{-1, 1}, {-8, 2}, {-2, 3}, {5, 4}, {-3, -7}, {-6, 6}, {-4, -5}}},
     {{{-1, 1}, {-2, 2}, {-8, 3}, {-3, 4}, {-7, 5}, {-4, 6}, {-5, -6}}},
     {{{-1, 1}, {-8, 2}, {-2, 3}, {5, 4}, {-3, -7}, {-6, 6}, {-4, -5}}}},
    {{{{{-1, 1}, {-18, 2}, {-17, 0}},
       {{-1, 1},
        {-36, 2},
        {-18, 3},
        {-35, 4},
        {-52, 5},
        {7, 6},
        {-34, 8},
        {-33, -49},
        {-20, 0},
        {0, 0},
        {0, 0},
        {0, 0},
        {0, 0},
        {0, 0},
        {0, 0}},
       {{-1, 1},    {3, 2},     {5, 4},     {-86, 6},  {-66, 7},   {9, 8},    {11, 10},
        {-18, 12},  {-51, 13},  {-37, -52}, {-69, 14}, {-38, 15},  {-53, 16}, {-35, 17},
        {-50, -70}, {-22, -49}, {-33, 18},  {-17, 19}, {-34, -65}, {-81, 20}, {-54, 0},
        {0, 0},     {0, 0},     {0, 0},     {0, 0},    {0, 0},     {0, 0},    {0, 0},
        {0, 0},     {0, 0},     {0, 0},     {0, 0},    {0, 0},     {0, 0},    {0, 0}},
       {{2, 1},    {4, 3},     {-1, 5},    {-69, 6},   {-120, 7},  {-68, 8},     {10, 9},
        {12, 11},  {14, 13},   {-52, -54}, {-18, 15},  {-70, 16},  {-67, 17},    {19, 18},
        {-17, 20}, {-113, 21}, {23, 22},   {-83, 24},  {-24, 25},  {-103, -104}, {-51, -55},
        {27, 26},  {-71, 28},  {-86, 29},  {-35, 30},  {-66, 31},  {-39, -50},   {-82, -98},
        {-72, 32}, {-56, -87}, {-34, 33},  {-33, -88}, {-40, -97}, {-65, 34},    {-49, 35},
        {-81, 0},  {0, 0},     {0, 0},     {0, 0},     {0, 0},     {0, 0},       {0, 0},
        {0, 0},    {0, 0},     {0, 0},     {0, 0},     {0, 0},     {0, 0},       {0, 0},
        {0, 0},    {0, 0},     {0, 0},     {0, 0},     {0, 0},     {0, 0},       {0, 0},
        {0, 0},    {0, 0},     {0, 0},     {0, 0},     {0, 0},     {0, 0},       {0, 0}}},
      {{{-1, 1}, {-18, 2}, {-17, 0}},
       {{-1, 1},
        {-36, 2},
        {-18, 3},
        {-35, 4},
        {-52, 5},
        {7, 6},
        {-34, 8},
        {-33, -49},
        {-20, 0},
        {0, 0},
        {0, 0},
        {0, 0},
        {0, 0},
        {0, 0},
        {0, 0}},
       {{-1, 1},    {3, 2},     {5, 4},     {-86, 6},  {-66, 7},   {9, 8},    {11, 10},
        {-18, 12},  {-51, 13},  {-37, -52}, {-69, 14}, {-38, 15},  {-53, 16}, {-35, 17},
        {-50, -70}, {-22, -49}, {-33, 18},  {-17, 19}, {-34, -65}, {-81, 20}, {-54, 0},
        {0, 0},     {0, 0},     {0, 0},     {0, 0},    {0, 0},     {0, 0},    {0, 0},
        {0, 0},     {0, 0},     {0, 0},     {0, 0},    {0, 0},     {0, 0},    {0, 0}},
       {{2, 1},    {4, 3},     {-1, 5},    {-69, 6},   {-120, 7},  {-68, 8},     {10, 9},
        {12, 11},  {14, 13},   {-52, -54}, {-18, 15},  {-70, 16},  {-67, 17},    {19, 18},
        {-17, 20}, {-113, 21}, {23, 22},   {-83, 24},  {-24, 25},  {-103, -104}, {-51, -55},
        {27, 26},  {-71, 28},  {-86, 29},  {-35, 30},  {-66, 31},  {-39, -50},   {-82, -98},
        {-72, 32}, {-56, -87}, {-34, 33},  {-33, -88}, {-40, -97}, {-65, 34},    {-49, 35},
        {-81, 0},  {0, 0},     {0, 0},     {0, 0},     {0, 0},     {0, 0},       {0, 0},
        {0, 0},    {0, 0},     {0, 0},     {0, 0},     {0, 0},     {0, 0},       {0, 0},
        {0, 0},    {0, 0},     {0, 0},     {0, 0},     {0, 0},     {0, 0},       {0, 0},
        {0, 0},    {0, 0},     {0, 0},     {0, 0},     {0, 0},     {0, 0},       {0, 0}}}},
     {{{{-1, 1}, {-18, 2}, {-17, 0}},
       {{-1, 1},
        {3, 2},
        {-18, 4},
        {-52, 5},
        {-34, -36},
        {-35, 6},
        {-17, 7},
        {-33, 8},
        {-20, 9},
        {-49, 0},
        {0, 0},
        {0, 0},
        {0, 0},
        {0, 0},
        {0, 0}},
       {{-1, 1},    {3, 2},    {-52, 4},   {-86, 5},   {-35, 6},   {-53, 7},  {-70, 8},
        {-17, 9},   {-37, 10}, {12, 11},   {-38, -66}, {-18, 13},  {-51, 14}, {16, 15},
        {-34, -69}, {18, 17},  {-54, -65}, {-50, 19},  {-33, -49}, {-22, 0},  {0, 0},
        {0, 0},     {0, 0},    {0, 0},     {0, 0},     {0, 0},     {0, 0},    {0, 0},
        {0, 0},     {0, 0},    {0, 0},     {0, 0},     {0, 0},     {0, 0},    {0, 0}},
       {{-1, 1},   {-69, 2},   {4, 3},     {-120, 5},  {7, 6},     {-113, 8},  {-68, 9},
        {11, 10},  {-17, 12},  {-52, 13},  {-24, 14},  {-18, 15},  {17, 16},   {-104, 18},
        {20, 19},  {-54, -70}, {22, 21},   {24, 23},   {-86, -97}, {-103, 25}, {-83, 26},
        {-35, 27}, {-34, -98}, {-40, 28},  {-39, -67}, {30, 29},   {-33, -51}, {-87, 31},
        {-88, 32}, {-82, 33},  {-55, -81}, {-56, -71}, {-72, 34},  {-50, -66}, {-65, 35},
        {-49, 0},  {0, 0},     {0, 0},     {0, 0},     {0, 0},     {0, 0},     {0, 0},
        {0, 0},    {0, 0},     {0, 0},     {0, 0},     {0, 0},     {0, 0},     {0, 0},
        {0, 0},    {0, 0},     {0, 0},     {0, 0},     {0, 0},     {0, 0},     {0, 0},
        {0, 0},    {0, 0},     {0, 0},     {0, 0},     {0, 0},     {0, 0},     {0, 0}}},
      {{{-1, 1}, {-18, 2}, {-17, 0}},
       {{-1, 1},
        {3, 2},
        {-18, 4},
        {-52, 5},
        {-34, -36},
        {-35, 6},
        {-17, 7},
        {-33, 8},
        {-20, 9},
        {-49, 0},
        {0, 0},
        {0, 0},
        {0, 0},
        {0, 0},
        {0, 0}},
       {{-1, 1},    {3, 2},    {-52, 4},   {-86, 5},   {-35, 6},   {-53, 7},  {-70, 8},
        {-17, 9},   {-37, 10}, {12, 11},   {-38, -66}, {-18, 13},  {-51, 14}, {16, 15},
        {-34, -69}, {18, 17},  {-54, -65}, {-50, 19},  {-33, -49}, {-22, 0},  {0, 0},
        {0, 0},     {0, 0},    {0, 0},     {0, 0},     {0, 0},     {0, 0},    {0, 0},
        {0, 0},     {0, 0},    {0, 0},     {0, 0},     {0, 0},     {0, 0},    {0, 0}},
       {{-1, 1},   {-69, 2},   {4, 3},     {-120, 5},  {7, 6},     {-113, 8},  {-68, 9},
        {11, 10},  {-17, 12},  {-52, 13},  {-24, 14},  {-18, 15},  {17, 16},   {-104, 18},
        {20, 19},  {-54, -70}, {22, 21},   {24, 23},   {-86, -97}, {-103, 25}, {-83, 26},
        {-35, 27}, {-34, -98}, {-40, 28},  {-39, -67}, {30, 29},   {-33, -51}, {-87, 31},
        {-88, 32}, {-82, 33},  {-55, -81}, {-56, -71}, {-72, 34},  {-50, -66}, {-65, 35},
        {-49, 0},  {0, 0},     {0, 0},     {0, 0},     {0, 0},     {0, 0},     {0, 0},
        {0, 0},    {0, 0},     {0, 0},     {0, 0},     {0, 0},     {0, 0},     {0, 0},
        {0, 0},    {0, 0},     {0, 0},     {0, 0},     {0, 0},     {0, 0},     {0, 0},
        {0, 0},    {0, 0},     {0, 0},     {0, 0},     {0, 0},     {0, 0},     {0, 0}}}},
     {{{{-1, 1}, {-18, 2}, {-17, 0}},
       {{-1, 1},
        {-36, 2},
        {-18, 3},
        {-35, 4},
        {-52, 5},
        {7, 6},
        {-34, 8},
        {-33, -49},
        {-20, 0},
        {0, 0},
        {0, 0},
        {0, 0},
        {0, 0},
        {0, 0},
        {0, 0}},
       {{-1, 1},    {3, 2},     {5, 4},     {-86, 6},  {-66, 7},   {9, 8},    {11, 10},
        {-18, 12},  {-51, 13},  {-37, -52}, {-69, 14}, {-38, 15},  {-53, 16}, {-35, 17},
        {-50, -70}, {-22, -49}, {-33, 18},  {-17, 19}, {-34, -65}, {-81, 20}, {-54, 0},
        {0, 0},     {0, 0},     {0, 0},     {0, 0},    {0, 0},     {0, 0},    {0, 0},
        {0, 0},     {0, 0},     {0, 0},     {0, 0},    {0, 0},     {0, 0},    {0, 0}},
       {{2, 1},    {4, 3},     {-1, 5},    {-69, 6},   {-120, 7},  {-68, 8},     {10, 9},
        {12, 11},  {14, 13},   {-52, -54}, {-18, 15},  {-70, 16},  {-67, 17},    {19, 18},
        {-17, 20}, {-113, 21}, {23, 22},   {-83, 24},  {-24, 25},  {-103, -104}, {-51, -55},
        {27, 26},  {-71, 28},  {-86, 29},  {-35, 30},  {-66, 31},  {-39, -50},   {-82, -98},
        {-72, 32}, {-56, -87}, {-34, 33},  {-33, -88}, {-40, -97}, {-65, 34},    {-49, 35},
        {-81, 0},  {0, 0},     {0, 0},     {0, 0},     {0, 0},     {0, 0},       {0, 0},
        {0, 0},    {0, 0},     {0, 0},     {0, 0},     {0, 0},     {0, 0},       {0, 0},
        {0, 0},    {0, 0},     {0, 0},     {0, 0},     {0, 0},     {0, 0},       {0, 0},
        {0, 0},    {0, 0},     {0, 0},     {0, 0},     {0, 0},     {0, 0},       {0, 0}}},
      {{{-1, 1}, {-18, 2}, {-17, 0}},
       {{-1, 1},
        {-36, 2},
        {-18, 3},
        {-35, 4},
        {-52, 5},
        {7, 6},
        {-34, 8},
        {-33, -49},
        {-20, 0},
        {0, 0},
        {0, 0},
        {0, 0},
        {0, 0},
        {0, 0},
        {0, 0}},
       {{-1, 1},    {3, 2},     {5, 4},     {-86, 6},  {-66, 7},   {9, 8},    {11, 10},
        {-18, 12},  {-51, 13},  {-37, -52}, {-69, 14}, {-38, 15},  {-53, 16}, {-35, 17},
        {-50, -70}, {-22, -49}, {-33, 18},  {-17, 19}, {-34, -65}, {-81, 20}, {-54, 0},
        {0, 0},     {0, 0},     {0, 0},     {0, 0},    {0, 0},     {0, 0},    {0, 0},
        {0, 0},     {0, 0},     {0, 0},     {0, 0},    {0, 0},     {0, 0},    {0, 0}},
       {{2, 1},    {4, 3},     {-1, 5},    {-69, 6},   {-120, 7},  {-68, 8},     {10, 9},
        {12, 11},  {14, 13},   {-52, -54}, {-18, 15},  {-70, 16},  {-67, 17},    {19, 18},
        {-17, 20}, {-113, 21}, {23, 22},   {-83, 24},  {-24, 25},  {-103, -104}, {-51, -55},
        {27, 26},  {-71, 28},  {-86, 29},  {-35, 30},  {-66, 31},  {-39, -50},   {-82, -98},
        {-72, 32}, {-56, -87}, {-34, 33},  {-33, -88}, {-40, -97}, {-65, 34},    {-49, 35},
        {-81, 0},  {0, 0},     {0, 0},     {0, 0},     {0, 0},     {0, 0},       {0, 0},
        {0, 0},    {0, 0},     {0, 0},     {0, 0},     {0, 0},     {0, 0},       {0, 0},
        {0, 0},    {0, 0},     {0, 0},     {0, 0},     {0, 0},     {0, 0},       {0, 0},
        {0, 0},    {0, 0},     {0, 0},     {0, 0},     {0, 0},     {0, 0},       {0, 0}}}}}};

const ia_huff_pt0_nodes_struct ixheaacd_huff_part0_nodes = {
    {{2, 1},    {4, 3},     {6, 5},     {8, 7},     {10, 9},    {12, 11},   {14, 13},   {-8, 15},
     {-9, 16},  {-10, 17},  {-18, 18},  {-17, -19}, {-16, 19},  {-11, -20}, {-15, -21}, {-7, 20},
     {-22, 21}, {-12, -14}, {-13, -23}, {23, 22},   {-24, -31}, {-6, 24},   {-25, -26}, {26, 25},
     {-5, -27}, {-28, 27},  {-4, 28},   {-29, 29},  {-1, -30},  {-2, -3}},
    {{2, 1}, {-5, 3}, {-4, -6}, {-3, 4}, {-2, 5}, {-1, 6}, {-7, -8}},
    {{2, 1},    {4, 3},     {6, 5},    {-15, 7},  {-14, -16}, {-13, 8},  {-12, 9},
     {-11, 10}, {-10, 11},  {-8, -9},  {-17, 12}, {14, 13},   {-7, 15},  {-18, 16},
     {-6, 17},  {-5, 18},   {-4, -19}, {-3, 19},  {-1, 20},   {-2, -20}, {22, 21},
     {-21, 23}, {-22, -26}, {-23, 24}, {-24, -25}}};

const ia_huff_pt0_nodes_struct ixheaacd_huff_pilot_nodes = {
    {{2, 1},    {4, 3},     {6, 5},     {8, 7},     {10, 9},    {12, 11},   {14, 13},   {-8, 15},
     {-9, 16},  {-10, 17},  {-18, 18},  {-17, -19}, {-16, 19},  {-11, -20}, {-15, -21}, {-7, 20},
     {-22, 21}, {-12, -14}, {-13, -23}, {23, 22},   {-24, -31}, {-6, 24},   {-25, -26}, {26, 25},
     {-5, -27}, {-28, 27},  {-4, 28},   {-29, 29},  {-1, -30},  {-2, -3}},
    {{2, 1}, {-5, 3}, {-4, -6}, {-3, 4}, {-2, 5}, {-1, 6}, {-7, -8}},
    {{2, 1},    {4, 3},     {6, 5},    {-15, 7},  {-14, -16}, {-13, 8},  {-12, 9},
     {-11, 10}, {-10, 11},  {-8, -9},  {-17, 12}, {14, 13},   {-7, 15},  {-18, 16},
     {-6, 17},  {-5, 18},   {-4, -19}, {-3, 19},  {-1, 20},   {-2, -20}, {22, 21},
     {-21, 23}, {-22, -26}, {-23, 24}, {-24, -25}}};

const ia_huff_lav_nodes_struct ixheaacd_huff_lav_idx_nodes = {{{-1, 1}, {-2, 2}, {-3, -4}}};

const ia_huff_res_nodes_struct ixheaacd_huff_reshape_nodes = {
    {{2, 1},     {4, 3},     {6, 5},    {-33, 7},  {-17, 8},  {-49, 9},  {-34, 10}, {12, 11},
     {-18, -35}, {-50, 13},  {15, 14},  {-40, 16}, {-36, 17}, {-19, 18}, {-1, -37}, {-51, 19},
     {21, 20},   {-38, -65}, {-2, -39}, {-20, 22}, {-52, 23}, {25, 24},  {-21, 26}, {-66, 27},
     {-53, 28},  {-3, 29},   {31, 30},  {-22, 32}, {-54, 33}, {-4, 34},  {-56, 35}, {-24, -67},
     {-23, -55}, {-8, -72},  {-5, 36},  {-68, 37}, {-6, 38},  {-7, -69}, {-70, -71}}};

const FLOAT32 ixheaacd_im_weight[16][8][31] = {
    {

        {0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f},
        {0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f},
        {0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f},
        {0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f},
        {0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f},
        {0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f},
        {0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f},
        {0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f}},
    {

        {-0.0000000112f, -0.0021408275f, -0.0037915856f, -0.0066939779f, -0.0117513090f,
         -0.0204205140f, -0.0282191336f, -0.0386330411f, -0.0521795079f, -0.0691007078f,
         -0.0889061838f, -0.1028472632f, -0.1162045002f, -0.1275303215f, -0.1352165043f,
         -0.1379496902f, -0.1352165043f, -0.1275303215f, -0.1162045151f, -0.1028472632f,
         -0.0889061838f, -0.0691007152f, -0.0521795042f, -0.0386330411f, -0.0282191373f,
         -0.0204205140f, -0.0117513090f, -0.0066939779f, -0.0037915856f, -0.0021408275f,
         -0.0000000112f},
        {-0.0000000112f, -0.0020066053f, -0.0035547465f, -0.0062785484f, -0.0110301562f,
         -0.0191908441f, -0.0265479907f, -0.0363945216f, -0.0492380410f, -0.0653315485f,
         -0.0842306316f, -0.0975688994f, -0.1103724390f, -0.1212451607f, -0.1286316365f,
         -0.1312596500f, -0.1286316365f, -0.1212451607f, -0.1103724539f, -0.0975688994f,
         -0.0842306316f, -0.0653315485f, -0.0492380410f, -0.0363945179f, -0.0265479945f,
         -0.0191908441f, -0.0110301562f, -0.0062785484f, -0.0035547465f, -0.0020066053f,
         -0.0000000112f},
        {-0.0000000112f, -0.0018022917f, -0.0031940117f, -0.0056451149f, -0.0099285468f,
         -0.0173068047f, -0.0239810087f, -0.0329449996f, -0.0446879528f, -0.0594761744f,
         -0.0769355893f, -0.0893112868f, -0.1012277678f, -0.1113727987f, -0.1182772070f,
         -0.1207359731f, -0.1182772145f, -0.1113727987f, -0.1012277678f, -0.0893112868f,
         -0.0769355893f, -0.0594761670f, -0.0446879528f, -0.0329449996f, -0.0239810087f,
         -0.0173068047f, -0.0099285468f, -0.0056451149f, -0.0031940117f, -0.0018022917f,
         -0.0000000112f},
        {-0.0000000075f, -0.0012891144f, -0.0022867322f, -0.0040483177f, -0.0071406178f,
         -0.0125075802f, -0.0174052790f, -0.0240450911f, -0.0328458101f, -0.0440842398f,
         -0.0575582460f, -0.0672323778f, -0.0766361356f, -0.0847055018f, -0.0902284831f,
         -0.0922011584f, -0.0902284905f, -0.0847054794f, -0.0766361505f, -0.0672323853f,
         -0.0575582460f, -0.0440842435f, -0.0328458101f, -0.0240450911f, -0.0174052827f,
         -0.0125075765f, -0.0071406178f, -0.0040483177f, -0.0022867322f, -0.0012891144f,
         -0.0000000075f},
        {-0.0000000037f, -0.0007896237f, -0.0014020018f, -0.0024860986f, -0.0043976195f,
         -0.0077406205f, -0.0108190365f, -0.0150338411f, -0.0206919834f, -0.0280320831f,
         -0.0369941890f, -0.0435322672f, -0.0499662980f, -0.0555463918f, -0.0593958311f,
         -0.0607765391f, -0.0593958348f, -0.0555463918f, -0.0499663055f, -0.0435322709f,
         -0.0369941890f, -0.0280320831f, -0.0206919834f, -0.0150338374f, -0.0108190365f,
         -0.0077406205f, -0.0043976195f, -0.0024860986f, -0.0014020018f, -0.0007896237f,
         -0.0000000037f},
        {0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f},
        {0.0000000075f, 0.0012713782f, 0.0022661425f, 0.0040463172f, 0.0072463304f, 0.0130392574f,
         0.0186092220f, 0.0266334303f, 0.0382109210f, 0.0548328981f, 0.0785857737f, 0.1031111330f,
         0.1333933324f, 0.1665901542f, 0.1946617961f, 0.2060326636f, 0.1946618259f, 0.1665901244f,
         0.1333933473f, 0.1031111330f, 0.0785857737f, 0.0548328906f, 0.0382109210f, 0.0266334265f,
         0.0186092220f, 0.0130392574f, 0.0072463304f, 0.0040463172f, 0.0022661425f, 0.0012713782f,
         0.0000000075f},
        {0.0000000112f, 0.0021414421f, 0.0038233139f, 0.0068472549f, 0.0123301037f, 0.0224180110f,
         0.0323300436f, 0.0470142886f, 0.0691649169f, 0.1103344262f, 0.1914317459f, 0.2921350002f,
         0.4732147753f, 0.8167075515f, 1.4096112251f, 1.8493235111f, 1.4096120596f, 0.8167073727f,
         0.4732148349f, 0.2921350002f, 0.1914317757f, 0.1103344262f, 0.0691649169f, 0.0470142849f,
         0.0323300473f, 0.0224180073f, 0.0123301037f, 0.0068472549f, 0.0038233139f, 0.0021414421f,
         0.0000000112f}},
    {

        {-0.0000000224f, -0.0039605126f, -0.0070208944f, -0.0124152638f, -0.0218554586f,
         -0.0381546505f, -0.0529386774f, -0.0728518367f, -0.0990312099f, -0.1321374029f,
         -0.1714010537f, -0.1993359923f, -0.2263071835f, -0.2493202984f, -0.2650071084f,
         -0.2705980539f, -0.2650071084f, -0.2493202686f, -0.2263071984f, -0.1993360072f,
         -0.1714010835f, -0.1321374029f, -0.0990312099f, -0.0728518218f, -0.0529386811f,
         -0.0381546505f, -0.0218554623f, -0.0124152638f, -0.0070208944f, -0.0039605126f,
         -0.0000000224f},
        {-0.0000000224f, -0.0037119202f, -0.0065814704f, -0.0116420984f, -0.0205062106f,
         -0.0358339138f, -0.0497612022f, -0.0685553476f, -0.0933211446f, -0.1247262210f,
         -0.1620853394f, -0.1887322366f, -0.2145074457f, -0.2365338504f, -0.2515646219f,
         -0.2569248080f, -0.2515646219f, -0.2365338504f, -0.2145074606f, -0.1887322664f,
         -0.1620853394f, -0.1247262210f, -0.0933211446f, -0.0685553402f, -0.0497612059f,
         -0.0358339138f, -0.0205062106f, -0.0116420984f, -0.0065814704f, -0.0037119202f,
         -0.0000000224f},
        {-0.0000000186f, -0.0033335909f, -0.0059123859f, -0.0104638673f, -0.0184471272f,
         -0.0322837904f, -0.0448903739f, -0.0619516075f, -0.0845159143f, -0.1132542193f,
         -0.1476069838f, -0.1722094864f, -0.1960791647f, -0.2165289074f, -0.2305092514f,
         -0.2354996800f, -0.2305092812f, -0.2165289074f, -0.1960791945f, -0.1722095013f,
         -0.1476069987f, -0.1132542193f, -0.0845159143f, -0.0619516037f, -0.0448903739f,
         -0.0322837941f, -0.0184471309f, -0.0104638673f, -0.0059123859f, -0.0033335909f,
         -0.0000000186f},
        {-0.0000000149f, -0.0023837052f, -0.0042307824f, -0.0074973591f, -0.0132469125f,
         -0.0232715160f, -0.0324691795f, -0.0450118184f, -0.0617620312f, -0.0833501816f,
         -0.1095077544f, -0.1284611970f, -0.1470141709f, -0.1630301923f, -0.1740406305f,
         -0.1779824793f, -0.1740406305f, -0.1630301923f, -0.1470141858f, -0.1284611970f,
         -0.1095077544f, -0.0833501816f, -0.0617620312f, -0.0450118184f, -0.0324691832f,
         -0.0232715160f, -0.0132469125f, -0.0074973591f, -0.0042307824f, -0.0023837052f,
         -0.0000000149f},
        {-0.0000000075f, -0.0014596879f, -0.0025926158f, -0.0046001561f, -0.0081458427f,
         -0.0143647529f, -0.0201114044f, -0.0280098952f, -0.0386673734f, -0.0525827743f,
         -0.0697054639f, -0.0822848827f, -0.0947335809f, -0.1055838689f, -0.1130971760f,
         -0.1157975048f, -0.1130971834f, -0.1055838689f, -0.0947335884f, -0.0822848827f,
         -0.0697054639f, -0.0525827669f, -0.0386673696f, -0.0280098915f, -0.0201114081f,
         -0.0143647529f, -0.0081458427f, -0.0046001561f, -0.0025926158f, -0.0014596879f,
         -0.0000000075f},
        {0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f},
        {0.0000000149f, 0.0023475029f, 0.0041818954f, 0.0074593760f, 0.0133338906f, 0.0239118338f,
         0.0340123922f, 0.0484390482f, 0.0689862818f, 0.0979072377f, 0.1372926533f, 0.1694079041f,
         0.2086421102f, 0.2509776056f, 0.2844191492f, 0.2973977327f, 0.2844191492f, 0.2509775758f,
         0.2086421251f, 0.1694079340f, 0.1372926682f, 0.0979072377f, 0.0689862818f, 0.0484390408f,
         0.0340123959f, 0.0239118338f, 0.0133338906f, 0.0074593760f, 0.0041818954f, 0.0023475029f,
         0.0000000149f},
        {0.0000000224f, 0.0039520524f, 0.0070491731f, 0.0126024745f, 0.0226208717f, 0.0408787355f,
         0.0585894026f, 0.0843905658f, 0.1222686619f, 0.1781808585f, 0.2806743085f, 0.3863530755f,
         0.5320819616f, 0.7150993347f, 0.8931091428f, 0.9723875523f, 0.8931093216f, 0.7150993347f,
         0.5320819616f, 0.3863530755f, 0.2806743681f, 0.1781808585f, 0.1222686619f, 0.0843905583f,
         0.0585894100f, 0.0408787355f, 0.0226208754f, 0.0126024783f, 0.0070491731f, 0.0039520524f,
         0.0000000224f}},
    {

        {-0.0000000298f, -0.0051840469f, -0.0092027225f, -0.0163133591f, -0.0288398713f,
         -0.0507133082f, -0.0708183646f, -0.0982891619f, -0.1350691319f, -0.1826232225f,
         -0.2404572219f, -0.2825006247f, -0.3237607479f, -0.3594581187f, -0.3840393722f,
         -0.3928474486f, -0.3840393722f, -0.3594581187f, -0.3237607479f, -0.2825005651f,
         -0.2404572070f, -0.1826232225f, -0.1350691319f, -0.0982891619f, -0.0708183795f,
         -0.0507133119f, -0.0288398750f, -0.0163133591f, -0.0092027225f, -0.0051840469f,
         -0.0000000298f},
        {-0.0000000261f, -0.0048581101f, -0.0086250156f, -0.0152920857f, -0.0270430781f,
         -0.0475800671f, -0.0664762110f, -0.0923245847f, -0.1269837022f, -0.1718791127f,
         -0.2265993804f, -0.2664566636f, -0.3056311905f, -0.3395695388f, -0.3629629016f,
         -0.3713498116f, -0.3629629016f, -0.3395695090f, -0.3056312203f, -0.2664566636f,
         -0.2265993953f, -0.1718791127f, -0.1269837171f, -0.0923245698f, -0.0664762333f,
         -0.0475800708f, -0.0270430781f, -0.0152920857f, -0.0086250156f, -0.0048581101f,
         -0.0000000261f},
        {-0.0000000261f, -0.0043622032f, -0.0077458210f, -0.0137371235f, -0.0243051313f,
         -0.0427990705f, -0.0598423555f, -0.0831969902f, -0.1145843118f, -0.1553593576f,
         -0.2052282989f, -0.2416637540f, -0.2775619924f, -0.3087284863f, -0.3302457929f,
         -0.3379668295f, -0.3302457929f, -0.3087284863f, -0.2775620222f, -0.2416637540f,
         -0.2052282989f, -0.1553593576f, -0.1145842969f, -0.0831969753f, -0.0598423593f,
         -0.0427990742f, -0.0243051313f, -0.0137371235f, -0.0077458210f, -0.0043622032f,
         -0.0000000261f},
        {-0.0000000186f, -0.0031178668f, -0.0055385008f, -0.0098293871f, -0.0174126737f,
         -0.0307279304f, -0.0430483781f, -0.0600074269f, -0.0829356760f, -0.1129490435f,
         -0.1499940902f, -0.1772867739f, -0.2043576390f, -0.2280011624f, -0.2443988174f,
         -0.2502972782f, -0.2443988174f, -0.2280011177f, -0.2043576539f, -0.1772867888f,
         -0.1499940902f, -0.1129490361f, -0.0829356685f, -0.0600074232f, -0.0430483781f,
         -0.0307279266f, -0.0174126774f, -0.0098293871f, -0.0055385008f, -0.0031178668f,
         -0.0000000186f},
        {-0.0000000112f, -0.0019084513f, -0.0033914447f, -0.0060230605f, -0.0106827281f,
         -0.0188915879f, -0.0265177265f, -0.0370627642f, -0.0514063872f, -0.0703314394f,
         -0.0939192176f, -0.1114559472f, -0.1289804578f, -0.1443904936f, -0.1551341563f,
         -0.1590099633f, -0.1551341563f, -0.1443904787f, -0.1289804578f, -0.1114559621f,
         -0.0939192176f, -0.0703314394f, -0.0514063835f, -0.0370627567f, -0.0265177302f,
         -0.0188915879f, -0.0106827319f, -0.0060230605f, -0.0033914447f, -0.0019084513f,
         -0.0000000112f},
        {0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f},
        {0.0000000186f, 0.0030638538f, 0.0054534115f, 0.0097127110f, 0.0173145495f, 0.0308970734f,
         0.0437387861f, 0.0618620813f, 0.0872256160f, 0.1220206320f, 0.1676785648f, 0.2034175098f,
         0.2407984287f, 0.2751578987f, 0.2999968529f, 0.3091448545f, 0.2999968529f, 0.2751578689f,
         0.2407984734f, 0.2034175098f, 0.1676785648f, 0.1220206320f, 0.0872256160f, 0.0618620738f,
         0.0437387899f, 0.0308970734f, 0.0173145495f, 0.0097127147f, 0.0054534115f, 0.0030638538f,
         0.0000000186f},
        {0.0000000298f, 0.0051542334f, 0.0091803372f, 0.0163703524f, 0.0292467400f, 0.0523967445f,
         0.0744579434f, 0.1058912277f, 0.1504984796f, 0.2129460871f, 0.2973079085f, 0.3654728234f,
         0.4390078187f, 0.5227220654f, 0.5883262753f, 0.6135464311f, 0.5883263350f, 0.5227220654f,
         0.4390078485f, 0.3654727936f, 0.2973079383f, 0.2129460573f, 0.1504984647f, 0.1058912203f,
         0.0744579583f, 0.0523967408f, 0.0292467475f, 0.0163703524f, 0.0091803372f, 0.0051542334f,
         0.0000000298f}},
    {

        {-0.0000000298f, -0.0056232363f, -0.0099989995f, -0.0177771710f, -0.0315911807f,
         -0.0560568646f, -0.0789347738f, -0.1108068749f, -0.1546058059f, -0.2131874412f,
         -0.2874797881f, -0.3436433673f, -0.4005688727f, -0.4512940049f, -0.4870319068f,
         -0.5000000596f, -0.4870318770f, -0.4512940049f, -0.4005689025f, -0.3436433673f,
         -0.2874797881f, -0.2131874263f, -0.1546057910f, -0.1108068675f, -0.0789347813f,
         -0.0560568646f, -0.0315911844f, -0.0177771710f, -0.0099989995f, -0.0056232363f,
         -0.0000000298f},
        {-0.0000000298f, -0.0052689724f, -0.0093690604f, -0.0166572109f, -0.0296009369f,
         -0.0525252819f, -0.0739618763f, -0.1038260460f, -0.1448656321f, -0.1997566223f,
         -0.2693685591f, -0.3219937980f, -0.3753330112f, -0.4228624403f, -0.4563488960f,
         -0.4685000181f, -0.4563488662f, -0.4228624701f, -0.3753330410f, -0.3219938278f,
         -0.2693685591f, -0.1997566223f, -0.1448656321f, -0.1038260311f, -0.0739618912f,
         -0.0525252856f, -0.0296009406f, -0.0166572109f, -0.0093690641f, -0.0052689724f,
         -0.0000000298f},
        {-0.0000000261f, -0.0047301538f, -0.0084109604f, -0.0149538033f, -0.0265738703f,
         -0.0471539162f, -0.0663983598f, -0.0932085291f, -0.1300513148f, -0.1793290079f,
         -0.2418222427f, -0.2890659571f, -0.3369505107f, -0.3796194792f, -0.4096814692f,
         -0.4205900431f, -0.4096814990f, -0.3796194792f, -0.3369505405f, -0.2890659273f,
         -0.2418222576f, -0.1793290079f, -0.1300513148f, -0.0932085216f, -0.0663983598f,
         -0.0471539162f, -0.0265738703f, -0.0149538033f, -0.0084109604f, -0.0047301538f,
         -0.0000000261f},
        {-0.0000000186f, -0.0033791140f, -0.0060085990f, -0.0106826574f, -0.0189837739f,
         -0.0336856917f, -0.0474334881f, -0.0665860698f, -0.0929057151f, -0.1281086057f,
         -0.1727523506f, -0.2065021843f, -0.2407098413f, -0.2711915970f, -0.2926672101f,
         -0.3004600108f, -0.2926672101f, -0.2711915672f, -0.2407098711f, -0.2065021843f,
         -0.1727523655f, -0.1281086057f, -0.0929057226f, -0.0665860623f, -0.0474334918f,
         -0.0336856917f, -0.0189837739f, -0.0106826574f, -0.0060085990f, -0.0033791140f,
         -0.0000000186f},
        {-0.0000000112f, -0.0020673275f, -0.0036760308f, -0.0065355971f, -0.0116141811f,
         -0.0206087455f, -0.0290195793f, -0.0407370403f, -0.0568392761f, -0.0783762336f,
         -0.1056890637f, -0.1263370365f, -0.1472651362f, -0.1659137160f, -0.1790523976f,
         -0.1838199943f, -0.1790523976f, -0.1659137160f, -0.1472651511f, -0.1263370514f,
         -0.1056890711f, -0.0783762261f, -0.0568392724f, -0.0407370329f, -0.0290195830f,
         -0.0206087418f, -0.0116141811f, -0.0065356009f, -0.0036760308f, -0.0020673275f,
         -0.0000000112f},
        {0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f},
        {0.0000000186f, 0.0033120848f, 0.0058894120f, 0.0104707554f, 0.0186072066f, 0.0330174938f,
         0.0464925803f, 0.0652652532f, 0.0910628140f, 0.1255674064f, 0.1693255901f, 0.2024059296f,
         0.2359350473f, 0.2658121586f, 0.2868617475f, 0.2944999933f, 0.2868617773f, 0.2658121288f,
         0.2359350622f, 0.2024059445f, 0.1693255901f, 0.1255674064f, 0.0910628140f, 0.0652652457f,
         0.0464925840f, 0.0330174938f, 0.0186072066f, 0.0104707554f, 0.0058894120f, 0.0033120848f,
         0.0000000186f},
        {0.0000000298f, 0.0055670030f, 0.0098990090f, 0.0175994001f, 0.0312752686f, 0.0554962978f,
         0.0781454220f, 0.1096988022f, 0.1530597508f, 0.2110555619f, 0.2846049964f, 0.3402069509f,
         0.3965631723f, 0.4467810690f, 0.4821615815f, 0.4950000048f, 0.4821615815f, 0.4467810690f,
         0.3965632021f, 0.3402069509f, 0.2846049964f, 0.2110555619f, 0.1530597359f, 0.1096988022f,
         0.0781454295f, 0.0554962978f, 0.0312752724f, 0.0175994039f, 0.0098990090f, 0.0055670030f,
         0.0000000298f}},
    {

        {-0.0000000298f, -0.0052064098f, -0.0092734247f, -0.0165368542f, -0.0295458250f,
         -0.0529378690f, -0.0752342194f, -0.1070103794f, -0.1521206498f, -0.2153066695f,
         -0.3007343411f, -0.3698226213f, -0.4447503388f, -0.5307881832f, -0.5978006721f,
         -0.6235857010f, -0.5978006721f, -0.5307881236f, -0.4447503388f, -0.3698226511f,
         -0.3007343411f, -0.2153066695f, -0.1521206498f, -0.1070103645f, -0.0752342343f,
         -0.0529378653f, -0.0295458287f, -0.0165368542f, -0.0092734247f, -0.0052064098f,
         -0.0000000298f},
        {-0.0000000261f, -0.0048777387f, -0.0086870864f, -0.0154883042f, -0.0276628584f,
         -0.0495328866f, -0.0703521222f, -0.0999773294f, -0.1419382244f, -0.2005145401f,
         -0.2793169618f, -0.3426927924f, -0.4107417464f, -0.4813471735f, -0.5399245620f,
         -0.5623379350f, -0.5399245620f, -0.4813471735f, -0.4107417464f, -0.3426928222f,
         -0.2793169916f, -0.2005145550f, -0.1419382244f, -0.0999773145f, -0.0703521222f,
         -0.0495328903f, -0.0276628584f, -0.0154883042f, -0.0086870864f, -0.0048777387f,
         -0.0000000261f},
        {-0.0000000261f, -0.0043780245f, -0.0077958480f, -0.0138952583f, -0.0248045996f,
         -0.0443725996f, -0.0629648566f, -0.0893598348f, -0.1266185045f, -0.1783709079f,
         -0.2474884093f, -0.3026292324f, -0.3613662124f, -0.4163920283f, -0.4594896138f,
         -0.4775324762f, -0.4594896734f, -0.4163920283f, -0.3613662422f, -0.3026292324f,
         -0.2474884093f, -0.1783709079f, -0.1266184896f, -0.0893598348f, -0.0629648566f,
         -0.0443725996f, -0.0248045996f, -0.0138952583f, -0.0077958442f, -0.0043780245f,
         -0.0000000261f},
        {-0.0000000186f, -0.0031259395f, -0.0055640303f, -0.0099100843f, -0.0176675394f,
         -0.0315306410f, -0.0446406342f, -0.0631476343f, -0.0890584141f, -0.1246242076f,
         -0.1713303179f, -0.2079202831f, -0.2462213635f, -0.2814548314f, -0.3069431484f,
         -0.3163340688f, -0.3069431186f, -0.2814547718f, -0.2462213486f, -0.2079202682f,
         -0.1713303477f, -0.1246242002f, -0.0890584067f, -0.0631476343f, -0.0446406379f,
         -0.0315306373f, -0.0176675431f, -0.0099100843f, -0.0055640303f, -0.0031259395f,
         -0.0000000186f},
        {-0.0000000112f, -0.0019114725f, -0.0034010001f, -0.0060532652f, -0.0107781142f,
         -0.0191919580f, -0.0271133929f, -0.0382369235f, -0.0536935478f, -0.0746848807f,
         -0.1018501967f, -0.1228085682f, -0.1444384754f, -0.1640539616f, -0.1780739129f,
         -0.1832032204f, -0.1780739427f, -0.1640539765f, -0.1444384903f, -0.1228085831f,
         -0.1018502116f, -0.0746848732f, -0.0536935404f, -0.0382369198f, -0.0271133929f,
         -0.0191919580f, -0.0107781179f, -0.0060532652f, -0.0034010001f, -0.0019114725f,
         -0.0000000112f},
        {0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f},
        {0.0000000186f, 0.0030560978f, 0.0054288842f, 0.0096351840f, 0.0170697011f, 0.0301259123f,
         0.0422091261f, 0.0588454232f, 0.0813441202f, 0.1108067334f, 0.1471893340f, 0.1740057766f,
         0.2006137222f, 0.2238604128f, 0.2399868369f, 0.2457885146f, 0.2399868369f, 0.2238603979f,
         0.2006137520f, 0.1740057617f, 0.1471893340f, 0.1108067334f, 0.0813441128f, 0.0588454120f,
         0.0422091298f, 0.0301259123f, 0.0170697011f, 0.0096351840f, 0.0054288842f, 0.0030560978f,
         0.0000000186f},
        {0.0000000298f, 0.0051323175f, 0.0091110431f, 0.0161513090f, 0.0285548456f, 0.0502165109f,
         0.0701301694f, 0.0973443240f, 0.1337892562f, 0.1809239388f, 0.2382676303f, 0.2799672484f,
         0.3208998740f, 0.3563212454f, 0.3807162344f, 0.3894583583f, 0.3807162642f, 0.3563212454f,
         0.3208998740f, 0.2799672484f, 0.2382676452f, 0.1809239388f, 0.1337892562f, 0.0973443240f,
         0.0701301768f, 0.0502165109f, 0.0285548493f, 0.0161513127f, 0.0091110431f, 0.0051323175f,
         0.0000000298f}},
    {

        {-0.0000000224f, -0.0039921328f, -0.0071208887f, -0.0127314143f, -0.0228547081f,
         -0.0413094275f, -0.0592183881f, -0.0853221565f, -0.1236763671f, -0.1803686619f,
         -0.2854516804f, -0.3939453363f, -0.5444797277f, -0.7350655198f, -0.9220947623f,
         -1.0059221983f, -0.9220948815f, -0.7350654006f, -0.5444797873f, -0.3939453661f,
         -0.2854517102f, -0.1803686619f, -0.1236763671f, -0.0853221565f, -0.0592183881f,
         -0.0413094275f, -0.0228547081f, -0.0127314143f, -0.0071208887f, -0.0039921328f,
         -0.0000000224f},
        {-0.0000000224f, -0.0037396848f, -0.0066692568f, -0.0119196586f, -0.0213833861f,
         -0.0386023782f, -0.0552692898f, -0.0794829726f, -0.1148765832f, -0.1667534262f,
         -0.2564018369f, -0.3483759165f, -0.4713715911f, -0.6198635101f, -0.7582825422f,
         -0.8181172013f, -0.7582825422f, -0.6198634505f, -0.4713717401f, -0.3483759463f,
         -0.2564018667f, -0.1667534411f, -0.1148765981f, -0.0794829652f, -0.0552692972f,
         -0.0386023745f, -0.0213833861f, -0.0119196586f, -0.0066692568f, -0.0037396848f,
         -0.0000000224f},
        {-0.0000000186f, -0.0033559687f, -0.0059831366f, -0.0106875487f, -0.0191539265f,
         -0.0345134847f, -0.0493235812f, -0.0707350969f, -0.1017966494f, -0.1467751563f,
         -0.2165540755f, -0.2881157100f, -0.3792885542f, -0.4829951525f, -0.5739276409f,
         -0.6116424799f, -0.5739278197f, -0.4829950929f, -0.3792886436f, -0.2881157100f,
         -0.2165541053f, -0.1467751563f, -0.1017966419f, -0.0707350895f, -0.0493235812f,
         -0.0345134847f, -0.0191539265f, -0.0106875487f, -0.0059831366f, -0.0033559650f,
         -0.0000000186f},
        {-0.0000000149f, -0.0023951232f, -0.0042668879f, -0.0076114945f, -0.0136074573f,
         -0.0244078562f, -0.0347254649f, -0.0494702719f, -0.0704879165f, -0.1001076326f,
         -0.1405195594f, -0.1735420525f, -0.2150437981f, -0.2592166960f, -0.2942399085f,
         -0.3078633845f, -0.2942398787f, -0.2592166662f, -0.2150438130f, -0.1735420525f,
         -0.1405195594f, -0.1001076251f, -0.0704879165f, -0.0494702719f, -0.0347254686f,
         -0.0244078562f, -0.0136074610f, -0.0076114945f, -0.0042668879f, -0.0023951232f,
         -0.0000000149f},
        {-0.0000000075f, -0.0014639609f, -0.0026061311f, -0.0046428740f, -0.0082807541f,
         -0.0147897042f, -0.0209544301f, -0.0296728536f, -0.0419111885f, -0.0587732308f,
         -0.0810343996f, -0.0985725969f, -0.1170293614f, -0.1341015100f, -0.1465103477f,
         -0.1510950923f, -0.1465103626f, -0.1341015100f, -0.1170293689f, -0.0985725969f,
         -0.0810344145f, -0.0587732270f, -0.0419111885f, -0.0296728499f, -0.0209544301f,
         -0.0147897005f, -0.0082807541f, -0.0046428740f, -0.0026061311f, -0.0014639609f,
         -0.0000000075f},
        {0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f},
        {0.0000000149f, 0.0023365319f, 0.0041472092f, 0.0073497258f, 0.0129875094f, 0.0228201896f,
         0.0318449698f, 0.0441566631f, 0.0606067479f, 0.0818213895f, 0.1075451672f, 0.1261962205f,
         0.1444622874f, 0.1602374464f, 0.1710857302f, 0.1749702245f, 0.1710857451f, 0.1602374315f,
         0.1444623023f, 0.1261962354f, 0.1075451672f, 0.0818213820f, 0.0606067516f, 0.0441566594f,
         0.0318449736f, 0.0228201896f, 0.0129875094f, 0.0073497258f, 0.0041472055f, 0.0023365319f,
         0.0000000149f},
        {0.0000000224f, 0.0039210618f, 0.0069511682f, 0.0122926161f, 0.0216415301f, 0.0377869830f,
         0.0524356216f, 0.0721722171f, 0.0981289670f, 0.1309677958f, 0.1699328423f, 0.1976661384f,
         0.2244503647f, 0.2473092973f, 0.2628936768f, 0.2684486508f, 0.2628937066f, 0.2473092973f,
         0.2244503349f, 0.1976661384f, 0.1699328423f, 0.1309678108f, 0.0981289595f, 0.0721722171f,
         0.0524356328f, 0.0377869830f, 0.0216415338f, 0.0122926198f, 0.0069511719f, 0.0039210618f,
         0.0000000224f}},
    {

        {-0.0000000112f, -0.0021631867f, -0.0038622990f, -0.0069175921f, -0.0124585107f,
         -0.0226575360f, -0.0326844864f, -0.0475502796f, -0.0700031072f, -0.1121732816f,
         -0.1955563724f, -0.3002188802f, -0.4916101098f, -0.8663685918f, -1.5518788099f,
         -2.0947244167f, -1.5518796444f, -0.8663682938f, -0.4916102588f, -0.3002189398f,
         -0.1955564171f, -0.1121732742f, -0.0700031072f, -0.0475502722f, -0.0326844901f,
         -0.0226575360f, -0.0124585107f, -0.0069175921f, -0.0038622990f, -0.0021631867f,
         -0.0000000112f},
        {-0.0000000112f, -0.0020262375f, -0.0036168285f, -0.0064748600f, -0.0116508976f,
         -0.0211532563f, -0.0304619446f, -0.0441976115f, -0.0647818893f, -0.1009719074f,
         -0.1710277349f, -0.2535219491f, -0.3905530870f, -0.6167426109f, -0.9282656312f,
         -1.1122730970f, -0.9282659292f, -0.6167425513f, -0.3905532360f, -0.2535219789f,
         -0.1710277349f, -0.1009719074f, -0.0647818893f, -0.0441976078f, -0.0304619484f,
         -0.0211532563f, -0.0116508938f, -0.0064748600f, -0.0036168285f, -0.0020262338f,
         -0.0000000112f},
        {-0.0000000112f, -0.0018181130f, -0.0032440424f, -0.0058033094f, -0.0104286373f,
         -0.0188865587f, -0.0271281414f, -0.0392048433f, -0.0570997782f, -0.0855292380f,
         -0.1394104958f, -0.1978724152f, -0.2847256064f, -0.4054927230f, -0.5376322865f,
         -0.6018701792f, -0.5376325250f, -0.4054926634f, -0.2847256958f, -0.1978724003f,
         -0.1394105256f, -0.0855292305f, -0.0570997708f, -0.0392048396f, -0.0271281451f,
         -0.0188865587f, -0.0104286410f, -0.0058033094f, -0.0032440424f, -0.0018181130f,
         -0.0000000112f},
        {-0.0000000075f, -0.0012971871f, -0.0023122653f, -0.0041290335f, -0.0073956437f,
         -0.0133119002f, -0.0190039128f, -0.0272102170f, -0.0390642770f, -0.0561143979f,
         -0.0809218660f, -0.1064853594f, -0.1382554770f, -0.1733478010f, -0.2032405138f,
         -0.2154063880f, -0.2032405138f, -0.1733477712f, -0.1382555068f, -0.1064853594f,
         -0.0809218735f, -0.0561144017f, -0.0390642807f, -0.0272102132f, -0.0190039128f,
         -0.0133119002f, -0.0073956437f, -0.0041290298f, -0.0023122653f, -0.0012971871f,
         -0.0000000075f},
        {-0.0000000037f, -0.0007926486f, -0.0014115572f, -0.0025163069f, -0.0044930279f,
         -0.0080412179f, -0.0114155896f, -0.0162114650f, -0.0229923278f, -0.0324336179f,
         -0.0450868085f, -0.0552201346f, -0.0660551935f, -0.0763022304f, -0.0853320658f,
         -0.0887728930f, -0.0853320807f, -0.0763022304f, -0.0660551935f, -0.0552201308f,
         -0.0450868122f, -0.0324336141f, -0.0229923241f, -0.0162114613f, -0.0114155896f,
         -0.0080412179f, -0.0044930279f, -0.0025163069f, -0.0014115609f, -0.0007926486f,
         -0.0000000037f},
        {0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f},
        {0.0000000075f, 0.0012636185f, 0.0022416152f, 0.0039687753f, 0.0070013292f, 0.0122666061f,
         0.0170736760f, 0.0235937759f, 0.0322411545f, 0.0432920381f, 0.0565523952f, 0.0660799965f,
         0.0753463656f, 0.0833015144f, 0.0887481645f, 0.0906939134f, 0.0887481719f, 0.0833015069f,
         0.0753463805f, 0.0660799891f, 0.0565523952f, 0.0432920381f, 0.0322411582f, 0.0235937759f,
         0.0170736797f, 0.0122666061f, 0.0070013292f, 0.0039687753f, 0.0022416152f, 0.0012636185f,
         0.0000000075f},
        {0.0000000112f, 0.0021195263f, 0.0037540123f, 0.0066280924f, 0.0116370060f, 0.0202258043f,
         0.0279547423f, 0.0382792614f, 0.0517152064f, 0.0685065836f, 0.0881702006f, 0.1020170972f,
         0.1152879074f, 0.1265430748f, 0.1341825128f, 0.1368993223f, 0.1341825277f, 0.1265430599f,
         0.1152879149f, 0.1020170972f, 0.0881702006f, 0.0685065836f, 0.0517152064f, 0.0382792577f,
         0.0279547460f, 0.0202258043f, 0.0116370060f, 0.0066280924f, 0.0037540123f, 0.0021195263f,
         0.0000000112f}},
    {

        {0.0000000000f,  0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000037f,
         0.0000000037f,  0.0000000075f, 0.0000000112f, 0.0000000149f, 0.0000000261f,
         0.0000000484f,  0.0000000782f, 0.0000001453f, 0.0000003390f, 0.0000013672f,
         -3.2000000477f, 0.0000013672f, 0.0000003390f, 0.0000001453f, 0.0000000782f,
         0.0000000484f,  0.0000000261f, 0.0000000149f, 0.0000000112f, 0.0000000075f,
         0.0000000037f,  0.0000000037f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f},
        {0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000037f, 0.0000000037f,
         0.0000000075f, 0.0000000112f, 0.0000000149f, 0.0000000261f, 0.0000000410f, 0.0000000671f,
         0.0000001080f, 0.0000002012f, 0.0000003800f, 0.0000005402f, 0.0000003800f, 0.0000002012f,
         0.0000001080f, 0.0000000671f, 0.0000000410f, 0.0000000261f, 0.0000000149f, 0.0000000112f,
         0.0000000075f, 0.0000000037f, 0.0000000037f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f},
        {0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000037f, 0.0000000037f,
         0.0000000075f, 0.0000000075f, 0.0000000149f, 0.0000000186f, 0.0000000335f, 0.0000000484f,
         0.0000000745f, 0.0000001155f, 0.0000001639f, 0.0000001937f, 0.0000001639f, 0.0000001155f,
         0.0000000745f, 0.0000000484f, 0.0000000335f, 0.0000000186f, 0.0000000149f, 0.0000000075f,
         0.0000000075f, 0.0000000037f, 0.0000000037f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f},
        {0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000037f,
         0.0000000037f, 0.0000000075f, 0.0000000075f, 0.0000000112f, 0.0000000186f, 0.0000000261f,
         0.0000000335f, 0.0000000447f, 0.0000000522f, 0.0000000559f, 0.0000000522f, 0.0000000447f,
         0.0000000335f, 0.0000000261f, 0.0000000186f, 0.0000000112f, 0.0000000075f, 0.0000000075f,
         0.0000000037f, 0.0000000037f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f},
        {0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000037f, 0.0000000037f, 0.0000000037f, 0.0000000075f, 0.0000000112f, 0.0000000112f,
         0.0000000149f, 0.0000000186f, 0.0000000186f, 0.0000000224f, 0.0000000186f, 0.0000000186f,
         0.0000000149f, 0.0000000112f, 0.0000000112f, 0.0000000075f, 0.0000000037f, 0.0000000037f,
         0.0000000037f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f},
        {0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f},
        {0.0000000000f,  0.0000000000f,  0.0000000000f,  0.0000000000f,  0.0000000000f,
         -0.0000000037f, -0.0000000037f, -0.0000000037f, -0.0000000075f, -0.0000000112f,
         -0.0000000112f, -0.0000000149f, -0.0000000186f, -0.0000000186f, -0.0000000186f,
         -0.0000000186f, -0.0000000186f, -0.0000000186f, -0.0000000186f, -0.0000000149f,
         -0.0000000112f, -0.0000000112f, -0.0000000075f, -0.0000000037f, -0.0000000037f,
         -0.0000000037f, 0.0000000000f,  0.0000000000f,  0.0000000000f,  0.0000000000f,
         0.0000000000f},
        {0.0000000000f,  0.0000000000f,  0.0000000000f,  0.0000000000f,  -0.0000000037f,
         -0.0000000037f, -0.0000000075f, -0.0000000075f, -0.0000000112f, -0.0000000149f,
         -0.0000000186f, -0.0000000224f, -0.0000000261f, -0.0000000298f, -0.0000000298f,
         -0.0000000298f, -0.0000000298f, -0.0000000298f, -0.0000000261f, -0.0000000224f,
         -0.0000000186f, -0.0000000149f, -0.0000000112f, -0.0000000075f, -0.0000000075f,
         -0.0000000037f, -0.0000000037f, 0.0000000000f,  0.0000000000f,  0.0000000000f,
         0.0000000000f}},
    {

        {0.0000000112f, 0.0021631867f, 0.0038622953f, 0.0069175921f, 0.0124585070f, 0.0226575322f,
         0.0326844826f, 0.0475502722f, 0.0700030923f, 0.1121732593f, 0.1955563575f, 0.3002188206f,
         0.4916100204f, 0.8663684726f, 1.5518785715f, 2.0947239399f, 1.5518792868f, 0.8663681746f,
         0.4916101992f, 0.3002188802f, 0.1955563724f, 0.1121732593f, 0.0700030923f, 0.0475502647f,
         0.0326844826f, 0.0226575322f, 0.0124585107f, 0.0069175921f, 0.0038622990f, 0.0021631867f,
         0.0000000112f},
        {0.0000000112f, 0.0020262338f, 0.0036168285f, 0.0064748600f, 0.0116508938f, 0.0211532526f,
         0.0304619409f, 0.0441976078f, 0.0647818819f, 0.1009718925f, 0.1710277200f, 0.2535218894f,
         0.3905530572f, 0.6167424917f, 0.9282655120f, 1.1122729778f, 0.9282657504f, 0.6167424321f,
         0.3905531764f, 0.2535219491f, 0.1710277200f, 0.1009718925f, 0.0647818893f, 0.0441976003f,
         0.0304619446f, 0.0211532526f, 0.0116508938f, 0.0064748600f, 0.0036168285f, 0.0020262338f,
         0.0000000112f},
        {0.0000000112f, 0.0018181130f, 0.0032440424f, 0.0058033094f, 0.0104286373f, 0.0188865550f,
         0.0271281339f, 0.0392048396f, 0.0570997633f, 0.0855292231f, 0.1394104809f, 0.1978723854f,
         0.2847255766f, 0.4054926634f, 0.5376322269f, 0.6018700600f, 0.5376324654f, 0.4054926336f,
         0.2847256362f, 0.1978723705f, 0.1394104958f, 0.0855292156f, 0.0570997633f, 0.0392048359f,
         0.0271281414f, 0.0188865550f, 0.0104286373f, 0.0058033094f, 0.0032440424f, 0.0018181130f,
         0.0000000112f},
        {0.0000000075f, 0.0012971871f, 0.0023122616f, 0.0041290298f, 0.0073956437f, 0.0133119002f,
         0.0190039091f, 0.0272102095f, 0.0390642695f, 0.0561143905f, 0.0809218511f, 0.1064853519f,
         0.1382554471f, 0.1733477712f, 0.2032404840f, 0.2154063582f, 0.2032404691f, 0.1733477414f,
         0.1382554919f, 0.1064853519f, 0.0809218585f, 0.0561143905f, 0.0390642732f, 0.0272102095f,
         0.0190039091f, 0.0133118965f, 0.0073956437f, 0.0041290298f, 0.0023122616f, 0.0012971871f,
         0.0000000075f},
        {0.0000000037f, 0.0007926486f, 0.0014115572f, 0.0025163032f, 0.0044930279f, 0.0080412142f,
         0.0114155896f, 0.0162114613f, 0.0229923241f, 0.0324336104f, 0.0450868048f, 0.0552201271f,
         0.0660551786f, 0.0763022155f, 0.0853320509f, 0.0887728706f, 0.0853320658f, 0.0763022155f,
         0.0660551861f, 0.0552201271f, 0.0450868085f, 0.0324336104f, 0.0229923204f, 0.0162114613f,
         0.0114155896f, 0.0080412142f, 0.0044930279f, 0.0025163069f, 0.0014115572f, 0.0007926486f,
         0.0000000037f},
        {0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f},
        {-0.0000000075f, -0.0012636185f, -0.0022416152f, -0.0039687753f, -0.0070013292f,
         -0.0122666024f, -0.0170736760f, -0.0235937759f, -0.0322411507f, -0.0432920344f,
         -0.0565523803f, -0.0660799891f, -0.0753463581f, -0.0833015069f, -0.0887481570f,
         -0.0906938910f, -0.0887481570f, -0.0833014995f, -0.0753463656f, -0.0660799891f,
         -0.0565523840f, -0.0432920344f, -0.0322411507f, -0.0235937722f, -0.0170736760f,
         -0.0122666024f, -0.0070013292f, -0.0039687753f, -0.0022416152f, -0.0012636185f,
         -0.0000000075f},
        {-0.0000000112f, -0.0021195263f, -0.0037540086f, -0.0066280887f, -0.0116370022f,
         -0.0202258006f, -0.0279547386f, -0.0382792503f, -0.0517151989f, -0.0685065687f,
         -0.0881701857f, -0.1020170897f, -0.1152879000f, -0.1265430450f, -0.1341824830f,
         -0.1368992925f, -0.1341824979f, -0.1265430450f, -0.1152879000f, -0.1020170897f,
         -0.0881701857f, -0.0685065687f, -0.0517151989f, -0.0382792465f, -0.0279547423f,
         -0.0202258006f, -0.0116370060f, -0.0066280887f, -0.0037540086f, -0.0021195263f,
         -0.0000000112f}},
    {

        {0.0000000224f, 0.0039921328f, 0.0071208850f, 0.0127314143f, 0.0228547044f, 0.0413094237f,
         0.0592183806f, 0.0853221565f, 0.1236763671f, 0.1803686619f, 0.2854516804f, 0.3939453363f,
         0.5444797277f, 0.7350655198f, 0.9220948815f, 1.0059223175f, 0.9220950603f, 0.7350654006f,
         0.5444797873f, 0.3939453959f, 0.2854517102f, 0.1803686470f, 0.1236763671f, 0.0853221416f,
         0.0592183881f, 0.0413094237f, 0.0228547081f, 0.0127314143f, 0.0071208850f, 0.0039921328f,
         0.0000000224f},
        {0.0000000224f, 0.0037396848f, 0.0066692568f, 0.0119196586f, 0.0213833824f, 0.0386023745f,
         0.0552692823f, 0.0794829652f, 0.1148765832f, 0.1667534113f, 0.2564018667f, 0.3483759165f,
         0.4713715911f, 0.6198635101f, 0.7582825422f, 0.8181172609f, 0.7582826018f, 0.6198634505f,
         0.4713717401f, 0.3483759463f, 0.2564018369f, 0.1667534262f, 0.1148765832f, 0.0794829577f,
         0.0552692935f, 0.0386023745f, 0.0213833824f, 0.0119196586f, 0.0066692568f, 0.0037396848f,
         0.0000000224f},
        {0.0000000186f, 0.0033559650f, 0.0059831366f, 0.0106875487f, 0.0191539228f, 0.0345134847f,
         0.0493235774f, 0.0707350895f, 0.1017966419f, 0.1467751414f, 0.2165540457f, 0.2881157100f,
         0.3792885542f, 0.4829951525f, 0.5739276409f, 0.6116424799f, 0.5739278197f, 0.4829950929f,
         0.3792886436f, 0.2881156802f, 0.2165541053f, 0.1467751414f, 0.1017966270f, 0.0707350820f,
         0.0493235849f, 0.0345134847f, 0.0191539265f, 0.0106875449f, 0.0059831366f, 0.0033559650f,
         0.0000000186f},
        {0.0000000149f, 0.0023951232f, 0.0042668879f, 0.0076114945f, 0.0136074573f, 0.0244078524f,
         0.0347254612f, 0.0494702682f, 0.0704879165f, 0.1001076251f, 0.1405195445f, 0.1735420227f,
         0.2150437981f, 0.2592166960f, 0.2942399085f, 0.3078634143f, 0.2942398787f, 0.2592166662f,
         0.2150438130f, 0.1735420525f, 0.1405195594f, 0.1001076251f, 0.0704879165f, 0.0494702682f,
         0.0347254649f, 0.0244078524f, 0.0136074573f, 0.0076114945f, 0.0042668879f, 0.0023951232f,
         0.0000000149f},
        {0.0000000075f, 0.0014639609f, 0.0026061311f, 0.0046428703f, 0.0082807541f, 0.0147897005f,
         0.0209544264f, 0.0296728499f, 0.0419111848f, 0.0587732270f, 0.0810343996f, 0.0985725895f,
         0.1170293465f, 0.1341015100f, 0.1465103328f, 0.1510950923f, 0.1465103626f, 0.1341015100f,
         0.1170293614f, 0.0985725969f, 0.0810344070f, 0.0587732270f, 0.0419111848f, 0.0296728462f,
         0.0209544301f, 0.0147897005f, 0.0082807541f, 0.0046428740f, 0.0026061311f, 0.0014639609f,
         0.0000000075f},
        {0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f},
        {-0.0000000149f, -0.0023365319f, -0.0041472055f, -0.0073497221f, -0.0129875094f,
         -0.0228201896f, -0.0318449698f, -0.0441566557f, -0.0606067441f, -0.0818213820f,
         -0.1075451598f, -0.1261962205f, -0.1444622725f, -0.1602374315f, -0.1710857153f,
         -0.1749702245f, -0.1710857302f, -0.1602374166f, -0.1444622725f, -0.1261962205f,
         -0.1075451523f, -0.0818213746f, -0.0606067479f, -0.0441566557f, -0.0318449698f,
         -0.0228201859f, -0.0129875094f, -0.0073497221f, -0.0041472055f, -0.0023365319f,
         -0.0000000149f},
        {-0.0000000224f, -0.0039210618f, -0.0069511682f, -0.0122926161f, -0.0216415301f,
         -0.0377869830f, -0.0524356179f, -0.0721722096f, -0.0981289595f, -0.1309677958f,
         -0.1699328125f, -0.1976661086f, -0.2244503498f, -0.2473092675f, -0.2628936768f,
         -0.2684485912f, -0.2628936768f, -0.2473092675f, -0.2244503498f, -0.1976661086f,
         -0.1699328125f, -0.1309677958f, -0.0981289521f, -0.0721722096f, -0.0524356291f,
         -0.0377869792f, -0.0216415301f, -0.0122926198f, -0.0069511682f, -0.0039210618f,
         -0.0000000224f}},
    {

        {0.0000000298f, 0.0052064098f, 0.0092734247f, 0.0165368505f, 0.0295458250f, 0.0529378653f,
         0.0752342194f, 0.1070103794f, 0.1521206498f, 0.2153066397f, 0.3007343411f, 0.3698226213f,
         0.4447503686f, 0.5307883024f, 0.5978007317f, 0.6235858798f, 0.5978007913f, 0.5307883024f,
         0.4447503686f, 0.3698226511f, 0.3007343411f, 0.2153066397f, 0.1521206498f, 0.1070103645f,
         0.0752342343f, 0.0529378615f, 0.0295458250f, 0.0165368505f, 0.0092734247f, 0.0052064061f,
         0.0000000298f},
        {0.0000000261f, 0.0048777387f, 0.0086870864f, 0.0154883042f, 0.0276628546f, 0.0495328866f,
         0.0703521222f, 0.0999773145f, 0.1419382244f, 0.2005145401f, 0.2793169618f, 0.3426927626f,
         0.4107417464f, 0.4813472927f, 0.5399246812f, 0.5623379946f, 0.5399246812f, 0.4813472331f,
         0.4107417464f, 0.3426927924f, 0.2793169618f, 0.2005145401f, 0.1419382244f, 0.0999772996f,
         0.0703521222f, 0.0495328866f, 0.0276628546f, 0.0154883005f, 0.0086870864f, 0.0048777387f,
         0.0000000261f},
        {0.0000000261f, 0.0043780245f, 0.0077958442f, 0.0138952583f, 0.0248045959f, 0.0443725958f,
         0.0629648566f, 0.0893598348f, 0.1266184896f, 0.1783709228f, 0.2474883795f, 0.3026292324f,
         0.3613662124f, 0.4163920283f, 0.4594897032f, 0.4775325954f, 0.4594897032f, 0.4163919985f,
         0.3613662422f, 0.3026292324f, 0.2474884391f, 0.1783709079f, 0.1266184747f, 0.0893598199f,
         0.0629648566f, 0.0443725996f, 0.0248045996f, 0.0138952583f, 0.0077958442f, 0.0043780245f,
         0.0000000261f},
        {0.0000000186f, 0.0031259395f, 0.0055640303f, 0.0099100843f, 0.0176675394f, 0.0315306373f,
         0.0446406342f, 0.0631476343f, 0.0890584067f, 0.1246242076f, 0.1713303179f, 0.2079202831f,
         0.2462213188f, 0.2814548016f, 0.3069431484f, 0.3163340688f, 0.3069431484f, 0.2814548016f,
         0.2462213784f, 0.2079202831f, 0.1713303179f, 0.1246242076f, 0.0890584141f, 0.0631476343f,
         0.0446406342f, 0.0315306373f, 0.0176675394f, 0.0099100843f, 0.0055640303f, 0.0031259395f,
         0.0000000186f},
        {0.0000000112f, 0.0019114725f, 0.0034010001f, 0.0060532652f, 0.0107781142f, 0.0191919580f,
         0.0271133892f, 0.0382369235f, 0.0536935441f, 0.0746848807f, 0.1018502042f, 0.1228085682f,
         0.1444384903f, 0.1640539765f, 0.1780739427f, 0.1832032055f, 0.1780739427f, 0.1640539765f,
         0.1444384903f, 0.1228085682f, 0.1018502042f, 0.0746848658f, 0.0536935441f, 0.0382369198f,
         0.0271133929f, 0.0191919580f, 0.0107781179f, 0.0060532652f, 0.0034010001f, 0.0019114725f,
         0.0000000112f},
        {0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f},
        {-0.0000000186f, -0.0030560978f, -0.0054288842f, -0.0096351840f, -0.0170696974f,
         -0.0301259086f, -0.0422091223f, -0.0588454194f, -0.0813441128f, -0.1108067334f,
         -0.1471893191f, -0.1740057468f, -0.2006137222f, -0.2238603830f, -0.2399867922f,
         -0.2457885146f, -0.2399868220f, -0.2238603532f, -0.2006137371f, -0.1740057468f,
         -0.1471893340f, -0.1108067334f, -0.0813441128f, -0.0588454083f, -0.0422091298f,
         -0.0301259086f, -0.0170696974f, -0.0096351840f, -0.0054288842f, -0.0030560978f,
         -0.0000000186f},
        {-0.0000000298f, -0.0051323175f, -0.0091110431f, -0.0161513090f, -0.0285548419f,
         -0.0502165072f, -0.0701301694f, -0.0973443240f, -0.1337892413f, -0.1809239089f,
         -0.2382676005f, -0.2799672186f, -0.3208998442f, -0.3563211858f, -0.3807161450f,
         -0.3894582987f, -0.3807161450f, -0.3563212156f, -0.3208998442f, -0.2799672484f,
         -0.2382676005f, -0.1809239089f, -0.1337892264f, -0.0973443091f, -0.0701301768f,
         -0.0502165109f, -0.0285548456f, -0.0161513090f, -0.0091110431f, -0.0051323175f,
         -0.0000000298f}},
    {

        {0.0000000298f, 0.0056232363f, 0.0099989995f, 0.0177771747f, 0.0315911807f, 0.0560568646f,
         0.0789347738f, 0.1108068749f, 0.1546058059f, 0.2131874412f, 0.2874797881f, 0.3436433673f,
         0.4005688727f, 0.4512940049f, 0.4870318770f, 0.5000000000f, 0.4870318770f, 0.4512939751f,
         0.4005689025f, 0.3436433673f, 0.2874797881f, 0.2131874263f, 0.1546057910f, 0.1108068675f,
         0.0789347813f, 0.0560568646f, 0.0315911844f, 0.0177771747f, 0.0099989995f, 0.0056232363f,
         0.0000000298f},
        {0.0000000298f, 0.0052689724f, 0.0093690641f, 0.0166572109f, 0.0296009369f, 0.0525252819f,
         0.0739618763f, 0.1038260460f, 0.1448656321f, 0.1997566223f, 0.2693685591f, 0.3219937980f,
         0.3753330112f, 0.4228624403f, 0.4563488662f, 0.4684999883f, 0.4563488662f, 0.4228624403f,
         0.3753330410f, 0.3219938278f, 0.2693685591f, 0.1997566223f, 0.1448656321f, 0.1038260311f,
         0.0739618912f, 0.0525252856f, 0.0296009406f, 0.0166572109f, 0.0093690641f, 0.0052689724f,
         0.0000000298f},
        {0.0000000261f, 0.0047301538f, 0.0084109604f, 0.0149538033f, 0.0265738741f, 0.0471539162f,
         0.0663983598f, 0.0932085291f, 0.1300513148f, 0.1793290079f, 0.2418222427f, 0.2890659571f,
         0.3369505107f, 0.3796194792f, 0.4096814692f, 0.4205900133f, 0.4096814990f, 0.3796194792f,
         0.3369505405f, 0.2890659273f, 0.2418222576f, 0.1793290079f, 0.1300513148f, 0.0932085216f,
         0.0663983598f, 0.0471539162f, 0.0265738741f, 0.0149538033f, 0.0084109604f, 0.0047301538f,
         0.0000000261f},
        {0.0000000186f, 0.0033791140f, 0.0060085990f, 0.0106826574f, 0.0189837739f, 0.0336856917f,
         0.0474334881f, 0.0665860698f, 0.0929057151f, 0.1281086057f, 0.1727523506f, 0.2065021843f,
         0.2407098413f, 0.2711915970f, 0.2926672101f, 0.3004600108f, 0.2926672101f, 0.2711915672f,
         0.2407098711f, 0.2065021843f, 0.1727523655f, 0.1281086057f, 0.0929057226f, 0.0665860623f,
         0.0474334918f, 0.0336856917f, 0.0189837776f, 0.0106826574f, 0.0060085990f, 0.0033791140f,
         0.0000000186f},
        {0.0000000112f, 0.0020673275f, 0.0036760308f, 0.0065356009f, 0.0116141811f, 0.0206087455f,
         0.0290195793f, 0.0407370403f, 0.0568392761f, 0.0783762336f, 0.1056890637f, 0.1263370365f,
         0.1472651362f, 0.1659137160f, 0.1790523976f, 0.1838199943f, 0.1790523976f, 0.1659137160f,
         0.1472651511f, 0.1263370514f, 0.1056890711f, 0.0783762261f, 0.0568392724f, 0.0407370329f,
         0.0290195830f, 0.0206087455f, 0.0116141848f, 0.0065356009f, 0.0036760308f, 0.0020673275f,
         0.0000000112f},
        {0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f},
        {-0.0000000186f, -0.0033120848f, -0.0058894120f, -0.0104707517f, -0.0186072066f,
         -0.0330174938f, -0.0464925803f, -0.0652652532f, -0.0910628140f, -0.1255674064f,
         -0.1693255901f, -0.2024059296f, -0.2359350473f, -0.2658121586f, -0.2868617475f,
         -0.2944999933f, -0.2868617773f, -0.2658121288f, -0.2359350622f, -0.2024059445f,
         -0.1693255901f, -0.1255674064f, -0.0910628140f, -0.0652652457f, -0.0464925840f,
         -0.0330174938f, -0.0186072066f, -0.0104707554f, -0.0058894120f, -0.0033120848f,
         -0.0000000186f},
        {-0.0000000298f, -0.0055670030f, -0.0098990090f, -0.0175994001f, -0.0312752686f,
         -0.0554962978f, -0.0781454220f, -0.1096988022f, -0.1530597508f, -0.2110555619f,
         -0.2846049964f, -0.3402069509f, -0.3965631723f, -0.4467810690f, -0.4821615517f,
         -0.4950000048f, -0.4821615815f, -0.4467810392f, -0.3965632021f, -0.3402069509f,
         -0.2846049964f, -0.2110555619f, -0.1530597359f, -0.1096988022f, -0.0781454295f,
         -0.0554962978f, -0.0312752724f, -0.0175994001f, -0.0098990090f, -0.0055670030f,
         -0.0000000298f}},
    {

        {0.0000000298f, 0.0051840469f, 0.0092027225f, 0.0163133591f, 0.0288398713f, 0.0507133044f,
         0.0708183646f, 0.0982891619f, 0.1350691319f, 0.1826231927f, 0.2404571772f, 0.2825005352f,
         0.3237606883f, 0.3594580293f, 0.3840392828f, 0.3928474188f, 0.3840392828f, 0.3594580293f,
         0.3237607181f, 0.2825005352f, 0.2404572070f, 0.1826231927f, 0.1350691170f, 0.0982891470f,
         0.0708183646f, 0.0507133044f, 0.0288398750f, 0.0163133591f, 0.0092027225f, 0.0051840469f,
         0.0000000298f},
        {0.0000000261f, 0.0048581101f, 0.0086250156f, 0.0152920857f, 0.0270430744f, 0.0475800633f,
         0.0664762184f, 0.0923245773f, 0.1269837022f, 0.1718790978f, 0.2265993506f, 0.2664566338f,
         0.3056311607f, 0.3395694792f, 0.3629627824f, 0.3713497519f, 0.3629627824f, 0.3395694792f,
         0.3056311607f, 0.2664566338f, 0.2265993655f, 0.1718791127f, 0.1269836873f, 0.0923245549f,
         0.0664762259f, 0.0475800633f, 0.0270430781f, 0.0152920857f, 0.0086250156f, 0.0048581101f,
         0.0000000261f},
        {0.0000000261f, 0.0043622032f, 0.0077458210f, 0.0137371235f, 0.0243051276f, 0.0427990668f,
         0.0598423518f, 0.0831969753f, 0.1145843044f, 0.1553593576f, 0.2052282989f, 0.2416637242f,
         0.2775619626f, 0.3087284565f, 0.3302457333f, 0.3379667401f, 0.3302457333f, 0.3087284565f,
         0.2775619924f, 0.2416636944f, 0.2052282989f, 0.1553593576f, 0.1145842969f, 0.0831969678f,
         0.0598423555f, 0.0427990705f, 0.0243051313f, 0.0137371235f, 0.0077458210f, 0.0043622032f,
         0.0000000261f},
        {0.0000000186f, 0.0031178668f, 0.0055385008f, 0.0098293871f, 0.0174126737f, 0.0307279304f,
         0.0430483744f, 0.0600074232f, 0.0829356611f, 0.1129490286f, 0.1499940604f, 0.1772867441f,
         0.2043576241f, 0.2280011177f, 0.2443987727f, 0.2502972782f, 0.2443987727f, 0.2280010879f,
         0.2043576539f, 0.1772867590f, 0.1499940753f, 0.1129490286f, 0.0829356611f, 0.0600074194f,
         0.0430483781f, 0.0307279266f, 0.0174126774f, 0.0098293871f, 0.0055385008f, 0.0031178668f,
         0.0000000186f},
        {0.0000000112f, 0.0019084513f, 0.0033914447f, 0.0060230605f, 0.0106827281f, 0.0188915879f,
         0.0265177228f, 0.0370627567f, 0.0514063723f, 0.0703314394f, 0.0939192027f, 0.1114559397f,
         0.1289804429f, 0.1443904638f, 0.1551341414f, 0.1590099335f, 0.1551341563f, 0.1443904638f,
         0.1289804578f, 0.1114559397f, 0.0939192176f, 0.0703314245f, 0.0514063723f, 0.0370627530f,
         0.0265177265f, 0.0188915879f, 0.0106827281f, 0.0060230605f, 0.0033914447f, 0.0019084513f,
         0.0000000112f},
        {0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f},
        {-0.0000000186f, -0.0030638538f, -0.0054534115f, -0.0097127110f, -0.0173145495f,
         -0.0308970734f, -0.0437387861f, -0.0618620813f, -0.0872256160f, -0.1220206320f,
         -0.1676785499f, -0.2034175098f, -0.2407984585f, -0.2751578987f, -0.2999968529f,
         -0.3091448545f, -0.2999968827f, -0.2751578689f, -0.2407984585f, -0.2034175098f,
         -0.1676785499f, -0.1220206320f, -0.0872256160f, -0.0618620738f, -0.0437387861f,
         -0.0308970734f, -0.0173145495f, -0.0097127110f, -0.0054534115f, -0.0030638538f,
         -0.0000000186f},
        {-0.0000000298f, -0.0051542334f, -0.0091803335f, -0.0163703524f, -0.0292467363f,
         -0.0523967445f, -0.0744579434f, -0.1058912203f, -0.1504984796f, -0.2129460722f,
         -0.2973079383f, -0.3654728234f, -0.4390078187f, -0.5227221847f, -0.5883264542f,
         -0.6135464907f, -0.5883265138f, -0.5227221251f, -0.4390078783f, -0.3654728234f,
         -0.2973079383f, -0.2129460722f, -0.1504984796f, -0.1058912128f, -0.0744579583f,
         -0.0523967408f, -0.0292467438f, -0.0163703524f, -0.0091803372f, -0.0051542334f,
         -0.0000000298f}},
    {

        {0.0000000224f, 0.0039605126f, 0.0070208944f, 0.0124152638f, 0.0218554623f, 0.0381546579f,
         0.0529386885f, 0.0728518516f, 0.0990312248f, 0.1321374178f, 0.1714010984f, 0.1993360221f,
         0.2263072431f, 0.2493203282f, 0.2650071383f, 0.2705981135f, 0.2650071681f, 0.2493203282f,
         0.2263072580f, 0.1993360221f, 0.1714010984f, 0.1321374327f, 0.0990312248f, 0.0728518367f,
         0.0529386923f, 0.0381546579f, 0.0218554661f, 0.0124152638f, 0.0070208944f, 0.0039605126f,
         0.0000000224f},
        {0.0000000224f, 0.0037119240f, 0.0065814704f, 0.0116420984f, 0.0205062144f, 0.0358339176f,
         0.0497612096f, 0.0685553625f, 0.0933211744f, 0.1247262433f, 0.1620853692f, 0.1887322813f,
         0.2145074904f, 0.2365339100f, 0.2515646815f, 0.2569248676f, 0.2515646815f, 0.2365339100f,
         0.2145075202f, 0.1887322962f, 0.1620853692f, 0.1247262433f, 0.0933211744f, 0.0685553551f,
         0.0497612134f, 0.0358339213f, 0.0205062144f, 0.0116420984f, 0.0065814704f, 0.0037119202f,
         0.0000000224f},
        {0.0000000186f, 0.0033335947f, 0.0059123896f, 0.0104638711f, 0.0184471309f, 0.0322837941f,
         0.0448903851f, 0.0619516149f, 0.0845159292f, 0.1132542491f, 0.1476069987f, 0.1722095311f,
         0.1960792094f, 0.2165289670f, 0.2305093110f, 0.2354997098f, 0.2305093408f, 0.2165289521f,
         0.1960792243f, 0.1722095460f, 0.1476070136f, 0.1132542342f, 0.0845159292f, 0.0619516112f,
         0.0448903851f, 0.0322837979f, 0.0184471346f, 0.0104638711f, 0.0059123859f, 0.0033335947f,
         0.0000000186f},
        {0.0000000149f, 0.0023837052f, 0.0042307861f, 0.0074973591f, 0.0132469125f, 0.0232715197f,
         0.0324691869f, 0.0450118259f, 0.0617620423f, 0.0833501965f, 0.1095077693f, 0.1284612119f,
         0.1470142007f, 0.1630302370f, 0.1740406454f, 0.1779825240f, 0.1740406454f, 0.1630302221f,
         0.1470142156f, 0.1284612268f, 0.1095077768f, 0.0833501965f, 0.0617620423f, 0.0450118259f,
         0.0324691869f, 0.0232715197f, 0.0132469162f, 0.0074973591f, 0.0042307861f, 0.0023837052f,
         0.0000000149f},
        {0.0000000075f, 0.0014596879f, 0.0025926158f, 0.0046001561f, 0.0081458427f, 0.0143647566f,
         0.0201114081f, 0.0280098990f, 0.0386673771f, 0.0525827818f, 0.0697054788f, 0.0822848827f,
         0.0947335958f, 0.1055838838f, 0.1130971909f, 0.1157975346f, 0.1130971909f, 0.1055838838f,
         0.0947336033f, 0.0822848976f, 0.0697054863f, 0.0525827743f, 0.0386673771f, 0.0280098990f,
         0.0201114118f, 0.0143647566f, 0.0081458464f, 0.0046001561f, 0.0025926158f, 0.0014596879f,
         0.0000000075f},
        {0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f},
        {-0.0000000149f, -0.0023475029f, -0.0041818954f, -0.0074593760f, -0.0133338906f,
         -0.0239118375f, -0.0340123996f, -0.0484390557f, -0.0689862818f, -0.0979072601f,
         -0.1372926533f, -0.1694079638f, -0.2086421251f, -0.2509776056f, -0.2844191492f,
         -0.2973977327f, -0.2844191790f, -0.2509775758f, -0.2086421549f, -0.1694079638f,
         -0.1372926831f, -0.0979072601f, -0.0689862967f, -0.0484390482f, -0.0340124033f,
         -0.0239118375f, -0.0133338906f, -0.0074593797f, -0.0041818954f, -0.0023475029f,
         -0.0000000149f},
        {-0.0000000224f, -0.0039520524f, -0.0070491731f, -0.0126024783f, -0.0226208754f,
         -0.0408787429f, -0.0585894138f, -0.0843905732f, -0.1222686917f, -0.1781808734f,
         -0.2806743383f, -0.3863531053f, -0.5320819616f, -0.7150993347f, -0.8931089044f,
         -0.9723873734f, -0.8931091428f, -0.7150992155f, -0.5320819616f, -0.3863530755f,
         -0.2806743681f, -0.1781808734f, -0.1222686768f, -0.0843905732f, -0.0585894212f,
         -0.0408787429f, -0.0226208791f, -0.0126024783f, -0.0070491731f, -0.0039520524f,
         -0.0000000224f}},
    {

        {0.0000000112f, 0.0021408275f, 0.0037915856f, 0.0066939741f, 0.0117513053f, 0.0204205140f,
         0.0282191299f, 0.0386330411f, 0.0521795005f, 0.0691007078f, 0.0889061689f, 0.1028472483f,
         0.1162044853f, 0.1275303066f, 0.1352164894f, 0.1379496753f, 0.1352164894f, 0.1275303066f,
         0.1162045002f, 0.1028472483f, 0.0889061838f, 0.0691007078f, 0.0521795005f, 0.0386330374f,
         0.0282191336f, 0.0204205140f, 0.0117513090f, 0.0066939741f, 0.0037915856f, 0.0021408275f,
         0.0000000112f},
        {0.0000000112f, 0.0020066053f, 0.0035547465f, 0.0062785484f, 0.0110301524f, 0.0191908441f,
         0.0265479870f, 0.0363945179f, 0.0492380373f, 0.0653315485f, 0.0842306241f, 0.0975688770f,
         0.1103724316f, 0.1212451532f, 0.1286316216f, 0.1312596500f, 0.1286316216f, 0.1212451532f,
         0.1103724390f, 0.0975688845f, 0.0842306241f, 0.0653315485f, 0.0492380373f, 0.0363945141f,
         0.0265479907f, 0.0191908441f, 0.0110301562f, 0.0062785484f, 0.0035547465f, 0.0020066053f,
         0.0000000112f},
        {0.0000000112f, 0.0018022917f, 0.0031940117f, 0.0056451149f, 0.0099285431f, 0.0173068047f,
         0.0239810050f, 0.0329449996f, 0.0446879491f, 0.0594761632f, 0.0769355893f, 0.0893112868f,
         0.1012277603f, 0.1113727987f, 0.1182771921f, 0.1207359582f, 0.1182772070f, 0.1113727987f,
         0.1012277603f, 0.0893112868f, 0.0769355893f, 0.0594761632f, 0.0446879491f, 0.0329449959f,
         0.0239810087f, 0.0173068047f, 0.0099285431f, 0.0056451149f, 0.0031940117f, 0.0018022917f,
         0.0000000112f},
        {0.0000000075f, 0.0012891144f, 0.0022867322f, 0.0040483177f, 0.0071406178f, 0.0125075765f,
         0.0174052790f, 0.0240450874f, 0.0328458026f, 0.0440842360f, 0.0575582422f, 0.0672323704f,
         0.0766361356f, 0.0847054869f, 0.0902284831f, 0.0922011435f, 0.0902284831f, 0.0847054794f,
         0.0766361356f, 0.0672323704f, 0.0575582422f, 0.0440842398f, 0.0328458063f, 0.0240450874f,
         0.0174052827f, 0.0125075765f, 0.0071406178f, 0.0040483177f, 0.0022867322f, 0.0012891144f,
         0.0000000075f},
        {0.0000000037f, 0.0007896237f, 0.0014020018f, 0.0024860986f, 0.0043976195f, 0.0077406205f,
         0.0108190365f, 0.0150338374f, 0.0206919834f, 0.0280320831f, 0.0369941816f, 0.0435322635f,
         0.0499662943f, 0.0555463880f, 0.0593958236f, 0.0607765317f, 0.0593958311f, 0.0555463880f,
         0.0499663018f, 0.0435322635f, 0.0369941816f, 0.0280320793f, 0.0206919834f, 0.0150338374f,
         0.0108190365f, 0.0077406205f, 0.0043976195f, 0.0024860986f, 0.0014020018f, 0.0007896237f,
         0.0000000037f},
        {0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f},
        {-0.0000000075f, -0.0012713782f, -0.0022661425f, -0.0040463172f, -0.0072463304f,
         -0.0130392574f, -0.0186092220f, -0.0266334265f, -0.0382109173f, -0.0548328906f,
         -0.0785857737f, -0.1031111181f, -0.1333933324f, -0.1665901542f, -0.1946617961f,
         -0.2060326487f, -0.1946618110f, -0.1665901244f, -0.1333933473f, -0.1031111181f,
         -0.0785857663f, -0.0548328944f, -0.0382109173f, -0.0266334228f, -0.0186092220f,
         -0.0130392574f, -0.0072463304f, -0.0040463172f, -0.0022661425f, -0.0012713782f,
         -0.0000000075f},
        {-0.0000000112f, -0.0021414421f, -0.0038233139f, -0.0068472512f, -0.0123300999f,
         -0.0224180073f, -0.0323300436f, -0.0470142849f, -0.0691649169f, -0.1103344113f,
         -0.1914317608f, -0.2921350002f, -0.4732148349f, -0.8167076707f, -1.4096118212f,
         -1.8493247032f, -1.4096126556f, -0.8167075515f, -0.4732148647f, -0.2921350002f,
         -0.1914317757f, -0.1103344113f, -0.0691649020f, -0.0470142812f, -0.0323300473f,
         -0.0224180073f, -0.0123301037f, -0.0068472549f, -0.0038233139f, -0.0021414421f,
         -0.0000000112f}}};

const FLOAT32 ixheaacd_re_weight[16][8][31] = {

    {

        {0.5000000000f,  0.4971804619f,  0.4949752390f,  0.4910309315f,  0.4839466512f,
         0.4711385369f,  0.4588382840f,  0.4411309958f,  0.4155683815f,  0.3786902130f,
         0.3259756267f,  0.2796038389f,  0.2229698598f,  0.1560545117f,  0.0805236399f,
         0.0000000000f,  -0.0805236399f, -0.1560545266f, -0.2229698896f, -0.2796038687f,
         -0.3259756267f, -0.3786902130f, -0.4155683815f, -0.4411309958f, -0.4588383138f,
         -0.4711385369f, -0.4839466512f, -0.4910309613f, -0.4949752688f, -0.4971804321f,
         -0.5000000000f},
        {0.5000000000f,  0.4973547161f,  0.4952812195f,  0.4915628731f,  0.4848551154f,
         0.4726418555f,  0.4608217478f,  0.4436736703f,  0.4186950922f,  0.3823071420f,
         0.3297900558f,  0.2832620144f,  0.2261611372f,  0.1584401429f,  0.0818051845f,
         0.0000000000f,  -0.0818051845f, -0.1584401578f, -0.2261611372f, -0.2832620144f,
         -0.3297900856f, -0.3823071420f, -0.4186950922f, -0.4436736703f, -0.4608217478f,
         -0.4726418853f, -0.4848551452f, -0.4915628731f, -0.4952812195f, -0.4973546565f,
         -0.5000000000f},
        {0.5000000000f,  0.4976201355f,  0.4957476556f,  0.4923752248f,  0.4862467945f,
         0.4749561548f,  0.4638883471f,  0.4476265609f,  0.4235888422f,  0.3880125880f,
         0.3358573616f,  0.2891118824f,  0.2312888801f,  0.1622879505f,  0.0838772804f,
         0.0000000000f,  -0.0838772804f, -0.1622879654f, -0.2312888950f, -0.2891118526f,
         -0.3358573914f, -0.3880126476f, -0.4235888422f, -0.4476265907f, -0.4638883471f,
         -0.4749561548f, -0.4862467945f, -0.4923752248f, -0.4957476854f, -0.4976201057f,
         -0.5000000000f},
        {0.5000000000f,  0.4982874393f,  0.4969230890f,  0.4944299161f,  0.4897895753f,
         0.4809119105f,  0.4718552828f,  0.4580222666f,  0.4366562366f,  0.4035232663f,
         0.3526770473f,  0.3055384457f,  0.2458558977f,  0.1733215600f,  0.0898552686f,
         0.0000000000f,  -0.0898552686f, -0.1733215749f, -0.2458558679f, -0.3055384457f,
         -0.3526770473f, -0.4035232663f, -0.4366561770f, -0.4580222666f, -0.4718553126f,
         -0.4809119105f, -0.4897895753f, -0.4944299459f, -0.4969231188f, -0.4982874393f,
         -0.5000000000f},
        {0.5000000000f,  0.4989379942f,  0.4980724454f,  0.4964498281f,  0.4933045506f,
         0.4869143069f,  0.4799970984f,  0.4688419700f,  0.4505754411f,  0.4205142260f,
         0.3716892004f,  0.3245028853f,  0.2630047202f,  0.1865197271f,  0.0970816985f,
         0.0000000000f,  -0.0970816985f, -0.1865197271f, -0.2630047202f, -0.3245028257f,
         -0.3716892302f, -0.4205142260f, -0.4505754411f, -0.4688419998f, -0.4799970984f,
         -0.4869143367f, -0.4933045506f, -0.4964498281f, -0.4980724454f, -0.4989379644f,
         -0.5000000000f},
        {0.5000000000f,  0.4999683797f,  0.4999000132f,  0.4996838570f,  0.4990009665f,
         0.4968476892f,  0.4937299490f,  0.4875672758f,  0.4754966497f,  0.4522733092f,
         0.4090909064f,  0.3631930947f,  0.2992399931f,  0.2152527571f,  0.1131368279f,
         0.0000000000f,  -0.1131368279f, -0.2152527571f, -0.2992399931f, -0.3631930947f,
         -0.4090909064f, -0.4522732794f, -0.4754966199f, -0.4875672758f, -0.4937299788f,
         -0.4968476892f, -0.4990009964f, -0.4996838868f, -0.4999000132f, -0.4999683797f,
         -0.5000000000f},
        {0.5000000596f,  0.5016326308f,  0.5028703809f,  0.5049995780f,  0.5085534453f,
         0.5141122937f,  0.5184206367f,  0.5228864551f,  0.5257800817f,  0.5226357579f,
         0.5154753923f,  0.5085130334f,  0.4721691608f,  0.3829773664f,  0.2211726457f,
         0.0000000000f,  -0.2211726457f, -0.3829773664f, -0.4721692204f, -0.5085130334f,
         -0.5154754519f, -0.5226357579f, -0.5257800817f, -0.5228864551f, -0.5184206963f,
         -0.5141122937f, -0.5085535049f, -0.5049996376f, -0.5028703809f, -0.5016326308f,
         -0.5000000596f},
        {0.5000000596f,  0.5027751923f,  0.5049232244f,  0.5087171793f,  0.5153799057f,
         0.5269514322f,  0.5375180840f,  0.5518481731f,  0.5710597038f,  0.6521918178f,
         0.7913578749f,  0.9470402002f,  1.2054057121f,  1.6852766275f,  2.6426265240f,
         0.0000000000f,  -2.6426310539f, -1.6852763891f, -1.2054058313f, -0.9470402002f,
         -0.7913579345f, -0.6521918178f, -0.5710596442f, -0.5518481135f, -0.5375181437f,
         -0.5269514322f, -0.5153799057f, -0.5087171793f, -0.5049232244f, -0.5027751923f,
         -0.5000000596f}},
    {

        {0.5000000000f,  0.4973910451f,  0.4953450263f,  0.4916738272f,  0.4850449860f,
         0.4729567766f,  0.4612380564f,  0.4442087412f,  0.4193551540f,  0.3830735385f,
         0.3306015134f,  0.2840420902f,  0.2268431634f,  0.1589508802f,  0.0820798650f,
         0.0000000000f,  -0.0820798576f, -0.1589508951f, -0.2268431783f, -0.2840420902f,
         -0.3306015134f, -0.3830735683f, -0.4193551242f, -0.4442086816f, -0.4612380862f,
         -0.4729567766f, -0.4850450158f, -0.4916738570f, -0.4953449965f, -0.4973909855f,
         -0.5000000000f},
        {0.5000000000f,  0.4975522459f,  0.4956282973f,  0.4921671450f,  0.4858898818f,
         0.4743613005f,  0.4630986154f,  0.4466060102f,  0.4223214984f,  0.3865298629f,
         0.3342745602f,  0.2875820398f,  0.2299449295f,  0.1612776965f,  0.0833326429f,
         0.0000000000f,  -0.0833326355f, -0.1612777114f, -0.2299449295f, -0.2875820100f,
         -0.3342745602f, -0.3865298331f, -0.4223214984f, -0.4466060400f, -0.4630986452f,
         -0.4743613005f, -0.4858898818f, -0.4921671748f, -0.4956283271f, -0.4975521863f,
         -0.5000000000f},
        {0.5000000000f,  0.4977977276f,  0.4960601032f,  0.4929202795f,  0.4871834517f,
         0.4765217602f,  0.4659720957f,  0.4503277540f,  0.4269563556f,  0.3919708133f,
         0.3401035368f,  0.2932292819f,  0.2349164933f,  0.1650211811f,  0.0853530467f,
         0.0000000000f,  -0.0853530392f, -0.1650211811f, -0.2349164784f, -0.2932292819f,
         -0.3401035368f, -0.3919707835f, -0.4269563556f, -0.4503277540f, -0.4659721255f,
         -0.4765217602f, -0.4871834517f, -0.4929203391f, -0.4960601330f, -0.4977976680f,
         -0.5000000000f},
        {0.5000000000f,  0.4984147847f,  0.4971478283f,  0.4948240519f,  0.4904728234f,
         0.4820713699f,  0.4734190702f,  0.4600848258f,  0.4392839074f,  0.4066926241f,
         0.3561752141f,  0.3089951873f,  0.2489543557f,  0.1756889224f,  0.0911452249f,
         0.0000000000f,  -0.0911452249f, -0.1756889224f, -0.2489543557f, -0.3089951873f,
         -0.3561752439f, -0.4066926539f, -0.4392838776f, -0.4600848556f, -0.4734191597f,
         -0.4820713401f, -0.4904728830f, -0.4948240817f, -0.4971478581f, -0.4984148145f,
         -0.5000000000f},
        {0.5000000000f,  0.4990161359f,  0.4982108474f,  0.4966937900f,  0.4937312901f,
         0.4876496494f,  0.4810023904f,  0.4701921344f,  0.4523362219f,  0.4227000475f,
         0.3741825819f,  0.3270231485f,  0.2653121948f,  0.1883139759f,  0.0980708972f,
         0.0000000000f,  -0.0980708972f, -0.1883139908f, -0.2653121948f, -0.3270231485f,
         -0.3741825819f, -0.4227000475f, -0.4523362219f, -0.4701920748f, -0.4810024500f,
         -0.4876496494f, -0.4937313497f, -0.4966937602f, -0.4982108474f, -0.4990161359f,
         -0.5000000000f},
        {0.5000000000f,  0.4999683797f,  0.4999000132f,  0.4996838570f,  0.4990009665f,
         0.4968476892f,  0.4937299490f,  0.4875672758f,  0.4754966497f,  0.4522733092f,
         0.4090909064f,  0.3631930947f,  0.2992399931f,  0.2152527571f,  0.1131368279f,
         0.0000000000f,  -0.1131368279f, -0.2152527571f, -0.2992399931f, -0.3631930947f,
         -0.4090909064f, -0.4522732794f, -0.4754966199f, -0.4875672758f, -0.4937299788f,
         -0.4968476892f, -0.4990009964f, -0.4996838868f, -0.4999000132f, -0.4999683797f,
         -0.5000000000f},
        {0.5000000596f,  0.5015053153f,  0.5026424527f,  0.5045889616f,  0.5078070164f,
         0.5127342939f,  0.5164096355f,  0.5199240446f,  0.5213798285f,  0.5160900950f,
         0.4961368442f,  0.4834818840f,  0.4421011508f,  0.3525197506f,  0.2006191462f,
         0.0000000000f,  -0.2006191611f, -0.3525197506f, -0.4421012104f, -0.4834818840f,
         -0.4961368442f, -0.5160900354f, -0.5213798285f, -0.5199240446f, -0.5164096951f,
         -0.5127342939f, -0.5078070164f, -0.5045889020f, -0.5026424527f, -0.5015053153f,
         -0.5000000596f},
        {0.5000000596f,  0.5025598407f,  0.5045354366f,  0.5080122352f,  0.5140760541f,
         0.5244651437f,  0.5337679982f,  0.5460379124f,  0.5614778399f,  0.6178392172f,
         0.7190375924f,  0.8149638772f,  0.9330949783f,  1.0282076597f,  0.8643130064f,
         0.0000000000f,  -0.8643135428f, -1.0282076597f, -0.9330950975f, -0.8149638772f,
         -0.7190377116f, -0.6178392172f, -0.5614778399f, -0.5460379124f, -0.5337680578f,
         -0.5244650841f, -0.5140760541f, -0.5080122352f, -0.5045354962f, -0.5025598407f,
         -0.5000000596f}},
    {

        {0.5000000000f,  0.4979922175f,  0.4964025617f,  0.4935186803f,  0.4882142544f,
         0.4782521725f,  0.4682838917f,  0.4533392787f,  0.4307335615f,  0.3964424431f,
         0.3449379802f,  0.2979410589f,  0.2390869260f,  0.1681751311f,  0.0870600939f,
         0.0000000000f,  -0.0870600939f, -0.1681751609f, -0.2390869260f, -0.2979410589f,
         -0.3449379802f, -0.3964424133f, -0.4307335615f, -0.4533392191f, -0.4682839215f,
         -0.4782522023f, -0.4882142544f, -0.4935186505f, -0.4964025617f, -0.4979921579f,
         -0.5000000000f},
        {0.5000000000f,  0.4981160462f,  0.4966207743f,  0.4939002991f,  0.4888732731f,
         0.4793626070f,  0.4697723091f,  0.4552863240f,  0.4331887662f,  0.3993673325f,
         0.3481221497f,  0.3010586798f,  0.2418578863f,  0.1702777445f,  0.0882006139f,
         0.0000000000f,  -0.0882006139f, -0.1702777445f, -0.2418578863f, -0.3010587096f,
         -0.3481221497f, -0.3993673027f, -0.4331887662f, -0.4552863240f, -0.4697723091f,
         -0.4793626070f, -0.4888732731f, -0.4939003289f, -0.4966207743f, -0.4981160164f,
         -0.5000000000f},
        {0.5000000000f,  0.4983044863f,  0.4969531596f,  0.4944825768f,  0.4898807108f,
         0.4810664356f,  0.4720634520f,  0.4582964182f,  0.4370048046f,  0.4039427042f,
         0.3531388044f,  0.3059939146f,  0.2462634444f,  0.1736325473f,  0.0900245756f,
         0.0000000000f,  -0.0900245681f, -0.1736325473f, -0.2462634742f, -0.3059939146f,
         -0.3531388342f, -0.4039427042f, -0.4370048046f, -0.4582964182f, -0.4720634818f,
         -0.4810664058f, -0.4898807704f, -0.4944825768f, -0.4969531298f, -0.4983044863f,
         -0.5000000000f},
        {0.5000000000f,  0.4987780154f,  0.4977895021f,  0.4959515929f,  0.4924345016f,
         0.4854198098f,  0.4779591858f,  0.4661146402f,  0.4470350742f,  0.4161445498f,
         0.3667378426f,  0.3195213675f,  0.2584639788f,  0.1830018759f,  0.0951471180f,
         0.0000000000f,  -0.0951471031f, -0.1830018908f, -0.2584639490f, -0.3195213974f,
         -0.3667378426f, -0.4161445200f, -0.4470350742f, -0.4661146402f, -0.4779591858f,
         -0.4854198396f, -0.4924345613f, -0.4959515929f, -0.4977895021f, -0.4987780452f,
         -0.5000000000f},
        {0.5000000000f,  0.4992391467f,  0.4986056089f,  0.4973905385f,  0.4949527979f,
         0.4897618592f,  0.4839001894f,  0.4741017818f,  0.4574657679f,  0.4291163385f,
         0.3815677166f,  0.3345352709f,  0.2722316980f,  0.1937220246f,  0.1010626405f,
         0.0000000000f,  -0.1010626331f, -0.1937220395f, -0.2722316980f, -0.3345352709f,
         -0.3815677166f, -0.4291163385f, -0.4574657679f, -0.4741017818f, -0.4839001894f,
         -0.4897618592f, -0.4949527979f, -0.4973905683f, -0.4986056685f, -0.4992391169f,
         -0.5000000000f},
        {0.5000000000f,  0.4999683797f,  0.4999000132f,  0.4996838570f,  0.4990009665f,
         0.4968476892f,  0.4937299490f,  0.4875672758f,  0.4754966497f,  0.4522733092f,
         0.4090909064f,  0.3631930947f,  0.2992399931f,  0.2152527571f,  0.1131368279f,
         0.0000000000f,  -0.1131368279f, -0.2152527571f, -0.2992399931f, -0.3631930947f,
         -0.4090909064f, -0.4522732794f, -0.4754966199f, -0.4875672758f, -0.4937299788f,
         -0.4968476892f, -0.4990009964f, -0.4996838868f, -0.4999000132f, -0.4999683797f,
         -0.5000000000f},
        {0.5000000000f,  0.5011434555f,  0.5019949079f,  0.5034251213f,  0.5056989789f,
         0.5088702440f,  0.5108083487f,  0.5117562413f,  0.5094295144f,  0.4987166524f,
         0.4690935910f,  0.4298956990f,  0.3742347956f,  0.2874245048f,  0.1586372554f,
         0.0000000000f,  -0.1586372554f, -0.2874245346f, -0.3742347956f, -0.4298956990f,
         -0.4690936506f, -0.4987166524f, -0.5094294548f, -0.5117561817f, -0.5108084679f,
         -0.5088702440f, -0.5056990385f, -0.5034251213f, -0.5019949675f, -0.5011434555f,
         -0.5000000000f},
        {0.5000000596f,  0.5019482374f,  0.5034363270f,  0.5060207844f,  0.5104164481f,
         0.5175731182f,  0.5235039592f,  0.5304464698f,  0.5371760726f,  0.5399831533f,
         0.5705516934f,  0.5833024383f,  0.5678070188f,  0.4872314930f,  0.2963677347f,
         0.0000000000f,  -0.2963677943f, -0.4872314930f, -0.5678070784f, -0.5833024383f,
         -0.5705517530f, -0.5399830937f, -0.5371760130f, -0.5304464102f, -0.5235040188f,
         -0.5175731182f, -0.5104165077f, -0.5060207844f, -0.5034362674f, -0.5019482374f,
         -0.5000000596f}},
    {

        {0.5000000000f,  0.4988959730f,  0.4979980290f,  0.4963187873f,  0.4930755794f,
         0.4865204096f,  0.4794592559f,  0.4681210220f,  0.4496374130f,  0.4193532467f,
         0.3703693151f,  0.3231719732f,  0.2617889345f,  0.1855761409f,  0.0965621769f,
         0.0000000000f,  -0.0965621769f, -0.1855761558f, -0.2617889643f, -0.3231719434f,
         -0.3703693151f, -0.4193532169f, -0.4496374130f, -0.4681210220f, -0.4794593155f,
         -0.4865204692f, -0.4930756390f, -0.4963187873f, -0.4979980290f, -0.4988959432f,
         -0.5000000000f},
        {0.5000000000f,  0.4989632964f,  0.4981172681f,  0.4965288043f,  0.4934426546f,
         0.4871520996f,  0.4803220332f,  0.4692780674f,  0.4511435628f,  0.4212186337f,
         0.3724914491f,  0.3253129125f,  0.2637456059f,  0.1870953441f,  0.0973988697f,
         0.0000000000f,  -0.0973988622f, -0.1870953441f, -0.2637456357f, -0.3253129125f,
         -0.3724914491f, -0.4212185740f, -0.4511435628f, -0.4692780375f, -0.4803220928f,
         -0.4871521592f, -0.4934426844f, -0.4965288043f, -0.4981172979f, -0.4989632666f,
         -0.5000000000f},
        {0.5000000000f,  0.4990658462f,  0.4982986450f,  0.4968487024f,  0.4940025806f,
         0.4881176353f,  0.4816432893f,  0.4710545242f,  0.4534637034f,  0.4241041243f,
         0.3757902384f,  0.3286524117f,  0.2668075860f,  0.1894792169f,  0.0987142026f,
         0.0000000000f,  -0.0987141877f, -0.1894792318f, -0.2668076158f, -0.3286524117f,
         -0.3757902086f, -0.4241041243f, -0.4534636736f, -0.4710544348f, -0.4816432893f,
         -0.4881176651f, -0.4940025806f, -0.4968487322f, -0.4982987046f, -0.4990658164f,
         -0.5000000000f},
        {0.5000000000f,  0.4993230999f,  0.4987545311f,  0.4976536036f,  0.4954148531f,
         0.4905641079f,  0.4850046337f,  0.4755989015f,  0.4594423771f,  0.4316084087f,
         0.3844630718f,  0.3375001550f,  0.2749801576f,  0.1958818436f,  0.1022618562f,
         0.0000000000f,  -0.1022618562f, -0.1958818585f, -0.2749801576f, -0.3375001550f,
         -0.3844630718f, -0.4316083491f, -0.4594423175f, -0.4755989015f, -0.4850046337f,
         -0.4905640781f, -0.4954148829f, -0.4976535738f, -0.4987545311f, -0.4993230700f,
         -0.5000000000f},
        {0.5000000000f,  0.4995733500f,  0.4991982579f,  0.4984387755f,  0.4967978001f,
         0.4929749966f,  0.4883366227f,  0.4801396132f,  0.4654795825f,  0.4392894208f,
         0.3934856355f,  0.3468125761f,  0.2836796939f,  0.2027634680f,  0.1061001420f,
         0.0000000000f,  -0.1061001420f, -0.2027634680f, -0.2836797237f, -0.3468125761f,
         -0.3934856355f, -0.4392894208f, -0.4654795825f, -0.4801395833f, -0.4883366823f,
         -0.4929749668f, -0.4967978299f, -0.4984387755f, -0.4991982877f, -0.4995733202f,
         -0.5000000000f},
        {0.5000000000f,  0.4999683797f,  0.4999000132f,  0.4996838570f,  0.4990009665f,
         0.4968476892f,  0.4937299490f,  0.4875672758f,  0.4754966497f,  0.4522733092f,
         0.4090909064f,  0.3631930947f,  0.2992399931f,  0.2152527571f,  0.1131368279f,
         0.0000000000f,  -0.1131368279f, -0.2152527571f, -0.2992399931f, -0.3631930947f,
         -0.4090909064f, -0.4522732794f, -0.4754966199f, -0.4875672758f, -0.4937299788f,
         -0.4968476892f, -0.4990009964f, -0.4996838868f, -0.4999000132f, -0.4999683797f,
         -0.5000000000f},
        {0.5000000000f,  0.5006032586f,  0.5010305047f,  0.5016981363f,  0.5025926232f,
         0.5032470226f,  0.5027559996f,  0.5002208352f,  0.4929866195f,  0.4757096469f,
         0.4384897351f,  0.3950820863f,  0.3305715621f,  0.2411795557f,  0.1280656606f,
         0.0000000000f,  -0.1280656606f, -0.2411795706f, -0.3305716217f, -0.3950820863f,
         -0.4384897351f, -0.4757096469f, -0.4929866195f, -0.5002207756f, -0.5027559996f,
         -0.5032470226f, -0.5025926232f, -0.5016981959f, -0.5010305047f, -0.5006032586f,
         -0.5000000000f},
        {0.5000000000f,  0.5010370016f,  0.5018045902f,  0.5030835867f,  0.5050826669f,
         0.5077480078f,  0.5091921091f,  0.5094215274f,  0.5060614347f,  0.4939221144f,
         0.4625603855f,  0.4223127365f,  0.3585619032f,  0.2725897431f,  0.1494219303f,
         0.0000000000f,  -0.1494219303f, -0.2725897431f, -0.3585619330f, -0.4223127365f,
         -0.4625604451f, -0.4939220548f, -0.5060613751f, -0.5094215274f, -0.5091921091f,
         -0.5077479482f, -0.5050827861f, -0.5030835867f, -0.5018045902f, -0.5010369420f,
         -0.5000000000f}},
    {

        {0.5000000000f,  0.4999683797f,  0.4999000132f,  0.4996838570f,  0.4990009665f,
         0.4968476892f,  0.4937299490f,  0.4875672758f,  0.4754966497f,  0.4522733092f,
         0.4090909064f,  0.3631930947f,  0.2992399931f,  0.2152527571f,  0.1131368354f,
         0.0000000000f,  -0.1131368279f, -0.2152527720f, -0.2992399931f, -0.3631930947f,
         -0.4090909064f, -0.4522732794f, -0.4754966199f, -0.4875672758f, -0.4937299788f,
         -0.4968476892f, -0.4990009964f, -0.4996838868f, -0.4999000132f, -0.4999683797f,
         -0.5000000000f},
        {0.5000000000f,  0.4999683797f,  0.4999000132f,  0.4996838570f,  0.4990009665f,
         0.4968476892f,  0.4937299490f,  0.4875672758f,  0.4754966497f,  0.4522733092f,
         0.4090909064f,  0.3631930947f,  0.2992399931f,  0.2152527571f,  0.1131368354f,
         0.0000000000f,  -0.1131368279f, -0.2152527720f, -0.2992399931f, -0.3631930947f,
         -0.4090909064f, -0.4522732794f, -0.4754966199f, -0.4875672758f, -0.4937299788f,
         -0.4968476892f, -0.4990009964f, -0.4996838868f, -0.4999000132f, -0.4999683797f,
         -0.5000000000f},
        {0.5000000000f,  0.4999683797f,  0.4999000132f,  0.4996838570f,  0.4990009665f,
         0.4968476892f,  0.4937299490f,  0.4875672758f,  0.4754966497f,  0.4522733092f,
         0.4090909064f,  0.3631930947f,  0.2992399931f,  0.2152527571f,  0.1131368279f,
         0.0000000000f,  -0.1131368279f, -0.2152527571f, -0.2992399931f, -0.3631930947f,
         -0.4090909064f, -0.4522732794f, -0.4754966199f, -0.4875672758f, -0.4937299788f,
         -0.4968476892f, -0.4990009964f, -0.4996838868f, -0.4999000132f, -0.4999683797f,
         -0.5000000000f},
        {0.5000000000f,  0.4999683797f,  0.4999000132f,  0.4996838570f,  0.4990009665f,
         0.4968476892f,  0.4937299490f,  0.4875672758f,  0.4754966497f,  0.4522733092f,
         0.4090909064f,  0.3631930947f,  0.2992399931f,  0.2152527571f,  0.1131368279f,
         0.0000000000f,  -0.1131368279f, -0.2152527571f, -0.2992399931f, -0.3631930947f,
         -0.4090909064f, -0.4522732794f, -0.4754966199f, -0.4875672758f, -0.4937299788f,
         -0.4968476892f, -0.4990009964f, -0.4996838868f, -0.4999000132f, -0.4999683797f,
         -0.5000000000f},
        {0.5000000000f,  0.4999683797f,  0.4999000132f,  0.4996838570f,  0.4990009665f,
         0.4968476892f,  0.4937299490f,  0.4875672758f,  0.4754966497f,  0.4522733092f,
         0.4090909064f,  0.3631930947f,  0.2992399931f,  0.2152527571f,  0.1131368279f,
         0.0000000000f,  -0.1131368279f, -0.2152527571f, -0.2992399931f, -0.3631930947f,
         -0.4090909064f, -0.4522732794f, -0.4754966199f, -0.4875672758f, -0.4937299788f,
         -0.4968476892f, -0.4990009964f, -0.4996838868f, -0.4999000132f, -0.4999683797f,
         -0.5000000000f},
        {0.5000000000f,  0.4999683797f,  0.4999000132f,  0.4996838570f,  0.4990009665f,
         0.4968476892f,  0.4937299490f,  0.4875672758f,  0.4754966497f,  0.4522733092f,
         0.4090909064f,  0.3631930947f,  0.2992399931f,  0.2152527571f,  0.1131368279f,
         0.0000000000f,  -0.1131368279f, -0.2152527571f, -0.2992399931f, -0.3631930947f,
         -0.4090909064f, -0.4522732794f, -0.4754966199f, -0.4875672758f, -0.4937299788f,
         -0.4968476892f, -0.4990009964f, -0.4996838868f, -0.4999000132f, -0.4999683797f,
         -0.5000000000f},
        {0.5000000000f,  0.4999683797f,  0.4999000132f,  0.4996838570f,  0.4990009665f,
         0.4968476892f,  0.4937299490f,  0.4875672758f,  0.4754966497f,  0.4522733092f,
         0.4090909064f,  0.3631930947f,  0.2992399931f,  0.2152527571f,  0.1131368279f,
         0.0000000000f,  -0.1131368279f, -0.2152527571f, -0.2992399931f, -0.3631930947f,
         -0.4090909064f, -0.4522732794f, -0.4754966199f, -0.4875672758f, -0.4937299788f,
         -0.4968476892f, -0.4990009964f, -0.4996838868f, -0.4999000132f, -0.4999683797f,
         -0.5000000000f},
        {0.5000000000f,  0.4999683797f,  0.4999000132f,  0.4996838570f,  0.4990009665f,
         0.4968476892f,  0.4937299490f,  0.4875672758f,  0.4754966497f,  0.4522733092f,
         0.4090909064f,  0.3631930947f,  0.2992399931f,  0.2152527571f,  0.1131368354f,
         0.0000000000f,  -0.1131368279f, -0.2152527869f, -0.2992399931f, -0.3631930947f,
         -0.4090909064f, -0.4522732794f, -0.4754966199f, -0.4875672758f, -0.4937299788f,
         -0.4968476892f, -0.4990009964f, -0.4996838868f, -0.4999000132f, -0.4999683797f,
         -0.5000000000f}},
    {

        {0.5000000000f,  0.5010477901f,  0.5018239021f,  0.5031182766f,  0.5051452518f,
         0.5078617930f,  0.5093557239f,  0.5096575022f,  0.5064008832f,  0.4944033921f,
         0.4632124305f,  0.4230656624f,  0.3596195877f,  0.2740280628f,  0.1503099203f,
         0.0000000000f,  -0.1503099054f, -0.2740280628f, -0.3596195877f, -0.4230656624f,
         -0.4632123709f, -0.4944033921f, -0.5064008832f, -0.5096574426f, -0.5093557239f,
         -0.5078617930f, -0.5051453114f, -0.5031182766f, -0.5018239021f, -0.5010477304f,
         -0.5000000000f},
        {0.5000000000f,  0.5009795427f,  0.5017020702f,  0.5028998852f,  0.5047514439f,
         0.5071461797f,  0.5083272457f,  0.5081763268f,  0.5042734742f,  0.4913944900f,
         0.4591502845f,  0.4183884561f,  0.3544511199f,  0.2652116716f,  0.1448854357f,
         0.0000000000f,  -0.1448854357f, -0.2652117014f, -0.3544511199f, -0.4183884561f,
         -0.4591503441f, -0.4913944900f, -0.5042734742f, -0.5081762671f, -0.5083272457f,
         -0.5071461797f, -0.5047514439f, -0.5028998852f, -0.5017020702f, -0.5009795427f,
         -0.5000000000f},
        {0.5000000000f,  0.5008758903f,  0.5015168786f,  0.5025681257f,  0.5041542053f,
         0.5060635209f,  0.5067747831f,  0.5059480071f,  0.5010886192f,  0.4869216383f,
         0.4531719685f,  0.4115628898f,  0.3473646939f,  0.2555567026f,  0.1373466253f,
         0.0000000000f,  -0.1373466253f, -0.2555567324f, -0.3473647237f, -0.4115628898f,
         -0.4531719685f, -0.4869215786f, -0.5010885596f, -0.5059480071f, -0.5067747831f,
         -0.5060635209f, -0.5041542053f, -0.5025681257f, -0.5015168786f, -0.5008758307f,
         -0.5000000000f},
        {0.5000000000f,  0.5006161928f,  0.5010534525f,  0.5017392039f,  0.5026661158f,
         0.5033791661f,  0.5029437542f,  0.5004871488f,  0.4933607578f,  0.4762222767f,
         0.4391518533f,  0.3958169818f,  0.3313112259f,  0.2418053150f,  0.1284317821f,
         0.0000000000f,  -0.1284317672f, -0.2418053150f, -0.3313111961f, -0.3958169818f,
         -0.4391519129f, -0.4762222767f, -0.4933606982f, -0.5004870892f, -0.5029437542f,
         -0.5033791065f, -0.5026661158f, -0.5017392635f, -0.5010534525f, -0.5006161332f,
         -0.5000000000f},
        {0.5000000000f,  0.5003644228f,  0.5006047487f,  0.5009382963f,  0.5012336969f,
         0.5008131266f,  0.4993060529f,  0.4953505993f,  0.4861895740f,  0.4664809406f,
         0.4267134070f,  0.3821379840f,  0.3176780939f,  0.2303762883f,  0.1217892319f,
         0.0000000000f,  -0.1217892170f, -0.2303763181f, -0.3176780939f, -0.3821379840f,
         -0.4267134368f, -0.4664809406f, -0.4861895442f, -0.4953505993f, -0.4993061125f,
         -0.5008131266f, -0.5012336969f, -0.5009382963f, -0.5006047487f, -0.5003644228f,
         -0.5000000000f},
        {0.5000000000f,  0.4999683797f,  0.4999000132f,  0.4996838570f,  0.4990009665f,
         0.4968476892f,  0.4937299490f,  0.4875672758f,  0.4754966497f,  0.4522733092f,
         0.4090909064f,  0.3631930947f,  0.2992399931f,  0.2152527571f,  0.1131368279f,
         0.0000000000f,  -0.1131368279f, -0.2152527571f, -0.2992399931f, -0.3631930947f,
         -0.4090909064f, -0.4522732794f, -0.4754966199f, -0.4875672758f, -0.4937299788f,
         -0.4968476892f, -0.4990009964f, -0.4996838868f, -0.4999000132f, -0.4999683797f,
         -0.5000000000f},
        {0.5000000000f,  0.4993358850f,  0.4987771511f,  0.4976935983f,  0.4954852760f,
         0.4906864166f,  0.4851732254f,  0.4758279026f,  0.4597451985f,  0.4319911301f,
         0.3849090934f,  0.3379579186f,  0.2754054368f,  0.1962166280f,  0.1024479866f,
         0.0000000000f,  -0.1024479717f, -0.1962166429f, -0.2754054368f, -0.3379579186f,
         -0.3849091232f, -0.4319911599f, -0.4597451687f, -0.4758278131f, -0.4851732850f,
         -0.4906864166f, -0.4954852760f, -0.4976935983f, -0.4987771511f, -0.4993358552f,
         -0.5000000000f},
        {0.5000000000f,  0.4989066720f,  0.4980169535f,  0.4963521063f,  0.4931337833f,
         0.4866205156f,  0.4795958996f,  0.4683040977f,  0.4498755038f,  0.4196476638f,
         0.3707037568f,  0.3235089481f,  0.2620966136f,  0.1858148128f,  0.0966935381f,
         0.0000000000f,  -0.0966935307f, -0.1858148277f, -0.2620966136f, -0.3235089481f,
         -0.3707037866f, -0.4196476638f, -0.4498754740f, -0.4683040380f, -0.4795959294f,
         -0.4866205454f, -0.4931338131f, -0.4963521063f, -0.4980169237f, -0.4989066422f,
         -0.5000000000f}},
    {

        {0.5000000596f,  0.5019683242f,  0.5034724474f,  0.5060860515f,  0.5105357766f,
         0.5177959800f,  0.5238327980f,  0.5309391022f,  0.5379270315f,  0.5411472321f,
         0.5744604468f,  0.5888173580f,  0.5752269030f,  0.4958270490f,  0.3029264808f,
         0.0000000000f,  -0.3029264808f, -0.4958269894f, -0.5752269030f, -0.5888173580f,
         -0.5744604468f, -0.5411472321f, -0.5379270315f, -0.5309391022f, -0.5238327980f,
         -0.5177959800f, -0.5105358362f, -0.5060860515f, -0.5034723878f, -0.5019683242f,
         -0.5000000596f},
        {0.5000000596f,  0.5018416047f,  0.5032451153f,  0.5056754351f,  0.5097854137f,
         0.5163972378f,  0.5217715502f,  0.5278583169f,  0.5332472920f,  0.5339364409f,
         0.5506924391f,  0.5557163954f,  0.5314731002f,  0.4462319613f,  0.2658600509f,
         0.0000000000f,  -0.2658600509f, -0.4462319613f, -0.5314732194f, -0.5557163954f,
         -0.5506924391f, -0.5339364409f, -0.5332472920f, -0.5278582573f, -0.5217716098f,
         -0.5163972378f, -0.5097853541f, -0.5056754351f, -0.5032451153f, -0.5018416047f,
         -0.5000000596f},
        {0.5000000596f,  0.5016490817f,  0.5028999448f,  0.5050527453f,  0.5086503625f,
         0.5142914653f,  0.5186827183f,  0.5232735872f,  0.5263579488f,  0.5235015154f,
         0.5180896521f,  0.5119441748f,  0.4763633013f,  0.3873093724f,  0.2241453975f,
         0.0000000000f,  -0.2241454273f, -0.3873093724f, -0.4763633311f, -0.5119441748f,
         -0.5180897117f, -0.5235014558f, -0.5263578892f, -0.5232735872f, -0.5186827183f,
         -0.5142914653f, -0.5086504221f, -0.5050527453f, -0.5028999448f, -0.5016490817f,
         -0.5000000596f},
        {0.5000000000f,  0.5011672974f,  0.5020375848f,  0.5035016537f,  0.5058373213f,
         0.5091226101f,  0.5111725330f,  0.5122836232f,  0.5101932287f,  0.4998099208f,
         0.4705953598f,  0.4316509366f,  0.3780660629f,  0.2909714878f,  0.1608594358f,
         0.0000000000f,  -0.1608594209f, -0.2909714878f, -0.3780660927f, -0.4316509366f,
         -0.4705953598f, -0.4998098612f, -0.5101932287f, -0.5122836232f, -0.5111725926f,
         -0.5091226101f, -0.5058373213f, -0.5035016537f, -0.5020375848f, -0.5011672974f,
         -0.5000000000f},
        {0.5000000000f,  0.5007008314f,  0.5012044907f,  0.5020091534f,  0.5031501055f,
         0.5042502880f,  0.5041841865f,  0.5022494197f,  0.4958427250f,  0.4796353579f,
         0.4435822964f,  0.4007542133f,  0.3363020420f,  0.2460453212f,  0.1309203655f,
         0.0000000000f,  -0.1309203506f, -0.2460453212f, -0.3363020718f, -0.4007542133f,
         -0.4435823560f, -0.4796352983f, -0.4958426654f, -0.5022494197f, -0.5041842461f,
         -0.5042502880f, -0.5031501651f, -0.5020092130f, -0.5012044907f, -0.5007008314f,
         -0.5000000000f},
        {0.5000000000f,  0.4999683797f,  0.4999000132f,  0.4996838570f,  0.4990009665f,
         0.4968476892f,  0.4937299490f,  0.4875672758f,  0.4754966497f,  0.4522733092f,
         0.4090909064f,  0.3631930947f,  0.2992399931f,  0.2152527571f,  0.1131368279f,
         0.0000000000f,  -0.1131368279f, -0.2152527571f, -0.2992399931f, -0.3631930947f,
         -0.4090909064f, -0.4522732794f, -0.4754966199f, -0.4875672758f, -0.4937299788f,
         -0.4968476892f, -0.4990009964f, -0.4996838868f, -0.4999000132f, -0.4999683797f,
         -0.5000000000f},
        {0.5000000000f,  0.4988015890f,  0.4978311360f,  0.4960248172f,  0.4925622642f,
         0.4856388867f,  0.4782574177f,  0.4665130377f,  0.4475508630f,  0.4167790711f,
         0.3674541414f,  0.3202401102f,  0.2591174543f,  0.1835071146f,  0.0954245627f,
         0.0000000000f,  -0.0954245627f, -0.1835071146f, -0.2591174543f, -0.3202401102f,
         -0.3674541414f, -0.4167790413f, -0.4475508630f, -0.4665130079f, -0.4782574475f,
         -0.4856388569f, -0.4925622940f, -0.4960248470f, -0.4978311062f, -0.4988015294f,
         -0.5000000000f},
        {0.5000000000f,  0.4980117977f,  0.4964371324f,  0.4935791790f,  0.4883186519f,
         0.4784279168f,  0.4685191810f,  0.4536466599f,  0.4311205149f,  0.3969023824f,
         0.3454375863f,  0.2984294593f,  0.2395204306f,  0.1685037017f,  0.0872381777f,
         0.0000000000f,  -0.0872381777f, -0.1685037017f, -0.2395204306f, -0.2984294891f,
         -0.3454375863f, -0.3969023824f, -0.4311204851f, -0.4536466599f, -0.4685192108f,
         -0.4784279168f, -0.4883186519f, -0.4935792387f, -0.4964371920f, -0.4980118275f,
         -0.5000000000f}},
    {

        {0.5000000596f,  0.5025862455f,  0.5045830011f,  0.5080985427f,  0.5142353773f,
         0.5247681141f,  0.5342236161f,  0.5467404723f,  0.5625994205f,  0.6218548417f,
         0.7271847725f,  0.8291400671f,  0.9596735835f,  1.0798219442f,  0.9420299530f,
         0.0000000000f,  -0.9420303106f, -1.0798217058f, -0.9596738815f, -0.8291401863f,
         -0.7271848917f, -0.6218547821f, -0.5625994205f, -0.5467404127f, -0.5342236161f,
         -0.5247680545f, -0.5142353773f, -0.5080985427f, -0.5045830011f, -0.5025862455f,
         -0.5000000596f},
        {0.5000000596f,  0.5024200678f,  0.5042841434f,  0.5075557828f,  0.5132341385f,
         0.5228683949f,  0.5313730240f,  0.5423596501f,  0.5556432009f,  0.5973936319f,
         0.6787342429f,  0.7472499609f,  0.8136605620f,  0.8203776479f,  0.6013670564f,
         0.0000000000f,  -0.6013671160f, -0.8203776479f, -0.8136607409f, -0.7472500801f,
         -0.6787342429f, -0.5973935723f, -0.5556432009f, -0.5423595905f, -0.5313730240f,
         -0.5228683949f, -0.5132341385f, -0.5075558424f, -0.5042841434f, -0.5024200678f,
         -0.5000000596f},
        {0.5000000596f,  0.5021677613f,  0.5038304925f,  0.5067336559f,  0.5117224455f,
         0.5200182796f,  0.5271236300f,  0.5358940363f,  0.5455409884f,  0.5636704564f,
         0.6162818074f,  0.6496601105f,  0.6607547998f,  0.6008188725f,  0.3879746199f,
         0.0000000000f,  -0.3879747093f, -0.6008188725f, -0.6607549191f, -0.6496600509f,
         -0.6162818670f, -0.5636703968f, -0.5455409288f, -0.5358939767f, -0.5271236897f,
         -0.5200182796f, -0.5117224455f, -0.5067337155f, -0.5038304925f, -0.5021677017f,
         -0.5000000596f},
        {0.5000000596f,  0.5015365481f,  0.5026984215f,  0.5046897531f,  0.5079899430f,
         0.5130717754f,  0.5169013739f,  0.5206471086f,  0.5224504471f,  0.5176750422f,
         0.5007511973f,  0.4893990755f,  0.4491262436f,  0.3595432043f,  0.2053054571f,
         0.0000000000f,  -0.2053054571f, -0.3595432043f, -0.4491263032f, -0.4893990755f,
         -0.5007511973f, -0.5176750422f, -0.5224504471f, -0.5206470490f, -0.5169014335f,
         -0.5130717754f, -0.5079900026f, -0.5046896935f, -0.5026984215f, -0.5015365481f,
         -0.5000000596f},
        {0.5000000000f,  0.5009260774f,  0.5016064644f,  0.5027285814f,  0.5044430494f,
         0.5065867305f,  0.5075244904f,  0.5070229173f,  0.5026227236f,  0.4890713692f,
         0.4560364485f,  0.4148247242f,  0.3507413268f,  0.2586806417f,  0.1408952773f,
         0.0000000000f,  -0.1408952773f, -0.2586806417f, -0.3507413268f, -0.4148246944f,
         -0.4560364783f, -0.4890713692f, -0.5026226640f, -0.5070229173f, -0.5075244904f,
         -0.5065867305f, -0.5044430494f, -0.5027285814f, -0.5016064644f, -0.5009260178f,
         -0.5000000000f},
        {0.5000000000f,  0.4999683797f,  0.4999000132f,  0.4996838570f,  0.4990009665f,
         0.4968476892f,  0.4937299490f,  0.4875672758f,  0.4754966497f,  0.4522733092f,
         0.4090909064f,  0.3631930947f,  0.2992399931f,  0.2152527571f,  0.1131368279f,
         0.0000000000f,  -0.1131368279f, -0.2152527571f, -0.2992399931f, -0.3631930947f,
         -0.4090909064f, -0.4522732794f, -0.4754966199f, -0.4875672758f, -0.4937299788f,
         -0.4968476892f, -0.4990009964f, -0.4996838868f, -0.4999000132f, -0.4999683797f,
         -0.5000000000f},
        {0.5000000000f,  0.4984455407f,  0.4972019792f,  0.4949190915f,  0.4906377792f,
         0.4823517799f,  0.4737979174f,  0.4605855942f,  0.4399236441f,  0.4074669182f,
         0.3570330739f,  0.3098451197f,  0.2497179806f,  0.1762735248f,  0.0914641768f,
         0.0000000000f,  -0.0914641768f, -0.1762735248f, -0.2497179955f, -0.3098450899f,
         -0.3570331335f, -0.4074669182f, -0.4399236441f, -0.4605855346f, -0.4737979472f,
         -0.4823517799f, -0.4906377792f, -0.4949190915f, -0.4972020090f, -0.4984455109f,
         -0.5000000000f},
        {0.5000000000f,  0.4974165857f,  0.4953899384f,  0.4917520583f,  0.4851788282f,
         0.4731788635f,  0.4615318775f,  0.4445866942f,  0.4198218584f,  0.3836160004f,
         0.3311764300f,  0.2845952809f,  0.2273271382f,  0.1593134999f,  0.0822749436f,
         0.0000000000f,  -0.0822749436f, -0.1593135148f, -0.2273271531f, -0.2845952809f,
         -0.3311764300f, -0.3836159706f, -0.4198218286f, -0.4445866644f, -0.4615319073f,
         -0.4731788635f, -0.4851788580f, -0.4917520583f, -0.4953899384f, -0.4974165857f,
         -0.5000000000f}},
    {

        {0.5000000596f,  0.5028037429f,  0.5049747825f,  0.5088109374f,  0.5155536532f,
         0.5272840858f,  0.5380216837f,  0.5526331663f,  0.5736158490f,  0.6570396423f,
         0.8020626903f,  0.9678543210f,  1.2539665699f,  1.8414286375f,  3.6350917816f,
         -3.2000000477f, -3.6350977421f, -1.8414278030f, -1.2539669275f, -0.9678544402f,
         -0.8020627499f, -0.6570395231f, -0.5736158490f, -0.5526331663f, -0.5380217433f,
         -0.5272840261f, -0.5155536532f, -0.5088109374f, -0.5049747825f, -0.5028037429f,
         -0.5000000596f},
        {0.5000000596f,  0.5026236773f,  0.5046505332f,  0.5082210898f,  0.5144618750f,
         0.5251991153f,  0.5348724723f,  0.5477427244f,  0.5642039180f,  0.6276481748f,
         0.7390776277f,  0.8501415253f,  1.0001310110f,  1.1627105474f,  1.0799337626f,
         0.0000000000f,  -1.0799342394f, -1.1627105474f, -1.0001313686f, -0.8501416445f,
         -0.7390776873f, -0.6276481152f, -0.5642039180f, -0.5477426648f, -0.5348724723f,
         -0.5251991153f, -0.5144618750f, -0.5082210898f, -0.5046504736f, -0.5026236773f,
         -0.5000000596f},
        {0.5000000596f,  0.5023502707f,  0.5041584373f,  0.5073279142f,  0.5128144622f,
         0.5220750570f,  0.5301869512f,  0.5405472517f,  0.5527920127f,  0.5876652598f,
         0.6602216363f,  0.7174301744f,  0.7646963000f,  0.7450429201f,  0.5219343901f,
         0.0000000000f,  -0.5219346285f, -0.7450428605f, -0.7646964192f, -0.7174301744f,
         -0.6602216959f, -0.5876652002f, -0.5527919531f, -0.5405471921f, -0.5301870108f,
         -0.5220750570f, -0.5128144622f, -0.5073279142f, -0.5041584969f, -0.5023502111f,
         -0.5000000596f},
        {0.5000000596f,  0.5016664267f,  0.5029309988f,  0.5051088333f,  0.5087524056f,
         0.5144805312f,  0.5189592838f,  0.5236825943f,  0.5269688368f,  0.5244184136f,
         0.5208731890f,  0.5156101584f,  0.4808640778f,  0.3919814229f,  0.2273655832f,
         0.0000000000f,  -0.2273655832f, -0.3919814229f, -0.4808641970f, -0.5156101584f,
         -0.5208732486f, -0.5244183540f, -0.5269688368f, -0.5236825347f, -0.5189592838f,
         -0.5144804716f, -0.5087524652f, -0.5051088929f, -0.5029310584f, -0.5016664267f,
         -0.5000000596f},
        {0.5000000000f,  0.5010051727f,  0.5017478466f,  0.5029819608f,  0.5048993826f,
         0.5074149370f,  0.5087133050f,  0.5087317824f,  0.5050703287f,  0.4925194979f,
         0.4606651962f,  0.4201289415f,  0.3562709987f,  0.2684594989f,  0.1468786299f,
         0.0000000000f,  -0.1468786299f, -0.2684595585f, -0.3562710285f, -0.4201289117f,
         -0.4606651962f, -0.4925194383f, -0.5050702691f, -0.5087317824f, -0.5087133050f,
         -0.5074148774f, -0.5048993826f, -0.5029820204f, -0.5017478466f, -0.5010051727f,
         -0.5000000000f},
        {0.5000000000f,  0.4999683797f,  0.4999000132f,  0.4996838570f,  0.4990009665f,
         0.4968476892f,  0.4937299490f,  0.4875672758f,  0.4754966497f,  0.4522733092f,
         0.4090909064f,  0.3631930947f,  0.2992399931f,  0.2152527571f,  0.1131368279f,
         0.0000000000f,  -0.1131368279f, -0.2152527571f, -0.2992399931f, -0.3631930947f,
         -0.4090909064f, -0.4522732794f, -0.4754966199f, -0.4875672758f, -0.4937299788f,
         -0.4968476892f, -0.4990009964f, -0.4996838868f, -0.4999000132f, -0.4999683797f,
         -0.5000000000f},
        {0.5000000000f,  0.4983206391f,  0.4969816804f,  0.4945325255f,  0.4899673164f,
         0.4812132120f,  0.4722613096f,  0.4585570693f,  0.4373364151f,  0.4043420255f,
         0.3535786867f,  0.3064280450f,  0.2466521561f,  0.1739292294f,  0.0901861414f,
         0.0000000000f,  -0.0901861340f, -0.1739292443f, -0.2466521412f, -0.3064280450f,
         -0.3535786867f, -0.4043420255f, -0.4373364449f, -0.4585570395f, -0.4722613096f,
         -0.4812132120f, -0.4899673462f, -0.4945325553f, -0.4969816506f, -0.4983206391f,
         -0.5000000000f},
        {0.5000000000f,  0.4972080886f,  0.4950237870f,  0.4911153018f,  0.4840905368f,
         0.4713762403f,  0.4591514468f,  0.4415317178f,  0.4160600305f,  0.3792575300f,
         0.3265722692f,  0.2801750302f,  0.2234674245f,  0.1564260125f,  0.0807230473f,
         0.0000000000f,  -0.0807230398f, -0.1564260125f, -0.2234674245f, -0.2801750600f,
         -0.3265722394f, -0.3792575002f, -0.4160600007f, -0.4415317178f, -0.4591514468f,
         -0.4713762403f, -0.4840905368f, -0.4911153018f, -0.4950237870f, -0.4972080886f,
         -0.5000000000f}},
    {

        {0.5000000596f,  0.5025862455f,  0.5045830011f,  0.5080985427f,  0.5142353773f,
         0.5247681141f,  0.5342236161f,  0.5467404723f,  0.5625994205f,  0.6218548417f,
         0.7271847725f,  0.8291400671f,  0.9596735835f,  1.0798219442f,  0.9420299530f,
         0.0000000000f,  -0.9420303106f, -1.0798217058f, -0.9596738815f, -0.8291401863f,
         -0.7271848917f, -0.6218547821f, -0.5625994205f, -0.5467404127f, -0.5342236161f,
         -0.5247680545f, -0.5142353773f, -0.5080985427f, -0.5045830011f, -0.5025862455f,
         -0.5000000596f},
        {0.5000000596f,  0.5024200678f,  0.5042841434f,  0.5075557828f,  0.5132341385f,
         0.5228683949f,  0.5313730240f,  0.5423596501f,  0.5556432009f,  0.5973936319f,
         0.6787342429f,  0.7472499609f,  0.8136605620f,  0.8203776479f,  0.6013670564f,
         0.0000000000f,  -0.6013671160f, -0.8203776479f, -0.8136607409f, -0.7472500801f,
         -0.6787342429f, -0.5973935723f, -0.5556432009f, -0.5423595905f, -0.5313730240f,
         -0.5228683949f, -0.5132341385f, -0.5075558424f, -0.5042841434f, -0.5024200678f,
         -0.5000000596f},
        {0.5000000596f,  0.5021677613f,  0.5038304925f,  0.5067336559f,  0.5117224455f,
         0.5200182796f,  0.5271236300f,  0.5358940363f,  0.5455409884f,  0.5636704564f,
         0.6162818074f,  0.6496601105f,  0.6607547998f,  0.6008188725f,  0.3879746199f,
         0.0000000000f,  -0.3879747093f, -0.6008188725f, -0.6607549191f, -0.6496600509f,
         -0.6162818670f, -0.5636703968f, -0.5455409288f, -0.5358939767f, -0.5271236897f,
         -0.5200182796f, -0.5117224455f, -0.5067337155f, -0.5038304925f, -0.5021677017f,
         -0.5000000596f},
        {0.5000000596f,  0.5015365481f,  0.5026984215f,  0.5046897531f,  0.5079899430f,
         0.5130717754f,  0.5169013739f,  0.5206471086f,  0.5224504471f,  0.5176750422f,
         0.5007511973f,  0.4893990755f,  0.4491262436f,  0.3595432043f,  0.2053054571f,
         0.0000000000f,  -0.2053054571f, -0.3595432043f, -0.4491263032f, -0.4893990755f,
         -0.5007511973f, -0.5176750422f, -0.5224504471f, -0.5206470490f, -0.5169014335f,
         -0.5130717754f, -0.5079900026f, -0.5046896935f, -0.5026984215f, -0.5015365481f,
         -0.5000000596f},
        {0.5000000000f,  0.5009260774f,  0.5016064644f,  0.5027285814f,  0.5044430494f,
         0.5065867305f,  0.5075244904f,  0.5070229173f,  0.5026227236f,  0.4890713692f,
         0.4560364485f,  0.4148247242f,  0.3507413268f,  0.2586806417f,  0.1408952773f,
         0.0000000000f,  -0.1408952773f, -0.2586806417f, -0.3507413268f, -0.4148246944f,
         -0.4560364783f, -0.4890713692f, -0.5026226640f, -0.5070229173f, -0.5075244904f,
         -0.5065867305f, -0.5044430494f, -0.5027285814f, -0.5016064644f, -0.5009260178f,
         -0.5000000000f},
        {0.5000000000f,  0.4999683797f,  0.4999000132f,  0.4996838570f,  0.4990009665f,
         0.4968476892f,  0.4937299490f,  0.4875672758f,  0.4754966497f,  0.4522733092f,
         0.4090909064f,  0.3631930947f,  0.2992399931f,  0.2152527571f,  0.1131368279f,
         0.0000000000f,  -0.1131368279f, -0.2152527571f, -0.2992399931f, -0.3631930947f,
         -0.4090909064f, -0.4522732794f, -0.4754966199f, -0.4875672758f, -0.4937299788f,
         -0.4968476892f, -0.4990009964f, -0.4996838868f, -0.4999000132f, -0.4999683797f,
         -0.5000000000f},
        {0.5000000000f,  0.4984455407f,  0.4972019792f,  0.4949190915f,  0.4906377792f,
         0.4823517799f,  0.4737979174f,  0.4605855942f,  0.4399236441f,  0.4074669182f,
         0.3570330739f,  0.3098451197f,  0.2497179806f,  0.1762735248f,  0.0914641768f,
         0.0000000000f,  -0.0914641768f, -0.1762735248f, -0.2497179955f, -0.3098450899f,
         -0.3570331335f, -0.4074669182f, -0.4399236441f, -0.4605855346f, -0.4737979472f,
         -0.4823517799f, -0.4906377792f, -0.4949190915f, -0.4972020090f, -0.4984455109f,
         -0.5000000000f},
        {0.5000000000f,  0.4974165857f,  0.4953899384f,  0.4917520583f,  0.4851788282f,
         0.4731788635f,  0.4615318775f,  0.4445866942f,  0.4198218584f,  0.3836160004f,
         0.3311764300f,  0.2845952809f,  0.2273271382f,  0.1593134999f,  0.0822749436f,
         0.0000000000f,  -0.0822749436f, -0.1593135148f, -0.2273271531f, -0.2845952809f,
         -0.3311764300f, -0.3836159706f, -0.4198218286f, -0.4445866644f, -0.4615319073f,
         -0.4731788635f, -0.4851788580f, -0.4917520583f, -0.4953899384f, -0.4974165857f,
         -0.5000000000f}},
    {

        {0.5000000596f,  0.5019683242f,  0.5034724474f,  0.5060860515f,  0.5105357766f,
         0.5177959800f,  0.5238327980f,  0.5309391022f,  0.5379270911f,  0.5411472321f,
         0.5744605064f,  0.5888174176f,  0.5752269030f,  0.4958270788f,  0.3029264808f,
         0.0000000000f,  -0.3029265106f, -0.4958270490f, -0.5752269626f, -0.5888174772f,
         -0.5744605064f, -0.5411472321f, -0.5379270911f, -0.5309391022f, -0.5238327980f,
         -0.5177959800f, -0.5105358362f, -0.5060860515f, -0.5034723878f, -0.5019683242f,
         -0.5000000596f},
        {0.5000000596f,  0.5018416047f,  0.5032451153f,  0.5056754351f,  0.5097854137f,
         0.5163972378f,  0.5217715502f,  0.5278583169f,  0.5332472920f,  0.5339364409f,
         0.5506924391f,  0.5557163954f,  0.5314732194f,  0.4462319911f,  0.2658600807f,
         0.0000000000f,  -0.2658601105f, -0.4462319911f, -0.5314732790f, -0.5557164550f,
         -0.5506924391f, -0.5339364409f, -0.5332472920f, -0.5278582573f, -0.5217716098f,
         -0.5163972378f, -0.5097853541f, -0.5056754351f, -0.5032451153f, -0.5018416047f,
         -0.5000000596f},
        {0.5000000596f,  0.5016490817f,  0.5028999448f,  0.5050527453f,  0.5086503625f,
         0.5142914653f,  0.5186827183f,  0.5232735872f,  0.5263579488f,  0.5235015154f,
         0.5180896521f,  0.5119442344f,  0.4763633311f,  0.3873094022f,  0.2241454273f,
         0.0000000000f,  -0.2241454422f, -0.3873094022f, -0.4763633311f, -0.5119441748f,
         -0.5180897117f, -0.5235014558f, -0.5263578892f, -0.5232735872f, -0.5186827779f,
         -0.5142914653f, -0.5086504221f, -0.5050527453f, -0.5028999448f, -0.5016490817f,
         -0.5000000596f},
        {0.5000000000f,  0.5011672974f,  0.5020375848f,  0.5035016537f,  0.5058373213f,
         0.5091226101f,  0.5111725330f,  0.5122836232f,  0.5101932287f,  0.4998099208f,
         0.4705953300f,  0.4316509366f,  0.3780660927f,  0.2909715176f,  0.1608594507f,
         0.0000000000f,  -0.1608594358f, -0.2909715474f, -0.3780661225f, -0.4316509366f,
         -0.4705953598f, -0.4998098910f, -0.5101932287f, -0.5122836232f, -0.5111725926f,
         -0.5091226101f, -0.5058373213f, -0.5035016537f, -0.5020375848f, -0.5011672974f,
         -0.5000000000f},
        {0.5000000000f,  0.5007008314f,  0.5012044907f,  0.5020091534f,  0.5031501055f,
         0.5042502880f,  0.5041841865f,  0.5022494197f,  0.4958427250f,  0.4796353281f,
         0.4435823262f,  0.4007542133f,  0.3363020718f,  0.2460453361f,  0.1309203655f,
         0.0000000000f,  -0.1309203655f, -0.2460453361f, -0.3363020718f, -0.4007542133f,
         -0.4435823560f, -0.4796353281f, -0.4958426654f, -0.5022494197f, -0.5041842461f,
         -0.5042502880f, -0.5031501651f, -0.5020092130f, -0.5012044907f, -0.5007008314f,
         -0.5000000000f},
        {0.5000000000f,  0.4999683797f,  0.4999000132f,  0.4996838570f,  0.4990009665f,
         0.4968476892f,  0.4937299490f,  0.4875672758f,  0.4754966497f,  0.4522733092f,
         0.4090909064f,  0.3631930947f,  0.2992399931f,  0.2152527571f,  0.1131368279f,
         0.0000000000f,  -0.1131368279f, -0.2152527571f, -0.2992399931f, -0.3631930947f,
         -0.4090909064f, -0.4522732794f, -0.4754966199f, -0.4875672758f, -0.4937299788f,
         -0.4968476892f, -0.4990009964f, -0.4996838868f, -0.4999000132f, -0.4999683797f,
         -0.5000000000f},
        {0.5000000000f,  0.4988015890f,  0.4978311360f,  0.4960248172f,  0.4925622642f,
         0.4856388867f,  0.4782574177f,  0.4665130079f,  0.4475508630f,  0.4167790711f,
         0.3674541414f,  0.3202401102f,  0.2591174543f,  0.1835071146f,  0.0954245627f,
         0.0000000000f,  -0.0954245627f, -0.1835071146f, -0.2591174543f, -0.3202401102f,
         -0.3674541116f, -0.4167790413f, -0.4475508630f, -0.4665130079f, -0.4782574475f,
         -0.4856388569f, -0.4925622940f, -0.4960248470f, -0.4978311062f, -0.4988015294f,
         -0.5000000000f},
        {0.5000000000f,  0.4980117977f,  0.4964371324f,  0.4935791790f,  0.4883186519f,
         0.4784279168f,  0.4685191810f,  0.4536466300f,  0.4311205149f,  0.3969023824f,
         0.3454375863f,  0.2984294593f,  0.2395204306f,  0.1685037017f,  0.0872381777f,
         0.0000000000f,  -0.0872381777f, -0.1685037017f, -0.2395204306f, -0.2984294593f,
         -0.3454375863f, -0.3969023526f, -0.4311204851f, -0.4536466599f, -0.4685192108f,
         -0.4784279168f, -0.4883186519f, -0.4935792387f, -0.4964371920f, -0.4980118275f,
         -0.5000000000f}},
    {

        {0.5000000000f,  0.5010477901f,  0.5018239021f,  0.5031182766f,  0.5051453114f,
         0.5078617930f,  0.5093557239f,  0.5096575022f,  0.5064009428f,  0.4944033921f,
         0.4632124305f,  0.4230656624f,  0.3596196771f,  0.2740281522f,  0.1503099501f,
         0.0000000000f,  -0.1503099501f, -0.2740281820f, -0.3596196771f, -0.4230656624f,
         -0.4632124305f, -0.4944033921f, -0.5064008832f, -0.5096575022f, -0.5093557835f,
         -0.5078617930f, -0.5051452518f, -0.5031182766f, -0.5018239021f, -0.5010477304f,
         -0.5000000000f},
        {0.5000000000f,  0.5009795427f,  0.5017020702f,  0.5028998852f,  0.5047514439f,
         0.5071461797f,  0.5083272457f,  0.5081763268f,  0.5042734742f,  0.4913944900f,
         0.4591503739f,  0.4183884263f,  0.3544511497f,  0.2652117610f,  0.1448854804f,
         0.0000000000f,  -0.1448854804f, -0.2652117610f, -0.3544511199f, -0.4183884561f,
         -0.4591503739f, -0.4913944900f, -0.5042735338f, -0.5081762671f, -0.5083272457f,
         -0.5071461797f, -0.5047514439f, -0.5028998256f, -0.5017020702f, -0.5009795427f,
         -0.5000000000f},
        {0.5000000000f,  0.5008758903f,  0.5015168786f,  0.5025681257f,  0.5041542053f,
         0.5060635209f,  0.5067747831f,  0.5059480071f,  0.5010885596f,  0.4869216979f,
         0.4531719685f,  0.4115628898f,  0.3473647535f,  0.2555567026f,  0.1373466700f,
         0.0000000000f,  -0.1373466551f, -0.2555567324f, -0.3473647535f, -0.4115628600f,
         -0.4531720281f, -0.4869216383f, -0.5010885596f, -0.5059480071f, -0.5067747831f,
         -0.5060635209f, -0.5041542649f, -0.5025681257f, -0.5015168786f, -0.5008758307f,
         -0.5000000000f},
        {0.5000000000f,  0.5006161928f,  0.5010533929f,  0.5017392039f,  0.5026661158f,
         0.5033791661f,  0.5029437542f,  0.5004872084f,  0.4933607578f,  0.4762223363f,
         0.4391518831f,  0.3958170116f,  0.3313111961f,  0.2418053001f,  0.1284317970f,
         0.0000000000f,  -0.1284317821f, -0.2418053001f, -0.3313112259f, -0.3958170116f,
         -0.4391518831f, -0.4762222767f, -0.4933607578f, -0.5004871488f, -0.5029437542f,
         -0.5033791065f, -0.5026661158f, -0.5017392635f, -0.5010534525f, -0.5006161332f,
         -0.5000000000f},
        {0.5000000000f,  0.5003644228f,  0.5006047487f,  0.5009382963f,  0.5012336969f,
         0.5008131266f,  0.4993060529f,  0.4953506589f,  0.4861895740f,  0.4664809704f,
         0.4267134368f,  0.3821379840f,  0.3176781237f,  0.2303763181f,  0.1217892319f,
         0.0000000000f,  -0.1217892319f, -0.2303763330f, -0.3176781535f, -0.3821379840f,
         -0.4267134368f, -0.4664809406f, -0.4861895740f, -0.4953505993f, -0.4993061125f,
         -0.5008131266f, -0.5012336969f, -0.5009382963f, -0.5006047487f, -0.5003644228f,
         -0.5000000000f},
        {0.5000000000f,  0.4999683797f,  0.4999000132f,  0.4996838570f,  0.4990009665f,
         0.4968476892f,  0.4937299490f,  0.4875672758f,  0.4754966497f,  0.4522733092f,
         0.4090909064f,  0.3631930947f,  0.2992399931f,  0.2152527571f,  0.1131368279f,
         0.0000000000f,  -0.1131368279f, -0.2152527571f, -0.2992399931f, -0.3631930947f,
         -0.4090909064f, -0.4522732794f, -0.4754966199f, -0.4875672758f, -0.4937299788f,
         -0.4968476892f, -0.4990009964f, -0.4996838868f, -0.4999000132f, -0.4999683797f,
         -0.5000000000f},
        {0.5000000000f,  0.4993358850f,  0.4987771511f,  0.4976935983f,  0.4954852164f,
         0.4906864166f,  0.4851732254f,  0.4758279026f,  0.4597451985f,  0.4319911599f,
         0.3849090934f,  0.3379579186f,  0.2754054070f,  0.1962166131f,  0.1024479717f,
         0.0000000000f,  -0.1024479717f, -0.1962166280f, -0.2754054070f, -0.3379579186f,
         -0.3849091530f, -0.4319911599f, -0.4597451687f, -0.4758278131f, -0.4851732850f,
         -0.4906864166f, -0.4954852462f, -0.4976935983f, -0.4987771511f, -0.4993358850f,
         -0.5000000000f},
        {0.5000000000f,  0.4989066720f,  0.4980169535f,  0.4963521063f,  0.4931337833f,
         0.4866205156f,  0.4795958996f,  0.4683040977f,  0.4498754740f,  0.4196476638f,
         0.3707037270f,  0.3235089183f,  0.2620966136f,  0.1858147979f,  0.0966935307f,
         0.0000000000f,  -0.0966935158f, -0.1858148128f, -0.2620966136f, -0.3235089481f,
         -0.3707037270f, -0.4196476340f, -0.4498754442f, -0.4683040380f, -0.4795959294f,
         -0.4866205454f, -0.4931338131f, -0.4963521063f, -0.4980169237f, -0.4989066422f,
         -0.5000000000f}},
    {

        {0.5000000000f,  0.4999683797f,  0.4999000132f,  0.4996838570f,  0.4990009665f,
         0.4968476892f,  0.4937299490f,  0.4875672758f,  0.4754966497f,  0.4522733092f,
         0.4090909064f,  0.3631930947f,  0.2992399931f,  0.2152527571f,  0.1131368279f,
         0.0000000000f,  -0.1131368279f, -0.2152527571f, -0.2992399931f, -0.3631930947f,
         -0.4090909064f, -0.4522732794f, -0.4754966199f, -0.4875672758f, -0.4937299788f,
         -0.4968476892f, -0.4990009964f, -0.4996838868f, -0.4999000132f, -0.4999683797f,
         -0.5000000000f},
        {0.5000000000f,  0.4999683797f,  0.4999000132f,  0.4996838570f,  0.4990009665f,
         0.4968476892f,  0.4937299490f,  0.4875672758f,  0.4754966497f,  0.4522733092f,
         0.4090909064f,  0.3631930947f,  0.2992399931f,  0.2152527571f,  0.1131368279f,
         0.0000000000f,  -0.1131368279f, -0.2152527571f, -0.2992399931f, -0.3631930947f,
         -0.4090909064f, -0.4522732794f, -0.4754966199f, -0.4875672758f, -0.4937299788f,
         -0.4968476892f, -0.4990009964f, -0.4996838868f, -0.4999000132f, -0.4999683797f,
         -0.5000000000f},
        {0.5000000000f,  0.4999683797f,  0.4999000132f,  0.4996838570f,  0.4990009665f,
         0.4968476892f,  0.4937299490f,  0.4875672758f,  0.4754966497f,  0.4522733092f,
         0.4090909064f,  0.3631930947f,  0.2992399931f,  0.2152527571f,  0.1131368279f,
         0.0000000000f,  -0.1131368279f, -0.2152527571f, -0.2992399931f, -0.3631930947f,
         -0.4090909064f, -0.4522732794f, -0.4754966199f, -0.4875672758f, -0.4937299788f,
         -0.4968476892f, -0.4990009964f, -0.4996838868f, -0.4999000132f, -0.4999683797f,
         -0.5000000000f},
        {0.5000000000f,  0.4999683797f,  0.4999000132f,  0.4996838570f,  0.4990009665f,
         0.4968476892f,  0.4937299490f,  0.4875672758f,  0.4754966497f,  0.4522733092f,
         0.4090909064f,  0.3631930947f,  0.2992399931f,  0.2152527571f,  0.1131368279f,
         0.0000000000f,  -0.1131368279f, -0.2152527571f, -0.2992399931f, -0.3631930947f,
         -0.4090909064f, -0.4522732794f, -0.4754966199f, -0.4875672758f, -0.4937299788f,
         -0.4968476892f, -0.4990009964f, -0.4996838868f, -0.4999000132f, -0.4999683797f,
         -0.5000000000f},
        {0.5000000000f,  0.4999683797f,  0.4999000132f,  0.4996838570f,  0.4990009665f,
         0.4968476892f,  0.4937299490f,  0.4875672758f,  0.4754966497f,  0.4522733092f,
         0.4090909064f,  0.3631930947f,  0.2992399931f,  0.2152527571f,  0.1131368279f,
         0.0000000000f,  -0.1131368279f, -0.2152527571f, -0.2992399931f, -0.3631930947f,
         -0.4090909064f, -0.4522732794f, -0.4754966199f, -0.4875672758f, -0.4937299788f,
         -0.4968476892f, -0.4990009964f, -0.4996838868f, -0.4999000132f, -0.4999683797f,
         -0.5000000000f},
        {0.5000000000f,  0.4999683797f,  0.4999000132f,  0.4996838570f,  0.4990009665f,
         0.4968476892f,  0.4937299490f,  0.4875672758f,  0.4754966497f,  0.4522733092f,
         0.4090909064f,  0.3631930947f,  0.2992399931f,  0.2152527571f,  0.1131368279f,
         0.0000000000f,  -0.1131368279f, -0.2152527571f, -0.2992399931f, -0.3631930947f,
         -0.4090909064f, -0.4522732794f, -0.4754966199f, -0.4875672758f, -0.4937299788f,
         -0.4968476892f, -0.4990009964f, -0.4996838868f, -0.4999000132f, -0.4999683797f,
         -0.5000000000f},
        {0.5000000000f,  0.4999683797f,  0.4999000132f,  0.4996838570f,  0.4990009665f,
         0.4968476892f,  0.4937299490f,  0.4875672758f,  0.4754966497f,  0.4522733092f,
         0.4090909064f,  0.3631930947f,  0.2992399931f,  0.2152527571f,  0.1131368279f,
         0.0000000000f,  -0.1131368279f, -0.2152527571f, -0.2992399931f, -0.3631930947f,
         -0.4090909064f, -0.4522732794f, -0.4754966199f, -0.4875672758f, -0.4937299788f,
         -0.4968476892f, -0.4990009964f, -0.4996838868f, -0.4999000132f, -0.4999683797f,
         -0.5000000000f},
        {0.5000000000f,  0.4999683797f,  0.4999000132f,  0.4996838570f,  0.4990009665f,
         0.4968476892f,  0.4937299490f,  0.4875672758f,  0.4754966497f,  0.4522733092f,
         0.4090909064f,  0.3631930947f,  0.2992399931f,  0.2152527571f,  0.1131368279f,
         0.0000000000f,  -0.1131368279f, -0.2152527571f, -0.2992399931f, -0.3631930947f,
         -0.4090909064f, -0.4522732794f, -0.4754966199f, -0.4875672758f, -0.4937299788f,
         -0.4968476892f, -0.4990009964f, -0.4996838868f, -0.4999000132f, -0.4999683797f,
         -0.5000000000f}},
    {

        {0.5000000000f,  0.4988959730f,  0.4979980290f,  0.4963187873f,  0.4930755794f,
         0.4865204096f,  0.4794592559f,  0.4681210220f,  0.4496374130f,  0.4193531871f,
         0.3703692853f,  0.3231719136f,  0.2617889047f,  0.1855761111f,  0.0965621620f,
         0.0000000000f,  -0.0965621546f, -0.1855761409f, -0.2617889345f, -0.3231719136f,
         -0.3703693151f, -0.4193531871f, -0.4496374130f, -0.4681210220f, -0.4794592857f,
         -0.4865204096f, -0.4930756390f, -0.4963187873f, -0.4979980290f, -0.4988959432f,
         -0.5000000000f},
        {0.5000000000f,  0.4989632964f,  0.4981172681f,  0.4965288043f,  0.4934426546f,
         0.4871520996f,  0.4803220332f,  0.4692780674f,  0.4511435628f,  0.4212186337f,
         0.3724914193f,  0.3253129125f,  0.2637456059f,  0.1870953143f,  0.0973988548f,
         0.0000000000f,  -0.0973988473f, -0.1870953292f, -0.2637456059f, -0.3253128827f,
         -0.3724914193f, -0.4212186038f, -0.4511435330f, -0.4692780375f, -0.4803220928f,
         -0.4871520996f, -0.4934426844f, -0.4965288043f, -0.4981172979f, -0.4989632666f,
         -0.5000000000f},
        {0.5000000000f,  0.4990658462f,  0.4982986450f,  0.4968487024f,  0.4940025806f,
         0.4881176353f,  0.4816432595f,  0.4710544348f,  0.4534637332f,  0.4241041243f,
         0.3757902384f,  0.3286523819f,  0.2668075860f,  0.1894792318f,  0.0987142026f,
         0.0000000000f,  -0.0987141877f, -0.1894792318f, -0.2668075860f, -0.3286523819f,
         -0.3757902384f, -0.4241040945f, -0.4534636736f, -0.4710544348f, -0.4816432893f,
         -0.4881176651f, -0.4940026104f, -0.4968487322f, -0.4982987046f, -0.4990658164f,
         -0.5000000000f},
        {0.5000000000f,  0.4993230999f,  0.4987545311f,  0.4976536036f,  0.4954148531f,
         0.4905641079f,  0.4850046337f,  0.4755989015f,  0.4594423175f,  0.4316083491f,
         0.3844630420f,  0.3375000954f,  0.2749801576f,  0.1958818436f,  0.1022618562f,
         0.0000000000f,  -0.1022618413f, -0.1958818436f, -0.2749801576f, -0.3375000954f,
         -0.3844630718f, -0.4316083491f, -0.4594423175f, -0.4755989015f, -0.4850046337f,
         -0.4905640781f, -0.4954148829f, -0.4976535738f, -0.4987545311f, -0.4993230700f,
         -0.5000000000f},
        {0.5000000000f,  0.4995733500f,  0.4991982579f,  0.4984387755f,  0.4967978001f,
         0.4929749966f,  0.4883366227f,  0.4801396132f,  0.4654795229f,  0.4392894208f,
         0.3934856057f,  0.3468125761f,  0.2836797237f,  0.2027634382f,  0.1061001420f,
         0.0000000000f,  -0.1061001420f, -0.2027634382f, -0.2836797237f, -0.3468125463f,
         -0.3934856355f, -0.4392894208f, -0.4654795229f, -0.4801395833f, -0.4883366823f,
         -0.4929749668f, -0.4967978299f, -0.4984387755f, -0.4991982877f, -0.4995733202f,
         -0.5000000000f},
        {0.5000000000f,  0.4999683797f,  0.4999000132f,  0.4996838570f,  0.4990009665f,
         0.4968476892f,  0.4937299490f,  0.4875672758f,  0.4754966497f,  0.4522733092f,
         0.4090909064f,  0.3631930947f,  0.2992399931f,  0.2152527571f,  0.1131368279f,
         0.0000000000f,  -0.1131368279f, -0.2152527571f, -0.2992399931f, -0.3631930947f,
         -0.4090909064f, -0.4522732794f, -0.4754966199f, -0.4875672758f, -0.4937299788f,
         -0.4968476892f, -0.4990009964f, -0.4996838868f, -0.4999000132f, -0.4999683797f,
         -0.5000000000f},
        {0.5000000000f,  0.5006032586f,  0.5010305047f,  0.5016981363f,  0.5025926232f,
         0.5032470226f,  0.5027559996f,  0.5002208352f,  0.4929866195f,  0.4757096469f,
         0.4384897351f,  0.3950820863f,  0.3305716217f,  0.2411795706f,  0.1280656755f,
         0.0000000000f,  -0.1280656755f, -0.2411796004f, -0.3305716217f, -0.3950820863f,
         -0.4384897351f, -0.4757096469f, -0.4929866195f, -0.5002207756f, -0.5027559996f,
         -0.5032470226f, -0.5025926828f, -0.5016981959f, -0.5010305047f, -0.5006032586f,
         -0.5000000000f},
        {0.5000000000f,  0.5010370016f,  0.5018045902f,  0.5030835867f,  0.5050826669f,
         0.5077480078f,  0.5091921091f,  0.5094215274f,  0.5060614347f,  0.4939221144f,
         0.4625604451f,  0.4223127663f,  0.3585619628f,  0.2725898027f,  0.1494219899f,
         0.0000000000f,  -0.1494219750f, -0.2725898027f, -0.3585619926f, -0.4223127961f,
         -0.4625605047f, -0.4939221144f, -0.5060614347f, -0.5094215274f, -0.5091921091f,
         -0.5077480078f, -0.5050827861f, -0.5030835867f, -0.5018045902f, -0.5010369420f,
         -0.5000000000f}},
    {

        {0.5000000000f,  0.4979922175f,  0.4964025617f,  0.4935186803f,  0.4882142544f,
         0.4782521725f,  0.4682838917f,  0.4533392787f,  0.4307336509f,  0.3964424431f,
         0.3449379802f,  0.2979410589f,  0.2390869260f,  0.1681751311f,  0.0870600939f,
         0.0000000000f,  -0.0870600939f, -0.1681751460f, -0.2390869558f, -0.2979410589f,
         -0.3449379802f, -0.3964424431f, -0.4307335615f, -0.4533392787f, -0.4682839215f,
         -0.4782521725f, -0.4882142544f, -0.4935186505f, -0.4964025617f, -0.4979921579f,
         -0.5000000000f},
        {0.5000000000f,  0.4981160462f,  0.4966207743f,  0.4939002991f,  0.4888732731f,
         0.4793626070f,  0.4697723091f,  0.4552863240f,  0.4331888258f,  0.3993673325f,
         0.3481221795f,  0.3010587096f,  0.2418579161f,  0.1702777445f,  0.0882006139f,
         0.0000000000f,  -0.0882006139f, -0.1702777743f, -0.2418579161f, -0.3010587096f,
         -0.3481221795f, -0.3993673027f, -0.4331887960f, -0.4552863240f, -0.4697723091f,
         -0.4793626070f, -0.4888732731f, -0.4939003289f, -0.4966207743f, -0.4981160164f,
         -0.5000000000f},
        {0.5000000000f,  0.4983044863f,  0.4969531596f,  0.4944825768f,  0.4898807108f,
         0.4810664356f,  0.4720634520f,  0.4582964182f,  0.4370048046f,  0.4039427638f,
         0.3531388044f,  0.3059939146f,  0.2462634593f,  0.1736325473f,  0.0900245756f,
         0.0000000000f,  -0.0900245681f, -0.1736325473f, -0.2462634593f, -0.3059939146f,
         -0.3531388342f, -0.4039427042f, -0.4370048046f, -0.4582964182f, -0.4720634818f,
         -0.4810664356f, -0.4898807704f, -0.4944825768f, -0.4969531298f, -0.4983044863f,
         -0.5000000000f},
        {0.5000000000f,  0.4987780154f,  0.4977895021f,  0.4959515929f,  0.4924345016f,
         0.4854198098f,  0.4779591858f,  0.4661146402f,  0.4470350742f,  0.4161445498f,
         0.3667378426f,  0.3195213675f,  0.2584639788f,  0.1830018908f,  0.0951471180f,
         0.0000000000f,  -0.0951471031f, -0.1830018908f, -0.2584639788f, -0.3195213974f,
         -0.3667378724f, -0.4161445200f, -0.4470350742f, -0.4661146402f, -0.4779591858f,
         -0.4854198396f, -0.4924345613f, -0.4959515929f, -0.4977895319f, -0.4987780452f,
         -0.5000000000f},
        {0.5000000000f,  0.4992391467f,  0.4986056089f,  0.4973905385f,  0.4949527979f,
         0.4897618592f,  0.4839001894f,  0.4741017818f,  0.4574657679f,  0.4291163385f,
         0.3815677166f,  0.3345352709f,  0.2722316682f,  0.1937220246f,  0.1010626405f,
         0.0000000000f,  -0.1010626331f, -0.1937220395f, -0.2722316980f, -0.3345352709f,
         -0.3815677166f, -0.4291163385f, -0.4574657679f, -0.4741017818f, -0.4839001894f,
         -0.4897618592f, -0.4949527979f, -0.4973905683f, -0.4986056685f, -0.4992391169f,
         -0.5000000000f},
        {0.5000000000f,  0.4999683797f,  0.4999000132f,  0.4996838570f,  0.4990009665f,
         0.4968476892f,  0.4937299490f,  0.4875672758f,  0.4754966497f,  0.4522733092f,
         0.4090909064f,  0.3631930947f,  0.2992399931f,  0.2152527571f,  0.1131368279f,
         0.0000000000f,  -0.1131368279f, -0.2152527571f, -0.2992399931f, -0.3631930947f,
         -0.4090909064f, -0.4522732794f, -0.4754966199f, -0.4875672758f, -0.4937299788f,
         -0.4968476892f, -0.4990009964f, -0.4996838868f, -0.4999000132f, -0.4999683797f,
         -0.5000000000f},
        {0.5000000000f,  0.5011434555f,  0.5019949079f,  0.5034251213f,  0.5056989789f,
         0.5088702440f,  0.5108084083f,  0.5117562413f,  0.5094295144f,  0.4987166524f,
         0.4690935910f,  0.4298956990f,  0.3742347658f,  0.2874245048f,  0.1586372405f,
         0.0000000000f,  -0.1586372405f, -0.2874245048f, -0.3742347956f, -0.4298956990f,
         -0.4690936506f, -0.4987166524f, -0.5094294548f, -0.5117561817f, -0.5108084679f,
         -0.5088702440f, -0.5056990385f, -0.5034251213f, -0.5019949675f, -0.5011434555f,
         -0.5000000000f},
        {0.5000000596f,  0.5019482374f,  0.5034363270f,  0.5060207844f,  0.5104164481f,
         0.5175731182f,  0.5235039592f,  0.5304464102f,  0.5371760726f,  0.5399830937f,
         0.5705516338f,  0.5833023787f,  0.5678069592f,  0.4872313440f,  0.2963676453f,
         0.0000000000f,  -0.2963677049f, -0.4872313440f, -0.5678069592f, -0.5833023787f,
         -0.5705516338f, -0.5399830341f, -0.5371760726f, -0.5304464102f, -0.5235040188f,
         -0.5175731182f, -0.5104165077f, -0.5060207844f, -0.5034362674f, -0.5019482374f,
         -0.5000000596f}},
    {

        {0.5000000000f,  0.4973910451f,  0.4953450263f,  0.4916738272f,  0.4850449860f,
         0.4729567766f,  0.4612380564f,  0.4442087412f,  0.4193551242f,  0.3830735385f,
         0.3306014538f,  0.2840420604f,  0.2268431634f,  0.1589508802f,  0.0820798650f,
         0.0000000000f,  -0.0820798576f, -0.1589508951f, -0.2268431783f, -0.2840420604f,
         -0.3306014538f, -0.3830735683f, -0.4193551242f, -0.4442086816f, -0.4612380564f,
         -0.4729567766f, -0.4850450158f, -0.4916738570f, -0.4953449965f, -0.4973909855f,
         -0.5000000000f},
        {0.5000000000f,  0.4975522459f,  0.4956282973f,  0.4921671450f,  0.4858898818f,
         0.4743613005f,  0.4630986154f,  0.4466060102f,  0.4223214984f,  0.3865298629f,
         0.3342745304f,  0.2875820100f,  0.2299449295f,  0.1612776965f,  0.0833326429f,
         0.0000000000f,  -0.0833326355f, -0.1612777114f, -0.2299449295f, -0.2875820100f,
         -0.3342745602f, -0.3865298331f, -0.4223214984f, -0.4466060400f, -0.4630986452f,
         -0.4743613005f, -0.4858898818f, -0.4921671748f, -0.4956283271f, -0.4975521863f,
         -0.5000000000f},
        {0.5000000000f,  0.4977977276f,  0.4960601032f,  0.4929202795f,  0.4871834517f,
         0.4765217602f,  0.4659720957f,  0.4503277540f,  0.4269563556f,  0.3919707835f,
         0.3401035368f,  0.2932292819f,  0.2349164933f,  0.1650211811f,  0.0853530467f,
         0.0000000000f,  -0.0853530392f, -0.1650211811f, -0.2349164784f, -0.2932292819f,
         -0.3401035368f, -0.3919707835f, -0.4269563556f, -0.4503277242f, -0.4659721255f,
         -0.4765217602f, -0.4871834517f, -0.4929203391f, -0.4960601330f, -0.4977976680f,
         -0.5000000000f},
        {0.5000000000f,  0.4984147847f,  0.4971478283f,  0.4948240519f,  0.4904728234f,
         0.4820713699f,  0.4734190702f,  0.4600848258f,  0.4392839074f,  0.4066926241f,
         0.3561752141f,  0.3089951873f,  0.2489543557f,  0.1756889224f,  0.0911452249f,
         0.0000000000f,  -0.0911452249f, -0.1756889224f, -0.2489543557f, -0.3089951873f,
         -0.3561752439f, -0.4066926539f, -0.4392838776f, -0.4600848556f, -0.4734191597f,
         -0.4820713401f, -0.4904728830f, -0.4948240817f, -0.4971478581f, -0.4984148145f,
         -0.5000000000f},
        {0.5000000000f,  0.4990161359f,  0.4982108474f,  0.4966937900f,  0.4937312901f,
         0.4876496494f,  0.4810023904f,  0.4701921344f,  0.4523362219f,  0.4227000475f,
         0.3741825819f,  0.3270231485f,  0.2653121948f,  0.1883139759f,  0.0980708972f,
         0.0000000000f,  -0.0980708972f, -0.1883139908f, -0.2653121948f, -0.3270231187f,
         -0.3741825819f, -0.4227000475f, -0.4523362219f, -0.4701920748f, -0.4810024500f,
         -0.4876495600f, -0.4937313497f, -0.4966937602f, -0.4982108474f, -0.4990161359f,
         -0.5000000000f},
        {0.5000000000f,  0.4999683797f,  0.4999000132f,  0.4996838570f,  0.4990009665f,
         0.4968476892f,  0.4937299490f,  0.4875672758f,  0.4754966497f,  0.4522733092f,
         0.4090909064f,  0.3631930947f,  0.2992399931f,  0.2152527571f,  0.1131368279f,
         0.0000000000f,  -0.1131368279f, -0.2152527571f, -0.2992399931f, -0.3631930947f,
         -0.4090909064f, -0.4522732794f, -0.4754966199f, -0.4875672758f, -0.4937299788f,
         -0.4968476892f, -0.4990009964f, -0.4996838868f, -0.4999000132f, -0.4999683797f,
         -0.5000000000f},
        {0.5000000596f,  0.5015053153f,  0.5026424527f,  0.5045889616f,  0.5078070164f,
         0.5127342939f,  0.5164096355f,  0.5199240446f,  0.5213798285f,  0.5160900950f,
         0.4961368442f,  0.4834818840f,  0.4421011508f,  0.3525198102f,  0.2006191760f,
         0.0000000000f,  -0.2006191611f, -0.3525197804f, -0.4421012104f, -0.4834818840f,
         -0.4961368442f, -0.5160900950f, -0.5213798285f, -0.5199240446f, -0.5164096951f,
         -0.5127342939f, -0.5078070164f, -0.5045889616f, -0.5026424527f, -0.5015053153f,
         -0.5000000596f},
        {0.5000000596f,  0.5025598407f,  0.5045354962f,  0.5080122352f,  0.5140760541f,
         0.5244651437f,  0.5337679982f,  0.5460379124f,  0.5614778399f,  0.6178392172f,
         0.7190376520f,  0.8149639368f,  0.9330952168f,  1.0282080173f,  0.8643135428f,
         0.0000000000f,  -0.8643140197f, -1.0282078981f, -0.9330952764f, -0.8149639368f,
         -0.7190377116f, -0.6178392172f, -0.5614778399f, -0.5460379124f, -0.5337680578f,
         -0.5244650841f, -0.5140760541f, -0.5080122352f, -0.5045354962f, -0.5025598407f,
         -0.5000000596f}}

};

const FLOAT32 ixheaacd_beta[16][8][31] = {
    {

        {0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f},
        {0.0000000112f, 0.0019540936f, 0.0034606718f, 0.0061091632f, 0.0107228868f, 0.0186282881f,
         0.0257363543f, 0.0352233760f, 0.0475566611f, 0.0629518107f, 0.0809580833f, 0.0936254412f,
         0.1057573855f, 0.1160409376f, 0.1230182052f, 0.1254990250f, 0.1230182126f, 0.1160409376f,
         0.1057573855f, 0.0936254412f, 0.0809580907f, 0.0629518107f, 0.0475566611f, 0.0352233723f,
         0.0257363543f, 0.0186282881f, 0.0107228868f, 0.0061091632f, 0.0034606718f, 0.0019540936f,
         0.0000000112f},
        {0.0000000186f, 0.0030265115f, 0.0053620972f, 0.0094724931f, 0.0166464634f, 0.0289774239f,
         0.0401044935f, 0.0550108925f, 0.0744772330f, 0.0989024863f, 0.1276271343f, 0.1479234397f,
         0.1674221754f, 0.1839915216f, 0.1952533126f, 0.1992611140f, 0.1952533126f, 0.1839915067f,
         0.1674221903f, 0.1479234397f, 0.1276271492f, 0.0989024863f, 0.0744772330f, 0.0550108925f,
         0.0401044972f, 0.0289774239f, 0.0166464634f, 0.0094724931f, 0.0053620972f, 0.0030265115f,
         0.0000000186f},
        {0.0000000261f, 0.0044795908f, 0.0079446994f, 0.0140600502f, 0.0247849934f, 0.0433696434f,
         0.0602979437f, 0.0832019523f, 0.1134835035f, 0.1520351619f, 0.1980977207f, 0.2310739607f,
         0.2630588710f, 0.2904545665f, 0.3091802299f, 0.3158638775f, 0.3091802299f, 0.2904545665f,
         0.2630588710f, 0.2310739756f, 0.1980977207f, 0.1520351619f, 0.1134835035f, 0.0832019523f,
         0.0602979474f, 0.0433696434f, 0.0247849971f, 0.0140600502f, 0.0079446994f, 0.0044795908f,
         0.0000000261f},
        {0.0000000298f, 0.0052186511f, 0.0092647560f, 0.0164252073f, 0.0290434174f, 0.0510888547f,
         0.0713650510f, 0.0990892947f, 0.1362429261f, 0.1843356937f, 0.2429044843f, 0.2855334580f,
         0.3274079263f, 0.3636668324f, 0.3886501491f, 0.3976052999f, 0.3886501789f, 0.3636668026f,
         0.3274079263f, 0.2855334580f, 0.2429044992f, 0.1843357086f, 0.1362429261f, 0.0990892947f,
         0.0713650584f, 0.0510888584f, 0.0290434174f, 0.0164252073f, 0.0092647560f, 0.0052186511f,
         0.0000000298f},
        {0.0000000298f, 0.0056232363f, 0.0099989995f, 0.0177771747f, 0.0315911807f, 0.0560568646f,
         0.0789347738f, 0.1108068749f, 0.1546058059f, 0.2131874412f, 0.2874797881f, 0.3436433673f,
         0.4005688727f, 0.4512940049f, 0.4870318770f, 0.5000000000f, 0.4870318770f, 0.4512939751f,
         0.4005689025f, 0.3436433673f, 0.2874797881f, 0.2131874263f, 0.1546057910f, 0.1108068675f,
         0.0789347813f, 0.0560568646f, 0.0315911844f, 0.0177771747f, 0.0099989995f, 0.0056232363f,
         0.0000000298f},
        {0.0000000261f, 0.0045594499f, 0.0081285350f, 0.0145191513f, 0.0260186046f, 0.0468755513f,
         0.0669798329f, 0.0960334241f, 0.1381545961f, 0.1990868747f, 0.2927374542f, 0.3888260126f,
         0.5107848644f, 0.6488836408f, 0.7694273591f, 0.8192751408f, 0.7694274187f, 0.6488835216f,
         0.5107849240f, 0.3888260126f, 0.2927374840f, 0.1990868896f, 0.1381545961f, 0.0960334167f,
         0.0669798404f, 0.0468755476f, 0.0260186046f, 0.0145191513f, 0.0081285350f, 0.0045594499f,
         0.0000000261f},
        {0.0000000037f, 0.0007977076f, 0.0014247037f, 0.0025531128f, 0.0046027601f, 0.0083869211f,
         0.0121226721f, 0.0176920481f, 0.0261930563f, 0.0433672927f, 0.0784488842f, 0.1264052540f,
         0.2276235074f, 0.4984348118f, 1.6047799587f, 5.8778095245f, 1.6047828197f, 0.4984346628f,
         0.2276235521f, 0.1264052540f, 0.0784488916f, 0.0433672965f, 0.0261930563f, 0.0176920481f,
         0.0121226721f, 0.0083869211f, 0.0046027601f, 0.0025531128f, 0.0014247037f, 0.0007977076f,
         0.0000000037f}},
    {

        {0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f},
        {0.0000000112f, 0.0019548684f, 0.0034630969f, 0.0061166696f, 0.0107457712f, 0.0186960548f,
         0.0258635134f, 0.0354561731f, 0.0479685590f, 0.0636471361f, 0.0820589513f, 0.0950533152f,
         0.1075267568f, 0.1181191504f, 0.1253151745f, 0.1278754473f, 0.1253151745f, 0.1181191429f,
         0.1075267643f, 0.0950533152f, 0.0820589513f, 0.0636471361f, 0.0479685590f, 0.0354561731f,
         0.0258635171f, 0.0186960548f, 0.0107457712f, 0.0061166734f, 0.0034630969f, 0.0019548684f,
         0.0000000112f},
        {0.0000000186f, 0.0030275919f, 0.0053654797f, 0.0094829798f, 0.0166785270f, 0.0290729403f,
         0.0402846411f, 0.0553428568f, 0.0750693232f, 0.0999114066f, 0.1292407066f, 0.1500300914f,
         0.1700480729f, 0.1870902777f, 0.1986886710f, 0.2028190643f, 0.1986886710f, 0.1870902628f,
         0.1700480729f, 0.1500300914f, 0.1292407066f, 0.0999113992f, 0.0750693232f, 0.0553428531f,
         0.0402846411f, 0.0290729403f, 0.0166785270f, 0.0094829798f, 0.0053654797f, 0.0030275919f,
         0.0000000186f},
        {0.0000000261f, 0.0044807382f, 0.0079482906f, 0.0140712596f, 0.0248195715f, 0.0434742048f,
         0.0604977794f, 0.0835766271f, 0.1141664237f, 0.1532292813f, 0.2000626326f, 0.2336882651f,
         0.2663741410f, 0.2944218218f, 0.3136188090f, 0.3204754591f, 0.3136188090f, 0.2944217920f,
         0.2663741708f, 0.2336882651f, 0.2000626326f, 0.1532292962f, 0.1141664162f, 0.0835766271f,
         0.0604977906f, 0.0434742048f, 0.0248195753f, 0.0140712596f, 0.0079482906f, 0.0044807382f,
         0.0000000261f},
        {0.0000000298f, 0.0052194707f, 0.0092673339f, 0.0164332762f, 0.0290685408f, 0.0511660054f,
         0.0715145171f, 0.0993746519f, 0.1367753297f, 0.1852938682f, 0.2445339411f, 0.2877510786f,
         0.3302804232f, 0.3671652079f, 0.3926102221f, 0.4017367959f, 0.3926102519f, 0.3671651781f,
         0.3302804828f, 0.2877510786f, 0.2445339262f, 0.1852938682f, 0.1367753297f, 0.0993746296f,
         0.0715145245f, 0.0511660054f, 0.0290685445f, 0.0164332762f, 0.0092673302f, 0.0052194707f,
         0.0000000298f},
        {0.0000000298f, 0.0056232363f, 0.0099989995f, 0.0177771747f, 0.0315911807f, 0.0560568646f,
         0.0789347738f, 0.1108068749f, 0.1546058059f, 0.2131874412f, 0.2874797881f, 0.3436433673f,
         0.4005688727f, 0.4512940049f, 0.4870318770f, 0.5000000000f, 0.4870318770f, 0.4512939751f,
         0.4005689025f, 0.3436433673f, 0.2874797881f, 0.2131874263f, 0.1546057910f, 0.1108068675f,
         0.0789347813f, 0.0560568646f, 0.0315911844f, 0.0177771747f, 0.0099989995f, 0.0056232363f,
         0.0000000298f},
        {0.0000000261f, 0.0045582913f, 0.0081248507f, 0.0145073459f, 0.0259804092f, 0.0467499122f,
         0.0667200089f, 0.0954893604f, 0.1369983852f, 0.1965934485f, 0.2817551196f, 0.3696863651f,
         0.4782577753f, 0.5972789526f, 0.6979247928f, 0.7386929393f, 0.6979249120f, 0.5972788334f,
         0.4782578349f, 0.3696863651f, 0.2817551494f, 0.1965934336f, 0.1369983703f, 0.0954893529f,
         0.0667200163f, 0.0467499122f, 0.0259804130f, 0.0145073459f, 0.0081248507f, 0.0045582913f,
         0.0000000261f},
        {0.0000000037f, 0.0007973649f, 0.0014236122f, 0.0025495738f, 0.0045911148f, 0.0083473474f,
         0.0120380968f, 0.0175057761f, 0.0257535614f, 0.0410830304f, 0.0712796226f, 0.1087764874f,
         0.1762015671f, 0.3041011095f, 0.5248688459f, 0.6885957122f, 0.5248691440f, 0.3041010499f,
         0.1762015820f, 0.1087764949f, 0.0712796375f, 0.0410830304f, 0.0257535614f, 0.0175057724f,
         0.0120380968f, 0.0083473474f, 0.0045911148f, 0.0025495775f, 0.0014236122f, 0.0007973649f,
         0.0000000037f}},
    {

        {0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f},
        {0.0000000112f, 0.0019570850f, 0.0034700334f, 0.0061382130f, 0.0108117498f, 0.0188931711f,
         0.0262362324f, 0.0361453071f, 0.0492028967f, 0.0657609925f, 0.0854583159f, 0.0995077044f,
         0.1130974889f, 0.1247107610f, 0.1326356083f, 0.1354617327f, 0.1326356083f, 0.1247107461f,
         0.1130974963f, 0.0995077044f, 0.0854583159f, 0.0657609925f, 0.0492028967f, 0.0361453034f,
         0.0262362324f, 0.0188931711f, 0.0108117498f, 0.0061382130f, 0.0034700334f, 0.0019570850f,
         0.0000000112f},
        {0.0000000186f, 0.0030306727f, 0.0053751357f, 0.0095130354f, 0.0167708695f, 0.0293502137f,
         0.0408112556f, 0.0563221611f, 0.0768360794f, 0.1029629856f, 0.1341941655f, 0.1565610915f,
         0.1782617569f, 0.1968532801f, 0.2095632553f, 0.2141001821f, 0.2095632553f, 0.1968532652f,
         0.1782617867f, 0.1565610915f, 0.1341941804f, 0.1029629931f, 0.0768360794f, 0.0563221574f,
         0.0408112593f, 0.0293502137f, 0.0167708695f, 0.0095130354f, 0.0053751357f, 0.0030306727f,
         0.0000000186f},
        {0.0000000261f, 0.0044840015f, 0.0079585500f, 0.0141033232f, 0.0249188393f, 0.0437761769f,
         0.0610779524f, 0.0846719742f, 0.1161808893f, 0.1567904651f, 0.2059956193f, 0.2416490465f,
         0.2765491605f, 0.3066769838f, 0.3273887634f, 0.3348038197f, 0.3273887634f, 0.3066769540f,
         0.2765491605f, 0.2416490614f, 0.2059956342f, 0.1567904651f, 0.1161808893f, 0.0846719667f,
         0.0610779561f, 0.0437761769f, 0.0249188431f, 0.0141033232f, 0.0079585500f, 0.0044840015f,
         0.0000000261f},
        {0.0000000298f, 0.0052218027f, 0.0092746764f, 0.0164563321f, 0.0291404575f, 0.0513876304f,
         0.0719453543f, 0.1002009511f, 0.1383263767f, 0.1881065071f, 0.2493602335f, 0.2943610847f,
         0.3388943374f, 0.3777095377f, 0.4045871496f, 0.4142471850f, 0.4045871794f, 0.3777095079f,
         0.3388943672f, 0.2943610847f, 0.2493602186f, 0.1881065071f, 0.1383263767f, 0.1002009436f,
         0.0719453618f, 0.0513876304f, 0.0291404612f, 0.0164563321f, 0.0092746764f, 0.0052218027f,
         0.0000000298f},
        {0.0000000298f, 0.0056232363f, 0.0099989995f, 0.0177771747f, 0.0315911807f, 0.0560568646f,
         0.0789347738f, 0.1108068749f, 0.1546058059f, 0.2131874412f, 0.2874797881f, 0.3436433673f,
         0.4005688727f, 0.4512940049f, 0.4870318770f, 0.5000000000f, 0.4870318770f, 0.4512939751f,
         0.4005689025f, 0.3436433673f, 0.2874797881f, 0.2131874263f, 0.1546057910f, 0.1108068675f,
         0.0789347813f, 0.0560568646f, 0.0315911844f, 0.0177771747f, 0.0099989995f, 0.0056232363f,
         0.0000000298f},
        {0.0000000261f, 0.0045550019f, 0.0081143826f, 0.0144738853f, 0.0258725621f, 0.0463975929f,
         0.0659963265f, 0.0939892456f, 0.1338583082f, 0.1899754107f, 0.2663972974f, 0.3287125528f,
         0.4048410654f, 0.4869871736f, 0.5518758893f, 0.5770590305f, 0.5518758893f, 0.4869871438f,
         0.4048411250f, 0.3287125528f, 0.2663973570f, 0.1899754107f, 0.1338582933f, 0.0939892307f,
         0.0659963414f, 0.0463975891f, 0.0258725658f, 0.0144738853f, 0.0081143863f, 0.0045550019f,
         0.0000000261f},
        {0.0000000037f, 0.0007963963f, 0.0014205091f, 0.0025395826f, 0.0045584328f, 0.0082376562f,
         0.0118066110f, 0.0170059167f, 0.0246388987f, 0.0359060131f, 0.0565599240f, 0.0778557137f,
         0.1072221845f, 0.1441028267f, 0.1799743623f, 0.1959501207f, 0.1799744070f, 0.1441028118f,
         0.1072221920f, 0.0778557137f, 0.0565599315f, 0.0359060131f, 0.0246388987f, 0.0170059167f,
         0.0118066110f, 0.0082376562f, 0.0045584328f, 0.0025395826f, 0.0014205091f, 0.0007963963f,
         0.0000000037f}},
    {

        {0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f},
        {0.0000000112f, 0.0019604117f, 0.0034804866f, 0.0061708763f, 0.0109128021f, 0.0192001797f,
         0.0268254243f, 0.0372561179f, 0.0512422584f, 0.0693590865f, 0.0914405808f, 0.1075243503f,
         0.1233326197f, 0.1370278895f, 0.1464678943f, 0.1498523057f, 0.1464678943f, 0.1370278746f,
         0.1233326346f, 0.1075243577f, 0.0914405808f, 0.0693590865f, 0.0512422584f, 0.0372561105f,
         0.0268254280f, 0.0192001797f, 0.0109128058f, 0.0061708800f, 0.0034804903f, 0.0019604117f,
         0.0000000112f},
        {0.0000000186f, 0.0030353032f, 0.0053896904f, 0.0095585547f, 0.0169119760f, 0.0297804140f,
         0.0416394584f, 0.0578900613f, 0.0797299594f, 0.1081020311f, 0.1428017914f, 0.1681542695f,
         0.1931329519f, 0.2148192078f, 0.2297913432f, 0.2351637930f, 0.2297913432f, 0.2148192078f,
         0.1931329817f, 0.1681542695f, 0.1428017914f, 0.1081020311f, 0.0797299519f, 0.0578900538f,
         0.0416394621f, 0.0297804177f, 0.0169119798f, 0.0095585547f, 0.0053896904f, 0.0030353032f,
         0.0000000186f},
        {0.0000000261f, 0.0044889040f, 0.0079739802f, 0.0141517222f, 0.0250696540f, 0.0442400984f,
         0.0619782880f, 0.0863948390f, 0.1194054559f, 0.1626167744f, 0.2159518450f, 0.2552461028f,
         0.2942210138f, 0.3282614052f, 0.3518697023f, 0.3603619337f, 0.3518697023f, 0.3282613754f,
         0.2942210138f, 0.2552461028f, 0.2159518450f, 0.1626167595f, 0.1194054410f, 0.0863948315f,
         0.0619782880f, 0.0442400984f, 0.0250696540f, 0.0141517222f, 0.0079739802f, 0.0044889040f,
         0.0000000261f},
        {0.0000000298f, 0.0052252971f, 0.0092856996f, 0.0164910108f, 0.0292490833f, 0.0517247654f,
         0.0726049617f, 0.1014770418f, 0.1407495737f, 0.1925659627f, 0.2571487725f, 0.3051639795f,
         0.3531456888f, 0.3953380585f, 0.4247539937f, 0.4353658557f, 0.4247539937f, 0.3953380287f,
         0.3531457186f, 0.3051640093f, 0.2571487725f, 0.1925659627f, 0.1407495588f, 0.1014770344f,
         0.0726049691f, 0.0517247617f, 0.0292490870f, 0.0164910108f, 0.0092856996f, 0.0052252971f,
         0.0000000298f},
        {0.0000000298f, 0.0056232363f, 0.0099989995f, 0.0177771747f, 0.0315911807f, 0.0560568646f,
         0.0789347738f, 0.1108068749f, 0.1546058059f, 0.2131874412f, 0.2874797881f, 0.3436433673f,
         0.4005688727f, 0.4512940049f, 0.4870318770f, 0.5000000000f, 0.4870318770f, 0.4512939751f,
         0.4005689025f, 0.3436433673f, 0.2874797881f, 0.2131874263f, 0.1546057910f, 0.1108068675f,
         0.0789347813f, 0.0560568646f, 0.0315911844f, 0.0177771747f, 0.0099989995f, 0.0056232363f,
         0.0000000298f},
        {0.0000000261f, 0.0045500919f, 0.0080987960f, 0.0144242346f, 0.0257136337f, 0.0458848849f,
         0.0649559572f, 0.0918706506f, 0.1295377314f, 0.1812113971f, 0.2490174621f, 0.3020929396f,
         0.3576069176f, 0.4086337388f, 0.4455217719f, 0.4591073692f, 0.4455218017f, 0.4086337090f,
         0.3576069772f, 0.3020929396f, 0.2490174621f, 0.1812113971f, 0.1295377314f, 0.0918706357f,
         0.0649559572f, 0.0458848849f, 0.0257136375f, 0.0144242346f, 0.0080987960f, 0.0045500919f,
         0.0000000261f},
        {0.0000000037f, 0.0007949509f, 0.0014159046f, 0.0025248416f, 0.0045107976f, 0.0080812797f,
         0.0114838332f, 0.0163318664f, 0.0232117511f, 0.0328431986f, 0.0458545312f, 0.0563677698f,
         0.0677092522f, 0.0806207210f, 0.0907390118f, 0.0946287736f, 0.0907390192f, 0.0806207135f,
         0.0677092597f, 0.0563677736f, 0.0458545350f, 0.0328431949f, 0.0232117511f, 0.0163318627f,
         0.0114838332f, 0.0080812797f, 0.0045107976f, 0.0025248416f, 0.0014159046f, 0.0007949509f,
         0.0000000037f}},
    {

        {0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f},
        {0.0000000112f, 0.0019643605f, 0.0034929439f, 0.0062100887f, 0.0110357292f, 0.0195823126f,
         0.0275742412f, 0.0387081020f, 0.0540083535f, 0.0744726434f, 0.1004251465f, 0.1200447381f,
         0.1399304867f, 0.1576502621f, 0.1701345742f, 0.1746647209f, 0.1701345742f, 0.1576502770f,
         0.1399305016f, 0.1200447381f, 0.1004251465f, 0.0744726434f, 0.0540083535f, 0.0387080982f,
         0.0275742412f, 0.0195823126f, 0.0110357292f, 0.0062100887f, 0.0034929439f, 0.0019643605f,
         0.0000000112f},
        {0.0000000186f, 0.0030407943f, 0.0054070093f, 0.0096130967f, 0.0170830972f, 0.0303130411f,
         0.0426843874f, 0.0599193908f, 0.0836038888f, 0.1152822077f, 0.1554561853f, 0.1858269274f,
         0.2166096866f, 0.2440395653f, 0.2633650005f, 0.2703776062f, 0.2633650303f, 0.2440395504f,
         0.2166097015f, 0.1858269274f, 0.1554561853f, 0.1152822077f, 0.0836038888f, 0.0599193871f,
         0.0426843911f, 0.0303130411f, 0.0170830972f, 0.0096130967f, 0.0054070130f, 0.0030407943f,
         0.0000000186f},
        {0.0000000261f, 0.0044947043f, 0.0079922937f, 0.0142094567f, 0.0252511203f, 0.0448067673f,
         0.0630932897f, 0.0885689482f, 0.1235778332f, 0.1704026759f, 0.2297852188f, 0.2746772766f,
         0.3201783597f, 0.3607234061f, 0.3892890215f, 0.3996545672f, 0.3892890513f, 0.3607234061f,
         0.3201783895f, 0.2746773064f, 0.2297852337f, 0.1704026610f, 0.1235778257f, 0.0885689408f,
         0.0630932897f, 0.0448067635f, 0.0252511241f, 0.0142094567f, 0.0079922937f, 0.0044947043f,
         0.0000000261f},
        {0.0000000298f, 0.0052294321f, 0.0092987530f, 0.0165322050f, 0.0293787941f, 0.0521311015f,
         0.0734068304f, 0.1030468717f, 0.1437784731f, 0.1982575357f, 0.2673470378f, 0.3195773959f,
         0.3725163043f, 0.4196890593f, 0.4529241323f, 0.4649840891f, 0.4529241621f, 0.4196890295f,
         0.3725163341f, 0.3195773959f, 0.2673470676f, 0.1982575357f, 0.1437784731f, 0.1030468568f,
         0.0734068379f, 0.0521311015f, 0.0293787979f, 0.0165322050f, 0.0092987530f, 0.0052294284f,
         0.0000000298f},
        {0.0000000298f, 0.0056232363f, 0.0099989995f, 0.0177771747f, 0.0315911807f, 0.0560568646f,
         0.0789347738f, 0.1108068749f, 0.1546058059f, 0.2131874412f, 0.2874797881f, 0.3436433673f,
         0.4005688727f, 0.4512940049f, 0.4870318770f, 0.5000000000f, 0.4870318770f, 0.4512939751f,
         0.4005689025f, 0.3436433673f, 0.2874797881f, 0.2131874263f, 0.1546057910f, 0.1108068675f,
         0.0789347813f, 0.0560568646f, 0.0315911844f, 0.0177771747f, 0.0099989995f, 0.0056232363f,
         0.0000000298f},
        {0.0000000261f, 0.0045443214f, 0.0080805235f, 0.0143663213f, 0.0255298801f, 0.0453014039f,
         0.0637897998f, 0.0895466954f, 0.1249420568f, 0.1722838134f, 0.2323219031f, 0.2777095437f,
         0.3237129450f, 0.3647055924f, 0.3935865462f, 0.4040665329f, 0.3935865760f, 0.3647055626f,
         0.3237129450f, 0.2777095735f, 0.2323219180f, 0.1722838134f, 0.1249420494f, 0.0895466879f,
         0.0637898073f, 0.0453014039f, 0.0255298801f, 0.0143663213f, 0.0080805235f, 0.0045443214f,
         0.0000000261f},
        {0.0000000037f, 0.0007932559f, 0.0014105327f, 0.0025077760f, 0.0044564828f, 0.0079077892f,
         0.0111351162f, 0.0156312287f, 0.0218098238f, 0.0300737768f, 0.0405539945f, 0.0484768376f,
         0.0565071665f, 0.0636628196f, 0.0687042698f, 0.0705336481f, 0.0687042698f, 0.0636628196f,
         0.0565071702f, 0.0484768413f, 0.0405539945f, 0.0300737731f, 0.0218098238f, 0.0156312250f,
         0.0111351162f, 0.0079077892f, 0.0044564828f, 0.0025077760f, 0.0014105327f, 0.0007932559f,
         0.0000000037f}},
    {

        {0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f},
        {0.0000000112f, 0.0019683354f, 0.0035055354f, 0.0062500574f, 0.0111629069f, 0.0199882090f,
         0.0283894800f, 0.0403442569f, 0.0572769120f, 0.0809144527f, 0.1127139181f, 0.1382882297f,
         0.1657482833f, 0.1942400038f, 0.2178779542f, 0.2269225121f, 0.2178779691f, 0.1942399889f,
         0.1657482982f, 0.1382882297f, 0.1127139181f, 0.0809144527f, 0.0572769120f, 0.0403442495f,
         0.0283894837f, 0.0199882090f, 0.0111629069f, 0.0062500574f, 0.0035055354f, 0.0019683354f,
         0.0000000112f},
        {0.0000000186f, 0.0030463114f, 0.0054244995f, 0.0096685886f, 0.0172595158f, 0.0308753066f,
         0.0438121483f, 0.0621782839f, 0.0881035775f, 0.1241138950f, 0.1722071767f, 0.2105752081f,
         0.2514455318f, 0.2897335589f, 0.3197216690f, 0.3322762251f, 0.3197216988f, 0.2897335291f,
         0.2514455616f, 0.2105752230f, 0.1722071767f, 0.1241138950f, 0.0881035626f, 0.0621782765f,
         0.0438121520f, 0.0308753066f, 0.0172595158f, 0.0096685886f, 0.0054244995f, 0.0030463114f,
         0.0000000186f},
        {0.0000000261f, 0.0045005269f, 0.0080107339f, 0.0142679065f, 0.0254365876f, 0.0453957841f,
         0.0642707124f, 0.0909159034f, 0.1282205731f, 0.1794259250f, 0.2466703653f, 0.2993502319f,
         0.3544936478f, 0.4052205384f, 0.4419169724f, 0.4554374516f, 0.4419169724f, 0.4052204788f,
         0.3544936478f, 0.2993502319f, 0.2466703951f, 0.1794259101f, 0.1282205582f, 0.0909158960f,
         0.0642707199f, 0.0453957841f, 0.0254365914f, 0.0142679065f, 0.0080107339f, 0.0045005269f,
         0.0000000261f},
        {0.0000000298f, 0.0052335747f, 0.0093118623f, 0.0165737085f, 0.0295102485f, 0.0525471680f,
         0.0742358714f, 0.1046918705f, 0.1470117569f, 0.2044855654f, 0.2788636088f, 0.3362472057f,
         0.3954694271f, 0.4491761923f, 0.4875625372f, 0.5016064644f, 0.4875625372f, 0.4491761923f,
         0.3954694569f, 0.3362472057f, 0.2788636386f, 0.2044855654f, 0.1470117420f, 0.1046918631f,
         0.0742358789f, 0.0525471680f, 0.0295102522f, 0.0165737085f, 0.0093118623f, 0.0052335709f,
         0.0000000298f},
        {0.0000000298f, 0.0056232363f, 0.0099989995f, 0.0177771747f, 0.0315911807f, 0.0560568646f,
         0.0789347738f, 0.1108068749f, 0.1546058059f, 0.2131874412f, 0.2874797881f, 0.3436433673f,
         0.4005688727f, 0.4512940049f, 0.4870318770f, 0.5000000000f, 0.4870318770f, 0.4512939751f,
         0.4005689025f, 0.3436433673f, 0.2874797881f, 0.2131874263f, 0.1546057910f, 0.1108068675f,
         0.0789347813f, 0.0560568646f, 0.0315911844f, 0.0177771747f, 0.0099989995f, 0.0056232363f,
         0.0000000298f},
        {0.0000000261f, 0.0045385733f, 0.0080623738f, 0.0143091008f, 0.0253500082f, 0.0447396338f,
         0.0626842678f, 0.0873906389f, 0.1208031848f, 0.1645577550f, 0.2185891271f, 0.2584138811f,
         0.2979290783f, 0.3324524164f, 0.3564015925f, 0.3650175929f, 0.3564015925f, 0.3324524164f,
         0.2979291081f, 0.2584138811f, 0.2185891271f, 0.1645577699f, 0.1208031774f, 0.0873906240f,
         0.0626842752f, 0.0447396338f, 0.0253500082f, 0.0143091008f, 0.0080623738f, 0.0045385733f,
         0.0000000261f},
        {0.0000000037f, 0.0007915683f, 0.0014052205f, 0.0024910569f, 0.0044040829f, 0.0077450164f,
         0.0108163506f, 0.0150136538f, 0.0206346437f, 0.0279043429f, 0.0367485993f, 0.0431800336f,
         0.0494931713f, 0.0549563020f, 0.0587187968f, 0.0600671209f, 0.0587188005f, 0.0549563020f,
         0.0494931713f, 0.0431800373f, 0.0367486030f, 0.0279043429f, 0.0206346437f, 0.0150136538f,
         0.0108163506f, 0.0077450164f, 0.0044040829f, 0.0024910569f, 0.0014052168f, 0.0007915683f,
         0.0000000037f}},
    {

        {0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f},
        {0.0000000112f, 0.0019717216f, 0.0035163164f, 0.0062845536f, 0.0112742335f, 0.0203528218f,
         0.0291403309f, 0.0419068150f, 0.0605678447f, 0.0879195333f, 0.1351860017f, 0.1836786717f,
         0.2485272437f, 0.3268185258f, 0.3997989297f, 0.4313463271f, 0.3997989595f, 0.3268184960f,
         0.2485273033f, 0.1836786866f, 0.1351860166f, 0.0879195333f, 0.0605678484f, 0.0419068113f,
         0.0291403346f, 0.0203528218f, 0.0112742335f, 0.0062845536f, 0.0035163164f, 0.0019717216f,
         0.0000000112f},
        {0.0000000186f, 0.0030510165f, 0.0054394603f, 0.0097163878f, 0.0174134374f, 0.0313772969f,
         0.0448416248f, 0.0643075109f, 0.0925465450f, 0.1334379315f, 0.1968761533f, 0.2619350851f,
         0.3448232114f, 0.4391061664f, 0.5217757225f, 0.5560634732f, 0.5217758417f, 0.4391061068f,
         0.3448232710f, 0.2619350851f, 0.1968761683f, 0.1334379166f, 0.0925465375f, 0.0643075034f,
         0.0448416248f, 0.0313772969f, 0.0174134411f, 0.0097163878f, 0.0054394603f, 0.0030510165f,
         0.0000000186f},
        {0.0000000261f, 0.0045054816f, 0.0080264658f, 0.0143180229f, 0.0255970620f, 0.0459137484f,
         0.0653222576f, 0.0930587947f, 0.1325951964f, 0.1883130074f, 0.2643320858f, 0.3264508545f,
         0.4045200348f, 0.4876139164f, 0.5534962416f, 0.5791234970f, 0.5534962416f, 0.4876138568f,
         0.4045200646f, 0.3264508843f, 0.2643321157f, 0.1883129925f, 0.1325951964f, 0.0930587873f,
         0.0653222650f, 0.0459137484f, 0.0255970657f, 0.0143180229f, 0.0080264658f, 0.0045054816f,
         0.0000000261f},
        {0.0000000298f, 0.0052370913f, 0.0093230158f, 0.0166091397f, 0.0296230800f, 0.0529078096f,
         0.0749611408f, 0.1061499193f, 0.1499306262f, 0.2102518976f, 0.2898876965f, 0.3526277840f,
         0.4186539054f, 0.4797268510f, 0.5241174698f, 0.5405187011f, 0.5241175294f, 0.4797268212f,
         0.4186539650f, 0.3526278138f, 0.2898877263f, 0.2102518827f, 0.1499306262f, 0.1061499119f,
         0.0749611482f, 0.0529078059f, 0.0296230800f, 0.0166091397f, 0.0093230195f, 0.0052370913f,
         0.0000000298f},
        {0.0000000298f, 0.0056232363f, 0.0099989995f, 0.0177771747f, 0.0315911807f, 0.0560568646f,
         0.0789347738f, 0.1108068749f, 0.1546058059f, 0.2131874412f, 0.2874797881f, 0.3436433673f,
         0.4005688727f, 0.4512940049f, 0.4870318770f, 0.5000000000f, 0.4870318770f, 0.4512939751f,
         0.4005689025f, 0.3436433673f, 0.2874797881f, 0.2131874263f, 0.1546057910f, 0.1108068675f,
         0.0789347813f, 0.0560568646f, 0.0315911844f, 0.0177771747f, 0.0099989995f, 0.0056232363f,
         0.0000000298f},
        {0.0000000261f, 0.0045337155f, 0.0080470815f, 0.0142611191f, 0.0252004601f, 0.0442794114f,
         0.0617907457f, 0.0856798738f, 0.1175989881f, 0.1587630510f, 0.2086764723f, 0.2448662519f,
         0.2803090215f, 0.3109185398f, 0.3319681287f, 0.3395054638f, 0.3319681585f, 0.3109185100f,
         0.2803090513f, 0.2448662668f, 0.2086764723f, 0.1587630361f, 0.1175989881f, 0.0856798664f,
         0.0617907532f, 0.0442794114f, 0.0252004638f, 0.0142611191f, 0.0080470815f, 0.0045337155f,
         0.0000000261f},
        {0.0000000037f, 0.0007901490f, 0.0014007613f, 0.0024771392f, 0.0043610819f, 0.0076146238f,
         0.0105665363f, 0.0145437419f, 0.0197744034f, 0.0263919048f, 0.0342439152f, 0.0398325771f,
         0.0452299826f, 0.0498363897f, 0.0529768690f, 0.0540962704f, 0.0529768690f, 0.0498363897f,
         0.0452299826f, 0.0398325771f, 0.0342439152f, 0.0263919048f, 0.0197744034f, 0.0145437419f,
         0.0105665363f, 0.0076146238f, 0.0043610819f, 0.0024771392f, 0.0014007613f, 0.0007901490f,
         0.0000000037f}},
    {

        {0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f},
        {0.0000000112f, 0.0019739941f, 0.0035235770f, 0.0063079223f, 0.0113505051f, 0.0206078701f,
         0.0296765603f, 0.0430580825f, 0.0631116480f, 0.0983685851f, 0.1666181833f, 0.2469854802f,
         0.3804836273f, 0.6008414030f, 0.9043325186f, 1.0835957527f, 0.9043327570f, 0.6008412838f,
         0.3804837465f, 0.2469855100f, 0.1666181833f, 0.0983685851f, 0.0631116480f, 0.0430580750f,
         0.0296765603f, 0.0206078701f, 0.0113505051f, 0.0063079223f, 0.0035235770f, 0.0019739941f,
         0.0000000112f},
        {0.0000000186f, 0.0030541718f, 0.0054495223f, 0.0097487271f, 0.0175186098f, 0.0317266919f,
         0.0455713645f, 0.0658584908f, 0.0959193856f, 0.1436767876f, 0.2341895550f, 0.3323971331f,
         0.4782980084f, 0.6811693311f, 0.9031447768f, 1.0110551119f, 0.9031450748f, 0.6811692119f,
         0.4782981277f, 0.3323971033f, 0.2341895849f, 0.1436767727f, 0.0959193856f, 0.0658584833f,
         0.0455713719f, 0.0317266919f, 0.0175186135f, 0.0097487271f, 0.0054495223f, 0.0030541718f,
         0.0000000186f},
        {0.0000000261f, 0.0045088008f, 0.0080370344f, 0.0143518075f, 0.0257059969f, 0.0462698899f,
         0.0660543442f, 0.0945780575f, 0.1357807368f, 0.1950440407f, 0.2812705636f, 0.3701249063f,
         0.4805524051f, 0.6025272608f, 0.7064292431f, 0.7487157583f, 0.7064292431f, 0.6025272012f,
         0.4805524945f, 0.3701249063f, 0.2812705934f, 0.1950440556f, 0.1357807517f, 0.0945780426f,
         0.0660543516f, 0.0462698862f, 0.0257060006f, 0.0143518075f, 0.0080370344f, 0.0045088008f,
         0.0000000261f},
        {0.0000000298f, 0.0052394457f, 0.0093304962f, 0.0166329406f, 0.0296991989f, 0.0531529523f,
         0.0754577741f, 0.1071588024f, 0.1519807279f, 0.2143882662f, 0.2980266809f, 0.3650085926f,
         0.4366289973f, 0.5043625832f, 0.5640503764f, 0.5867944360f, 0.5640504360f, 0.5043625236f,
         0.4366289973f, 0.3650085926f, 0.2980266809f, 0.2143882662f, 0.1519807130f, 0.1071587950f,
         0.0754577741f, 0.0531529561f, 0.0296992026f, 0.0166329406f, 0.0093304962f, 0.0052394457f,
         0.0000000298f},
        {0.0000000298f, 0.0056232363f, 0.0099989995f, 0.0177771747f, 0.0315911807f, 0.0560568646f,
         0.0789347738f, 0.1108068749f, 0.1546058059f, 0.2131874412f, 0.2874797881f, 0.3436433673f,
         0.4005688727f, 0.4512940049f, 0.4870318770f, 0.5000000000f, 0.4870318770f, 0.4512939751f,
         0.4005689025f, 0.3436433673f, 0.2874797881f, 0.2131874263f, 0.1546057910f, 0.1108068675f,
         0.0789347813f, 0.0560568646f, 0.0315911844f, 0.0177771747f, 0.0099989995f, 0.0056232363f,
         0.0000000298f},
        {0.0000000261f, 0.0045304820f, 0.0080369115f, 0.0142293312f, 0.0251020007f, 0.0439797007f,
         0.0612145849f, 0.0845912322f, 0.1155948415f, 0.1552157849f, 0.2027583867f, 0.2369178981f,
         0.2701408267f, 0.2986625433f, 0.3181905448f, 0.3251666427f, 0.3181905448f, 0.2986625135f,
         0.2701408565f, 0.2369178981f, 0.2027584016f, 0.1552157849f, 0.1155948490f, 0.0845912248f,
         0.0612145923f, 0.0439797044f, 0.0251020044f, 0.0142293312f, 0.0080369115f, 0.0045304820f,
         0.0000000261f},
        {0.0000000037f, 0.0007892065f, 0.0013978072f, 0.0024679713f, 0.0043330416f, 0.0075310804f,
         0.0104089491f, 0.0142532848f, 0.0192561597f, 0.0255084299f, 0.0328301787f, 0.0379860699f,
         0.0429274589f, 0.0471183173f, 0.0499628633f, 0.0509744659f, 0.0499628671f, 0.0471183136f,
         0.0429274626f, 0.0379860736f, 0.0328301787f, 0.0255084261f, 0.0192561597f, 0.0142532811f,
         0.0104089528f, 0.0075310804f, 0.0043330416f, 0.0024679713f, 0.0013978072f, 0.0007892065f,
         0.0000000037f}},
    {

        {0.0000000000f,  0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f,  0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f,  0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         -3.2000000477f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f,  0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f,  0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f},
        {0.0000000112f, 0.0019747950f, 0.0035261363f, 0.0063161924f, 0.0113776550f, 0.0206997320f,
         0.0298720002f, 0.0434854478f, 0.0640839934f, 0.1033503860f, 0.1814315021f, 0.2809938192f,
         0.4676808715f, 0.8515646458f, 1.6239985228f, 2.3103787899f, 1.6239993572f, 0.8515645266f,
         0.4676810503f, 0.2809938490f, 0.1814315170f, 0.1033503786f, 0.0640839934f, 0.0434854440f,
         0.0298720002f, 0.0206997320f, 0.0113776587f, 0.0063161924f, 0.0035261363f, 0.0019747950f,
         0.0000000112f},
        {0.0000000186f, 0.0030552819f, 0.0054530725f, 0.0097601563f, 0.0175559968f, 0.0318521820f,
         0.0458361991f, 0.0664303452f, 0.0971942917f, 0.1497929543f, 0.2508868575f, 0.3670715094f,
         0.5535376668f, 0.8446811438f, 1.2149823904f, 1.4186795950f, 1.2149829865f, 0.8446810246f,
         0.5535378456f, 0.3670715392f, 0.2508868873f, 0.1497929394f, 0.0971942842f, 0.0664303303f,
         0.0458362028f, 0.0318521783f, 0.0175559968f, 0.0097601563f, 0.0054530725f, 0.0030552782f,
         0.0000000186f},
        {0.0000000261f, 0.0045099705f, 0.0080407523f, 0.0143637285f, 0.0257445797f, 0.0463969335f,
         0.0663173124f, 0.0951294750f, 0.1369550526f, 0.1975847185f, 0.2925730348f, 0.3899479210f,
         0.5145110488f, 0.6568877101f, 0.7823352814f, 0.8345331550f, 0.7823353410f, 0.6568875909f,
         0.5145111084f, 0.3899479508f, 0.2925730646f, 0.1975847185f, 0.1369550526f, 0.0951294526f,
         0.0663173199f, 0.0463969298f, 0.0257445835f, 0.0143637285f, 0.0080407523f, 0.0045099705f,
         0.0000000261f},
        {0.0000000298f, 0.0052402765f, 0.0093331225f, 0.0166413262f, 0.0297260657f, 0.0532398559f,
         0.0756345168f, 0.1075199619f, 0.1527208239f, 0.2158997804f, 0.3010516465f, 0.3696758151f,
         0.4435127378f, 0.5234289765f, 0.5880037546f, 0.6127629280f, 0.5880038142f, 0.5234289765f,
         0.4435127676f, 0.3696758151f, 0.3010516465f, 0.2158997506f, 0.1527208090f, 0.1075199544f,
         0.0756345242f, 0.0532398522f, 0.0297260694f, 0.0166413262f, 0.0093331262f, 0.0052402765f,
         0.0000000298f},
        {0.0000000298f, 0.0056232363f, 0.0099989995f, 0.0177771747f, 0.0315911807f, 0.0560568646f,
         0.0789347738f, 0.1108068749f, 0.1546058059f, 0.2131874412f, 0.2874797881f, 0.3436433673f,
         0.4005688727f, 0.4512940049f, 0.4870318770f, 0.5000000000f, 0.4870318770f, 0.4512939751f,
         0.4005689025f, 0.3436433673f, 0.2874797881f, 0.2131874263f, 0.1546057910f, 0.1108068675f,
         0.0789347813f, 0.0560568646f, 0.0315911844f, 0.0177771747f, 0.0099989995f, 0.0056232363f,
         0.0000000298f},
        {0.0000000261f, 0.0045293458f, 0.0080333501f, 0.0142182149f, 0.0250676982f, 0.0438758917f,
         0.0610160530f, 0.0842186734f, 0.1149150282f, 0.1540254205f, 0.2007966489f, 0.2343050987f,
         0.2668242753f, 0.2946906090f, 0.3137444556f, 0.3205463886f, 0.3137444556f, 0.2946906090f,
         0.2668242753f, 0.2343050987f, 0.2007966489f, 0.1540254205f, 0.1149150357f, 0.0842186660f,
         0.0610160567f, 0.0438758880f, 0.0250677019f, 0.0142182149f, 0.0080333501f, 0.0045293458f,
         0.0000000261f},
        {0.0000000037f, 0.0007888749f, 0.0013967715f, 0.0024647750f, 0.0043233223f, 0.0075023882f,
         0.0103552639f, 0.0141553432f, 0.0190836154f, 0.0252186134f, 0.0323737599f, 0.0373960882f,
         0.0421986058f, 0.0462643132f, 0.0490204468f, 0.0499999784f, 0.0490204468f, 0.0462643094f,
         0.0421986058f, 0.0373960882f, 0.0323737562f, 0.0252186134f, 0.0190836154f, 0.0141553432f,
         0.0103552639f, 0.0075023882f, 0.0043233223f, 0.0024647750f, 0.0013967715f, 0.0007888749f,
         0.0000000037f}},
    {

        {0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f},
        {0.0000000112f, 0.0019739941f, 0.0035235770f, 0.0063079223f, 0.0113505051f, 0.0206078701f,
         0.0296765603f, 0.0430580825f, 0.0631116480f, 0.0983685851f, 0.1666181833f, 0.2469854802f,
         0.3804836273f, 0.6008414030f, 0.9043325186f, 1.0835957527f, 0.9043327570f, 0.6008412838f,
         0.3804837465f, 0.2469855100f, 0.1666181833f, 0.0983685851f, 0.0631116480f, 0.0430580750f,
         0.0296765603f, 0.0206078701f, 0.0113505051f, 0.0063079223f, 0.0035235770f, 0.0019739941f,
         0.0000000112f},
        {0.0000000186f, 0.0030541718f, 0.0054495223f, 0.0097487271f, 0.0175186098f, 0.0317266919f,
         0.0455713645f, 0.0658584908f, 0.0959193856f, 0.1436767876f, 0.2341895550f, 0.3323971331f,
         0.4782980084f, 0.6811693311f, 0.9031447768f, 1.0110551119f, 0.9031450748f, 0.6811692119f,
         0.4782981277f, 0.3323971033f, 0.2341895849f, 0.1436767727f, 0.0959193856f, 0.0658584833f,
         0.0455713719f, 0.0317266919f, 0.0175186135f, 0.0097487271f, 0.0054495223f, 0.0030541718f,
         0.0000000186f},
        {0.0000000261f, 0.0045088008f, 0.0080370344f, 0.0143518075f, 0.0257059969f, 0.0462698899f,
         0.0660543442f, 0.0945780575f, 0.1357807368f, 0.1950440407f, 0.2812705636f, 0.3701249063f,
         0.4805524051f, 0.6025272608f, 0.7064292431f, 0.7487157583f, 0.7064292431f, 0.6025272012f,
         0.4805524945f, 0.3701249063f, 0.2812705934f, 0.1950440556f, 0.1357807517f, 0.0945780426f,
         0.0660543516f, 0.0462698862f, 0.0257060006f, 0.0143518075f, 0.0080370344f, 0.0045088008f,
         0.0000000261f},
        {0.0000000298f, 0.0052394457f, 0.0093304962f, 0.0166329406f, 0.0296991989f, 0.0531529523f,
         0.0754577741f, 0.1071588024f, 0.1519807279f, 0.2143882662f, 0.2980266809f, 0.3650085926f,
         0.4366289973f, 0.5043625832f, 0.5640503764f, 0.5867944360f, 0.5640504360f, 0.5043625236f,
         0.4366289973f, 0.3650085926f, 0.2980266809f, 0.2143882662f, 0.1519807130f, 0.1071587950f,
         0.0754577741f, 0.0531529561f, 0.0296992026f, 0.0166329406f, 0.0093304962f, 0.0052394457f,
         0.0000000298f},
        {0.0000000298f, 0.0056232363f, 0.0099989995f, 0.0177771747f, 0.0315911807f, 0.0560568646f,
         0.0789347738f, 0.1108068749f, 0.1546058059f, 0.2131874412f, 0.2874797881f, 0.3436433673f,
         0.4005688727f, 0.4512940049f, 0.4870318770f, 0.5000000000f, 0.4870318770f, 0.4512939751f,
         0.4005689025f, 0.3436433673f, 0.2874797881f, 0.2131874263f, 0.1546057910f, 0.1108068675f,
         0.0789347813f, 0.0560568646f, 0.0315911844f, 0.0177771747f, 0.0099989995f, 0.0056232363f,
         0.0000000298f},
        {0.0000000261f, 0.0045304820f, 0.0080369115f, 0.0142293312f, 0.0251020007f, 0.0439797007f,
         0.0612145849f, 0.0845912322f, 0.1155948415f, 0.1552157849f, 0.2027583867f, 0.2369178981f,
         0.2701408267f, 0.2986625433f, 0.3181905448f, 0.3251666427f, 0.3181905448f, 0.2986625135f,
         0.2701408565f, 0.2369178981f, 0.2027584016f, 0.1552157849f, 0.1155948490f, 0.0845912248f,
         0.0612145923f, 0.0439797044f, 0.0251020044f, 0.0142293312f, 0.0080369115f, 0.0045304820f,
         0.0000000261f},
        {0.0000000037f, 0.0007892065f, 0.0013978072f, 0.0024679713f, 0.0043330416f, 0.0075310804f,
         0.0104089491f, 0.0142532848f, 0.0192561597f, 0.0255084299f, 0.0328301787f, 0.0379860699f,
         0.0429274589f, 0.0471183173f, 0.0499628633f, 0.0509744659f, 0.0499628671f, 0.0471183136f,
         0.0429274626f, 0.0379860736f, 0.0328301787f, 0.0255084261f, 0.0192561597f, 0.0142532811f,
         0.0104089528f, 0.0075310804f, 0.0043330416f, 0.0024679713f, 0.0013978072f, 0.0007892065f,
         0.0000000037f}},
    {

        {0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f},
        {0.0000000112f, 0.0019717216f, 0.0035163164f, 0.0062845536f, 0.0112742335f, 0.0203528218f,
         0.0291403309f, 0.0419068150f, 0.0605678484f, 0.0879195333f, 0.1351860166f, 0.1836786717f,
         0.2485272735f, 0.3268185556f, 0.3997989595f, 0.4313464165f, 0.3997990191f, 0.3268185258f,
         0.2485273331f, 0.1836787015f, 0.1351860166f, 0.0879195333f, 0.0605678484f, 0.0419068113f,
         0.0291403346f, 0.0203528218f, 0.0112742335f, 0.0062845536f, 0.0035163164f, 0.0019717216f,
         0.0000000112f},
        {0.0000000186f, 0.0030510165f, 0.0054394603f, 0.0097163878f, 0.0174134374f, 0.0313772969f,
         0.0448416248f, 0.0643075109f, 0.0925465450f, 0.1334379315f, 0.1968761533f, 0.2619351149f,
         0.3448232412f, 0.4391061962f, 0.5217757821f, 0.5560635328f, 0.5217759013f, 0.4391061366f,
         0.3448233008f, 0.2619350851f, 0.1968761832f, 0.1334379166f, 0.0925465375f, 0.0643075034f,
         0.0448416322f, 0.0313772969f, 0.0174134411f, 0.0097163878f, 0.0054394603f, 0.0030510165f,
         0.0000000186f},
        {0.0000000261f, 0.0045054816f, 0.0080264658f, 0.0143180229f, 0.0255970620f, 0.0459137484f,
         0.0653222576f, 0.0930587947f, 0.1325951964f, 0.1883130074f, 0.2643320858f, 0.3264508545f,
         0.4045200646f, 0.4876139462f, 0.5534963012f, 0.5791235566f, 0.5534963012f, 0.4876138866f,
         0.4045200944f, 0.3264508843f, 0.2643321157f, 0.1883129925f, 0.1325951964f, 0.0930587873f,
         0.0653222650f, 0.0459137484f, 0.0255970657f, 0.0143180229f, 0.0080264658f, 0.0045054816f,
         0.0000000261f},
        {0.0000000298f, 0.0052370913f, 0.0093230158f, 0.0166091397f, 0.0296230800f, 0.0529078096f,
         0.0749611408f, 0.1061499193f, 0.1499306262f, 0.2102518976f, 0.2898877263f, 0.3526277840f,
         0.4186539352f, 0.4797269106f, 0.5241174698f, 0.5405187011f, 0.5241175294f, 0.4797268510f,
         0.4186539650f, 0.3526278138f, 0.2898877263f, 0.2102518976f, 0.1499306262f, 0.1061499119f,
         0.0749611482f, 0.0529078059f, 0.0296230800f, 0.0166091397f, 0.0093230195f, 0.0052370913f,
         0.0000000298f},
        {0.0000000298f, 0.0056232363f, 0.0099989995f, 0.0177771747f, 0.0315911807f, 0.0560568646f,
         0.0789347738f, 0.1108068749f, 0.1546058059f, 0.2131874412f, 0.2874797881f, 0.3436433673f,
         0.4005688727f, 0.4512940049f, 0.4870318770f, 0.5000000000f, 0.4870318770f, 0.4512939751f,
         0.4005689025f, 0.3436433673f, 0.2874797881f, 0.2131874263f, 0.1546057910f, 0.1108068675f,
         0.0789347813f, 0.0560568646f, 0.0315911844f, 0.0177771747f, 0.0099989995f, 0.0056232363f,
         0.0000000298f},
        {0.0000000261f, 0.0045337155f, 0.0080470815f, 0.0142611191f, 0.0252004601f, 0.0442794114f,
         0.0617907457f, 0.0856798664f, 0.1175989881f, 0.1587630510f, 0.2086764723f, 0.2448662668f,
         0.2803090215f, 0.3109185398f, 0.3319681287f, 0.3395054638f, 0.3319681585f, 0.3109185100f,
         0.2803090215f, 0.2448662668f, 0.2086764574f, 0.1587630361f, 0.1175989881f, 0.0856798664f,
         0.0617907532f, 0.0442794114f, 0.0252004638f, 0.0142611191f, 0.0080470815f, 0.0045337155f,
         0.0000000261f},
        {0.0000000037f, 0.0007901490f, 0.0014007613f, 0.0024771392f, 0.0043610819f, 0.0076146238f,
         0.0105665363f, 0.0145437419f, 0.0197744034f, 0.0263919048f, 0.0342439152f, 0.0398325771f,
         0.0452299826f, 0.0498363897f, 0.0529768690f, 0.0540962666f, 0.0529768690f, 0.0498363897f,
         0.0452299863f, 0.0398325771f, 0.0342439152f, 0.0263919011f, 0.0197744034f, 0.0145437419f,
         0.0105665363f, 0.0076146238f, 0.0043610819f, 0.0024771392f, 0.0014007613f, 0.0007901490f,
         0.0000000037f}},
    {

        {0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f},
        {0.0000000112f, 0.0019683354f, 0.0035055354f, 0.0062500574f, 0.0111629069f, 0.0199882090f,
         0.0283894800f, 0.0403442569f, 0.0572769158f, 0.0809144601f, 0.1127139255f, 0.1382882297f,
         0.1657483131f, 0.1942400485f, 0.2178780138f, 0.2269225717f, 0.2178780288f, 0.1942400336f,
         0.1657482982f, 0.1382882297f, 0.1127139255f, 0.0809144527f, 0.0572769195f, 0.0403442495f,
         0.0283894837f, 0.0199882090f, 0.0111629069f, 0.0062500574f, 0.0035055354f, 0.0019683354f,
         0.0000000112f},
        {0.0000000186f, 0.0030463114f, 0.0054244995f, 0.0096685886f, 0.0172595158f, 0.0308753066f,
         0.0438121483f, 0.0621782839f, 0.0881035700f, 0.1241139099f, 0.1722071767f, 0.2105752081f,
         0.2514455616f, 0.2897335589f, 0.3197217584f, 0.3322763145f, 0.3197217584f, 0.2897335589f,
         0.2514455616f, 0.2105752081f, 0.1722071916f, 0.1241139099f, 0.0881035626f, 0.0621782765f,
         0.0438121520f, 0.0308753066f, 0.0172595195f, 0.0096685886f, 0.0054244995f, 0.0030463114f,
         0.0000000186f},
        {0.0000000261f, 0.0045005269f, 0.0080107339f, 0.0142679065f, 0.0254365876f, 0.0453957841f,
         0.0642707124f, 0.0909159109f, 0.1282205731f, 0.1794259250f, 0.2466703802f, 0.2993502319f,
         0.3544936478f, 0.4052205384f, 0.4419170022f, 0.4554374814f, 0.4419170320f, 0.4052205086f,
         0.3544936776f, 0.2993502319f, 0.2466703951f, 0.1794259250f, 0.1282205731f, 0.0909159034f,
         0.0642707199f, 0.0453957841f, 0.0254365914f, 0.0142679065f, 0.0080107339f, 0.0045005269f,
         0.0000000261f},
        {0.0000000298f, 0.0052335747f, 0.0093118623f, 0.0165737085f, 0.0295102485f, 0.0525471680f,
         0.0742358714f, 0.1046918780f, 0.1470117569f, 0.2044855654f, 0.2788636386f, 0.3362472057f,
         0.3954694569f, 0.4491762221f, 0.4875625670f, 0.5016064048f, 0.4875625968f, 0.4491762221f,
         0.3954694867f, 0.3362472057f, 0.2788636386f, 0.2044855654f, 0.1470117569f, 0.1046918631f,
         0.0742358789f, 0.0525471680f, 0.0295102522f, 0.0165737085f, 0.0093118623f, 0.0052335709f,
         0.0000000298f},
        {0.0000000298f, 0.0056232363f, 0.0099989995f, 0.0177771747f, 0.0315911807f, 0.0560568646f,
         0.0789347738f, 0.1108068749f, 0.1546058059f, 0.2131874412f, 0.2874797881f, 0.3436433673f,
         0.4005688727f, 0.4512940049f, 0.4870318770f, 0.5000000000f, 0.4870318770f, 0.4512939751f,
         0.4005689025f, 0.3436433673f, 0.2874797881f, 0.2131874263f, 0.1546057910f, 0.1108068675f,
         0.0789347813f, 0.0560568646f, 0.0315911844f, 0.0177771747f, 0.0099989995f, 0.0056232363f,
         0.0000000298f},
        {0.0000000261f, 0.0045385733f, 0.0080623738f, 0.0143091008f, 0.0253500044f, 0.0447396338f,
         0.0626842678f, 0.0873906389f, 0.1208031848f, 0.1645577550f, 0.2185891271f, 0.2584138811f,
         0.2979290783f, 0.3324524164f, 0.3564015627f, 0.3650175929f, 0.3564015925f, 0.3324523866f,
         0.2979291081f, 0.2584138811f, 0.2185891420f, 0.1645577699f, 0.1208031774f, 0.0873906240f,
         0.0626842752f, 0.0447396338f, 0.0253500082f, 0.0143091008f, 0.0080623738f, 0.0045385733f,
         0.0000000261f},
        {0.0000000037f, 0.0007915683f, 0.0014052205f, 0.0024910569f, 0.0044040829f, 0.0077450164f,
         0.0108163506f, 0.0150136538f, 0.0206346437f, 0.0279043429f, 0.0367485955f, 0.0431800336f,
         0.0494931713f, 0.0549562946f, 0.0587187931f, 0.0600671172f, 0.0587187931f, 0.0549562946f,
         0.0494931750f, 0.0431800373f, 0.0367485955f, 0.0279043429f, 0.0206346437f, 0.0150136538f,
         0.0108163506f, 0.0077450164f, 0.0044040829f, 0.0024910569f, 0.0014052168f, 0.0007915683f,
         0.0000000037f}},
    {

        {0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f},
        {0.0000000112f, 0.0019643605f, 0.0034929439f, 0.0062100887f, 0.0110357292f, 0.0195823126f,
         0.0275742412f, 0.0387081020f, 0.0540083535f, 0.0744726434f, 0.1004251465f, 0.1200447381f,
         0.1399304867f, 0.1576502621f, 0.1701345593f, 0.1746647060f, 0.1701345742f, 0.1576502621f,
         0.1399305016f, 0.1200447381f, 0.1004251465f, 0.0744726434f, 0.0540083535f, 0.0387080982f,
         0.0275742412f, 0.0195823126f, 0.0110357292f, 0.0062100887f, 0.0034929439f, 0.0019643605f,
         0.0000000112f},
        {0.0000000186f, 0.0030407943f, 0.0054070093f, 0.0096130967f, 0.0170830972f, 0.0303130411f,
         0.0426843874f, 0.0599193908f, 0.0836038888f, 0.1152822077f, 0.1554561853f, 0.1858269274f,
         0.2166096866f, 0.2440395653f, 0.2633650005f, 0.2703775764f, 0.2633650303f, 0.2440395504f,
         0.2166097015f, 0.1858269274f, 0.1554561853f, 0.1152822077f, 0.0836038888f, 0.0599193871f,
         0.0426843911f, 0.0303130411f, 0.0170830972f, 0.0096130967f, 0.0054070130f, 0.0030407943f,
         0.0000000186f},
        {0.0000000261f, 0.0044947043f, 0.0079922937f, 0.0142094567f, 0.0252511203f, 0.0448067673f,
         0.0630932897f, 0.0885689482f, 0.1235778332f, 0.1704026759f, 0.2297852188f, 0.2746772766f,
         0.3201783597f, 0.3607234061f, 0.3892890215f, 0.3996545672f, 0.3892890513f, 0.3607234061f,
         0.3201783895f, 0.2746773064f, 0.2297852337f, 0.1704026610f, 0.1235778257f, 0.0885689408f,
         0.0630932897f, 0.0448067635f, 0.0252511241f, 0.0142094567f, 0.0079922937f, 0.0044947043f,
         0.0000000261f},
        {0.0000000298f, 0.0052294321f, 0.0092987530f, 0.0165322050f, 0.0293787941f, 0.0521311015f,
         0.0734068304f, 0.1030468717f, 0.1437784731f, 0.1982575357f, 0.2673470378f, 0.3195773959f,
         0.3725163043f, 0.4196890593f, 0.4529241323f, 0.4649840891f, 0.4529241621f, 0.4196890295f,
         0.3725163341f, 0.3195773959f, 0.2673470676f, 0.1982575357f, 0.1437784731f, 0.1030468568f,
         0.0734068379f, 0.0521311015f, 0.0293787979f, 0.0165322050f, 0.0092987530f, 0.0052294284f,
         0.0000000298f},
        {0.0000000298f, 0.0056232363f, 0.0099989995f, 0.0177771747f, 0.0315911807f, 0.0560568646f,
         0.0789347738f, 0.1108068749f, 0.1546058059f, 0.2131874412f, 0.2874797881f, 0.3436433673f,
         0.4005688727f, 0.4512940049f, 0.4870318770f, 0.5000000000f, 0.4870318770f, 0.4512939751f,
         0.4005689025f, 0.3436433673f, 0.2874797881f, 0.2131874263f, 0.1546057910f, 0.1108068675f,
         0.0789347813f, 0.0560568646f, 0.0315911844f, 0.0177771747f, 0.0099989995f, 0.0056232363f,
         0.0000000298f},
        {0.0000000261f, 0.0045443214f, 0.0080805235f, 0.0143663213f, 0.0255298801f, 0.0453014039f,
         0.0637897998f, 0.0895466954f, 0.1249420568f, 0.1722838134f, 0.2323219031f, 0.2777095437f,
         0.3237129450f, 0.3647055924f, 0.3935865462f, 0.4040665329f, 0.3935865760f, 0.3647055626f,
         0.3237129450f, 0.2777095735f, 0.2323219180f, 0.1722838134f, 0.1249420494f, 0.0895466879f,
         0.0637898073f, 0.0453014039f, 0.0255298801f, 0.0143663213f, 0.0080805235f, 0.0045443214f,
         0.0000000261f},
        {0.0000000037f, 0.0007932559f, 0.0014105327f, 0.0025077760f, 0.0044564828f, 0.0079077892f,
         0.0111351162f, 0.0156312287f, 0.0218098238f, 0.0300737768f, 0.0405539945f, 0.0484768376f,
         0.0565071665f, 0.0636628196f, 0.0687042698f, 0.0705336481f, 0.0687042698f, 0.0636628196f,
         0.0565071702f, 0.0484768413f, 0.0405539945f, 0.0300737731f, 0.0218098238f, 0.0156312250f,
         0.0111351162f, 0.0079077892f, 0.0044564828f, 0.0025077760f, 0.0014105327f, 0.0007932559f,
         0.0000000037f}},
    {

        {0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f},
        {0.0000000112f, 0.0019604117f, 0.0034804866f, 0.0061708763f, 0.0109128021f, 0.0192001797f,
         0.0268254243f, 0.0372561179f, 0.0512422584f, 0.0693590865f, 0.0914405733f, 0.1075243428f,
         0.1233326122f, 0.1370278746f, 0.1464678645f, 0.1498522907f, 0.1464678794f, 0.1370278597f,
         0.1233326122f, 0.1075243428f, 0.0914405733f, 0.0693590865f, 0.0512422547f, 0.0372561105f,
         0.0268254280f, 0.0192001797f, 0.0109128058f, 0.0061708800f, 0.0034804903f, 0.0019604117f,
         0.0000000112f},
        {0.0000000186f, 0.0030353032f, 0.0053896904f, 0.0095585547f, 0.0169119760f, 0.0297804140f,
         0.0416394584f, 0.0578900538f, 0.0797299594f, 0.1081020311f, 0.1428017914f, 0.1681542546f,
         0.1931329668f, 0.2148192078f, 0.2297913432f, 0.2351637781f, 0.2297913432f, 0.2148191929f,
         0.1931329668f, 0.1681542546f, 0.1428017914f, 0.1081020236f, 0.0797299519f, 0.0578900538f,
         0.0416394621f, 0.0297804177f, 0.0169119798f, 0.0095585547f, 0.0053896904f, 0.0030353032f,
         0.0000000186f},
        {0.0000000261f, 0.0044889040f, 0.0079739802f, 0.0141517222f, 0.0250696540f, 0.0442400984f,
         0.0619782880f, 0.0863948390f, 0.1194054484f, 0.1626167595f, 0.2159518152f, 0.2552460730f,
         0.2942210138f, 0.3282613754f, 0.3518696427f, 0.3603619635f, 0.3518696725f, 0.3282613456f,
         0.2942210138f, 0.2552460730f, 0.2159518450f, 0.1626167595f, 0.1194054410f, 0.0863948315f,
         0.0619782880f, 0.0442400984f, 0.0250696540f, 0.0141517222f, 0.0079739802f, 0.0044889040f,
         0.0000000261f},
        {0.0000000298f, 0.0052252971f, 0.0092856996f, 0.0164910108f, 0.0292490833f, 0.0517247654f,
         0.0726049617f, 0.1014770418f, 0.1407495439f, 0.1925659627f, 0.2571487725f, 0.3051639795f,
         0.3531456888f, 0.3953380287f, 0.4247539639f, 0.4353657961f, 0.4247539937f, 0.3953379989f,
         0.3531457186f, 0.3051639795f, 0.2571487725f, 0.1925659627f, 0.1407495439f, 0.1014770344f,
         0.0726049691f, 0.0517247617f, 0.0292490870f, 0.0164910108f, 0.0092856996f, 0.0052252971f,
         0.0000000298f},
        {0.0000000298f, 0.0056232363f, 0.0099989995f, 0.0177771747f, 0.0315911807f, 0.0560568646f,
         0.0789347738f, 0.1108068749f, 0.1546058059f, 0.2131874412f, 0.2874797881f, 0.3436433673f,
         0.4005688727f, 0.4512940049f, 0.4870318770f, 0.5000000000f, 0.4870318770f, 0.4512939751f,
         0.4005689025f, 0.3436433673f, 0.2874797881f, 0.2131874263f, 0.1546057910f, 0.1108068675f,
         0.0789347813f, 0.0560568646f, 0.0315911844f, 0.0177771747f, 0.0099989995f, 0.0056232363f,
         0.0000000298f},
        {0.0000000261f, 0.0045500919f, 0.0080987960f, 0.0144242346f, 0.0257136337f, 0.0458848849f,
         0.0649559572f, 0.0918706506f, 0.1295377463f, 0.1812113971f, 0.2490174472f, 0.3020929396f,
         0.3576069772f, 0.4086337686f, 0.4455218017f, 0.4591074288f, 0.4455218613f, 0.4086337388f,
         0.3576069772f, 0.3020929396f, 0.2490174621f, 0.1812113971f, 0.1295377314f, 0.0918706357f,
         0.0649559572f, 0.0458848849f, 0.0257136375f, 0.0144242346f, 0.0080987960f, 0.0045500919f,
         0.0000000261f},
        {0.0000000037f, 0.0007949509f, 0.0014159046f, 0.0025248416f, 0.0045107976f, 0.0080812797f,
         0.0114838332f, 0.0163318664f, 0.0232117549f, 0.0328431986f, 0.0458545387f, 0.0563677736f,
         0.0677092671f, 0.0806207359f, 0.0907390416f, 0.0946287960f, 0.0907390490f, 0.0806207284f,
         0.0677092746f, 0.0563677773f, 0.0458545424f, 0.0328431986f, 0.0232117511f, 0.0163318627f,
         0.0114838332f, 0.0080812797f, 0.0045107976f, 0.0025248416f, 0.0014159046f, 0.0007949509f,
         0.0000000037f}},
    {

        {0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f},
        {0.0000000112f, 0.0019570850f, 0.0034700334f, 0.0061382130f, 0.0108117498f, 0.0188931711f,
         0.0262362324f, 0.0361453071f, 0.0492029004f, 0.0657609925f, 0.0854583159f, 0.0995077118f,
         0.1130974963f, 0.1247107610f, 0.1326356232f, 0.1354617476f, 0.1326356232f, 0.1247107536f,
         0.1130975038f, 0.0995077044f, 0.0854583159f, 0.0657609925f, 0.0492029004f, 0.0361453034f,
         0.0262362324f, 0.0188931711f, 0.0108117498f, 0.0061382130f, 0.0034700334f, 0.0019570850f,
         0.0000000112f},
        {0.0000000186f, 0.0030306727f, 0.0053751357f, 0.0095130354f, 0.0167708695f, 0.0293502137f,
         0.0408112556f, 0.0563221611f, 0.0768360794f, 0.1029630005f, 0.1341941655f, 0.1565610766f,
         0.1782617718f, 0.1968532801f, 0.2095632553f, 0.2141001821f, 0.2095632553f, 0.1968532652f,
         0.1782617867f, 0.1565610915f, 0.1341941804f, 0.1029629931f, 0.0768360794f, 0.0563221574f,
         0.0408112593f, 0.0293502137f, 0.0167708695f, 0.0095130354f, 0.0053751357f, 0.0030306727f,
         0.0000000186f},
        {0.0000000261f, 0.0044840015f, 0.0079585500f, 0.0141033232f, 0.0249188393f, 0.0437761769f,
         0.0610779524f, 0.0846719742f, 0.1161808893f, 0.1567904651f, 0.2059956193f, 0.2416490465f,
         0.2765491605f, 0.3066769838f, 0.3273887634f, 0.3348038197f, 0.3273887634f, 0.3066769540f,
         0.2765491605f, 0.2416490614f, 0.2059956342f, 0.1567904651f, 0.1161808893f, 0.0846719667f,
         0.0610779561f, 0.0437761769f, 0.0249188431f, 0.0141033232f, 0.0079585500f, 0.0044840015f,
         0.0000000261f},
        {0.0000000298f, 0.0052218027f, 0.0092746764f, 0.0164563321f, 0.0291404575f, 0.0513876267f,
         0.0719453543f, 0.1002009511f, 0.1383263767f, 0.1881065071f, 0.2493602335f, 0.2943610847f,
         0.3388943374f, 0.3777095377f, 0.4045871496f, 0.4142472148f, 0.4045871794f, 0.3777095079f,
         0.3388943672f, 0.2943610847f, 0.2493602484f, 0.1881065071f, 0.1383263767f, 0.1002009436f,
         0.0719453618f, 0.0513876304f, 0.0291404612f, 0.0164563321f, 0.0092746764f, 0.0052218027f,
         0.0000000298f},
        {0.0000000298f, 0.0056232363f, 0.0099989995f, 0.0177771747f, 0.0315911807f, 0.0560568646f,
         0.0789347738f, 0.1108068749f, 0.1546058059f, 0.2131874412f, 0.2874797881f, 0.3436433673f,
         0.4005688727f, 0.4512940049f, 0.4870318770f, 0.5000000000f, 0.4870318770f, 0.4512939751f,
         0.4005689025f, 0.3436433673f, 0.2874797881f, 0.2131874263f, 0.1546057910f, 0.1108068675f,
         0.0789347813f, 0.0560568646f, 0.0315911844f, 0.0177771747f, 0.0099989995f, 0.0056232363f,
         0.0000000298f},
        {0.0000000261f, 0.0045550019f, 0.0081143826f, 0.0144738853f, 0.0258725621f, 0.0463975929f,
         0.0659963340f, 0.0939892456f, 0.1338582933f, 0.1899754107f, 0.2663972974f, 0.3287125826f,
         0.4048410356f, 0.4869871140f, 0.5518758297f, 0.5770589113f, 0.5518758893f, 0.4869870842f,
         0.4048410952f, 0.3287125826f, 0.2663973570f, 0.1899754107f, 0.1338582933f, 0.0939892307f,
         0.0659963414f, 0.0463975891f, 0.0258725658f, 0.0144738853f, 0.0081143863f, 0.0045550019f,
         0.0000000261f},
        {0.0000000037f, 0.0007963963f, 0.0014205091f, 0.0025395826f, 0.0045584328f, 0.0082376562f,
         0.0118066110f, 0.0170059167f, 0.0246388987f, 0.0359060094f, 0.0565599203f, 0.0778557062f,
         0.1072221622f, 0.1441027969f, 0.1799743026f, 0.1959500462f, 0.1799743474f, 0.1441027820f,
         0.1072221696f, 0.0778557062f, 0.0565599203f, 0.0359060094f, 0.0246388987f, 0.0170059167f,
         0.0118066110f, 0.0082376562f, 0.0045584328f, 0.0025395826f, 0.0014205091f, 0.0007963963f,
         0.0000000037f}},
    {

        {0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
         0.0000000000f},
        {0.0000000112f, 0.0019548684f, 0.0034630969f, 0.0061166696f, 0.0107457712f, 0.0186960548f,
         0.0258635134f, 0.0354561731f, 0.0479685590f, 0.0636471361f, 0.0820589438f, 0.0950533152f,
         0.1075267568f, 0.1181191504f, 0.1253151745f, 0.1278754473f, 0.1253151745f, 0.1181191429f,
         0.1075267568f, 0.0950533152f, 0.0820589513f, 0.0636471361f, 0.0479685590f, 0.0354561731f,
         0.0258635171f, 0.0186960548f, 0.0107457712f, 0.0061166734f, 0.0034630969f, 0.0019548684f,
         0.0000000112f},
        {0.0000000186f, 0.0030275919f, 0.0053654797f, 0.0094829798f, 0.0166785270f, 0.0290729403f,
         0.0402846411f, 0.0553428568f, 0.0750693232f, 0.0999113992f, 0.1292407066f, 0.1500300914f,
         0.1700480729f, 0.1870902777f, 0.1986886710f, 0.2028190494f, 0.1986886710f, 0.1870902628f,
         0.1700480729f, 0.1500301063f, 0.1292407066f, 0.0999113992f, 0.0750693232f, 0.0553428493f,
         0.0402846411f, 0.0290729403f, 0.0166785270f, 0.0094829798f, 0.0053654797f, 0.0030275919f,
         0.0000000186f},
        {0.0000000261f, 0.0044807382f, 0.0079482906f, 0.0140712596f, 0.0248195715f, 0.0434742048f,
         0.0604977794f, 0.0835766271f, 0.1141664237f, 0.1532292813f, 0.2000626326f, 0.2336882651f,
         0.2663741410f, 0.2944218218f, 0.3136188090f, 0.3204754591f, 0.3136188090f, 0.2944217920f,
         0.2663741708f, 0.2336882651f, 0.2000626326f, 0.1532292962f, 0.1141664162f, 0.0835766271f,
         0.0604977906f, 0.0434742048f, 0.0248195753f, 0.0140712596f, 0.0079482906f, 0.0044807382f,
         0.0000000261f},
        {0.0000000298f, 0.0052194707f, 0.0092673339f, 0.0164332762f, 0.0290685408f, 0.0511660054f,
         0.0715145171f, 0.0993746519f, 0.1367753297f, 0.1852938682f, 0.2445339411f, 0.2877510786f,
         0.3302804530f, 0.3671652079f, 0.3926102221f, 0.4017367959f, 0.3926102519f, 0.3671651781f,
         0.3302804828f, 0.2877510488f, 0.2445339262f, 0.1852938682f, 0.1367753297f, 0.0993746296f,
         0.0715145245f, 0.0511660017f, 0.0290685445f, 0.0164332762f, 0.0092673302f, 0.0052194707f,
         0.0000000298f},
        {0.0000000298f, 0.0056232363f, 0.0099989995f, 0.0177771747f, 0.0315911807f, 0.0560568646f,
         0.0789347738f, 0.1108068749f, 0.1546058059f, 0.2131874412f, 0.2874797881f, 0.3436433673f,
         0.4005688727f, 0.4512940049f, 0.4870318770f, 0.5000000000f, 0.4870318770f, 0.4512939751f,
         0.4005689025f, 0.3436433673f, 0.2874797881f, 0.2131874263f, 0.1546057910f, 0.1108068675f,
         0.0789347813f, 0.0560568646f, 0.0315911844f, 0.0177771747f, 0.0099989995f, 0.0056232363f,
         0.0000000298f},
        {0.0000000261f, 0.0045582913f, 0.0081248507f, 0.0145073459f, 0.0259804092f, 0.0467499122f,
         0.0667200089f, 0.0954893604f, 0.1369983852f, 0.1965934485f, 0.2817551196f, 0.3696863651f,
         0.4782578051f, 0.5972789526f, 0.6979248524f, 0.7386929989f, 0.6979249120f, 0.5972788930f,
         0.4782578349f, 0.3696863651f, 0.2817551494f, 0.1965934485f, 0.1369983703f, 0.0954893529f,
         0.0667200163f, 0.0467499122f, 0.0259804130f, 0.0145073459f, 0.0081248507f, 0.0045582913f,
         0.0000000261f},
        {0.0000000037f, 0.0007973649f, 0.0014236122f, 0.0025495738f, 0.0045911148f, 0.0083473474f,
         0.0120380968f, 0.0175057761f, 0.0257535614f, 0.0410830304f, 0.0712796301f, 0.1087764949f,
         0.1762015969f, 0.3041011989f, 0.5248691440f, 0.6885961890f, 0.5248694420f, 0.3041011393f,
         0.1762016118f, 0.1087765023f, 0.0712796375f, 0.0410830304f, 0.0257535614f, 0.0175057724f,
         0.0120380968f, 0.0083473474f, 0.0045911148f, 0.0025495775f, 0.0014236122f, 0.0007973649f,
         0.0000000037f}}};

const FLOAT32 ixheaacd_weight[16][8][31] = {
    {

        {0.5000000596f, 0.5028037429f, 0.5049747229f, 0.5088109374f, 0.5155536532f, 0.5272839665f,
         0.5380217433f, 0.5526331663f, 0.5721039176f, 0.5971546769f, 0.6274869442f, 0.6494780183f,
         0.6710323095f, 0.6896716356f, 0.7025068998f, 0.7071067691f, 0.7025068998f, 0.6896716356f,
         0.6710323691f, 0.6494780183f, 0.6274869442f, 0.5971546769f, 0.5721039176f, 0.5526331663f,
         0.5380217433f, 0.5272839665f, 0.5155536532f, 0.5088109374f, 0.5049747825f, 0.5028037429f,
         0.5000000596f},
        {0.5000000000f, 0.5026275516f, 0.5046628118f, 0.5082603693f, 0.5145876408f, 0.5256069303f,
         0.5357060432f, 0.5494661331f, 0.5678316951f, 0.5915051103f, 0.6202291846f, 0.6410904527f,
         0.6615636945f, 0.6792872548f, 0.6915015578f, 0.6958807707f, 0.6915016174f, 0.6792873144f,
         0.6615636945f, 0.6410903931f, 0.6202292442f, 0.5915051103f, 0.5678316951f, 0.5494661331f,
         0.5357059836f, 0.5256069303f, 0.5145876408f, 0.5082603693f, 0.5046628118f, 0.5026275516f,
         0.5000000596f},
        {0.5000000000f, 0.5023595095f, 0.5041879416f, 0.5074218512f, 0.5131149292f, 0.5230458379f,
         0.5321645737f, 0.5446138382f, 0.5612714887f, 0.5828074217f, 0.6090247035f, 0.6281185746f,
         0.6468966603f, 0.6631815434f, 0.6744188070f, 0.6784504652f, 0.6744188070f, 0.6631814837f,
         0.6468966603f, 0.6281185746f, 0.6090247035f, 0.5828074217f, 0.5612714887f, 0.5446138978f,
         0.5321645737f, 0.5230458379f, 0.5131149292f, 0.5074217916f, 0.5041879416f, 0.5023595095f,
         0.5000000596f},
        {0.5000000000f, 0.5016866922f, 0.5029953122f, 0.5053130984f, 0.5094034672f, 0.5165683627f,
         0.5231794715f, 0.5322527885f, 0.5444748402f, 0.5604054928f, 0.5799794793f, 0.5943493247f,
         0.6085679531f, 0.6209635735f, 0.6295502782f, 0.6326373219f, 0.6295503378f, 0.6209636331f,
         0.6085679531f, 0.5943493247f, 0.5799794793f, 0.5604054928f, 0.5444748402f, 0.5322527885f,
         0.5231794715f, 0.5165683627f, 0.5094034672f, 0.5053130984f, 0.5029953122f, 0.5016866922f,
         0.5000000596f},
        {0.5000000000f, 0.5010325909f, 0.5018346906f, 0.5032572150f, 0.5057737827f, 0.5102003217f,
         0.5143051744f, 0.5199697018f, 0.5276548266f, 0.5377621055f, 0.5503131151f, 0.5596145988f,
         0.5688871741f, 0.5770241618f, 0.5826888084f, 0.5847306848f, 0.5826888084f, 0.5770241618f,
         0.5688871145f, 0.5596145988f, 0.5503131151f, 0.5377621055f, 0.5276548266f, 0.5199697614f,
         0.5143051147f, 0.5102003217f, 0.5057737231f, 0.5032572150f, 0.5018346906f, 0.5010325909f,
         0.5000000000f},
        {0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f},
        {0.5000000000f, 0.4983411729f, 0.4970465600f, 0.4947369397f, 0.4906081855f, 0.4832093418f,
         0.4761866629f, 0.4662267566f, 0.4521820247f, 0.4326849580f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4326850176f, 0.4521820247f, 0.4662267566f,
         0.4761866629f, 0.4832093418f, 0.4906081855f, 0.4947369397f, 0.4970465600f, 0.4983412325f,
         0.5000000000f},
        {0.5000000000f, 0.4972087145f, 0.4950257242f, 0.4911214709f, 0.4841098487f, 0.4714359641f,
         0.4592681825f, 0.4417585433f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4417585433f,
         0.4592681825f, 0.4714359641f, 0.4841098487f, 0.4911214709f, 0.4950257242f, 0.4972087145f,
         0.5000000000f}},
    {

        {0.5000000000f, 0.5025908947f, 0.5045977831f, 0.5081456304f, 0.5143862367f, 0.5252569914f,
         0.5352224708f, 0.5488042235f, 0.5669378638f, 0.5903217196f, 0.6187070012f, 0.6393297315f,
         0.6595746279f, 0.6771045923f, 0.6891874671f, 0.6935198903f, 0.6891874671f, 0.6771045923f,
         0.6595746279f, 0.6393297315f, 0.6187070012f, 0.5903217793f, 0.5669378638f, 0.5488042235f,
         0.5352224708f, 0.5252569914f, 0.5143862367f, 0.5081456304f, 0.5045977831f, 0.5025908947f,
         0.5000000596f},
        {0.5000000000f, 0.5024280548f, 0.5043093562f, 0.5076363087f, 0.5134918094f, 0.5237017274f,
         0.5330721736f, 0.5458583832f, 0.5629557371f, 0.5850431919f, 0.6119084954f, 0.6314600110f,
         0.6506775022f, 0.6673356891f, 0.6788267493f, 0.6829485893f, 0.6788267493f, 0.6673356891f,
         0.6506775022f, 0.6314600110f, 0.6119084954f, 0.5850431919f, 0.5629557371f, 0.5458583832f,
         0.5330721736f, 0.5237017274f, 0.5134918094f, 0.5076363087f, 0.5043093562f, 0.5024280548f,
         0.5000000596f},
        {0.5000000000f, 0.5021802783f, 0.5038703680f, 0.5068606734f, 0.5121284127f, 0.5213274360f,
         0.5297849178f, 0.5413471460f, 0.5568445921f, 0.5769221783f, 0.6014210582f, 0.6192988157f,
         0.6369072795f, 0.6521973014f, 0.6627579927f, 0.6665487289f, 0.6627579927f, 0.6521973014f,
         0.6369072795f, 0.6192988157f, 0.6014210582f, 0.5769221783f, 0.5568445921f, 0.5413471460f,
         0.5297849178f, 0.5213274360f, 0.5121284127f, 0.5068606734f, 0.5038703680f, 0.5021802783f,
         0.5000000596f},
        {0.5000000000f, 0.5015584826f, 0.5027679205f, 0.5049106479f, 0.5086937547f, 0.5153259039f,
         0.5214512348f, 0.5298667550f, 0.5412179232f, 0.5560381413f, 0.5742831826f, 0.5877002478f,
         0.6009937525f, 0.6125962734f, 0.6206405163f, 0.6235337853f, 0.6206405163f, 0.6125962138f,
         0.6009937525f, 0.5877002478f, 0.5742831826f, 0.5560382009f, 0.5412179232f, 0.5298667550f,
         0.5214512944f, 0.5153258443f, 0.5086938143f, 0.5049106479f, 0.5027679205f, 0.5015585423f,
         0.5000000596f},
        {0.5000000000f, 0.5009540319f, 0.5016952753f, 0.5030100346f, 0.5053365231f, 0.5094310641f,
         0.5132302642f, 0.5184766650f, 0.5256009102f, 0.5349814296f, 0.5466461182f, 0.5553017855f,
         0.5639393330f, 0.5715261102f, 0.5768113732f, 0.5787173510f, 0.5768114328f, 0.5715261102f,
         0.5639393926f, 0.5553017855f, 0.5466461182f, 0.5349814296f, 0.5256009102f, 0.5184766650f,
         0.5132302642f, 0.5094310641f, 0.5053365827f, 0.5030099750f, 0.5016952157f, 0.5009540319f,
         0.5000000000f},
        {0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f},
        {0.5000000000f, 0.4984676838f, 0.4972720146f, 0.4951395094f, 0.4913294315f, 0.4845078886f,
         0.4780410528f, 0.4688831270f, 0.4559983313f, 0.4381728470f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4381728470f, 0.4559983313f, 0.4688831270f,
         0.4780410528f, 0.4845078886f, 0.4913294315f, 0.4951395094f, 0.4972720146f, 0.4984676838f,
         0.5000000000f},
        {0.5000000000f, 0.4974217415f, 0.4954061210f, 0.4918029308f, 0.4853377044f, 0.4736708105f,
         0.4624948800f, 0.4464591146f, 0.4234331250f, 0.4166666567f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4234331250f, 0.4464591146f,
         0.4624949098f, 0.4736708105f, 0.4853377044f, 0.4918029308f, 0.4954061210f, 0.4974217415f,
         0.5000000000f}},
    {

        {0.5000000000f, 0.5019841790f, 0.5035227537f, 0.5062461495f, 0.5110471249f, 0.5194411278f,
         0.5271694660f, 0.5377510190f, 0.5519614220f, 0.5704149008f, 0.5929919481f, 0.6095049381f,
         0.6257974505f, 0.6399660110f, 0.6497628689f, 0.6532815099f, 0.6497628689f, 0.6399660110f,
         0.6257974505f, 0.6095049381f, 0.5929919481f, 0.5704149008f, 0.5519614220f, 0.5377510190f,
         0.5271694660f, 0.5194411874f, 0.5110471249f, 0.5062461495f, 0.5035227537f, 0.5019841790f,
         0.5000000596f},
        {0.5000000000f, 0.5018594265f, 0.5033015609f, 0.5058549047f, 0.5103582144f, 0.5182378888f,
         0.5254992843f, 0.5354512334f, 0.5488330722f, 0.5662372708f, 0.5875679851f, 0.6031931639f,
         0.6186277270f, 0.6320636868f, 0.6413608193f, 0.6447013021f, 0.6413608193f, 0.6320636272f,
         0.6186277270f, 0.6031931639f, 0.5875679851f, 0.5662372708f, 0.5488330722f, 0.5354512334f,
         0.5254992843f, 0.5182378888f, 0.5103582144f, 0.5058549047f, 0.5033015609f, 0.5018594265f,
         0.5000000596f},
        {0.5000000000f, 0.5016695857f, 0.5029649734f, 0.5052592754f, 0.5093086362f, 0.5164023638f,
         0.5229487419f, 0.5319343805f, 0.5440405011f, 0.5598235130f, 0.5792210698f, 0.5934646130f,
         0.6075606942f, 0.6198514104f, 0.6283663511f, 0.6314277649f, 0.6283663511f, 0.6198514104f,
         0.6075607538f, 0.5934646130f, 0.5792211294f, 0.5598235130f, 0.5440405011f, 0.5319343805f,
         0.5229486823f, 0.5164024234f, 0.5093086362f, 0.5052592754f, 0.5029649138f, 0.5016695857f,
         0.5000000596f},
        {0.5000000000f, 0.5011932850f, 0.5021198988f, 0.5037627220f, 0.5066673160f, 0.5117711425f,
         0.5164980888f, 0.5230121613f, 0.5318337679f, 0.5434088707f, 0.5577428937f, 0.5683392882f,
         0.5788815022f, 0.5881162286f, 0.5945363641f, 0.5968489647f, 0.5945363641f, 0.5881162286f,
         0.5788815022f, 0.5683392882f, 0.5577428937f, 0.5434088707f, 0.5318337679f, 0.5230121613f,
         0.5164980888f, 0.5117711425f, 0.5066673160f, 0.5037627220f, 0.5021198988f, 0.5011932850f,
         0.5000000000f},
        {0.5000000000f, 0.5007303953f, 0.5012979507f, 0.5023053885f, 0.5040895343f, 0.5072339773f,
         0.5101568103f, 0.5142010450f, 0.5197073221f, 0.5269821882f, 0.5360659957f, 0.5428322554f,
         0.5496054292f, 0.5555711985f, 0.5597361326f, 0.5612398386f, 0.5597361922f, 0.5555711985f,
         0.5496054292f, 0.5428322554f, 0.5360659957f, 0.5269821286f, 0.5197073221f, 0.5142010450f,
         0.5101568103f, 0.5072339773f, 0.5040895343f, 0.5023053885f, 0.5012980103f, 0.5007303953f,
         0.5000000000f},
        {0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f},
        {0.5000000000f, 0.4988276362f, 0.4979133904f, 0.4962842464f, 0.4933774769f, 0.4881869853f,
         0.4832828939f, 0.4763666987f, 0.4666952491f, 0.4534370899f, 0.4360439777f, 0.4224200249f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4224200249f, 0.4360440373f, 0.4534370899f, 0.4666952491f, 0.4763666987f,
         0.4832829535f, 0.4881869853f, 0.4933775365f, 0.4962842464f, 0.4979134500f, 0.4988276362f,
         0.5000000000f},
        {0.5000000000f, 0.4980278611f, 0.4964878559f, 0.4937384725f, 0.4888174534f, 0.4799782038f,
         0.4715627432f, 0.4595820010f, 0.4425892234f, 0.4187846780f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4187846780f, 0.4425891936f, 0.4595820010f,
         0.4715627432f, 0.4799782038f, 0.4888174534f, 0.4937384725f, 0.4964878559f, 0.4980278611f,
         0.5000000000f}},
    {

        {0.5000000000f, 0.5010747910f, 0.5019095540f, 0.5033900142f, 0.5060086250f, 0.5106133819f,
         0.5148820281f, 0.5207706094f, 0.5287556648f, 0.5392510295f, 0.5522742867f, 0.5619193316f,
         0.5715291500f, 0.5799580812f, 0.5858238339f, 0.5879377723f, 0.5858238339f, 0.5799580812f,
         0.5715291500f, 0.5619193316f, 0.5522742271f, 0.5392510295f, 0.5287556648f, 0.5207706094f,
         0.5148820281f, 0.5106133819f, 0.5060086250f, 0.5033900142f, 0.5019095540f, 0.5010747910f,
         0.5000000000f},
        {0.5000000000f, 0.5010071397f, 0.5017895103f, 0.5031771064f, 0.5056321621f, 0.5099512339f,
         0.5139571428f, 0.5194865465f, 0.5269903541f, 0.5368629098f, 0.5491278768f, 0.5582211614f,
         0.5672890544f, 0.5752488375f, 0.5807913542f, 0.5827894807f, 0.5807913542f, 0.5752488375f,
         0.5672890544f, 0.5582211614f, 0.5491278768f, 0.5368629098f, 0.5269903541f, 0.5194864869f,
         0.5139572024f, 0.5099512339f, 0.5056321621f, 0.5031771064f, 0.5017895103f, 0.5010071397f,
         0.5000000000f},
        {0.5000000000f, 0.5009042621f, 0.5016067624f, 0.5028531551f, 0.5050591230f, 0.5089425445f,
         0.5125473142f, 0.5175274611f, 0.5242940187f, 0.5332102180f, 0.5443075299f, 0.5525490046f,
         0.5607786179f, 0.5680114627f, 0.5730524659f, 0.5748707652f, 0.5730524659f, 0.5680115223f,
         0.5607786775f, 0.5525490046f, 0.5443075299f, 0.5332102180f, 0.5242940187f, 0.5175274611f,
         0.5125473142f, 0.5089425445f, 0.5050590634f, 0.5028531551f, 0.5016067624f, 0.5009042621f,
         0.5000000000f},
        {0.5000000000f, 0.5006461143f, 0.5011484027f, 0.5020399094f, 0.5036193132f, 0.5064044595f,
         0.5089951158f, 0.5125823617f, 0.5174714923f, 0.5239394307f, 0.5320289135f, 0.5380636454f,
         0.5441119671f, 0.5494454503f, 0.5531721711f, 0.5545182824f, 0.5531721711f, 0.5494454503f,
         0.5441119671f, 0.5380636454f, 0.5320289135f, 0.5239394307f, 0.5174714923f, 0.5125823617f,
         0.5089950562f, 0.5064044595f, 0.5036192536f, 0.5020399094f, 0.5011484027f, 0.5006461143f,
         0.5000000000f},
        {0.5000000000f, 0.5003954172f, 0.5007029176f, 0.5012489557f, 0.5022173524f, 0.5039278865f,
         0.5055221915f, 0.5077348351f, 0.5107599497f, 0.5147782564f, 0.5198295116f, 0.5236158371f,
         0.5274257660f, 0.5307977200f, 0.5331605673f, 0.5340154171f, 0.5331605673f, 0.5307977200f,
         0.5274257660f, 0.5236158371f, 0.5198295116f, 0.5147782564f, 0.5107599497f, 0.5077348351f,
         0.5055221915f, 0.5039278865f, 0.5022173524f, 0.5012489557f, 0.5007029176f, 0.5003954172f,
         0.5000000000f},
        {0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f},
        {0.5000000000f, 0.4993658364f, 0.4988718629f, 0.4979924560f, 0.4964269102f, 0.4936419725f,
         0.4910234213f, 0.4873520732f, 0.4822612107f, 0.4753669202f, 0.4664771855f, 0.4596425891f,
         0.4526099563f, 0.4462499917f, 0.4417141378f, 0.4400566816f, 0.4417141378f, 0.4462499917f,
         0.4526099563f, 0.4596425891f, 0.4664771855f, 0.4753669202f, 0.4822612107f, 0.4873520732f,
         0.4910234213f, 0.4936419725f, 0.4964269102f, 0.4979925156f, 0.4988718629f, 0.4993658364f,
         0.5000000000f},
        {0.5000000000f, 0.4989336729f, 0.4981023371f, 0.4966210425f, 0.4939794540f, 0.4892660379f,
         0.4848169982f, 0.4785499275f, 0.4698013365f, 0.4578387141f, 0.4422026277f, 0.4300048947f,
         0.4172779918f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f,
         0.4172779918f, 0.4300048947f, 0.4422026277f, 0.4578386545f, 0.4698013365f, 0.4785499275f,
         0.4848169982f, 0.4892660379f, 0.4939795136f, 0.4966210425f, 0.4981023371f, 0.4989336729f,
         0.5000000000f}},
    {

        {0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f},
        {0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f},
        {0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f},
        {0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f},
        {0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f},
        {0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f},
        {0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f},
        {0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000596f, 0.5000000000f, 0.5000000000f, 0.5000000596f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f}},
    {

        {0.5000000000f, 0.4989228845f, 0.4980831146f, 0.4965868294f, 0.4939183295f, 0.4891564250f,
         0.4846611917f, 0.4783283472f, 0.4694863856f, 0.4573930204f, 0.4415802956f, 0.4292396903f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4292396903f, 0.4415802360f, 0.4573930204f, 0.4694863856f, 0.4783283472f,
         0.4846611917f, 0.4891564250f, 0.4939183295f, 0.4965868294f, 0.4980831146f, 0.4989228845f,
         0.5000000000f},
        {0.5000000000f, 0.4989907742f, 0.4982040823f, 0.4968025982f, 0.4943036735f, 0.4898466468f,
         0.4856418371f, 0.4797225595f, 0.4714670181f, 0.4601936638f, 0.4454868734f, 0.4340382218f,
         0.4221174717f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f,
         0.4221174419f, 0.4340382218f, 0.4454868734f, 0.4601936638f, 0.4714670181f, 0.4797225595f,
         0.4856418371f, 0.4898466468f, 0.4943036735f, 0.4968025982f, 0.4982040823f, 0.4989907742f,
         0.5000000000f},
        {0.5000000000f, 0.4990940988f, 0.4983880222f, 0.4971305132f, 0.4948891699f, 0.4908945858f,
         0.4871295691f, 0.4818353653f, 0.4744636714f, 0.4644210041f, 0.4513638616f, 0.4412364960f,
         0.4307287931f, 0.4211448431f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4211448431f,
         0.4307287931f, 0.4412364960f, 0.4513638616f, 0.4644210041f, 0.4744636118f, 0.4818353653f,
         0.4871295691f, 0.4908945858f, 0.4948891699f, 0.4971305132f, 0.4983880222f, 0.4990940988f,
         0.5000000000f},
        {0.5000000000f, 0.4993529916f, 0.4988490045f, 0.4979517758f, 0.4963543117f, 0.4935124516f,
         0.4908400774f, 0.4870927036f, 0.4818954766f, 0.4748552144f, 0.4657738209f, 0.4587891996f,
         0.4515995979f, 0.4450952113f, 0.4404549301f, 0.4387589991f, 0.4404549301f, 0.4450952113f,
         0.4515995383f, 0.4587891996f, 0.4657738805f, 0.4748552144f, 0.4818954766f, 0.4870927334f,
         0.4908400774f, 0.4935124516f, 0.4963543117f, 0.4979517758f, 0.4988490045f, 0.4993529916f,
         0.5000000000f},
        {0.5000000000f, 0.4996043146f, 0.4992960989f, 0.4987479150f, 0.4977727532f, 0.4960409999f,
         0.4944161773f, 0.4921435714f, 0.4890033603f, 0.4847714305f, 0.4793508947f, 0.4752120376f,
         0.4709798396f, 0.4671763778f, 0.4644779861f, 0.4634949565f, 0.4644779861f, 0.4671763778f,
         0.4709798396f, 0.4752120376f, 0.4793508947f, 0.4847714305f, 0.4890033603f, 0.4921435714f,
         0.4944161773f, 0.4960409999f, 0.4977727532f, 0.4987478554f, 0.4992960989f, 0.4996043146f,
         0.5000000000f},
        {0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f},
        {0.5000000000f, 0.5006332994f, 0.5011256337f, 0.5019994974f, 0.5035477281f, 0.5062782168f,
         0.5088182092f, 0.5123358369f, 0.5171306729f, 0.5234751701f, 0.5314123034f, 0.5373347998f,
         0.5432717204f, 0.5485079288f, 0.5521671772f, 0.5534890294f, 0.5521671772f, 0.5485079288f,
         0.5432717204f, 0.5373347998f, 0.5314123034f, 0.5234752297f, 0.5171306729f, 0.5123357773f,
         0.5088182092f, 0.5062782168f, 0.5035477281f, 0.5019994974f, 0.5011256337f, 0.5006332994f,
         0.5000000000f},
        {0.5000000000f, 0.5010640621f, 0.5018905401f, 0.5033562183f, 0.5059488416f, 0.5105082989f,
         0.5147353411f, 0.5205669403f, 0.5284758210f, 0.5388726592f, 0.5517760515f, 0.5613338947f,
         0.5708581805f, 0.5792131424f, 0.5850278735f, 0.5871236324f, 0.5850278735f, 0.5792131424f,
         0.5708581805f, 0.5613338947f, 0.5517760515f, 0.5388726592f, 0.5284758210f, 0.5205669403f,
         0.5147353411f, 0.5105082989f, 0.5059488416f, 0.5033562183f, 0.5018904805f, 0.5010640621f,
         0.5000000000f}},
    {

        {0.5000000000f, 0.4980079234f, 0.4964522421f, 0.4936747849f, 0.4887031913f, 0.4797717333f,
         0.4712667167f, 0.4591555893f, 0.4419712424f, 0.4178838134f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4178838134f, 0.4419712424f, 0.4591555893f,
         0.4712667167f, 0.4797717333f, 0.4887031913f, 0.4936747849f, 0.4964522421f, 0.4980079234f,
         0.5000000000f},
        {0.5000000000f, 0.4981336296f, 0.4966765046f, 0.4940757155f, 0.4894226193f, 0.4810712039f,
         0.4731284380f, 0.4618354440f, 0.4458500445f, 0.4235273004f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4235273004f, 0.4458500445f, 0.4618354440f,
         0.4731284380f, 0.4810712039f, 0.4894225895f, 0.4940757155f, 0.4966765046f, 0.4981336892f,
         0.5000000000f},
        {0.5000000000f, 0.4983248413f, 0.4970174134f, 0.4946847558f, 0.4905147851f, 0.4830409586f,
         0.4759460390f, 0.4658817351f, 0.4516856372f, 0.4319694936f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4319694936f, 0.4516856372f, 0.4658817351f,
         0.4759460390f, 0.4830409586f, 0.4905147851f, 0.4946847558f, 0.4970174134f, 0.4983248413f,
         0.5000000000f},
        {0.5000000000f, 0.4988038540f, 0.4978710711f, 0.4962087274f, 0.4932425618f, 0.4879449904f,
         0.4829386175f, 0.4758763313f, 0.4659966528f, 0.4524453282f, 0.4346525371f, 0.4207023382f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4207023382f, 0.4346525371f, 0.4524453282f, 0.4659966528f, 0.4758763313f,
         0.4829386175f, 0.4879449904f, 0.4932425618f, 0.4962087274f, 0.4978710711f, 0.4988038540f,
         0.5000000000f},
        {0.5000000000f, 0.4992685318f, 0.4986986518f, 0.4976839423f, 0.4958767295f, 0.4926598668f,
         0.4896325469f, 0.4853836596f, 0.4794833362f, 0.4714762270f, 0.4611217678f, 0.4531369507f,
         0.4448976219f, 0.4374250174f, 0.4320826530f, 0.4301276803f, 0.4320826530f, 0.4374250174f,
         0.4448976219f, 0.4531369507f, 0.4611217678f, 0.4714762270f, 0.4794833362f, 0.4853836596f,
         0.4896325469f, 0.4926598072f, 0.4958767295f, 0.4976839423f, 0.4986986518f, 0.4992685318f,
         0.5000000000f},
        {0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f},
        {0.5000000000f, 0.5011696219f, 0.5020779371f, 0.5036883950f, 0.5065358877f, 0.5115402937f,
         0.5161759257f, 0.5225655437f, 0.5312208533f, 0.5425815582f, 0.5566557646f, 0.5670637488f,
         0.5774215460f, 0.5864970684f, 0.5928076506f, 0.5950810909f, 0.5928076506f, 0.5864970684f,
         0.5774215460f, 0.5670637488f, 0.5566557646f, 0.5425815582f, 0.5312208533f, 0.5225655437f,
         0.5161759257f, 0.5115402341f, 0.5065358877f, 0.5036883950f, 0.5020778775f, 0.5011696219f,
         0.5000000000f},
        {0.5000000000f, 0.5019643307f, 0.5034876466f, 0.5061841011f, 0.5109378099f, 0.5192503333f,
         0.5269047022f, 0.5373865962f, 0.5514660478f, 0.5697538257f, 0.5921343565f, 0.6085074544f,
         0.6246649623f, 0.6387181878f, 0.6484364867f, 0.6519271135f, 0.6484364867f, 0.6387181878f,
         0.6246649027f, 0.6085074544f, 0.5921343565f, 0.5697538257f, 0.5514660478f, 0.5373866558f,
         0.5269047022f, 0.5192503333f, 0.5109378099f, 0.5061841011f, 0.5034876466f, 0.5019643903f,
         0.5000000596f}},
    {

        {0.5000000000f, 0.4973956347f, 0.4953595102f, 0.4917194545f, 0.4851873517f, 0.4733974338f,
         0.4621005356f, 0.4458855093f, 0.4225889444f, 0.4166666567f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4225889444f, 0.4458855093f,
         0.4621005356f, 0.4733974338f, 0.4851873517f, 0.4917194545f, 0.4953595102f, 0.4973956347f,
         0.5000000000f},
        {0.5000000000f, 0.4975600541f, 0.4956531823f, 0.4922452271f, 0.4861339033f, 0.4751173258f,
         0.4645794332f, 0.4494870603f, 0.4278794229f, 0.4166666567f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4278794229f, 0.4494870603f,
         0.4645794332f, 0.4751173258f, 0.4861338437f, 0.4922452271f, 0.4956531823f, 0.4975600541f,
         0.5000000000f},
        {0.5000000000f, 0.4978101552f, 0.4960994422f, 0.4930438697f, 0.4875699580f, 0.4777213931f,
         0.4683246017f, 0.4549102187f, 0.4358028471f, 0.4166666567f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4358028471f, 0.4549102187f,
         0.4683246017f, 0.4777213931f, 0.4875699580f, 0.4930438697f, 0.4960994422f, 0.4978101552f,
         0.5000000000f},
        {0.5000000000f, 0.4984366000f, 0.4972166717f, 0.4950406849f, 0.4911523461f, 0.4841892719f,
         0.4775862098f, 0.4682320654f, 0.4550639093f, 0.4368312657f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4368312657f, 0.4550639093f, 0.4682320654f,
         0.4775862098f, 0.4841892719f, 0.4911523461f, 0.4950406253f, 0.4972166717f, 0.4984366000f,
         0.5000000000f},
        {0.5000000000f, 0.4990440905f, 0.4982990324f, 0.4969717562f, 0.4946058393f, 0.4903875589f,
         0.4864100218f, 0.4808138311f, 0.4730155468f, 0.4623796046f, 0.4485287368f, 0.4377669692f,
         0.4265822172f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f,
         0.4265822172f, 0.4377669096f, 0.4485287070f, 0.4623796046f, 0.4730155468f, 0.4808138311f,
         0.4864100218f, 0.4903876185f, 0.4946058393f, 0.4969717562f, 0.4982990324f, 0.4990440905f,
         0.5000000000f},
        {0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f},
        {0.5000000000f, 0.5015276670f, 0.5027132034f, 0.5048136711f, 0.5085227489f, 0.5150263309f,
         0.5210343599f, 0.5292906761f, 0.5404308438f, 0.5549815893f, 0.5729033351f, 0.5860881805f,
         0.5991558433f, 0.6105647087f, 0.6184762716f, 0.6213221550f, 0.6184762716f, 0.6105646491f,
         0.5991559029f, 0.5860881805f, 0.5729033351f, 0.5549815893f, 0.5404308438f, 0.5292906761f,
         0.5210343599f, 0.5150263309f, 0.5085227489f, 0.5048136711f, 0.5027132034f, 0.5015276670f,
         0.5000000596f},
        {0.5000000000f, 0.5025650263f, 0.5045520067f, 0.5080648065f, 0.5142443776f, 0.5250104070f,
         0.5348817706f, 0.5483376980f, 0.5663076639f, 0.5894870162f, 0.6176328659f, 0.6380870938f,
         0.6581704617f, 0.6755633950f, 0.6875533462f, 0.6918526888f, 0.6875533462f, 0.6755633950f,
         0.6581704021f, 0.6380870938f, 0.6176328659f, 0.5894870162f, 0.5663076639f, 0.5483376980f,
         0.5348817110f, 0.5250104070f, 0.5142443776f, 0.5080648065f, 0.5045520067f, 0.5025650263f,
         0.5000000596f}},
    {

        {0.5000000000f, 0.4971804321f, 0.4949752688f, 0.4910309613f, 0.4839466810f, 0.4711386263f,
         0.4588383138f, 0.4411309958f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.0000000000f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4411309958f,
         0.4588383138f, 0.4711386263f, 0.4839466810f, 0.4910309613f, 0.4949752688f, 0.4971804321f,
         0.5000000000f},
        {0.5000000000f, 0.4973585308f, 0.4952933490f, 0.4916008413f, 0.4849737287f, 0.4730088115f,
         0.4615398645f, 0.4450696707f, 0.4213871956f, 0.4166666567f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4213872254f, 0.4450696707f,
         0.4615398645f, 0.4730088115f, 0.4849737287f, 0.4916008413f, 0.4952932894f, 0.4973585308f,
         0.5000000000f},
        {0.5000000000f, 0.4976293147f, 0.4957766831f, 0.4924663603f, 0.4865316749f, 0.4758392870f,
         0.4656187594f, 0.4509941638f, 0.4300864339f, 0.4166666567f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4300864339f, 0.4509941638f,
         0.4656187594f, 0.4758392870f, 0.4865316749f, 0.4924663603f, 0.4957766831f, 0.4976293147f,
         0.5000000000f},
        {0.5000000000f, 0.4983075559f, 0.4969865978f, 0.4946298003f, 0.4904162288f, 0.4828635156f,
         0.4756923914f, 0.4655179977f, 0.4511619806f, 0.4312142432f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4312142432f, 0.4511619806f, 0.4655179381f,
         0.4756923914f, 0.4828635156f, 0.4904162884f, 0.4946298003f, 0.4969866574f, 0.4983075559f,
         0.5000000000f},
        {0.5000000000f, 0.4989652634f, 0.4981585741f, 0.4967214465f, 0.4941587746f, 0.4895872176f,
         0.4852733612f, 0.4791988134f, 0.4707232416f, 0.4591425657f, 0.4440219402f, 0.4322400987f,
         0.4199612439f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f,
         0.4199612439f, 0.4322400391f, 0.4440219402f, 0.4591425657f, 0.4707232416f, 0.4791988134f,
         0.4852733612f, 0.4895872176f, 0.4941587746f, 0.4967214465f, 0.4981585741f, 0.4989652634f,
         0.5000000000f},
        {0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f},
        {0.5000000000f, 0.5016533136f, 0.5029361248f, 0.5052082539f, 0.5092185736f, 0.5162448287f,
         0.5227296948f, 0.5316320062f, 0.5436279774f, 0.5592706800f, 0.5785004497f, 0.5926237702f,
         0.6066032648f, 0.6187940836f, 0.6272407174f, 0.6302776933f, 0.6272407174f, 0.6187940836f,
         0.6066032648f, 0.5926238298f, 0.5785004497f, 0.5592706800f, 0.5436280370f, 0.5316320062f,
         0.5227296352f, 0.5162448287f, 0.5092185736f, 0.5052082539f, 0.5029360652f, 0.5016533136f,
         0.5000000596f},
        {0.5000000596f, 0.5027757883f, 0.5049252510f, 0.5087236166f, 0.5154004693f, 0.5270181894f,
         0.5376548171f, 0.5521317124f, 0.5714279413f, 0.5962615013f, 0.6263405681f, 0.6481539011f,
         0.6695383787f, 0.6880338192f, 0.7007715702f, 0.7053368092f, 0.7007715702f, 0.6880338192f,
         0.6695383191f, 0.6481539011f, 0.6263405681f, 0.5962615013f, 0.5714278817f, 0.5521317124f,
         0.5376548171f, 0.5270181298f, 0.5154004097f, 0.5087236166f, 0.5049252510f, 0.5027757883f,
         0.5000000596f}},
    {

        {0.5000000000f, 0.4973956347f, 0.4953595102f, 0.4917194545f, 0.4851873517f, 0.4733974338f,
         0.4621005356f, 0.4458855093f, 0.4225889444f, 0.4166666567f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4225889444f, 0.4458855093f,
         0.4621005356f, 0.4733974338f, 0.4851873517f, 0.4917194545f, 0.4953595102f, 0.4973956347f,
         0.5000000000f},
        {0.5000000000f, 0.4975600541f, 0.4956531823f, 0.4922452271f, 0.4861339033f, 0.4751173258f,
         0.4645794332f, 0.4494870603f, 0.4278794229f, 0.4166666567f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4278794229f, 0.4494870603f,
         0.4645794332f, 0.4751173258f, 0.4861338437f, 0.4922452271f, 0.4956531823f, 0.4975600541f,
         0.5000000000f},
        {0.5000000000f, 0.4978101552f, 0.4960994422f, 0.4930438697f, 0.4875699580f, 0.4777213931f,
         0.4683246017f, 0.4549102187f, 0.4358028471f, 0.4166666567f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4358028471f, 0.4549102187f,
         0.4683246017f, 0.4777213931f, 0.4875699580f, 0.4930438697f, 0.4960994422f, 0.4978101552f,
         0.5000000000f},
        {0.5000000000f, 0.4984366000f, 0.4972166717f, 0.4950406849f, 0.4911523461f, 0.4841892719f,
         0.4775862098f, 0.4682320654f, 0.4550639093f, 0.4368312657f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4368312657f, 0.4550639093f, 0.4682320654f,
         0.4775862098f, 0.4841892719f, 0.4911523461f, 0.4950406253f, 0.4972166717f, 0.4984366000f,
         0.5000000000f},
        {0.5000000000f, 0.4990440905f, 0.4982990324f, 0.4969717562f, 0.4946058393f, 0.4903875589f,
         0.4864100218f, 0.4808138311f, 0.4730155468f, 0.4623796046f, 0.4485287368f, 0.4377669692f,
         0.4265822172f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f,
         0.4265822172f, 0.4377669096f, 0.4485287070f, 0.4623796046f, 0.4730155468f, 0.4808138311f,
         0.4864100218f, 0.4903876185f, 0.4946058393f, 0.4969717562f, 0.4982990324f, 0.4990440905f,
         0.5000000000f},
        {0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f},
        {0.5000000000f, 0.5015276670f, 0.5027132034f, 0.5048136711f, 0.5085227489f, 0.5150263309f,
         0.5210343599f, 0.5292906761f, 0.5404308438f, 0.5549815893f, 0.5729033351f, 0.5860881805f,
         0.5991558433f, 0.6105647087f, 0.6184762716f, 0.6213221550f, 0.6184762716f, 0.6105646491f,
         0.5991559029f, 0.5860881805f, 0.5729033351f, 0.5549815893f, 0.5404308438f, 0.5292906761f,
         0.5210343599f, 0.5150263309f, 0.5085227489f, 0.5048136711f, 0.5027132034f, 0.5015276670f,
         0.5000000596f},
        {0.5000000000f, 0.5025650263f, 0.5045520067f, 0.5080648065f, 0.5142443776f, 0.5250104070f,
         0.5348817706f, 0.5483376980f, 0.5663076639f, 0.5894870162f, 0.6176328659f, 0.6380870938f,
         0.6581704617f, 0.6755633950f, 0.6875533462f, 0.6918526888f, 0.6875533462f, 0.6755633950f,
         0.6581704021f, 0.6380870938f, 0.6176328659f, 0.5894870162f, 0.5663076639f, 0.5483376980f,
         0.5348817110f, 0.5250104070f, 0.5142443776f, 0.5080648065f, 0.5045520067f, 0.5025650263f,
         0.5000000596f}},
    {

        {0.5000000000f, 0.4980079234f, 0.4964522421f, 0.4936747849f, 0.4887031913f, 0.4797717333f,
         0.4712667167f, 0.4591555893f, 0.4419712424f, 0.4178837836f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4178837836f, 0.4419712424f, 0.4591555893f,
         0.4712667167f, 0.4797717333f, 0.4887031913f, 0.4936747849f, 0.4964522421f, 0.4980079234f,
         0.5000000000f},
        {0.5000000000f, 0.4981336296f, 0.4966765046f, 0.4940757155f, 0.4894226193f, 0.4810712039f,
         0.4731284380f, 0.4618354440f, 0.4458500445f, 0.4235272706f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4235273004f, 0.4458500445f, 0.4618354440f,
         0.4731284380f, 0.4810712039f, 0.4894225895f, 0.4940757155f, 0.4966765046f, 0.4981336892f,
         0.5000000000f},
        {0.5000000000f, 0.4983248413f, 0.4970174134f, 0.4946847558f, 0.4905147851f, 0.4830409586f,
         0.4759460390f, 0.4658817351f, 0.4516856372f, 0.4319694936f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4319694936f, 0.4516856372f, 0.4658817351f,
         0.4759460390f, 0.4830409586f, 0.4905147851f, 0.4946847558f, 0.4970174134f, 0.4983248413f,
         0.5000000000f},
        {0.5000000000f, 0.4988038540f, 0.4978710711f, 0.4962087274f, 0.4932425618f, 0.4879449904f,
         0.4829386175f, 0.4758763313f, 0.4659966528f, 0.4524453282f, 0.4346525073f, 0.4207023382f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4207023382f, 0.4346525371f, 0.4524452984f, 0.4659966528f, 0.4758763313f,
         0.4829386175f, 0.4879449904f, 0.4932425618f, 0.4962087274f, 0.4978710711f, 0.4988038540f,
         0.5000000000f},
        {0.5000000000f, 0.4992685318f, 0.4986986518f, 0.4976839423f, 0.4958767295f, 0.4926598668f,
         0.4896325469f, 0.4853836596f, 0.4794833362f, 0.4714761972f, 0.4611217678f, 0.4531369507f,
         0.4448976219f, 0.4374250174f, 0.4320826530f, 0.4301276803f, 0.4320826530f, 0.4374250174f,
         0.4448976219f, 0.4531369507f, 0.4611217678f, 0.4714761972f, 0.4794833362f, 0.4853836596f,
         0.4896325469f, 0.4926598072f, 0.4958767295f, 0.4976839423f, 0.4986986518f, 0.4992685318f,
         0.5000000000f},
        {0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f},
        {0.5000000000f, 0.5011696219f, 0.5020779371f, 0.5036883950f, 0.5065358877f, 0.5115402937f,
         0.5161759257f, 0.5225655437f, 0.5312208533f, 0.5425816178f, 0.5566557646f, 0.5670638084f,
         0.5774215460f, 0.5864970684f, 0.5928076506f, 0.5950810909f, 0.5928076506f, 0.5864970684f,
         0.5774215460f, 0.5670638084f, 0.5566557646f, 0.5425815582f, 0.5312208533f, 0.5225655437f,
         0.5161759257f, 0.5115402341f, 0.5065358877f, 0.5036883950f, 0.5020778775f, 0.5011696219f,
         0.5000000000f},
        {0.5000000000f, 0.5019643307f, 0.5034876466f, 0.5061841011f, 0.5109378099f, 0.5192503333f,
         0.5269047022f, 0.5373866558f, 0.5514660478f, 0.5697538257f, 0.5921343565f, 0.6085074544f,
         0.6246649623f, 0.6387182474f, 0.6484364867f, 0.6519271135f, 0.6484364867f, 0.6387182474f,
         0.6246649623f, 0.6085074544f, 0.5921343565f, 0.5697538257f, 0.5514660478f, 0.5373866558f,
         0.5269047022f, 0.5192503333f, 0.5109378099f, 0.5061841011f, 0.5034876466f, 0.5019643903f,
         0.5000000596f}},
    {

        {0.5000000000f, 0.4989228845f, 0.4980831146f, 0.4965868294f, 0.4939183295f, 0.4891564250f,
         0.4846611917f, 0.4783283472f, 0.4694863856f, 0.4573929608f, 0.4415802360f, 0.4292396307f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4292396307f, 0.4415802360f, 0.4573929608f, 0.4694863856f, 0.4783283472f,
         0.4846611917f, 0.4891563654f, 0.4939182699f, 0.4965868294f, 0.4980831146f, 0.4989228845f,
         0.5000000000f},
        {0.5000000000f, 0.4989907742f, 0.4982040823f, 0.4968025982f, 0.4943036735f, 0.4898466468f,
         0.4856418371f, 0.4797225595f, 0.4714670181f, 0.4601936638f, 0.4454868436f, 0.4340381622f,
         0.4221174419f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f,
         0.4221173823f, 0.4340381622f, 0.4454868436f, 0.4601936638f, 0.4714670181f, 0.4797225595f,
         0.4856418371f, 0.4898466468f, 0.4943036735f, 0.4968025386f, 0.4982040823f, 0.4989907742f,
         0.5000000000f},
        {0.5000000000f, 0.4990940988f, 0.4983880222f, 0.4971305132f, 0.4948891699f, 0.4908945858f,
         0.4871295691f, 0.4818353653f, 0.4744636118f, 0.4644210041f, 0.4513638020f, 0.4412364364f,
         0.4307287931f, 0.4211447835f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4211447835f,
         0.4307287633f, 0.4412364364f, 0.4513638616f, 0.4644210041f, 0.4744636118f, 0.4818353653f,
         0.4871295691f, 0.4908945858f, 0.4948891699f, 0.4971305132f, 0.4983880222f, 0.4990940988f,
         0.5000000000f},
        {0.5000000000f, 0.4993529916f, 0.4988489449f, 0.4979517758f, 0.4963543117f, 0.4935124516f,
         0.4908400774f, 0.4870927036f, 0.4818954766f, 0.4748552144f, 0.4657738209f, 0.4587891996f,
         0.4515995383f, 0.4450951517f, 0.4404549301f, 0.4387589693f, 0.4404549301f, 0.4450951517f,
         0.4515995383f, 0.4587891996f, 0.4657738209f, 0.4748552144f, 0.4818954766f, 0.4870927036f,
         0.4908400774f, 0.4935124516f, 0.4963543117f, 0.4979517758f, 0.4988490045f, 0.4993529916f,
         0.5000000000f},
        {0.5000000000f, 0.4996043146f, 0.4992960989f, 0.4987479150f, 0.4977727532f, 0.4960409999f,
         0.4944161773f, 0.4921435714f, 0.4890033603f, 0.4847714305f, 0.4793508947f, 0.4752120376f,
         0.4709798396f, 0.4671763778f, 0.4644779861f, 0.4634948969f, 0.4644779861f, 0.4671763778f,
         0.4709798396f, 0.4752120376f, 0.4793508947f, 0.4847714305f, 0.4890033603f, 0.4921435714f,
         0.4944161773f, 0.4960409999f, 0.4977727532f, 0.4987478554f, 0.4992960989f, 0.4996043146f,
         0.5000000000f},
        {0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f},
        {0.5000000000f, 0.5006332994f, 0.5011256337f, 0.5019994974f, 0.5035477281f, 0.5062782168f,
         0.5088182092f, 0.5123358369f, 0.5171306729f, 0.5234752297f, 0.5314123034f, 0.5373347998f,
         0.5432717800f, 0.5485079288f, 0.5521671772f, 0.5534890294f, 0.5521672368f, 0.5485079288f,
         0.5432717800f, 0.5373347998f, 0.5314123631f, 0.5234752297f, 0.5171306729f, 0.5123357773f,
         0.5088182092f, 0.5062782168f, 0.5035477281f, 0.5019994974f, 0.5011256337f, 0.5006333590f,
         0.5000000000f},
        {0.5000000000f, 0.5010640621f, 0.5018905401f, 0.5033562183f, 0.5059488416f, 0.5105082989f,
         0.5147353411f, 0.5205669403f, 0.5284758806f, 0.5388726592f, 0.5517760515f, 0.5613339543f,
         0.5708582401f, 0.5792131424f, 0.5850278735f, 0.5871236920f, 0.5850278735f, 0.5792131424f,
         0.5708582401f, 0.5613339543f, 0.5517760515f, 0.5388726592f, 0.5284758210f, 0.5205669403f,
         0.5147353411f, 0.5105083585f, 0.5059489012f, 0.5033562183f, 0.5018904805f, 0.5010640621f,
         0.5000000000f}},
    {

        {0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f},
        {0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f},
        {0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f},
        {0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f},
        {0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f},
        {0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f},
        {0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f},
        {0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f}},
    {

        {0.5000000000f, 0.5010747910f, 0.5019095540f, 0.5033900142f, 0.5060086250f, 0.5106133819f,
         0.5148820281f, 0.5207706094f, 0.5287556648f, 0.5392510295f, 0.5522742867f, 0.5619193316f,
         0.5715291500f, 0.5799580812f, 0.5858238339f, 0.5879378319f, 0.5858238339f, 0.5799580812f,
         0.5715291500f, 0.5619193316f, 0.5522742867f, 0.5392510295f, 0.5287556648f, 0.5207706094f,
         0.5148820281f, 0.5106133819f, 0.5060086250f, 0.5033900142f, 0.5019095540f, 0.5010747910f,
         0.5000000000f},
        {0.5000000000f, 0.5010071397f, 0.5017895103f, 0.5031771064f, 0.5056321621f, 0.5099512339f,
         0.5139572024f, 0.5194865465f, 0.5269903541f, 0.5368629098f, 0.5491278768f, 0.5582211614f,
         0.5672890544f, 0.5752488375f, 0.5807913542f, 0.5827894807f, 0.5807913542f, 0.5752488375f,
         0.5672890544f, 0.5582211614f, 0.5491278768f, 0.5368629694f, 0.5269903541f, 0.5194864869f,
         0.5139572024f, 0.5099512339f, 0.5056321621f, 0.5031771660f, 0.5017895103f, 0.5010071397f,
         0.5000000000f},
        {0.5000000000f, 0.5009042621f, 0.5016067624f, 0.5028531551f, 0.5050591230f, 0.5089425445f,
         0.5125473738f, 0.5175274611f, 0.5242940784f, 0.5332102180f, 0.5443075895f, 0.5525490046f,
         0.5607786775f, 0.5680115223f, 0.5730525255f, 0.5748708248f, 0.5730525255f, 0.5680115223f,
         0.5607786775f, 0.5525490046f, 0.5443075895f, 0.5332102180f, 0.5242940187f, 0.5175274611f,
         0.5125473142f, 0.5089425445f, 0.5050591230f, 0.5028531551f, 0.5016067624f, 0.5009042621f,
         0.5000000000f},
        {0.5000000000f, 0.5006461143f, 0.5011484027f, 0.5020399094f, 0.5036193132f, 0.5064044595f,
         0.5089951158f, 0.5125823617f, 0.5174714923f, 0.5239394307f, 0.5320289135f, 0.5380636454f,
         0.5441119671f, 0.5494454503f, 0.5531721711f, 0.5545183420f, 0.5531721711f, 0.5494454503f,
         0.5441119671f, 0.5380636454f, 0.5320289135f, 0.5239394307f, 0.5174714923f, 0.5125823617f,
         0.5089950562f, 0.5064044595f, 0.5036192536f, 0.5020399094f, 0.5011484027f, 0.5006461143f,
         0.5000000000f},
        {0.5000000000f, 0.5003954172f, 0.5007029176f, 0.5012489557f, 0.5022173524f, 0.5039278865f,
         0.5055221915f, 0.5077348351f, 0.5107599497f, 0.5147782564f, 0.5198295116f, 0.5236158371f,
         0.5274258256f, 0.5307977200f, 0.5331605673f, 0.5340154171f, 0.5331605673f, 0.5307977200f,
         0.5274258256f, 0.5236158371f, 0.5198295116f, 0.5147782564f, 0.5107599497f, 0.5077348351f,
         0.5055221915f, 0.5039278865f, 0.5022173524f, 0.5012489557f, 0.5007029176f, 0.5003954172f,
         0.5000000000f},
        {0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f},
        {0.5000000000f, 0.4993658364f, 0.4988718629f, 0.4979924560f, 0.4964269102f, 0.4936419725f,
         0.4910234213f, 0.4873520732f, 0.4822612107f, 0.4753669202f, 0.4664771259f, 0.4596425593f,
         0.4526099563f, 0.4462499917f, 0.4417140782f, 0.4400566518f, 0.4417141378f, 0.4462499917f,
         0.4526099563f, 0.4596425593f, 0.4664771259f, 0.4753669202f, 0.4822612107f, 0.4873520732f,
         0.4910234213f, 0.4936419725f, 0.4964269102f, 0.4979925156f, 0.4988718629f, 0.4993658364f,
         0.5000000000f},
        {0.5000000000f, 0.4989336729f, 0.4981023371f, 0.4966210425f, 0.4939794540f, 0.4892660379f,
         0.4848169982f, 0.4785499275f, 0.4698013365f, 0.4578386545f, 0.4422026277f, 0.4300048649f,
         0.4172779620f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f,
         0.4172779620f, 0.4300048649f, 0.4422026277f, 0.4578386545f, 0.4698013365f, 0.4785499275f,
         0.4848169982f, 0.4892660379f, 0.4939795136f, 0.4966210425f, 0.4981023371f, 0.4989336729f,
         0.5000000000f}},
    {

        {0.5000000000f, 0.5019841790f, 0.5035227537f, 0.5062461495f, 0.5110471249f, 0.5194411278f,
         0.5271694660f, 0.5377510190f, 0.5519614220f, 0.5704149008f, 0.5929919481f, 0.6095048785f,
         0.6257974505f, 0.6399660110f, 0.6497628093f, 0.6532814503f, 0.6497628689f, 0.6399659514f,
         0.6257974505f, 0.6095049381f, 0.5929919481f, 0.5704149008f, 0.5519614220f, 0.5377510190f,
         0.5271694660f, 0.5194411278f, 0.5110471249f, 0.5062461495f, 0.5035227537f, 0.5019841790f,
         0.5000000596f},
        {0.5000000000f, 0.5018594265f, 0.5033015609f, 0.5058549047f, 0.5103582144f, 0.5182378888f,
         0.5254992843f, 0.5354512334f, 0.5488330722f, 0.5662372708f, 0.5875679851f, 0.6031931639f,
         0.6186277270f, 0.6320636272f, 0.6413608193f, 0.6447013021f, 0.6413607597f, 0.6320636272f,
         0.6186277270f, 0.6031931639f, 0.5875679851f, 0.5662372708f, 0.5488330722f, 0.5354512334f,
         0.5254992843f, 0.5182378888f, 0.5103582144f, 0.5058549047f, 0.5033015609f, 0.5018594265f,
         0.5000000596f},
        {0.5000000000f, 0.5016695857f, 0.5029649734f, 0.5052592754f, 0.5093086362f, 0.5164023638f,
         0.5229486823f, 0.5319343805f, 0.5440405011f, 0.5598235130f, 0.5792210698f, 0.5934645534f,
         0.6075606942f, 0.6198513508f, 0.6283662915f, 0.6314277649f, 0.6283662915f, 0.6198513508f,
         0.6075606942f, 0.5934646130f, 0.5792211294f, 0.5598235130f, 0.5440405011f, 0.5319343805f,
         0.5229486823f, 0.5164023638f, 0.5093086362f, 0.5052592754f, 0.5029649138f, 0.5016695857f,
         0.5000000596f},
        {0.5000000000f, 0.5011932850f, 0.5021198988f, 0.5037627220f, 0.5066673160f, 0.5117711425f,
         0.5164980888f, 0.5230121613f, 0.5318337679f, 0.5434088707f, 0.5577428937f, 0.5683392882f,
         0.5788815022f, 0.5881162286f, 0.5945363641f, 0.5968489647f, 0.5945363045f, 0.5881162286f,
         0.5788815022f, 0.5683392882f, 0.5577428937f, 0.5434088707f, 0.5318337679f, 0.5230121613f,
         0.5164980888f, 0.5117711425f, 0.5066673160f, 0.5037627220f, 0.5021198392f, 0.5011932850f,
         0.5000000000f},
        {0.5000000000f, 0.5007303953f, 0.5012979507f, 0.5023053885f, 0.5040895343f, 0.5072339177f,
         0.5101568103f, 0.5142010450f, 0.5197073221f, 0.5269821882f, 0.5360659957f, 0.5428322554f,
         0.5496053696f, 0.5555711985f, 0.5597361326f, 0.5612398386f, 0.5597361326f, 0.5555711985f,
         0.5496053696f, 0.5428322554f, 0.5360659957f, 0.5269821286f, 0.5197073221f, 0.5142010450f,
         0.5101568103f, 0.5072339773f, 0.5040895343f, 0.5023053885f, 0.5012980103f, 0.5007303953f,
         0.5000000000f},
        {0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f},
        {0.5000000000f, 0.4988276362f, 0.4979133904f, 0.4962842464f, 0.4933774769f, 0.4881869853f,
         0.4832829535f, 0.4763666987f, 0.4666952491f, 0.4534371495f, 0.4360439777f, 0.4224200845f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4224200845f, 0.4360440373f, 0.4534371495f, 0.4666952491f, 0.4763666987f,
         0.4832829535f, 0.4881869853f, 0.4933775365f, 0.4962842464f, 0.4979134500f, 0.4988276362f,
         0.5000000000f},
        {0.5000000000f, 0.4980278611f, 0.4964878559f, 0.4937384725f, 0.4888174534f, 0.4799782038f,
         0.4715627432f, 0.4595820010f, 0.4425892234f, 0.4187846780f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4187846780f, 0.4425892234f, 0.4595820010f,
         0.4715627432f, 0.4799782038f, 0.4888175130f, 0.4937384725f, 0.4964878559f, 0.4980278611f,
         0.5000000000f}},
    {

        {0.5000000000f, 0.5025908947f, 0.5045977831f, 0.5081456304f, 0.5143862367f, 0.5252569914f,
         0.5352224708f, 0.5488042235f, 0.5669378638f, 0.5903217196f, 0.6187070012f, 0.6393297315f,
         0.6595746279f, 0.6771045923f, 0.6891874671f, 0.6935199499f, 0.6891874671f, 0.6771046519f,
         0.6595746279f, 0.6393297315f, 0.6187070012f, 0.5903217793f, 0.5669378638f, 0.5488042235f,
         0.5352224708f, 0.5252569914f, 0.5143862367f, 0.5081456304f, 0.5045977831f, 0.5025908947f,
         0.5000000596f},
        {0.5000000000f, 0.5024280548f, 0.5043093562f, 0.5076363087f, 0.5134918094f, 0.5237017274f,
         0.5330721736f, 0.5458583832f, 0.5629557371f, 0.5850431919f, 0.6119084954f, 0.6314600110f,
         0.6506775022f, 0.6673357487f, 0.6788267493f, 0.6829485893f, 0.6788267493f, 0.6673356891f,
         0.6506775618f, 0.6314600110f, 0.6119084954f, 0.5850431919f, 0.5629557967f, 0.5458583832f,
         0.5330721736f, 0.5237017274f, 0.5134918094f, 0.5076363087f, 0.5043093562f, 0.5024280548f,
         0.5000000596f},
        {0.5000000000f, 0.5021802783f, 0.5038703680f, 0.5068606734f, 0.5121284127f, 0.5213274360f,
         0.5297849178f, 0.5413471460f, 0.5568445921f, 0.5769221783f, 0.6014210582f, 0.6192988753f,
         0.6369072795f, 0.6521973014f, 0.6627579927f, 0.6665487289f, 0.6627580523f, 0.6521973014f,
         0.6369072795f, 0.6192988753f, 0.6014210582f, 0.5769221783f, 0.5568445921f, 0.5413471460f,
         0.5297849178f, 0.5213274360f, 0.5121284127f, 0.5068606734f, 0.5038703680f, 0.5021802783f,
         0.5000000596f},
        {0.5000000000f, 0.5015584826f, 0.5027679205f, 0.5049106479f, 0.5086937547f, 0.5153259039f,
         0.5214512348f, 0.5298667550f, 0.5412179232f, 0.5560381413f, 0.5742831826f, 0.5877002478f,
         0.6009937525f, 0.6125962734f, 0.6206405163f, 0.6235337853f, 0.6206405163f, 0.6125962138f,
         0.6009937525f, 0.5877002478f, 0.5742831826f, 0.5560382009f, 0.5412179232f, 0.5298667550f,
         0.5214512944f, 0.5153258443f, 0.5086938143f, 0.5049106479f, 0.5027679205f, 0.5015585423f,
         0.5000000596f},
        {0.5000000000f, 0.5009540319f, 0.5016952753f, 0.5030100346f, 0.5053365231f, 0.5094310641f,
         0.5132302642f, 0.5184766650f, 0.5256009102f, 0.5349814296f, 0.5466461182f, 0.5553017855f,
         0.5639393926f, 0.5715261102f, 0.5768113732f, 0.5787173510f, 0.5768114328f, 0.5715261102f,
         0.5639393926f, 0.5553017855f, 0.5466461182f, 0.5349814296f, 0.5256009102f, 0.5184766650f,
         0.5132302642f, 0.5094310641f, 0.5053365827f, 0.5030099750f, 0.5016952157f, 0.5009540319f,
         0.5000000000f},
        {0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f, 0.5000000000f,
         0.5000000000f},
        {0.5000000000f, 0.4984676838f, 0.4972720146f, 0.4951395094f, 0.4913294315f, 0.4845078886f,
         0.4780410528f, 0.4688831270f, 0.4559983313f, 0.4381728470f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4381728172f, 0.4559983313f, 0.4688831270f,
         0.4780410528f, 0.4845078886f, 0.4913294315f, 0.4951395094f, 0.4972720146f, 0.4984676838f,
         0.5000000000f},
        {0.5000000000f, 0.4974217415f, 0.4954061210f, 0.4918029308f, 0.4853377044f, 0.4736708105f,
         0.4624948800f, 0.4464591146f, 0.4234331250f, 0.4166666567f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f,
         0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4166666567f, 0.4234331250f, 0.4464591146f,
         0.4624948800f, 0.4736708105f, 0.4853377044f, 0.4918029308f, 0.4954061210f, 0.4974217415f,
         0.5000000000f}}};

const WORD32 ixheaacd_atan_table_Q28[16][8][31] = {
    {
        {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
         0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
        {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
         0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
        {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
         0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
        {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
         0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
        {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
         0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
        {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
         0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
        {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
         0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
        {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
         0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    },
    {
        {105414360, 104839440, 104395760, 103614856, 102251296, 99903616, 97777528, 94910424,
         91113928,  86209256,  80075696,  75298264,  70016792,  64317196, 58324216, 52191708,
         46086824,  40171656,  34586568,  29438704,  24797036,  18844526, 14076835, 10372791,
         7563109,   5470589,   3149178,   1794887,   1017097,   574441,   3},
        {105414360, 104839456, 104395808, 103614992, 102251712, 99904768, 97779568, 94913880,
         91119464,  86217496,  80086976,  75311480,  70031656,  64333272, 58341012, 52208712,
         46103544,  40187596,  34601260,  29451742,  24808156,  18852650, 14082295, 10376209,
         7565131,   5471733,   3149591,   1795028,   1017143,   574456,   3},
        {105414360, 104839480, 104395880, 103615208, 102252344, 99906552, 97782736, 94919288,
         91128192,  86230640,  80105168,  75332944,  70055936,  64359672, 58368684, 52236768,
         46131100,  40213788,  34625280,  29472930,  24826096,  18865614, 14090922, 10381562,
         7568273,   5473501,   3150225,   1795244,   1017214,   574479,   3},
        {105414360, 104839536, 104396064, 103615760, 102253976, 99911160, 97791048, 94933704,
         91151936,  86267232,  80157136,  75395312,  70127632,  64438612, 58452120, 52321616,
         46214224,  40292168,  34696284,  29534604,  24877446,  18901780, 14114422, 10395857,
         7576530,   5478088,   3151847,   1795790,   1017394,   574537,   3},
        {105414360, 104839592, 104396240, 103616296, 102255600, 99915856, 97799664, 94949000,
         91177904,  86308736,  80218568,  75471136,  70217072,  64539228, 58560004, 52431916,
         46321792,  40392248,  34785076,  29609790,  24938336,  18942938, 14140199, 10411065,
         7585108,   5482768,   3153468,   1796330,   1017569,   574594,   3},
        {105414360, 104839680, 104396520, 103617168, 102258248, 99923736, 97814472, 94976184,
         91226104,  86390216,  80347528,  75638144,  70423488,  64780944, 58826448, 52707184,
         46587916,  40633420,  34990876,  29776224,  25066838,  19024148, 14188262, 10438183,
         7599892,   5490633,   3156118,   1797198,   1017849,   574683,   3},
        {105414360, 104839824, 104396976, 103618608, 102262752, 99937728, 97841960, 95029816,
         91329816,  86588048,  80716144,  76183448,  71203432,  65834132, 60122612, 54107316,
         47891724,  41697008,  35779764,  30327720,  25439258,  19223604, 14292623, 10492064,
         7627470,   5504663,   3160627,   1798637,   1018307,   574828,   3},
        {105414360, 104839928, 104397288, 103619616, 102266008, 99948384, 97863952, 95076024,
         91429712,  86814424,  81270904,  77262808,  73480384,  71228240, 75154792, 90330880,
         64216388,  47491216,  38190000,  31457082,  26014456,  19455916, 14394385, 10538885,
         7649673,   5515393,   3163899,   1799652,   1018625,   574928,   3},
    },
    {
        {210828704, 209763824, 208938560, 207478752, 204908032, 200419760, 196290896, 190633616,
         183000672, 172937648, 160110704, 149997200, 138756608, 126624216, 113938336, 101099072,
         88510592,  76526288,  65413280,  55341428,  46391316,  35074004,  26116856,  19208962,
         13991278,  10114556,  5820107,   3316738,   1879389,   1061436,   6},
        {210828704, 209763936, 208938896, 207479776, 204911072, 200428368, 196306384, 190660432,
         183044720, 173005232, 160205968, 150110720, 138885968, 126765280, 114085952, 101247824,
         88655264,  76662112,  65536160,  55448352,  46480712,  35137556,  26158596,  19234612,
         14006231,  10122925,  5823092,   3317749,   1879722,   1061544,   6},
        {210828704, 209764096, 208939392, 207481328, 204915728, 200441616, 196330368, 190702240,
         183113968, 173112496, 160358752, 150294096, 139096288, 126995848, 114328120, 101492232,
         88892824,  76884520,  65736460,  55621620,  46624620,  35238800,  26224436,  19274734,
         14029455,  10135852,  5827674,   3319296,   1880230,   1061707,   6},
        {210828704, 209764512, 208940688, 207485280, 204927584, 200475808, 196392960, 190812912,
         183300576, 173407904, 160790096, 150820544, 139709584, 127677032, 115050024, 102223720,
         89602656,  77544544,  66324264,  56122904,  47034384,  35520108,  26403298,  19381644,
         14090386,  10169363,  5839388,   3323218,   1881511,   1062120,   6},
        {210828704, 209764912, 208941952, 207489168, 204939376, 200510416, 196457296, 190929072,
         183501872, 173737520, 161290464, 151447920, 140459456, 128528208, 115965984, 103158064,
         90506880,  78375576,  67050572,  56727860,  47516240,  35838300,  26598646,  19495050,
         14153544,  10203491,  5851081,   3327087,   1882766,   1062523,   6},
        {210828704, 209765552, 208943952, 207495408, 204958528, 200567968, 196566624, 191132320,
         183868128, 174368352, 162309120, 152784192, 142129632, 130500344, 118149712, 105414360,
         92679000,  80328360,  68699080,  58044528,  48519584,  36460364,  26960592,  19696396,
         14262089,  10260740,  5870181,   3333310,   1884767,   1063161,   6},
        {210828704, 209766592, 208947200, 207505680, 204990800, 200668800, 196765424, 191522096,
         184625504, 175818192, 165011728, 156772288, 147807440, 138128784, 127521456, 115591336,
         102270680, 88260824,  74642472,  62217964,  51336324,  37958764,  27737034,  20093352,
         14463533,  10362519,  5902623,   3343611,   1888032,   1064195,   6},
        {210828704, 209767296, 208949456, 207512880, 205013952, 200744336, 196920864, 191846656,
         185318832, 177353312, 168608176, 163416640, 160727504, 165029712, 189073968, 241456736,
         178005808, 122049624, 90479408,  70104040,  55475472,  39658732,  28482874,  20435210,
         14624799,  10440064,  5926123,   3350871,   1890298,   1064906,   6},
    },
    {
        {316243072, 314846656, 313757568, 311816384, 308352896, 302171040, 296337664, 288127488,
         276678912, 261007920, 240267568, 223492192, 204621200, 184231600, 163158624, 142328864,
         122556352, 104403376, 88154704,  73876200,  61498028,  46182704,  34260640,  25149108,
         18299352,  13222145,  7605578,   4333750,   2455581,   1386840,   8},
        {316243072, 314846976, 313758496, 311819264, 308361632, 302196576, 296384960, 288212480,
         276825088, 261244544, 240620416, 223927248, 205130368, 184795488, 163749776, 142917424,
         123115312, 104911608, 88598136,  74247992,  61798064,  46386176,  34389240,  25225820,
         18343072,  13246210,  7614005,   4336575,   2456504,   1387138,   8},
        {316243072, 314847424, 313759936, 311823680, 308374976, 302235808, 296457920, 288344224,
         277053216, 261616816, 241180800, 224622832, 205949680, 185708032, 164710624, 143876432,
         124026392, 105738528, 89317024,  74847744,  62279204,  46709404,  34591704,  25345632,
         18410910,  13283357,  7626934,   4340894,   2457913,   1387591,   8},
        {316243072, 314848576, 313763520, 311834784, 308408896, 302336352, 296646528, 288688608,
         277658208, 262622336, 242727504, 226572640, 208281664, 188341088, 167512304, 146689696,
         126701240, 108155720, 91400008,  76564704,  63637504,  47602004,  35139296,  25663918,
         18588502,  13379501,  7659962,   4351840,   2461468,   1388732,   8},
        {316243072, 314849696, 313767008, 311845696, 308442400, 302437088, 296837792, 289043680,
         278295680, 263711664, 244460352, 228811376, 211025776, 191509408, 170942688, 150169152,
         130013904, 111127336, 93923424,  78603792,  65214388,  48602512,  35733560,  26000040,
         18772012,  13477197,  7692890,   4362631,   2464949,   1389845,   8},
        {316243072, 314851456, 313772576, 311863104, 308496480, 302602432, 297156960, 289649728,
         279417792, 265709120, 247806384, 233308320, 216768720, 198401536, 178640624, 158121536,
         137602432, 117841520, 99474352,  82934752,  68436688,  50533952,  36825288,  26593334,
         19086120,  13640627,  7746590,   4379971,   2470496,   1391611,   8},
        {316243072, 314854304, 313781600, 311891584, 308586432, 302885824, 297719616, 290762432,
         281600928, 269929056, 255733744, 245043360, 233506176, 220942800, 206510464, 188780448,
         167001392, 142516720, 118085768, 95972968,  77157136,  55082256,  39133424,  27751766,
         19665234,  13929855,  7837575,   4408639,   2479541,   1394467,   8},
        {316243072, 314856256, 313787808, 311911392, 308650144, 303093152, 298144768, 291644096,
         283459968, 273946560, 264748512, 260980608, 262699168, 277087168, 321151200, 394123840,
         324055360, 228764272, 162653280, 119096696, 89459480,  60122168,  41317836,  28739580,
         20125738,  14149189,  7903307,   4428811,   2485814,   1396432,   8},
    },
    {
        {421657440, 420139488, 418946528, 416800672, 412909824, 405768000, 398798528, 388615200,
         373701408, 352009344, 321306208, 295197120, 265052208, 232374288, 199428848, 168474672,
         140988912, 117445760, 97614400,  80976864,  67001780,  50094056,  37102532,  27221784,
         19805402,  14310412,  8231902,   4690748,   2657888,   1501102,   8},
        {421657440, 420140000, 418948192, 416805888, 412925952, 405817184, 398893152, 388794176,
         374031200, 352591488, 322263552, 296453088, 266595344, 234127472, 201261264, 170245184,
         142589072, 118816240, 98738176,  81865128,  67681552,  50525452,  37361620,  27370528,
         19887816,  14354855,  8247121,   4695786,   2659523,   1501627,   8},
        {421657440, 420140832, 418950752, 416813824, 412950592, 405892416, 399038240, 389069504,
         374540352, 353494496, 323757792, 298423616, 269031008, 236912448, 204189776, 173088128,
         145165408, 121023688, 100545224, 83288680,  68766080,  51208348,  37768500,  27602440,
         20015536,  14423394,  8270460,   4703485,   2662016,   1502426,   8},
        {421657440, 420142848, 418957120, 416833824, 413012864, 406083584, 399408640, 389776736,
         375859200, 355859264, 327727040, 303720672, 275669600, 244617728, 212408608, 181157024,
         152524352, 127334264, 105689200, 87307640,  71794608,  53080056,  38863244,  28216278,
         20349054,  14600477,  8330018,   4722985,   2668305,   1504437,   8},
        {421657440, 420144832, 418963328, 416853376, 413073952, 406272672, 399777696, 390488160,
         377202752, 358308992, 331931552, 309437728, 282992896, 253322832, 221909888, 190657120,
         161278448, 134848896, 111768392, 91990440,  75259304,  55157184,  40043144,  28861386,
         20692490,  14779977,  8389313,   4742194,   2674461,   1506398,   8},
        {421657440, 420147936, 418973184, 416884416, 413171584, 406578080, 400379520, 391663936,
         379464224, 362537056, 339441728, 319954336, 296943136, 270562688, 241463968, 210828720,
         180193472, 151094752, 124714296, 101703104, 82215704,  59120396,  42193204,  29993510,
         21277910,  15079353,  8485847,   4773030,   2684265,   1509508,   8},
        {421657440, 420152960, 418989056, 416934784, 413331648, 407087776, 401401312, 393709888,
         383542496, 370571008, 354857280, 343114528, 330489120, 316523552, 299496928, 276320320,
         244582704, 205903744, 165901392, 130010112, 100638336, 68322528,  46691836,  32186576,
         22350768,  15606794,  8648967,   4823931,   2700238,   1514536,   8},
        {421657440, 420156384, 418999936, 416969536, 413443296, 407450528, 402143200, 395241024,
         386740992, 377366336, 369662080, 368527968, 375197056, 397609792, 449444704, 516205376,
         465462368, 362087840, 258438672, 179525856, 126554704, 78481920,  50925604,  34045784,
         23199528,  16005132,  8766508,   4859691,   2711304,   1517993,   8},
    },
    {
        {527071776, 525663296, 524547840, 522522432, 518787424, 511719680, 504553280, 493592128,
         476455264, 449151072, 405692192, 364814688, 314764480, 260204640, 208654512, 165799504,
         132838864, 107993088, 88864512,  73593016,  61016300,  45833920,  34080076,  25068088,
         18265786,  13208915,  7602957,   4333255,   2455490,   1386823,   8},
        {527071776, 525663968, 524550016, 522529280, 518809216, 511789088, 504692864, 493873536,
         477023936, 450294176, 407912896, 368083040, 319153344, 265360480, 213877824, 170466944,
         136659360, 110950480, 91074048,  75204000,  62168492,  46509388,  34462976,  25278940,
         18379172,  13268763,  7622987,   4339800,   2457598,   1387497,   8},
        {527071776, 525665024, 524553312, 522539712, 518842368, 511894848, 504905440, 494302048,
         477888864, 452029248, 411276832, 373037344, 325837408, 273286560, 222000448, 177798416,
         142702912, 115647968, 94588960,  77764896,  63995604,  47574420,  35062716,  25607106,
         18554672,  13360983,  7653688,   4349799,   2460814,   1388524,   8},
        {527071776, 525667616, 524561568, 522565952, 518925728, 512160800, 505440320, 495379776,
         480060704, 456371808, 419671424, 385428736, 342733856, 293748832, 243537984, 197712496,
         159394864, 128736152, 104401184, 84889304,  69041664,  50472228,  36668388,  26472714,
         19011836,  13598833,  7731958,   4375112,   2468920,   1391105,   8},
        {527071776, 525670144, 524569600, 522591456, 519006944, 512420320, 505962656, 496432544,
         482180128, 460599008, 427832576, 397536000, 359516736, 314728096, 266563520, 219861040,
         178476000, 143891040, 115765904, 93067576,  74749312,  53662744,  38389064,  27378586,
         19481140,  13839382,  7809780,   4400025,   2476852,   1393623,   8},
        {527071776, 525674176, 524582304, 522631776, 519135520, 512832256, 506793344, 498109984,
         485562304, 467353856, 440933088, 417176416, 387412832, 351185728, 309140992, 263535888,
         217930800, 175886048, 139658944, 109895352, 86138704,  59717932,  41509480,  28961788,
         20278430,  14239528,  7936269,   4439982,   2489476,   1397613,   8},
        {527071776, 525680576, 524602688, 522696672, 519343104, 513501216, 508149376, 500867616,
         491177920, 478742400, 463639360, 452372192, 440252448, 426573952, 408733792, 381475072,
         338855168, 280525408, 216504432, 159999104, 116811992, 73859864,  48033652,  32018526,
         21734042,  14942109,  8149504,   4505844,   2510026,   1404063,   8},
        {527071776, 525684960, 524616608, 522741088, 519485728, 513964384, 509095872, 502817408,
         495235360, 487294368, 481973920, 483250624, 492921600, 517327296, 563364480, 613069184,
         582305664, 502086528, 381071808, 253160960, 162730896, 89940184,  54233516,  34613092,
         22883530,  15471362,  8302829,   4552048,   2524252,   1408495,   8},
    },
    {
        {632486144, 631404160, 630541632, 628962560, 626006848, 620254784, 614202752, 604493888,
         588124864, 558622016, 501272640, 434361248, 339721664, 238866928, 162754096, 116484152,
         89986864,  73763176,  62238744,  52877240,  44742032,  34289616,  25778564,  19071620,
         13937721,  10094245,  5816231,   3316020,   1879259,   1061412,   6},
        {632486144, 631404800, 630543680, 628969216, 626028480, 620326592, 614353408, 604818816,
         588856448, 560378560, 505802368, 442767520, 353024832, 254136256, 175962480, 126430968,
         96994048,  78520456,  65419852,  54997780,  46155356,  35055980,  26190098,  19289814,
         14051970,  10153425,  5835647,   3322294,   1881268,   1062052,   6},
        {632486144, 631405824, 630546880, 628979392, 626061312, 620435456, 614581376, 605308288,
         589949440, 562964736, 512317856, 454700768, 372074880, 276762944, 196044128, 141682288,
         107802384, 85920168,  70405200,  58335116,  48381672,  36259776,  26833198,  19628898,
         14228628,  10244553,  5865397,   3331877,   1884330,   1063026,   6},
        {632486144, 631408256, 630554752, 629004736, 626143360, 620706752, 615146880, 606512512,
         592597440, 569059456, 527028256, 480971968, 414517856, 330765376, 247566576, 182256848,
         137009328, 106116024, 84093808,  67506720,  54475932,  39516588,  28548308,  20520860,
         14687895,  10479249,  5941177,   3356125,   1892049,   1065476,   6},
        {632486144, 631410688, 630562432, 629029312, 626222784, 620968128, 615688640, 607654336,
         595061824, 574547584, 539620928, 502759456, 449954304, 379751840, 300289600, 227398144,
         170699200, 129631024, 99970280,  78022152,  61351280,  43090368,  30380256,  21451668,
         15158278,  10716186,  6016439,   3379975,   1899599,   1067865,   6},
        {632486144, 631414464, 630574528, 629067968, 626347520, 621376512, 616530368, 609410496,
         598784192, 582583360, 557211968, 532248416, 497725888, 450454656, 388712384, 316243072,
         243773744, 182031456, 134760256, 100237736, 75274184,  49902756,  33701968,  23075620,
         15955780,  11109605,  6138617,   3418196,   1911610,   1071650,   6},
        {632486144, 631420544, 630593856, 629129728, 626546304, 622024256, 617857472, 612152256,
         604500352, 594592960, 582468992, 573393728, 563597248, 552304000, 536529024, 509232736,
         458470464, 373144992, 265980880, 175277520, 115809552, 66314040,  40717416,  26216598,
         17410064,  11799018,  6344228,   3481124,   1931149,   1077765,   6},
        {632486144, 631424704, 630607040, 629171712, 626681152, 622462336, 618753152, 613998592,
         608344384, 602686208, 599701056, 602055040, 611306560, 631195136, 663846400, 695665664,
         678745600, 629219584, 527619200, 345921568, 187985760, 86310936,  47549656,  28903180,
         18560056,  12317920,  6491857,   3525223,   1944665,   1081966,   6},
    },
    {
        {737900480, 737313472, 736843456, 735978112, 734341632, 731092416, 727578432, 721723200,
         711172416, 689515200, 632898368, 524671456, 291627872, 124282568, 61909856,  39166204,
         32726406,  30782714,  28778620,  26053694,  22893106,  18076024,  13777827,  10259417,
         7520912,   5455094,   3146319,   1794368,   1017003,   574424,    3},
        {737900480, 737313856, 736844736, 735982272, 734355200, 731139072, 727679616, 721953472,
         711743296, 691176960, 639550656, 546400448, 337176160, 153194576, 79696616,  51414392,
         40409976,  35288896,  31462072,  27703048,  23931236,  18606918,  14052068,  10401011,
         7593699,   5492314,   3158367,   1798231,   1018235,   574816,    3},
        {737900480, 737314496, 736846656, 735988544, 734375872, 731209600, 727831808, 722297216,
         712582592, 693540736, 648325568, 572924864, 400936960, 201170544, 106893592, 68502096,
         51196844,  41932300,  35558792,  30265664,  25555562,  19438326,  14479913,  10620826,
         7706165,   5549599,   3176820,   1804132,   1020113,   575412,    3},
        {737900480, 737315968, 736851520, 736004224, 734427392, 731384128, 728205504, 723128192,
         714552448, 698767168, 665389440, 617851520, 518249088, 341071744, 189979888, 115866720,
         79793448,  59627348,  46625756,  37240340,  29975502,  21679968,  15618320,  11198082,
         7998192,   5697000,   3223802,   1819057,   1024845,   576910,    3},
        {737900480, 737317504, 736856256, 736019456, 734476992, 731550720, 728558400, 723898048,
         716313280, 703122688, 677714048, 645514624, 585425152, 469729280, 304799264, 181937120,
         116903752, 81417144,  59804904,  45335940,  34988372,  24141316,  16833072,  11799646,
         8296896,   5845648,   3270431,   1833731,   1029473,   578371,    3},
        {737900480, 737319808, 736863680, 736043264, 734554432, 731808256, 729097600, 725051328,
         718858688, 709018048, 692447360, 674422272, 645810304, 597029312, 509281120, 368950240,
         228619376, 140871152, 92090184,  63478204,  45453116,  28882404,  19041826,  12849181,
         8802888,   6092218,   3346065,   1857236,   1036832,   580686,    3},
        {737900480, 737323520, 736875456, 736081088, 734676800, 732210048, 729927424, 726786624,
         722546496, 717012160, 710183424, 705045120, 699473920, 692939328, 683288384, 664622720,
         621866048, 513176832, 298800288, 144682432, 80228568,  40814640,  23774754,  14887523,
         9725975,   6523960,   3473221,   1895906,   1048798,   584424,    3},
        {737900480, 737326016, 736883520, 736106688, 734759040, 732477632, 730474944, 727916992,
         724904832, 721986304, 720753536, 722497344, 728061952, 739005568, 755619392, 771010688,
         763544704, 740635136, 685348544, 485060256, 169322848, 56755684,  28517764,  16647276,
         10457803,  6848975,   3564451,   1922987,   1057072,   586991,    3},
    },
    {
        {-843314816, -843314816, -843314816, -843314816, -843314816, -843314816, -843314816,
         -843314816, -843314816, -843314816, -843314816, -843314752, -99,        -23,
         -8,         0,          -5,         -6,         -6,         -6,         -5,
         -4,         -3,         -2,         -2,         -1,         -1,         0,
         0,          0,          0},
        {-843314816, -843314816, -843314816, -843314816, -843314816, -843314816, -843314816,
         -843314816, -843314816, -843314816, -843314816, -843314752, -180,       -33,
         -14,        -9,         -7,         -7,         -7,         -6,         -5,
         -4,         -3,         -2,         -2,         -1,         -1,         0,
         0,          0,          0},
        {-843314816, -843314816, -843314816, -843314816, -843314816, -843314816, -843314816,
         -843314816, -843314816, -843314816, -843314816, -843314752, -3092,      -53,
         -23,        -14,        -11,        -9,         -8,         -7,         -6,
         -4,         -3,         -2,         -2,         -1,         -1,         0,
         0,          0,          0},
        {-843314816, -843314816, -843314816, -843314816, -843314816, -843314816, -843314816,
         -843314816, -843314816, -843314816, -843314816, -843314816, -843314752, -298,
         -55,        -28,        -19,        -14,        -11,        -9,         -7,
         -5,         -4,         -3,         -2,         -1,         -1,         0,
         0,          0,          0},
        {-843314816, -843314816, -843314816, -843314816, -843314816, -843314816, -843314816,
         -843314816, -843314816, -843314816, -843314816, -843314816, -843314816, -843314688,
         -193,       -55,        -30,        -20,        -14,        -11,        -8,
         -6,         -4,         -3,         -2,         -1,         -1,         0,
         0,          0,          0},
        {-843314816, -843314816, -843314816, -843314816, -843314816, -843314816, -843314816,
         -843314816, -843314816, -843314816, -843314816, -843314816, -843314816, -843314816,
         -843314752, -421657440, -91,        -40,        -24,        -16,        -11,
         -7,         -4,         -3,         -2,         -1,         -1,         0,
         0,          0,          0},
        {-843314816, -843314816, -843314816, -843314816, -843314816, -843314816, -843314816,
         -843314816, -843314816, -843314816, -843314816, -843314816, -843314816, -843314816,
         -843314816, -843314816, -843314816, -843314752, -252,       -43,        -21,
         -10,        -6,         -3,         -2,         -2,         -1,         0,
         0,          0,          0},
        {-843314816, -843314816, -843314816, -843314816, -843314816, -843314816, -843314816,
         -843314816, -843314816, -843314816, -843314816, -843314816, -843314816, -843314816,
         -843314816, -843314816, -843314816, -843314816, -843314816, -843314752, -56,
         -14,        -7,         -4,         -2,         -2,         -1,         0,
         0,          0,          0},
    },
    {
        {-737900480, -737313472, -736843456, -735978176, -734341632, -731092480, -727578496,
         -721723200, -711172416, -689515200, -632898368, -524671488, -291627872, -124282552,
         -61909848,  -39166196,  -32726402,  -30782708,  -28778616,  -26053690,  -22893104,
         -18076022,  -13777825,  -10259415,  -7520911,   -5455092,   -3146318,   -1794368,
         -1017003,   -574424,    -3},
        {-737900480, -737313856, -736844736, -735982272, -734355264, -731139072, -727679616,
         -721953472, -711743360, -691176960, -639550656, -546400448, -337176160, -153194560,
         -79696608,  -51414384,  -40409972,  -35288892,  -31462068,  -27703042,  -23931232,
         -18606916,  -14052066,  -10401010,  -7593697,   -5492313,   -3158366,   -1798231,
         -1018235,   -574816,    -3},
        {-737900480, -737314496, -736846656, -735988544, -734375872, -731209600, -727831808,
         -722297216, -712582592, -693540736, -648325568, -572924928, -400936960, -201170512,
         -106893576, -68502088,  -51196836,  -41932292,  -35558788,  -30265660,  -25555558,
         -19438322,  -14479910,  -10620825,  -7706164,   -5549598,   -3176819,   -1804131,
         -1020113,   -575412,    -3},
        {-737900480, -737316032, -736851520, -736004288, -734427392, -731384128, -728205504,
         -723128192, -714552448, -698767168, -665389504, -617851520, -518249088, -341071712,
         -189979872, -115866704, -79793440,  -59627336,  -46625748,  -37240336,  -29975498,
         -21679964,  -15618318,  -11198080,  -7998190,   -5696998,   -3223801,   -1819057,
         -1024845,   -576910,    -3},
        {-737900480, -737317504, -736856256, -736019456, -734476992, -731550784, -728558400,
         -723898112, -716313280, -703122688, -677714048, -645514624, -585425152, -469729280,
         -304799232, -181937104, -116903736, -81417128,  -59804896,  -45335932,  -34988368,
         -24141312,  -16833070,  -11799644,  -8296895,   -5845647,   -3270430,   -1833731,
         -1029472,   -578371,    -3},
        {-737900480, -737319808, -736863680, -736043264, -734554432, -731808256, -729097600,
         -725051328, -718858688, -709018112, -692447360, -674422272, -645810304, -597029312,
         -509281120, -368950240, -228619360, -140871136, -92090168,  -63478192,  -45453108,
         -28882400,  -19041824,  -12849179,  -8802887,   -6092216,   -3346064,   -1857235,
         -1036832,   -580686,    -3},
        {-737900480, -737323520, -736875520, -736081152, -734676800, -732210112, -729927424,
         -726786624, -722546560, -717012224, -710183488, -705045120, -699473920, -692939328,
         -683288448, -664622784, -621866048, -513176832, -298800256, -144682416, -80228552,
         -40814632,  -23774750,  -14887520,  -9725973,   -6523959,   -3473220,   -1895905,
         -1048798,   -584424,    -3},
        {-737900480, -737326080, -736883520, -736106752, -734759104, -732477632, -730474944,
         -727917056, -724904896, -721986368, -720753536, -722497344, -728061952, -739005568,
         -755619456, -771010688, -763544704, -740635136, -685348544, -485060256, -169322832,
         -56755676,  -28517758,  -16647273,  -10457802,  -6848973,   -3564450,   -1922987,
         -1057072,   -586991,    -3},
    },
    {
        {-632486144, -631404160, -630541632, -628962624, -626006912, -620254848, -614202752,
         -604493888, -588124928, -558622016, -501272672, -434361280, -339721664, -238866896,
         -162754096, -116484128, -89986864,  -73763168,  -62238740,  -52877228,  -44742028,
         -34289608,  -25778562,  -19071618,  -13937720,  -10094244,  -5816230,   -3316020,
         -1879259,   -1061412,   -6},
        {-632486144, -631404800, -630543744, -628969280, -626028480, -620326656, -614353408,
         -604818880, -588856448, -560378624, -505802400, -442767552, -353024864, -254136224,
         -175962480, -126430968, -96994048,  -78520448,  -65419836,  -54997768,  -46155352,
         -35055976,  -26190096,  -19289814,  -14051969,  -10153424,  -5835646,   -3322294,
         -1881267,   -1062052,   -6},
        {-632486144, -631405824, -630546880, -628979392, -626061312, -620435456, -614581376,
         -605308352, -589949440, -562964800, -512317888, -454700800, -372074880, -276762944,
         -196044080, -141682256, -107802384, -85920168,  -70405192,  -58335112,  -48381668,
         -36259772,  -26833196,  -19628898,  -14228625,  -10244552,  -5865396,   -3331876,
         -1884330,   -1063026,   -6},
        {-632486144, -631408320, -630554816, -629004736, -626143424, -620706752, -615146880,
         -606512512, -592597440, -569059456, -527028288, -480972000, -414517888, -330765376,
         -247566576, -182256848, -137009312, -106116016, -84093792,  -67506712,  -54475932,
         -39516584,  -28548306,  -20520858,  -14687894,  -10479248,  -5941176,   -3356124,
         -1892049,   -1065476,   -6},
        {-632486144, -631410688, -630562496, -629029312, -626222848, -620968128, -615688640,
         -607654400, -595061824, -574547648, -539620928, -502759488, -449954304, -379751872,
         -300289600, -227398144, -170699200, -129631024, -99970272,  -78022152,  -61351276,
         -43090364,  -30380254,  -21451666,  -15158277,  -10716185,  -6016438,   -3379975,
         -1899599,   -1067865,   -6},
        {-632486144, -631414528, -630574528, -629067968, -626347520, -621376576, -616530368,
         -609410560, -598784192, -582583424, -557211968, -532248448, -497725920, -450454688,
         -388712416, -316243072, -243773744, -182031456, -134760256, -100237728, -75274176,
         -49902756,  -33701964,  -23075618,  -15955779,  -11109604,  -6138616,   -3418196,
         -1911610,   -1071650,   -6},
        {-632486144, -631420608, -630593920, -629129728, -626546368, -622024256, -617857472,
         -612152256, -604500352, -594593024, -582468992, -573393792, -563597248, -552304000,
         -536529056, -509232736, -458470496, -373144992, -265980880, -175277520, -115809544,
         -66314036,  -40717412,  -26216596,  -17410062,  -11799017,  -6344227,   -3481124,
         -1931149,   -1077765,   -6},
        {-632486144, -631424704, -630607040, -629171712, -626681152, -622462336, -618753152,
         -613998656, -608344384, -602686272, -599701056, -602055040, -611306560, -631195136,
         -663846464, -695665728, -678745600, -629219648, -527619232, -345921600, -187985760,
         -86310936,  -47549652,  -28903178,  -18560056,  -12317919,  -6491856,   -3525223,
         -1944664,   -1081966,   -6},
    },
    {
        {-527071808, -525663328, -524547904, -522522464, -518787456, -511719712, -504553344,
         -493592160, -476455328, -449151136, -405692224, -364814720, -314764512, -260204640,
         -208654496, -165799488, -132838856, -107993080, -88864496,  -73593008,  -61016300,
         -45833920,  -34080072,  -25068086,  -18265786,  -13208914,  -7602956,   -4333254,
         -2455489,   -1386823,   -8},
        {-527071808, -525664032, -524550048, -522529344, -518809248, -511789152, -504692896,
         -493873600, -477024000, -450294240, -407912928, -368083072, -319153344, -265360496,
         -213877824, -170466928, -136659360, -110950464, -91074040,  -75203984,  -62168492,
         -46509388,  -34462972,  -25278938,  -18379172,  -13268760,  -7622986,   -4339799,
         -2457598,   -1387497,   -8},
        {-527071808, -525665056, -524553344, -522539776, -518842432, -511894880, -504905472,
         -494302080, -477888896, -452029312, -411276864, -373037408, -325837408, -273286560,
         -222000464, -177798416, -142702912, -115647952, -94588960,  -77764888,  -63995600,
         -47574416,  -35062712,  -25607104,  -18554672,  -13360983,  -7653687,   -4349798,
         -2460813,   -1388524,   -8},
        {-527071808, -525667680, -524561632, -522566016, -518925792, -512160864, -505440352,
         -495379840, -480060736, -456371840, -419671488, -385428768, -342733888, -293748864,
         -243538000, -197712512, -159394864, -128736136, -104401192, -84889288,  -69041664,
         -50472220,  -36668384,  -26472714,  -19011836,  -13598832,  -7731957,   -4375111,
         -2468919,   -1391105,   -8},
        {-527071808, -525670208, -524569664, -522591520, -519007008, -512420384, -505962688,
         -496432608, -482180192, -460599072, -427832640, -397536032, -359516800, -314728128,
         -266563552, -219861056, -178475984, -143891040, -115765912, -93067576,  -74749312,
         -53662744,  -38389064,  -27378586,  -19481138,  -13839381,  -7809779,   -4400024,
         -2476851,   -1393623,   -8},
        {-527071808, -525674208, -524582336, -522631840, -519135552, -512832288, -506793408,
         -498110048, -485562336, -467353888, -440933120, -417176480, -387412896, -351185760,
         -309141024, -263535920, -217930816, -175886064, -139658944, -109895352, -86138704,
         -59717932,  -41509480,  -28961786,  -20278428,  -14239527,  -7936268,   -4439981,
         -2489476,   -1397613,   -8},
        {-527071808, -525680640, -524602720, -522696736, -519343168, -513501280, -508149440,
         -500867680, -491177984, -478742432, -463639424, -452372288, -440252512, -426573984,
         -408733888, -381475168, -338855200, -280525440, -216504464, -159999152, -116811992,
         -73859864,  -48033648,  -32018524,  -21734040,  -14942109,  -8149503,   -4505843,
         -2510026,   -1404062,   -8},
        {-527071808, -525685024, -524616640, -522741120, -519485760, -513964448, -509095936,
         -502817440, -495235424, -487294400, -481973952, -483250688, -492921664, -517327360,
         -563364544, -613069184, -582305664, -502086560, -381071904, -253160976, -162730944,
         -89940184,  -54233516,  -34613092,  -22883530,  -15471361,  -8302828,   -4552048,
         -2524252,   -1408494,   -8},
    },
    {
        {-421657408, -420139456, -418946528, -416800672, -412909824, -405768000, -398798528,
         -388615168, -373701408, -352009344, -321306208, -295197120, -265052192, -232374288,
         -199428848, -168474672, -140988896, -117445752, -97614400,  -80976864,  -67001780,
         -50094052,  -37102532,  -27221788,  -19805402,  -14310412,  -8231902,   -4690747,
         -2657887,   -1501102,   -8},
        {-421657408, -420140000, -418948192, -416805888, -412925952, -405817184, -398893120,
         -388794176, -374031200, -352591488, -322263520, -296453056, -266595328, -234127456,
         -201261264, -170245168, -142589072, -118816232, -98738176,  -81865128,  -67681552,
         -50525456,  -37361620,  -27370528,  -19887816,  -14354855,  -8247121,   -4695785,
         -2659522,   -1501627,   -8},
        {-421657408, -420140800, -418950720, -416813824, -412950592, -405892416, -399038240,
         -389069472, -374540320, -353494496, -323757792, -298423616, -269030976, -236912448,
         -204189776, -173088112, -145165408, -121023680, -100545224, -83288680,  -68766080,
         -51208344,  -37768500,  -27602440,  -20015536,  -14423394,  -8270459,   -4703484,
         -2662016,   -1502426,   -8},
        {-421657408, -420142816, -418957120, -416833824, -413012832, -406083552, -399408640,
         -389776736, -375859200, -355859232, -327727008, -303720672, -275669600, -244617712,
         -212408608, -181157008, -152524352, -127334256, -105689208, -87307640,  -71794608,
         -53080056,  -38863244,  -28216278,  -20349054,  -14600477,  -8330017,   -4722985,
         -2668305,   -1504437,   -8},
        {-421657408, -420144800, -418963328, -416853344, -413073952, -406272672, -399777664,
         -390488160, -377202752, -358308960, -331931552, -309437728, -282992896, -253322816,
         -221909888, -190657120, -161278432, -134848896, -111768392, -91990440,  -75259304,
         -55157184,  -40043144,  -28861386,  -20692490,  -14779979,  -8389313,   -4742193,
         -2674461,   -1506398,   -8},
        {-421657408, -420147904, -418973152, -416884384, -413171584, -406578080, -400379520,
         -391663904, -379464224, -362537024, -339441728, -319954336, -296943136, -270562688,
         -241463968, -210828720, -180193456, -151094736, -124714296, -101703096, -82215704,
         -59120396,  -42193204,  -29993510,  -21277910,  -15079353,  -8485847,   -4773029,
         -2684265,   -1509508,   -8},
        {-421657408, -420152928, -418989024, -416934752, -413331616, -407087776, -401401280,
         -393709888, -383542496, -370571008, -354857280, -343114528, -330489120, -316523520,
         -299496896, -276320320, -244582704, -205903728, -165901376, -130010112, -100638328,
         -68322528,  -46691836,  -32186576,  -22350768,  -15606794,  -8648966,   -4823931,
         -2700238,   -1514536,   -8},
        {-421657408, -420156352, -418999936, -416969504, -413443264, -407450528, -402143200,
         -395241024, -386740960, -377366304, -369662048, -368527936, -375197024, -397609792,
         -449444704, -516205344, -465462368, -362087840, -258438672, -179525856, -126554704,
         -78481920,  -50925604,  -34045784,  -23199528,  -16005132,  -8766508,   -4859691,
         -2711304,   -1517993,   -8},
    },
    {
        {-316243008, -314846624, -313757504, -311816352, -308352832, -302171008, -296337632,
         -288127456, -276678880, -261007888, -240267536, -223492144, -204621168, -184231584,
         -163158624, -142328848, -122556336, -104403368, -88154688,  -73876192,  -61498028,
         -46182700,  -34260636,  -25149106,  -18299350,  -13222144,  -7605577,   -4333749,
         -2455580,   -1386840,   -8},
        {-316243008, -314846912, -313758464, -311819232, -308361568, -302196544, -296384928,
         -288212416, -276825056, -261244496, -240620368, -223927216, -205130336, -184795472,
         -163749760, -142917408, -123115296, -104911600, -88598128,  -74247992,  -61798056,
         -46386168,  -34389244,  -25225818,  -18343070,  -13246209,  -7614004,   -4336575,
         -2456504,   -1387137,   -8},
        {-316243008, -314847392, -313759872, -311823616, -308374912, -302235744, -296457888,
         -288344192, -277053152, -261616784, -241180768, -224622800, -205949648, -185708016,
         -164710592, -143876416, -124026376, -105738512, -89317016,  -74847736,  -62279196,
         -46709404,  -34591708,  -25345634,  -18410908,  -13283356,  -7626933,   -4340893,
         -2457913,   -1387591,   -8},
        {-316243008, -314848512, -313763456, -311834752, -308408832, -302336288, -296646464,
         -288688576, -277658176, -262622288, -242727472, -226572608, -208281632, -188341072,
         -167512272, -146689680, -126701224, -108155704, -91399992,  -76564696,  -63637496,
         -47602000,  -35139292,  -25663914,  -18588502,  -13379500,  -7659961,   -4351839,
         -2461468,   -1388732,   -8},
        {-316243008, -314849632, -313766976, -311845632, -308442368, -302437024, -296837728,
         -289043648, -278295616, -263711632, -244460304, -228811328, -211025744, -191509376,
         -170942672, -150169120, -130013896, -111127320, -93923416,  -78603784,  -65214380,
         -48602508,  -35733556,  -26000038,  -18772010,  -13477196,  -7692889,   -4362630,
         -2464949,   -1389845,   -8},
        {-316243008, -314851424, -313772512, -311863040, -308496416, -302602400, -297156896,
         -289649696, -279417728, -265709072, -247806336, -233308272, -216768688, -198401504,
         -178640608, -158121504, -137602416, -117841504, -99474336,  -82934744,  -68436680,
         -50533948,  -36825284,  -26593332,  -19086118,  -13640626,  -7746589,   -4379970,
         -2470496,   -1391610,   -8},
        {-316243008, -314854272, -313781536, -311891520, -308586368, -302885760, -297719584,
         -290762368, -281600896, -269929024, -255733712, -245043328, -233506144, -220942752,
         -206510416, -188780416, -167001360, -142516672, -118085752, -95972952,  -77157128,
         -55082252,  -39133420,  -27751764,  -19665234,  -13929854,  -7837574,   -4408639,
         -2479541,   -1394467,   -8},
        {-316243008, -314856224, -313787744, -311911360, -308650080, -303093120, -298144704,
         -291644064, -283459904, -273946496, -264748464, -260980560, -262699104, -277087104,
         -321151136, -394123776, -324055296, -228764208, -162653232, -119096664, -89459472,
         -60122148,  -41317832,  -28739578,  -20125736,  -14149188,  -7903306,   -4428810,
         -2485814,   -1396432,   -8},
    },
    {
        {-210828752, -209763872, -208938592, -207478800, -204908080, -200419808, -196290928,
         -190633648, -183000704, -172937696, -160110736, -149997216, -138756640, -126624232,
         -113938360, -101099096, -88510608,  -76526296,  -65413292,  -55341440,  -46391320,
         -35074012,  -26116860,  -19208966,  -13991280,  -10114557,  -5820108,   -3316738,
         -1879390,   -1061436,   -6},
        {-210828752, -209763984, -208938928, -207479824, -204911120, -200428400, -196306416,
         -190660464, -183044768, -173005280, -160206000, -150110752, -138886000, -126765304,
         -114085976, -101247840, -88655288,  -76662120,  -65536172,  -55448360,  -46480720,
         -35137564,  -26158602,  -19234616,  -14006233,  -10122926,  -5823093,   -3317749,
         -1879722,   -1061544,   -6},
        {-210828752, -209764144, -208939440, -207481376, -204915760, -200441648, -196330416,
         -190702288, -183114016, -173112528, -160358784, -150294128, -139096320, -126995880,
         -114328144, -101492256, -88892840,  -76884536,  -65736472,  -55621628,  -46624628,
         -35238804,  -26224440,  -19274738,  -14029458,  -10135854,  -5827674,   -3319296,
         -1880230,   -1061707,   -6},
        {-210828752, -209764560, -208940736, -207485328, -204927632, -200475856, -196392992,
         -190812944, -183300624, -173407952, -160790128, -150820560, -139709616, -127677056,
         -115050048, -102223736, -89602680,  -77544552,  -66324276,  -56122908,  -47034392,
         -35520116,  -26403304,  -19381648,  -14090389,  -10169365,  -5839389,   -3323218,
         -1881511,   -1062120,   -6},
        {-210828752, -209764960, -208941984, -207489216, -204939424, -200510464, -196457344,
         -190929120, -183501920, -173737552, -161290496, -151447952, -140459488, -128528240,
         -115966008, -103158080, -90506904,  -78375592,  -67050588,  -56727872,  -47516252,
         -35838308,  -26598652,  -19495052,  -14153547,  -10203492,  -5851082,   -3327087,
         -1882766,   -1062523,   -6},
        {-210828752, -209765600, -208944000, -207495456, -204958576, -200568016, -196566672,
         -191132352, -183868160, -174368384, -162309168, -152784224, -142129664, -130500376,
         -118149736, -105414376, -92679024,  -80328376,  -68699096,  -58044540,  -48519596,
         -36460372,  -26960598,  -19696400,  -14262092,  -10260742,  -5870182,   -3333310,
         -1884767,   -1063161,   -6},
        {-210828752, -209766624, -208947248, -207505712, -204990848, -200668832, -196765472,
         -191522144, -184625552, -175818224, -165011760, -156772320, -147807488, -138128816,
         -127521488, -115591360, -102270704, -88260840,  -74642488,  -62217976,  -51336332,
         -37958768,  -27737038,  -20093356,  -14463535,  -10362521,  -5902624,   -3343612,
         -1888032,   -1064195,   -6},
        {-210828752, -209767344, -208949504, -207512928, -205014000, -200744384, -196920912,
         -191846704, -185318880, -177353360, -168608208, -163416672, -160727552, -165029760,
         -189074016, -241456784, -178005872, -122049664, -90479424,  -70104056,  -55475480,
         -39658748,  -28482878,  -20435214,  -14624802,  -10440065,  -5926123,   -3350872,
         -1890299,   -1064907,   -6},
    },
    {
        {-105414352, -104839424, -104395752, -103614840, -102251280, -99903608, -97777512,
         -94910408,  -91113920,  -86209240,  -80075680,  -75298248,  -70016784, -64317188,
         -58324212,  -52191704,  -46086820,  -40171652,  -34586568,  -29438702, -24797034,
         -18844524,  -14076834,  -10372790,  -7563107,   -5470588,   -3149178,  -1794887,
         -1017097,   -574441,    -3},
        {-105414352, -104839440, -104395800, -103614984, -102251696, -99904760, -97779552,
         -94913864,  -91119448,  -86217488,  -80086968,  -75311472,  -70031648, -64333264,
         -58341004,  -52208708,  -46103540,  -40187592,  -34601256,  -29451740, -24808154,
         -18852650,  -14082296,  -10376208,  -7565130,   -5471732,   -3149590,  -1795028,
         -1017143,   -574456,    -3},
        {-105414352, -104839464, -104395864, -103615200, -102252328, -99906536, -97782720,
         -94919272,  -91128184,  -86230632,  -80105160,  -75332928,  -70055928, -64359668,
         -58368680,  -52236764,  -46131096,  -40213784,  -34625276,  -29472926, -24826094,
         -18865612,  -14090921,  -10381562,  -7568272,   -5473500,   -3150225,  -1795243,
         -1017214,   -574479,    -3},
        {-105414352, -104839520, -104396048, -103615744, -102253960, -99911152, -97791032,
         -94933688,  -91151920,  -86267216,  -80157128,  -75395304,  -70127624, -64438604,
         -58452116,  -52321612,  -46214216,  -40292164,  -34696280,  -29534602, -24877444,
         -18901780,  -14114420,  -10395856,  -7576529,   -5478088,   -3151847,  -1795790,
         -1017393,   -574537,    -3},
        {-105414352, -104839576, -104396224, -103616288, -102255584, -99915840, -97799648,
         -94948992,  -91177888,  -86308728,  -80218552,  -75471128,  -70217064, -64539224,
         -58559996,  -52431912,  -46321788,  -40392244,  -34785072,  -29609788, -24938334,
         -18942936,  -14140198,  -10411064,  -7585107,   -5482767,   -3153468,  -1796330,
         -1017569,   -574593,    -3},
        {-105414352, -104839672, -104396504, -103617152, -102258232, -99923720, -97814464,
         -94976168,  -91226088,  -86390208,  -80347520,  -75638136,  -70423480, -64780936,
         -58826440,  -52707176,  -46587912,  -40633416,  -34990872,  -29776222, -25066836,
         -19024146,  -14188261,  -10438183,  -7599891,   -5490632,   -3156117,  -1797198,
         -1017849,   -574683,    -3},
        {-105414352, -104839816, -104396960, -103618592, -102262736, -99937720, -97841944,
         -95029800,  -91329808,  -86588032,  -80716136,  -76183440,  -71203424, -65834124,
         -60122608,  -54107304,  -47891720,  -41697004,  -35779764,  -30327718, -25439256,
         -19223604,  -14292622,  -10492064,  -7627469,   -5504662,   -3160627,  -1798637,
         -1018307,   -574828,    -3},
        {-105414352, -104839912, -104397280, -103619608, -102266000, -99948376, -97863944,
         -95076008,  -91429704,  -86814408,  -81270896,  -77262800,  -73480376, -71228232,
         -75154784,  -90330848,  -64216360,  -47491208,  -38189996,  -31457080, -26014454,
         -19455914,  -14394384,  -10538884,  -7649672,   -5515392,   -3163898,  -1799652,
         -1018624,   -574928,    -3},
    }};

const FLOAT32 ixheaacd_c_l_table[31] = {
    0.0000000317f, 0.0056233243f, 0.0099995006f, 0.0177799836f, 0.0316069759f, 0.0561454296f,
    0.0791834071f, 0.1115021780f, 0.1565355211f, 0.2184644639f, 0.3015113473f, 0.3698741496f,
    0.4480625093f, 0.5336171389f, 0.6219832897f, 0.7071067691f, 0.7830305099f, 0.8457261920f,
    0.8940022588f, 0.9290818572f, 0.9534626007f, 0.9758449197f, 0.9876723289f, 0.9937641621f,
    0.9968600869f, 0.9984226227f, 0.9995003939f, 0.9998419285f, 0.9999499917f, 0.9999842048f,
    1.0000000000f};

const FLOAT32 ixheaacd_sin_table[8][31] = {
    {0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
     0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
     0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
     0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
     0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f, 0.0000000000f,
     0.0000000000f},
    {0.3493293524f, 0.3474976718f, 0.3460844457f, 0.3435976505f, 0.3392568827f, 0.3317862749f,
     0.3250220120f, 0.3158984482f, 0.3038074076f, 0.2881557941f, 0.2685075700f, 0.2531277537f,
     0.2360326201f, 0.2174609900f, 0.1977837533f, 0.1774823964f, 0.1571052223f, 0.1372086108f,
     0.1182965338f, 0.1007719785f, 0.0849095508f, 0.0645100474f, 0.0481502302f, 0.0354443900f,
     0.0258174147f, 0.0186577141f, 0.0107282447f, 0.0061101262f, 0.0034608445f, 0.0019541229f,
     0.0000000112f},
    {0.5407552123f, 0.5382068753f, 0.5362367034f, 0.5327616334f, 0.5266705155f, 0.5161136985f,
     0.5064760447f, 0.4933616221f, 0.4757848978f, 0.4527166188f, 0.4232914150f, 0.3999291360f,
     0.3736581206f, 0.3448006511f, 0.3139205575f, 0.2817977965f, 0.2493559569f, 0.2175544947f,
     0.1872726828f, 0.1592146605f, 0.1338564903f, 0.1013506278f, 0.0754068270f, 0.0553560853f,
     0.0402308255f, 0.0290232040f, 0.0166547857f, 0.0094739906f, 0.0053623673f, 0.0030265595f,
     0.0000000172f},
    {0.7993091345f, 0.7966092229f, 0.7945095897f, 0.7907798290f, 0.7841621637f, 0.7724518776f,
     0.7614971995f, 0.7461913228f, 0.7249697447f, 0.6959262490f, 0.6570158601f, 0.6247367263f,
     0.5871030688f, 0.5443126559f, 0.4970877469f, 0.4466989934f, 0.3948508203f, 0.3434380591f,
     0.2942485511f, 0.2487121671f, 0.2077666521f, 0.1557984799f, 0.1148999557f, 0.0837240443f,
     0.0604878739f, 0.0434381589f, 0.0247973837f, 0.0140622752f, 0.0079450961f, 0.0044796630f,
     0.0000000251f},
    {0.9299681783f, 0.9280369282f, 0.9265220165f, 0.9238031507f, 0.9188926220f, 0.9099379182f,
     0.9012627602f, 0.8886758685f, 0.8703642488f, 0.8437789083f, 0.8056230545f, 0.7719746232f,
     0.7307193279f, 0.6815125942f, 0.6248562932f, 0.5622988343f, 0.4963409901f, 0.4300053716f,
     0.3662271798f, 0.3073286414f, 0.2547603846f, 0.1888985783f, 0.1379434466f, 0.0997110680f,
     0.0715898424f, 0.0511695705f, 0.0290579367f, 0.0164278019f, 0.0092652198f, 0.0052187350f,
     0.0000000293f},
    {1.0000000000f, 0.9999842048f, 0.9999499917f, 0.9998419285f, 0.9995003939f, 0.9984226227f,
     0.9968600869f, 0.9937641621f, 0.9876723289f, 0.9758449197f, 0.9534626007f, 0.9290818572f,
     0.8940022588f, 0.8457261920f, 0.7830305099f, 0.7071067691f, 0.6219832897f, 0.5336171389f,
     0.4480625093f, 0.3698741496f, 0.3015113473f, 0.2184644639f, 0.1565355211f, 0.1115021780f,
     0.0791834071f, 0.0561454296f, 0.0316069759f, 0.0177799836f, 0.0099995006f, 0.0056233243f,
     0.0000000317f},
    {0.8081330657f, 0.8108102083f, 0.8128942847f, 0.8166009784f, 0.8231918216f, 0.8348951936f,
     0.8458821774f, 0.8612694144f, 0.8825767040f, 0.9113009572f, 0.9474825859f, 0.9732170701f,
     0.9941481352f, 0.9986549616f, 0.9692055583f, 0.8913472891f, 0.7698673606f, 0.6301086545f,
     0.4982543588f, 0.3874447048f, 0.2996203005f, 0.2040148675f, 0.1398789734f, 0.0966360196f,
     0.0671908110f, 0.0469496064f, 0.0260316096f, 0.0145214461f, 0.0081289429f, 0.0045595206f,
     0.0000000256f},
    {0.1410673708f, 0.1418570578f, 0.1424777508f, 0.1435948759f, 0.1456248760f, 0.1493785530f,
     0.1530961841f, 0.1586700380f, 0.1672619134f, 0.1810861230f, 0.2049261481f, 0.2318390310f,
     0.2772761881f, 0.3656858206f, 0.5848061442f, 0.9974968433f, 0.4645280242f, 0.2307321429f,
     0.1389672905f, 0.0922967792f, 0.0648033395f, 0.0405401327f, 0.0265092272f, 0.0178030711f,
     0.0121608619f, 0.0084001739f, 0.0046050628f, 0.0025535184f, 0.0014247773f, 0.0007977211f,
     0.0000000047f}};

const FLOAT32 ixheaacd_cos_table[8][31] = {
    {1.0000000000f, 1.0000000000f, 1.0000000000f, 1.0000000000f, 1.0000000000f, 1.0000000000f,
     1.0000000000f, 1.0000000000f, 1.0000000000f, 1.0000000000f, 1.0000000000f, 1.0000000000f,
     1.0000000000f, 1.0000000000f, 1.0000000000f, 1.0000000000f, 1.0000000000f, 1.0000000000f,
     1.0000000000f, 1.0000000000f, 1.0000000000f, 1.0000000000f, 1.0000000000f, 1.0000000000f,
     1.0000000000f, 1.0000000000f, 1.0000000000f, 1.0000000000f, 1.0000000000f, 1.0000000000f,
     1.0000000000f},
    {0.9369999766f, 0.9376808405f, 0.9382033348f, 0.9391169548f, 0.9406937957f, 0.9433546066f,
     0.9457064271f, 0.9487929940f, 0.9527334571f, 0.9575835466f, 0.9632775784f, 0.9674328566f,
     0.9717451334f, 0.9760690331f, 0.9802456498f, 0.9841240048f, 0.9875818491f, 0.9905421734f,
     0.9929783344f, 0.9949095249f, 0.9963886738f, 0.9979170561f, 0.9988400936f, 0.9993716478f,
     0.9996666908f, 0.9998259544f, 0.9999424219f, 0.9999813437f, 0.9999940395f, 0.9999980927f,
     1.0000000000f},
    {0.8411800265f, 0.8428127766f, 0.8440676332f, 0.8462653756f, 0.8500694633f, 0.8565201163f,
     0.8622540236f, 0.8698242903f, 0.8795616627f, 0.8916544318f, 0.9059935808f, 0.9165460467f,
     0.9275664687f, 0.9386759400f, 0.9494492412f, 0.9594737887f, 0.9684119225f, 0.9760481715f,
     0.9823079705f, 0.9872440100f, 0.9910007119f, 0.9948507547f, 0.9971528649f, 0.9984666705f,
     0.9991903901f, 0.9995787144f, 0.9998613000f, 0.9999551177f, 0.9999856353f, 0.9999954104f,
     1.0000000000f},
    {0.6009200215f, 0.6044946313f, 0.6072516441f, 0.6121006608f, 0.6205559969f, 0.6350733042f,
     0.6481682062f, 0.6657315493f, 0.6887807250f, 0.7181132436f, 0.7538767457f, 0.7808354497f,
     0.8095121980f, 0.8388824463f, 0.8677002788f, 0.8946843147f, 0.9187452197f, 0.9391753078f,
     0.9557289481f, 0.9685774446f, 0.9781784415f, 0.9877888560f, 0.9933770895f, 0.9964889884f,
     0.9981689453f, 0.9990561008f, 0.9996924996f, 0.9999011159f, 0.9999684095f, 0.9999899864f,
     1.0000000000f},
    {0.3676400185f, 0.3724882603f, 0.3762405813f, 0.3828677237f, 0.3945077062f, 0.4147444665f,
     0.4332729578f, 0.4585359693f, 0.4924084246f, 0.5366908908f, 0.5924285054f, 0.6356533170f,
     0.6826780438f, 0.7318063974f, 0.7807397842f, 0.8269340992f, 0.8681276441f, 0.9028263092f,
     0.9305254817f, 0.9516034126f, 0.9670042396f, 0.9819965959f, 0.9904401302f, 0.9950164557f,
     0.9974341393f, 0.9986900091f, 0.9995777011f, 0.9998650551f, 0.9999570847f, 0.9999864101f,
     1.0000000000f},
    {0.0000000317f, 0.0056233243f, 0.0099995006f, 0.0177799836f, 0.0316069759f, 0.0561454296f,
     0.0791834071f, 0.1115021780f, 0.1565355211f, 0.2184644639f, 0.3015113473f, 0.3698741496f,
     0.4480625093f, 0.5336171389f, 0.6219832897f, 0.7071067691f, 0.7830305099f, 0.8457261920f,
     0.8940022588f, 0.9290818572f, 0.9534626007f, 0.9758449197f, 0.9876723289f, 0.9937641621f,
     0.9968600869f, 0.9984226227f, 0.9995003939f, 0.9998419285f, 0.9999499917f, 0.9999842048f,
     1.0000000000f},
    {-0.5889999866f, -0.5853092074f, -0.5824112892f, -0.5772026181f, -0.5677633882f,
     -0.5504089594f, -0.5333698392f, -0.5081486106f, -0.4701685011f, -0.4117408693f,
     -0.3198074102f, -0.2298880965f, -0.1080254018f, 0.0518490225f,  0.2462531030f,
     0.4533210695f,  0.6382039785f,  0.7765069604f,  0.8670309186f,  0.9218929410f,
     0.9540585279f,  0.9789677858f,  0.9901686311f,  0.9953197837f,  0.9977401495f,
     0.9988972545f,  0.9996611476f,  0.9998945594f,  0.9999669790f,  0.9999896288f,
     1.0000000000f},
    {-0.9900000095f, -0.9898871779f, -0.9897980094f, -0.9896365404f, -0.9893398881f,
     -0.9887800813f, -0.9882112741f, -0.9873316884f, -0.9859125018f, -0.9834672213f,
     -0.9787774086f, -0.9727541804f, -0.9607902765f, -0.9307383299f, -0.8111730814f,
     0.0707106814f,  0.8855584264f,  0.9730173349f,  0.9902969599f,  0.9957315326f,
     0.9978980422f,  0.9991779327f,  0.9996485710f,  0.9998415112f,  0.9999260306f,
     0.9999647141f,  0.9999893904f,  0.9999967217f,  0.9999989867f,  0.9999997020f,
     1.0000000000f}};

const FLOAT32 ixheaacd_mps_polyphase_filter_coeff[10 * MAX_NUM_QMF_BANDS_SAC / 2] = {
    0.000000f,  0.002620f,  -0.000553f, 0.002787f,  -0.000562f, 0.002947f,  -0.000495f,
    0.003113f,  -0.000488f, 0.003274f,  -0.000489f, 0.003442f,  -0.000504f, 0.003601f,
    -0.000523f, 0.003760f,  -0.000547f, 0.003921f,  -0.000568f, 0.004082f,  -0.000587f,
    0.004226f,  -0.000613f, 0.004373f,  -0.000631f, 0.004521f,  -0.000654f, 0.004661f,
    -0.000678f, 0.004793f,  -0.000694f, 0.004914f,  -0.000716f, 0.005039f,  -0.000726f,
    0.005141f,  -0.000744f, 0.005246f,  -0.000749f, 0.005347f,  -0.000768f, 0.005420f,
    -0.000772f, 0.005488f,  -0.000783f, 0.005548f,  -0.000778f, 0.005594f,  -0.000780f,
    0.005622f,  -0.000780f, 0.005646f,  -0.000776f, 0.005639f,  -0.000763f, 0.005627f,
    -0.000753f, 0.005592f,  -0.000732f, 0.005540f,  -0.000722f, 0.005475f,  -0.000692f,
    0.005384f,  -0.000665f, 0.005272f,  -0.000634f, 0.005138f,  -0.000595f, 0.004984f,
    -0.000556f, 0.004811f,  -0.000515f, 0.004604f,  -0.000461f, 0.004380f,  -0.000410f,
    0.004125f,  -0.000350f, 0.003846f,  -0.000290f, 0.003540f,  -0.000210f, 0.003209f,
    -0.000145f, 0.002845f,  -0.000062f, 0.002451f,  0.000013f,  0.002027f,  0.000109f,
    0.001578f,  0.000204f,  0.001090f,  0.000295f,  0.000583f,  0.000403f,  0.000028f,
    0.000511f,  -0.000546f, 0.000624f,  -0.001157f, 0.000746f,  -0.001804f, 0.000861f,
    -0.002483f, 0.000989f,  -0.003193f, 0.001125f,  -0.003940f, 0.001258f,  -0.004722f,
    0.001390f,  -0.005534f, 0.001544f,  -0.006379f, 0.001687f,  -0.007262f, 0.001835f,
    -0.008180f, 0.001984f,  -0.009133f, 0.002146f,  -0.010115f, 0.002302f,  -0.011132f,
    0.002463f,  -0.012185f, 0.013272f,  0.070353f,  0.014390f,  0.068966f,  0.015541f,
    0.067453f,  0.016732f,  0.065769f,  0.017943f,  0.063944f,  0.019187f,  0.061960f,
    0.020453f,  0.059817f,  0.021747f,  0.057515f,  0.023068f,  0.055046f,  0.024416f,
    0.052409f,  0.025788f,  0.049598f,  0.027186f,  0.046630f,  0.028607f,  0.043477f,
    0.030050f,  0.040146f,  0.031502f,  0.036642f,  0.032975f,  0.032958f,  0.034462f,
    0.029082f,  0.035970f,  0.025031f,  0.037481f,  0.020800f,  0.039005f,  0.016370f,
    0.040535f,  0.011762f,  0.042065f,  0.006964f,  0.043610f,  0.001977f,  0.045149f,
    -0.003209f, 0.046684f,  -0.008571f, 0.048217f,  -0.014129f, 0.049739f,  -0.019883f,
    0.051256f,  -0.025823f, 0.052763f,  -0.031953f, 0.054245f,  -0.038278f, 0.055717f,
    -0.044781f, 0.057162f,  -0.051480f, 0.058592f,  -0.058371f, 0.059984f,  -0.065441f,
    0.061346f,  -0.072694f, 0.062686f,  -0.080137f, 0.063972f,  -0.087755f, 0.065225f,
    -0.095553f, 0.066437f,  -0.103533f, 0.067608f,  -0.111683f, 0.068704f,  -0.120008f,
    0.069763f,  -0.128500f, 0.070763f,  -0.137155f, 0.071700f,  -0.145977f, 0.072568f,
    -0.154961f, 0.073362f,  -0.164096f, 0.074100f,  -0.173381f, 0.074745f,  -0.182817f,
    0.075314f,  -0.192397f, 0.075801f,  -0.202125f, 0.076199f,  -0.211974f, 0.076499f,
    -0.221965f, 0.076709f,  -0.232069f, 0.076817f,  -0.242302f, 0.076823f,  -0.252648f,
    0.076720f,  -0.263105f, 0.076505f,  -0.273663f, 0.076175f,  -0.284321f, 0.075731f,
    -0.295072f, 0.075158f,  -0.305910f, 0.074466f,  -0.316828f, 0.073641f,  -0.327811f,
    0.072677f,  -0.338872f, 0.071583f,  -0.349991f, 0.361159f,  0.853739f,  0.372380f,
    0.853572f,  0.383635f,  0.853102f,  0.394921f,  0.852305f,  0.406232f,  0.851197f,
    0.417570f,  0.849780f,  0.428912f,  0.848032f,  0.440255f,  0.845982f,  0.451600f,
    0.843624f,  0.462931f,  0.840954f,  0.474245f,  0.837972f,  0.485525f,  0.834694f,
    0.496771f,  0.831104f,  0.507982f,  0.827228f,  0.519123f,  0.823042f,  0.530224f,
    0.818578f,  0.541255f,  0.813819f,  0.552205f,  0.808770f,  0.563079f,  0.803449f,
    0.573852f,  0.797847f,  0.584540f,  0.791974f,  0.595112f,  0.785835f,  0.605578f,
    0.779429f,  0.615911f,  0.772778f,  0.626124f,  0.765867f,  0.636198f,  0.758708f,
    0.646127f,  0.751314f,  0.655902f,  0.743683f,  0.665514f,  0.735821f,  0.674966f,
    0.727745f,  0.684235f,  0.719446f,  0.693328f,  0.710941f,  0.702239f,  0.702239f,
    0.710941f,  0.693328f,  0.719446f,  0.684235f,  0.727745f,  0.674966f,  0.735821f,
    0.665514f,  0.743683f,  0.655902f,  0.751314f,  0.646127f,  0.758708f,  0.636198f,
    0.765867f,  0.626124f,  0.772778f,  0.615911f,  0.779429f,  0.605578f,  0.785835f,
    0.595112f,  0.791974f,  0.584540f,  0.797847f,  0.573852f,  0.803449f,  0.563079f,
    0.808770f,  0.552205f,  0.813819f,  0.541255f,  0.818578f,  0.530224f,  0.823042f,
    0.519123f,  0.827228f,  0.507982f,  0.831104f,  0.496771f,  0.834694f,  0.485525f,
    0.837972f,  0.474245f,  0.840954f,  0.462931f,  0.843624f,  0.451600f,  0.845982f,
    0.440255f,  0.848032f,  0.428912f,  0.849780f,  0.417570f,  0.851197f,  0.406232f,
    0.852305f,  0.394921f,  0.853102f,  0.383635f,  0.853572f,  0.372380f,  -0.361159f,
    0.070353f,  -0.349991f, 0.071583f,  -0.338872f, 0.072677f,  -0.327811f, 0.073641f,
    -0.316828f, 0.074466f,  -0.305910f, 0.075158f,  -0.295072f, 0.075731f,  -0.284321f,
    0.076175f,  -0.273663f, 0.076505f,  -0.263105f, 0.076720f,  -0.252648f, 0.076823f,
    -0.242302f, 0.076817f,  -0.232069f, 0.076709f,  -0.221965f, 0.076499f,  -0.211974f,
    0.076199f,  -0.202125f, 0.075801f,  -0.192397f, 0.075314f,  -0.182817f, 0.074745f,
    -0.173381f, 0.074100f,  -0.164096f, 0.073362f,  -0.154961f, 0.072568f,  -0.145977f,
    0.071700f,  -0.137155f, 0.070763f,  -0.128500f, 0.069763f,  -0.120008f, 0.068704f,
    -0.111683f, 0.067608f,  -0.103533f, 0.066437f,  -0.095553f, 0.065225f,  -0.087755f,
    0.063972f,  -0.080137f, 0.062686f,  -0.072694f, 0.061346f,  -0.065441f, 0.059984f,
    -0.058371f, 0.058592f,  -0.051480f, 0.057162f,  -0.044781f, 0.055717f,  -0.038278f,
    0.054245f,  -0.031953f, 0.052763f,  -0.025823f, 0.051256f,  -0.019883f, 0.049739f,
    -0.014129f, 0.048217f,  -0.008571f, 0.046684f,  -0.003209f, 0.045149f,  0.001977f,
    0.043610f,  0.006964f,  0.042065f,  0.011762f,  0.040535f,  0.016370f,  0.039005f,
    0.020800f,  0.037481f,  0.025031f,  0.035970f,  0.029082f,  0.034462f,  0.032958f,
    0.032975f,  0.036642f,  0.031502f,  0.040146f,  0.030050f,  0.043477f,  0.028607f,
    0.046630f,  0.027186f,  0.049598f,  0.025788f,  0.052409f,  0.024416f,  0.055046f,
    0.023068f,  0.057515f,  0.021747f,  0.059817f,  0.020453f,  0.061960f,  0.019187f,
    0.063944f,  0.017943f,  0.065769f,  0.016732f,  0.067453f,  0.015541f,  0.068966f,
    0.014390f,  -0.013272f, 0.002620f,  -0.012185f, 0.002463f,  -0.011132f, 0.002302f,
    -0.010115f, 0.002146f,  -0.009133f, 0.001984f,  -0.008180f, 0.001835f,  -0.007262f,
    0.001687f,  -0.006379f, 0.001544f,  -0.005534f, 0.001390f,  -0.004722f, 0.001258f,
    -0.003940f, 0.001125f,  -0.003193f, 0.000989f,  -0.002483f, 0.000861f,  -0.001804f,
    0.000746f,  -0.001157f, 0.000624f,  -0.000546f, 0.000511f,  0.000028f,  0.000403f,
    0.000583f,  0.000295f,  0.001090f,  0.000204f,  0.001578f,  0.000109f,  0.002027f,
    0.000013f,  0.002451f,  -0.000062f, 0.002845f,  -0.000145f, 0.003209f,  -0.000210f,
    0.003540f,  -0.000290f, 0.003846f,  -0.000350f, 0.004125f,  -0.000410f, 0.004380f,
    -0.000461f, 0.004604f,  -0.000515f, 0.004811f,  -0.000556f, 0.004984f,  -0.000595f,
    0.005138f,  -0.000634f, 0.005272f,  -0.000665f, 0.005384f,  -0.000692f, 0.005475f,
    -0.000722f, 0.005540f,  -0.000732f, 0.005592f,  -0.000753f, 0.005627f,  -0.000763f,
    0.005639f,  -0.000776f, 0.005646f,  -0.000780f, 0.005622f,  -0.000780f, 0.005594f,
    -0.000778f, 0.005548f,  -0.000783f, 0.005488f,  -0.000772f, 0.005420f,  -0.000768f,
    0.005347f,  -0.000749f, 0.005246f,  -0.000744f, 0.005141f,  -0.000726f, 0.005039f,
    -0.000716f, 0.004914f,  -0.000694f, 0.004793f,  -0.000678f, 0.004661f,  -0.000654f,
    0.004521f,  -0.000631f, 0.004373f,  -0.000613f, 0.004226f,  -0.000587f, 0.004082f,
    -0.000568f, 0.003921f,  -0.000547f, 0.003760f,  -0.000523f, 0.003601f,  -0.000504f,
    0.003442f,  -0.000489f, 0.003274f,  -0.000488f, 0.003113f,  -0.000495f, 0.002947f,
    -0.000562f, 0.002787f,  -0.000553f};

const FLOAT32 ixheaacd_mps_post_twid[30] = {
    0.998795f, 0.049068f, 0.995185f, 0.098017f, 0.989177f, 0.146730f, 0.980785f, 0.195090f,
    0.970031f, 0.242980f, 0.956940f, 0.290285f, 0.941544f, 0.336890f, 0.923880f, 0.382683f,
    0.903989f, 0.427555f, 0.881921f, 0.471397f, 0.857729f, 0.514103f, 0.831470f, 0.555570f,
    0.803208f, 0.595699f, 0.773010f, 0.634393f, 0.740951f, 0.671559f};

const FLOAT32 ixheaacd_ldmps_pre_twid[32] = {
    0.0156202940f, 0.0003834558f, 0.0155826630f, 0.0011494453f, 0.0155074932f, 0.0019126660f,
    0.0153949633f, 0.0026712785f, 0.0152453454f, 0.0034234561f, 0.0150590008f, 0.0041673859f,
    0.0148363775f, 0.0049012764f, 0.0145780127f, 0.0056233592f, 0.0142845269f, 0.0063318950f,
    0.0139566287f, 0.0070251762f, 0.0135951089f, 0.0077015338f, 0.0132008363f, 0.0083593372f,
    0.0127747618f, 0.0089970026f, 0.0123179127f, 0.0096129924f, 0.0118313879f, 0.0102058258f,
    0.0113163600f, 0.0107740704f};

const FLOAT32 ixheaacd_mps_post_re_32[64] = {
    1.0000000000f,  0.9987954497f,  0.9951847196f,  0.9891765118f,  0.9807852507f,
    0.9700312614f,  0.9569403529f,  0.9415440559f,  0.9238795042f,  0.9039893150f,
    0.8819212317f,  0.8577286005f,  0.8314695954f,  0.8032075167f,  0.7730104327f,
    0.7409511209f,  0.7071067691f,  0.6715589166f,  0.6343932748f,  0.5956993103f,
    0.5555701852f,  0.5141026974f,  0.4713966548f,  0.4275551140f,  0.3826834261f,
    0.3368898332f,  0.2902846336f,  0.2429801226f,  0.1950902343f,  0.1467304826f,
    0.0980171338f,  0.0490676500f,  -0.0000000433f, -0.0490677357f, -0.0980172232f,
    -0.1467305720f, -0.1950903237f, -0.2429801971f, -0.2902847230f, -0.3368899226f,
    -0.3826835155f, -0.4275550842f, -0.4713968337f, -0.5141027570f, -0.5555703640f,
    -0.5956993699f, -0.6343932748f, -0.6715590358f, -0.7071067691f, -0.7409512401f,
    -0.7730104923f, -0.8032076359f, -0.8314696550f, -0.8577286005f, -0.8819213510f,
    -0.9039893150f, -0.9238796234f, -0.9415441155f, -0.9569403529f, -0.9700312614f,
    -0.9807853103f, -0.9891765118f, -0.9951847196f, -0.9987954497f};

const FLOAT32 ixheaacd_mps_post_im_32[64] = {
    0.0000000000f, 0.0490676761f, 0.0980171412f, 0.1467304677f, 0.1950903237f, 0.2429801822f,
    0.2902846634f, 0.3368898630f, 0.3826834559f, 0.4275550842f, 0.4713967443f, 0.5141027570f,
    0.5555702448f, 0.5956993103f, 0.6343933344f, 0.6715589762f, 0.7071067691f, 0.7409511805f,
    0.7730104327f, 0.8032075167f, 0.8314696550f, 0.8577286601f, 0.8819212914f, 0.9039893150f,
    0.9238795042f, 0.9415440559f, 0.9569403529f, 0.9700312614f, 0.9807853103f, 0.9891765118f,
    0.9951847196f, 0.9987954497f, 1.0000000000f, 0.9987954497f, 0.9951847196f, 0.9891765118f,
    0.9807852507f, 0.9700312614f, 0.9569402933f, 0.9415440559f, 0.9238795042f, 0.9039893150f,
    0.8819212317f, 0.8577286005f, 0.8314695358f, 0.8032075167f, 0.7730104923f, 0.7409510612f,
    0.7071067691f, 0.6715588570f, 0.6343932748f, 0.5956991315f, 0.5555701852f, 0.5141027570f,
    0.4713966250f, 0.4275550544f, 0.3826832771f, 0.3368898034f, 0.2902846932f, 0.2429800779f,
    0.1950903088f, 0.1467303336f, 0.0980170965f, 0.0490674861f,
};

const FLOAT32 ixheaacd_mps_pre_twid[64] = {
    0.015624f, 0.000192f, 0.015614f, 0.000575f, 0.015596f, 0.000958f, 0.015567f, 0.001341f,
    0.015530f, 0.001722f, 0.015483f, 0.002103f, 0.015427f, 0.002482f, 0.015361f, 0.002860f,
    0.015286f, 0.003236f, 0.015202f, 0.003610f, 0.015109f, 0.003982f, 0.015007f, 0.004352f,
    0.014895f, 0.004719f, 0.014775f, 0.005083f, 0.014646f, 0.005444f, 0.014508f, 0.005802f,
    0.014361f, 0.006156f, 0.014206f, 0.006507f, 0.014042f, 0.006853f, 0.013869f, 0.007196f,
    0.013689f, 0.007534f, 0.013500f, 0.007868f, 0.013302f, 0.008197f, 0.013097f, 0.008521f,
    0.012884f, 0.008840f, 0.012663f, 0.009153f, 0.012435f, 0.009461f, 0.012199f, 0.009763f,
    0.011956f, 0.010060f, 0.011705f, 0.010350f, 0.011448f, 0.010634f, 0.011183f, 0.010912f};

const FLOAT32 ixheaacd_ia_mps_hyb_filter_coeff_8[QMF_HYBRID_FILT_ORDER] = {
    0.007461f, 0.022704f, 0.045469f, 0.072661f, 0.098851f, 0.117937f, 0.125000f,
    0.117937f, 0.098851f, 0.072661f, 0.045469f, 0.022704f, 0.007462f};

const FLOAT32 ixheaacd_mps_hyb_filter_coeff_2[QMF_HYBRID_FILT_ORDER] = {
    0.000000f, 0.018995f, 0.000000f,  -0.072931f, 0.000000f, 0.305966f, 0.500000f,
    0.305966f, 0.000000f, -0.072931f, 0.000000f,  0.018995f, 0.000000f};

const FLOAT32 ixheaacd_sine[8][8] = {
    {0.000000f, -0.382683f, -0.707107f, -0.923880f, -1.000000f, -0.923880f, -0.707107f,
     -0.382683f},
    {0.000000f, -0.923880f, -0.707107f, 0.382684f, 1.000000f, 0.382683f, -0.707107f, -0.923880f},
    {0.000000f, -0.923880f, 0.707107f, 0.382683f, -1.000000f, 0.382684f, 0.707107f, -0.923880f},
    {0.000000f, -0.382683f, 0.707107f, -0.923879f, 1.000000f, -0.923880f, 0.707107f, -0.382683f},
    {0.000000f, 0.382684f, -0.707107f, 0.923880f, -1.000000f, 0.923879f, -0.707106f, 0.382684f},
    {0.000000f, 0.923880f, -0.707107f, -0.382684f, 1.000000f, -0.382683f, -0.707107f, 0.923880f},
    {0.000000f, 0.923880f, 0.707107f, -0.382683f, -1.000000f, -0.382684f, 0.707106f, 0.923880f},
    {0.000000f, 0.382683f, 0.707107f, 0.923879f, 1.000000f, 0.923880f, 0.707107f, 0.382683f}};

const FLOAT32 ixheaacd_cosine[8][8] = {
    {1.000000f, 0.923880f, 0.707107f, 0.382683f, -46.000000f, -0.382683f, -0.707107f, -0.923880f},
    {1.000000f, 0.382683f, -0.707107f, -0.923880f, 140.000000f, 0.923880f, 0.707107f, -0.382683f},
    {1.000000f, -0.382683f, -0.707107f, 0.923880f, -234.000000f, -0.923879f, 0.707107f,
     0.382683f},
    {1.000000f, -0.923880f, 0.707107f, -0.382684f, 328.000000f, 0.382683f, -0.707106f, 0.923880f},
    {1.000000f, -0.923880f, 0.707107f, -0.382683f, -422.000000f, 0.382684f, -0.707107f,
     0.923880f},
    {1.000000f, -0.382683f, -0.707107f, 0.923879f, 516.000000f, -0.923880f, 0.707106f, 0.382683f},
    {1.000000f, 0.382684f, -0.707107f, -0.923880f, -610.000000f, 0.923879f, 0.707107f,
     -0.382684f},
    {1.000000f, 0.923880f, 0.707107f, 0.382684f, 704.000000f, -0.382683f, -0.707106f,
     -0.923880f}};

const WORD32 ixheaacd_cosine2[2][13] = {
    {
        1073741823, 1073741823, 1073741823, 1073741823, 1073741823, 1073741823, 1073741823,
        1073741823, 1073741823, 1073741823, 1073741823, 1073741823, 1073741823,
    },
    {
        1073741823, -1073741823, 1073741823, -1073741823, 1073741823, -1073741823, 1073741823,
        -1073741823, 1073741823, -1073741823, 1073741823, -1073741823, 1073741823,
    },
};

const WORD32 ixheaacd_mps_gain_set_indx[29] = {1,  0,  4,  5,  6,  7,  8,  9,  10, 11,
                                               12, 13, 14, 15, 16, 17, 18, 19, 21, 23,
                                               25, 27, 30, 33, 37, 42, 48, 55, 70};

const FLOAT32 ixheaacd_ldmps_polyphase_filter_coeff[1280] = {
    -0.0007949257f, -0.0012320746f, -0.0016010543f, -0.0019807201f, -0.0023975046f,
    -0.0028387094f, -0.0033147549f, -0.0038251812f, -0.0043653073f, -0.0049372604f,
    -0.0055373814f, -0.0061642416f, -0.0068165790f, -0.0074901022f, -0.0081837112f,
    -0.0088949297f, -0.0096200043f, -0.0103569683f, -0.0111023858f, -0.0118535860f,
    -0.0126076927f, -0.0133608067f, -0.0141103314f, -0.0148531627f, -0.0155855091f,
    -0.0163043682f, -0.0170061402f, -0.0176877063f, -0.0183456801f, -0.0189761259f,
    -0.0195760578f, -0.0201421324f, -0.0206706170f, -0.0211581476f, -0.0216013081f,
    -0.0219969619f, -0.0223416910f, -0.0226317085f, -0.0228641648f, -0.0230358951f,
    -0.0231434479f, -0.0231835246f, -0.0231529772f, -0.0230491832f, -0.0228686444f,
    -0.0226079077f, -0.0222644433f, -0.0218351875f, -0.0213169195f, -0.0207061488f,
    -0.0199998133f, -0.0191956628f, -0.0182893611f, -0.0172771178f, -0.0161564853f,
    -0.0149233583f, -0.0135741979f, -0.0121037029f, -0.0105075520f, -0.0087857461f,
    -0.0069273291f, -0.0049293786f, -0.0028003342f, -0.0004685577f, 0.0022103144f,
    0.0051832944f,  0.0083509637f,  0.0116611840f,  0.0151316673f,  0.0187726468f,
    0.0225889906f,  0.0265906155f,  0.0307808779f,  0.0351639129f,  0.0397467501f,
    0.0445330814f,  0.0495262593f,  0.0547302663f,  0.0601483546f,  0.0657841489f,
    0.0716395080f,  0.0777165666f,  0.0840179473f,  0.0905451626f,  0.0972988978f,
    0.1042804047f,  0.1114900783f,  0.1189284250f,  0.1265947521f,  0.1344885528f,
    0.1426091045f,  0.1509550363f,  0.1595243514f,  0.1683151573f,  0.1773250401f,
    0.1865511388f,  0.1959902197f,  0.2056386322f,  0.2154925913f,  0.2255475521f,
    0.2357989848f,  0.2462418824f,  0.2568709552f,  0.2676805258f,  0.2786645591f,
    0.2898168266f,  0.3011307418f,  0.3125994802f,  0.3242157102f,  0.3359722793f,
    0.3478614092f,  0.3598752320f,  0.3720056713f,  0.3842444420f,  0.3965831101f,
    0.4090129435f,  0.4215250909f,  0.4341109097f,  0.4467608333f,  0.4594659507f,
    0.4722166657f,  0.4850038290f,  0.4978178144f,  0.5106483698f,  0.5234865546f,
    0.5363218188f,  0.5491440296f,  0.5619440079f,  -0.5746001601f, -0.5872559547f,
    -0.5998619199f, -0.6123980284f, -0.6248505116f, -0.6372103095f, -0.6494654417f,
    -0.6616044044f, -0.6736174226f, -0.6854929924f, -0.6972201467f, -0.7087881565f,
    -0.7201859951f, -0.7314035296f, -0.7424294949f, -0.7532534599f, -0.7638649344f,
    -0.7742537856f, -0.7844095230f, -0.7943222523f, -0.8039818406f, -0.8133789897f,
    -0.8225036860f, -0.8313468695f, -0.8398991823f, -0.8481519818f, -0.8560963273f,
    -0.8637239933f, -0.8710266352f, -0.8779965043f, -0.8846257925f, -0.8909071684f,
    -0.8968337178f, -0.9023985267f, -0.9075955749f, -0.9124187231f, -0.9168621302f,
    -0.9209204316f, -0.9245886207f, -0.9278619289f, -0.9307362437f, -0.9332075119f,
    -0.9352724552f, -0.9369278550f, -0.9381709695f, -0.9389997125f, -0.9394121170f,
    -0.9394068122f, -0.9389829040f, -0.9381397963f, -0.9368773103f, -0.9351961017f,
    -0.9330966473f, -0.9305803180f, -0.9276487827f, -0.9243040681f, -0.9205487967f,
    -0.9163856506f, -0.9118180275f, -0.9068503380f, -0.9014858603f, -0.8957295418f,
    -0.8895882368f, -0.8830582500f, -0.8761259913f, -0.8688043952f, -0.8611140251f,
    -0.8530684114f, -0.8446723223f, -0.8359322548f, -0.8268554807f, -0.8174491525f,
    -0.8077214956f, -0.7976809740f, -0.7873360515f, -0.7766956687f, -0.7657692432f,
    -0.7545663714f, -0.7430967689f, -0.7313705087f, -0.7193979621f, -0.7071895599f,
    -0.6947561502f, -0.6821083426f, -0.6692573428f, -0.6562142968f, -0.6429904699f,
    -0.6295973659f, -0.6160464287f, -0.6023493409f, -0.5885176659f, -0.5745630264f,
    -0.5604973435f, -0.5463322401f, -0.5320795774f, -0.5177509785f, -0.5033583045f,
    -0.4889132082f, -0.4744274616f, -0.4599125087f, -0.4453800321f, -0.4308412969f,
    -0.4163077474f, -0.4017905891f, -0.3873008788f, -0.3728497028f, -0.3584479988f,
    -0.3441060781f, -0.3298346698f, -0.3156442046f, -0.3015447557f, -0.2875462472f,
    -0.2736584544f, -0.2598909736f, -0.2462531626f, -0.2327540070f, -0.2194025517f,
    -0.2062072009f, -0.1931765229f, -0.1803186089f, -0.1676410586f, -0.1551517546f,
    -0.1428578347f, -0.1307662129f, -0.1188837960f, -0.1072167307f, -0.0957711190f,
    -0.0845528170f, 0.0735579357f,  0.0628051385f,  0.0522958934f,  0.0420338102f,
    0.0320230126f,  0.0222672001f,  0.0127700046f,  0.0035346728f,  -0.0054356726f,
    -0.0141385710f, -0.0225714780f, -0.0307325479f, -0.0386199504f, -0.0462324508f,
    -0.0535687581f, -0.0606284477f, -0.0674108788f, -0.0739159212f, -0.0801439285f,
    -0.0860951766f, -0.0917705968f, -0.0971711874f, -0.1022983864f, -0.1071535870f,
    -0.1117390916f, -0.1160565540f, -0.1201089993f, -0.1238986105f, -0.1274286509f,
    -0.1307021976f, -0.1337226629f, -0.1364936531f, -0.1390190870f, -0.1413030326f,
    -0.1433497667f, -0.1451636255f, -0.1467494071f, -0.1481117010f, -0.1492556185f,
    -0.1501862854f, -0.1509089023f, -0.1514289081f, -0.1517517567f, -0.1518831998f,
    -0.1518289149f, -0.1515947729f, -0.1511866748f, -0.1506105959f, -0.1498726010f,
    -0.1489787102f, -0.1479352117f, -0.1467481852f, -0.1454239190f, -0.1439685971f,
    -0.1423884183f, -0.1406896859f, -0.1388785988f, -0.1369612068f, -0.1349437684f,
    -0.1328323931f, -0.1306331158f, -0.1283520460f, -0.1259952188f, -0.1235680804f,
    -0.1210755706f, -0.1185237169f, -0.1159184426f, -0.1132654399f, -0.1105698794f,
    -0.1078369170f, -0.1050716117f, -0.1022789180f, -0.0994636714f, -0.0966306925f,
    -0.0937845483f, -0.0909297019f, -0.0880705118f, -0.0852110758f, -0.0823556259f,
    -0.0795079023f, -0.0766717792f, -0.0738509223f, -0.0710486695f, -0.0682684705f,
    -0.0655134097f, -0.0627865866f, -0.0600909144f, -0.0574291982f, -0.0548038296f,
    -0.0522173792f, -0.0496721379f, -0.0471702330f, -0.0447136387f, -0.0423043817f,
    -0.0399438478f, -0.0376337133f, -0.0353754386f, -0.0331703536f, -0.0310197119f,
    -0.0289245304f, -0.0268857535f, -0.0249042176f, -0.0229805857f, -0.0211154576f,
    -0.0193092767f, -0.0175623931f, -0.0158751141f, -0.0142475078f, -0.0126795555f,
    -0.0111712581f, -0.0097224051f, -0.0083327051f, -0.0070017893f, -0.0057292255f,
    -0.0045145033f, -0.0033569466f, -0.0022558495f, -0.0012104595f, -0.0002199477f,
    0.0007167263f,  0.0016004397f,  0.0024323659f,  0.0032136049f,  0.0039453004f,
    0.0046286648f,  0.0052649761f,  0.0058556525f,  0.0064016338f,  -0.0069030458f,
    -0.0073645366f, -0.0077859173f, -0.0081687812f, -0.0085145105f, -0.0088245263f,
    -0.0091004446f, -0.0093438197f, -0.0095560895f, -0.0097389296f, -0.0098937284f,
    -0.0100222183f, -0.0101256752f, -0.0102057597f, -0.0102638984f, -0.0103016300f,
    -0.0103203785f, -0.0103215463f, -0.0103065800f, -0.0102768280f, -0.0102336034f,
    -0.0101782102f, -0.0101119522f, -0.0100360261f, -0.0099515645f, -0.0098597351f,
    -0.0097616902f, -0.0096583357f, -0.0095505062f, -0.0094392402f, -0.0093253115f,
    -0.0092095714f, -0.0090927295f, -0.0089755040f, -0.0088585643f, -0.0087425476f,
    -0.0086279176f, -0.0085152360f, -0.0084048351f, -0.0082970457f, -0.0081921816f,
    -0.0080905585f, -0.0079923403f, -0.0078977877f, -0.0078069791f, -0.0077200048f,
    -0.0076368991f, -0.0075576920f, -0.0074823610f, -0.0074108820f, -0.0073430836f,
    -0.0072789183f, -0.0072182063f, -0.0071608433f, -0.0071066003f, -0.0070552491f,
    -0.0070065912f, -0.0069604507f, -0.0069165546f, -0.0068746237f, -0.0068344427f,
    -0.0067957863f, -0.0067584766f, -0.0067221262f, -0.0066861408f, -0.0066502281f,
    -0.0066143544f, -0.0065783206f, -0.0065418649f, -0.0065047294f, -0.0064666905f,
    -0.0064275563f, -0.0063871238f, -0.0063452618f, -0.0063017663f, -0.0062565422f,
    -0.0062093716f, -0.0061602155f, -0.0061089024f, -0.0060553551f, -0.0059994739f,
    -0.0059412112f, -0.0058804955f, -0.0058172857f, -0.0057515362f, -0.0056832312f,
    -0.0056123761f, -0.0055389581f, -0.0054629631f, -0.0053843958f, -0.0053033372f,
    -0.0052197399f, -0.0051336233f, -0.0050450461f, -0.0049540084f, -0.0048605883f,
    -0.0047647208f, -0.0046664691f, -0.0045659458f, -0.0044631511f, -0.0043581501f,
    -0.0042509669f, -0.0041416343f, -0.0040301653f, -0.0039165970f, -0.0038009947f,
    -0.0036834506f, -0.0035639144f, -0.0034424895f, -0.0033192560f, -0.0031942502f,
    -0.0030675260f, -0.0029391386f, -0.0028091520f, -0.0026777033f, -0.0025448306f,
    -0.0024106177f, -0.0022751903f, -0.0021385867f, -0.0020008814f, -0.0018621609f,
    -0.0017228508f, -0.0015830053f, -0.0014426354f, -0.0013017356f, -0.0011605313f,
    -0.0010187104f, -0.0008753659f, 0.0007250868f,  0.0005901512f,  0.0004571248f,
    0.0003254497f,  0.0001951829f,  0.0000666175f,  -0.0000600275f, -0.0001845164f,
    -0.0003065709f, -0.0004259665f, -0.0005424777f, -0.0006558085f, -0.0007659104f,
    -0.0008724863f, -0.0009753527f, -0.0010743001f, -0.0011691442f, -0.0012597255f,
    -0.0013458347f, -0.0014273394f, -0.0015040794f, -0.0015758807f, -0.0016426332f,
    -0.0017042002f, -0.0017605145f, -0.0018114587f, -0.0018569818f, -0.0018970286f,
    -0.0019315863f, -0.0019606268f, -0.0019841781f, -0.0020022886f, -0.0020149164f,
    -0.0020221891f, -0.0020242548f, -0.0020211563f, -0.0020131115f, -0.0020002127f,
    -0.0019826870f, -0.0019606939f, -0.0019344082f, -0.0019041235f, -0.0018700724f,
    -0.0018325197f, -0.0017917566f, -0.0017479789f, -0.0017015412f, -0.0016526897f,
    -0.0016016904f, -0.0015489543f, -0.0014947094f, -0.0014391905f, -0.0013827635f,
    -0.0013256427f, -0.0012681838f, -0.0012105964f, -0.0011530248f, -0.0010959618f,
    -0.0010395534f, -0.0009838343f, -0.0009290278f, -0.0008749813f, -0.0008215802f,
    -0.0007706117f, -0.0007240456f, -0.0006849431f, -0.0006499495f, -0.0006169267f,
    -0.0005864026f, -0.0005585561f, -0.0005332623f, -0.0005106712f, -0.0004907669f,
    -0.0004734583f, -0.0004585870f, -0.0004460039f, -0.0004356373f, -0.0004273243f,
    -0.0004208330f, -0.0004159436f, -0.0004123962f, -0.0004100222f, -0.0004085470f,
    -0.0004077079f, -0.0004073251f, -0.0004070932f, -0.0004067607f, -0.0004061488f,
    -0.0004050555f, -0.0004033837f, -0.0004008813f, -0.0003973767f, -0.0003928188f,
    -0.0003870558f, -0.0003799992f, -0.0003715968f, -0.0003617546f, -0.0003505340f,
    -0.0003378810f, -0.0003237817f, -0.0003083795f, -0.0002916576f, -0.0002737129f,
    -0.0002546264f, -0.0002344782f, -0.0002134573f, -0.0001916261f, -0.0001692856f,
    -0.0001466954f, -0.0001236852f, -0.0001005735f, -0.0000775065f, -0.0000546696f,
    -0.0000325590f, -0.0000109682f, 0.0000098813f,  0.0000295145f,  0.0000481009f,
    0.0000651376f,  0.0000805138f,  0.0000942973f,  0.0001058290f,  0.0001155818f,
    0.0001229653f,  0.0001266878f,  0.0001279376f,  0.0001216913f,  0.0000938624f,
    -0.0007949257f, -0.0012320746f, -0.0016010543f, -0.0019807201f, -0.0023975046f,
    -0.0028387094f, -0.0033147549f, -0.0038251812f, -0.0043653073f, -0.0049372604f,
    -0.0055373814f, -0.0061642416f, -0.0068165790f, -0.0074901022f, -0.0081837112f,
    -0.0088949297f, -0.0096200043f, -0.0103569683f, -0.0111023858f, -0.0118535860f,
    -0.0126076927f, -0.0133608067f, -0.0141103314f, -0.0148531627f, -0.0155855091f,
    -0.0163043682f, -0.0170061402f, -0.0176877063f, -0.0183456801f, -0.0189761259f,
    -0.0195760578f, -0.0201421324f, -0.0206706170f, -0.0211581476f, -0.0216013081f,
    -0.0219969619f, -0.0223416910f, -0.0226317085f, -0.0228641648f, -0.0230358951f,
    -0.0231434479f, -0.0231835246f, -0.0231529772f, -0.0230491832f, -0.0228686444f,
    -0.0226079077f, -0.0222644433f, -0.0218351875f, -0.0213169195f, -0.0207061488f,
    -0.0199998133f, -0.0191956628f, -0.0182893611f, -0.0172771178f, -0.0161564853f,
    -0.0149233583f, -0.0135741979f, -0.0121037029f, -0.0105075520f, -0.0087857461f,
    -0.0069273291f, -0.0049293786f, -0.0028003342f, -0.0004685577f, 0.0022103144f,
    0.0051832944f,  0.0083509637f,  0.0116611840f,  0.0151316673f,  0.0187726468f,
    0.0225889906f,  0.0265906155f,  0.0307808779f,  0.0351639129f,  0.0397467501f,
    0.0445330814f,  0.0495262593f,  0.0547302663f,  0.0601483546f,  0.0657841489f,
    0.0716395080f,  0.0777165666f,  0.0840179473f,  0.0905451626f,  0.0972988978f,
    0.1042804047f,  0.1114900783f,  0.1189284250f,  0.1265947521f,  0.1344885528f,
    0.1426091045f,  0.1509550363f,  0.1595243514f,  0.1683151573f,  0.1773250401f,
    0.1865511388f,  0.1959902197f,  0.2056386322f,  0.2154925913f,  0.2255475521f,
    0.2357989848f,  0.2462418824f,  0.2568709552f,  0.2676805258f,  0.2786645591f,
    0.2898168266f,  0.3011307418f,  0.3125994802f,  0.3242157102f,  0.3359722793f,
    0.3478614092f,  0.3598752320f,  0.3720056713f,  0.3842444420f,  0.3965831101f,
    0.4090129435f,  0.4215250909f,  0.4341109097f,  0.4467608333f,  0.4594659507f,
    0.4722166657f,  0.4850038290f,  0.4978178144f,  0.5106483698f,  0.5234865546f,
    0.5363218188f,  0.5491440296f,  0.5619440079f,  -0.5746001601f, -0.5872559547f,
    -0.5998619199f, -0.6123980284f, -0.6248505116f, -0.6372103095f, -0.6494654417f,
    -0.6616044044f, -0.6736174226f, -0.6854929924f, -0.6972201467f, -0.7087881565f,
    -0.7201859951f, -0.7314035296f, -0.7424294949f, -0.7532534599f, -0.7638649344f,
    -0.7742537856f, -0.7844095230f, -0.7943222523f, -0.8039818406f, -0.8133789897f,
    -0.8225036860f, -0.8313468695f, -0.8398991823f, -0.8481519818f, -0.8560963273f,
    -0.8637239933f, -0.8710266352f, -0.8779965043f, -0.8846257925f, -0.8909071684f,
    -0.8968337178f, -0.9023985267f, -0.9075955749f, -0.9124187231f, -0.9168621302f,
    -0.9209204316f, -0.9245886207f, -0.9278619289f, -0.9307362437f, -0.9332075119f,
    -0.9352724552f, -0.9369278550f, -0.9381709695f, -0.9389997125f, -0.9394121170f,
    -0.9394068122f, -0.9389829040f, -0.9381397963f, -0.9368773103f, -0.9351961017f,
    -0.9330966473f, -0.9305803180f, -0.9276487827f, -0.9243040681f, -0.9205487967f,
    -0.9163856506f, -0.9118180275f, -0.9068503380f, -0.9014858603f, -0.8957295418f,
    -0.8895882368f, -0.8830582500f, -0.8761259913f, -0.8688043952f, -0.8611140251f,
    -0.8530684114f, -0.8446723223f, -0.8359322548f, -0.8268554807f, -0.8174491525f,
    -0.8077214956f, -0.7976809740f, -0.7873360515f, -0.7766956687f, -0.7657692432f,
    -0.7545663714f, -0.7430967689f, -0.7313705087f, -0.7193979621f, -0.7071895599f,
    -0.6947561502f, -0.6821083426f, -0.6692573428f, -0.6562142968f, -0.6429904699f,
    -0.6295973659f, -0.6160464287f, -0.6023493409f, -0.5885176659f, -0.5745630264f,
    -0.5604973435f, -0.5463322401f, -0.5320795774f, -0.5177509785f, -0.5033583045f,
    -0.4889132082f, -0.4744274616f, -0.4599125087f, -0.4453800321f, -0.4308412969f,
    -0.4163077474f, -0.4017905891f, -0.3873008788f, -0.3728497028f, -0.3584479988f,
    -0.3441060781f, -0.3298346698f, -0.3156442046f, -0.3015447557f, -0.2875462472f,
    -0.2736584544f, -0.2598909736f, -0.2462531626f, -0.2327540070f, -0.2194025517f,
    -0.2062072009f, -0.1931765229f, -0.1803186089f, -0.1676410586f, -0.1551517546f,
    -0.1428578347f, -0.1307662129f, -0.1188837960f, -0.1072167307f, -0.0957711190f,
    -0.0845528170f, 0.0735579357f,  0.0628051385f,  0.0522958934f,  0.0420338102f,
    0.0320230126f,  0.0222672001f,  0.0127700046f,  0.0035346728f,  -0.0054356726f,
    -0.0141385710f, -0.0225714780f, -0.0307325479f, -0.0386199504f, -0.0462324508f,
    -0.0535687581f, -0.0606284477f, -0.0674108788f, -0.0739159212f, -0.0801439285f,
    -0.0860951766f, -0.0917705968f, -0.0971711874f, -0.1022983864f, -0.1071535870f,
    -0.1117390916f, -0.1160565540f, -0.1201089993f, -0.1238986105f, -0.1274286509f,
    -0.1307021976f, -0.1337226629f, -0.1364936531f, -0.1390190870f, -0.1413030326f,
    -0.1433497667f, -0.1451636255f, -0.1467494071f, -0.1481117010f, -0.1492556185f,
    -0.1501862854f, -0.1509089023f, -0.1514289081f, -0.1517517567f, -0.1518831998f,
    -0.1518289149f, -0.1515947729f, -0.1511866748f, -0.1506105959f, -0.1498726010f,
    -0.1489787102f, -0.1479352117f, -0.1467481852f, -0.1454239190f, -0.1439685971f,
    -0.1423884183f, -0.1406896859f, -0.1388785988f, -0.1369612068f, -0.1349437684f,
    -0.1328323931f, -0.1306331158f, -0.1283520460f, -0.1259952188f, -0.1235680804f,
    -0.1210755706f, -0.1185237169f, -0.1159184426f, -0.1132654399f, -0.1105698794f,
    -0.1078369170f, -0.1050716117f, -0.1022789180f, -0.0994636714f, -0.0966306925f,
    -0.0937845483f, -0.0909297019f, -0.0880705118f, -0.0852110758f, -0.0823556259f,
    -0.0795079023f, -0.0766717792f, -0.0738509223f, -0.0710486695f, -0.0682684705f,
    -0.0655134097f, -0.0627865866f, -0.0600909144f, -0.0574291982f, -0.0548038296f,
    -0.0522173792f, -0.0496721379f, -0.0471702330f, -0.0447136387f, -0.0423043817f,
    -0.0399438478f, -0.0376337133f, -0.0353754386f, -0.0331703536f, -0.0310197119f,
    -0.0289245304f, -0.0268857535f, -0.0249042176f, -0.0229805857f, -0.0211154576f,
    -0.0193092767f, -0.0175623931f, -0.0158751141f, -0.0142475078f, -0.0126795555f,
    -0.0111712581f, -0.0097224051f, -0.0083327051f, -0.0070017893f, -0.0057292255f,
    -0.0045145033f, -0.0033569466f, -0.0022558495f, -0.0012104595f, -0.0002199477f,
    0.0007167263f,  0.0016004397f,  0.0024323659f,  0.0032136049f,  0.0039453004f,
    0.0046286648f,  0.0052649761f,  0.0058556525f,  0.0064016338f,  -0.0069030458f,
    -0.0073645366f, -0.0077859173f, -0.0081687812f, -0.0085145105f, -0.0088245263f,
    -0.0091004446f, -0.0093438197f, -0.0095560895f, -0.0097389296f, -0.0098937284f,
    -0.0100222183f, -0.0101256752f, -0.0102057597f, -0.0102638984f, -0.0103016300f,
    -0.0103203785f, -0.0103215463f, -0.0103065800f, -0.0102768280f, -0.0102336034f,
    -0.0101782102f, -0.0101119522f, -0.0100360261f, -0.0099515645f, -0.0098597351f,
    -0.0097616902f, -0.0096583357f, -0.0095505062f, -0.0094392402f, -0.0093253115f,
    -0.0092095714f, -0.0090927295f, -0.0089755040f, -0.0088585643f, -0.0087425476f,
    -0.0086279176f, -0.0085152360f, -0.0084048351f, -0.0082970457f, -0.0081921816f,
    -0.0080905585f, -0.0079923403f, -0.0078977877f, -0.0078069791f, -0.0077200048f,
    -0.0076368991f, -0.0075576920f, -0.0074823610f, -0.0074108820f, -0.0073430836f,
    -0.0072789183f, -0.0072182063f, -0.0071608433f, -0.0071066003f, -0.0070552491f,
    -0.0070065912f, -0.0069604507f, -0.0069165546f, -0.0068746237f, -0.0068344427f,
    -0.0067957863f, -0.0067584766f, -0.0067221262f, -0.0066861408f, -0.0066502281f,
    -0.0066143544f, -0.0065783206f, -0.0065418649f, -0.0065047294f, -0.0064666905f,
    -0.0064275563f, -0.0063871238f, -0.0063452618f, -0.0063017663f, -0.0062565422f,
    -0.0062093716f, -0.0061602155f, -0.0061089024f, -0.0060553551f, -0.0059994739f,
    -0.0059412112f, -0.0058804955f, -0.0058172857f, -0.0057515362f, -0.0056832312f,
    -0.0056123761f, -0.0055389581f, -0.0054629631f, -0.0053843958f, -0.0053033372f,
    -0.0052197399f, -0.0051336233f, -0.0050450461f, -0.0049540084f, -0.0048605883f,
    -0.0047647208f, -0.0046664691f, -0.0045659458f, -0.0044631511f, -0.0043581501f,
    -0.0042509669f, -0.0041416343f, -0.0040301653f, -0.0039165970f, -0.0038009947f,
    -0.0036834506f, -0.0035639144f, -0.0034424895f, -0.0033192560f, -0.0031942502f,
    -0.0030675260f, -0.0029391386f, -0.0028091520f, -0.0026777033f, -0.0025448306f,
    -0.0024106177f, -0.0022751903f, -0.0021385867f, -0.0020008814f, -0.0018621609f,
    -0.0017228508f, -0.0015830053f, -0.0014426354f, -0.0013017356f, -0.0011605313f,
    -0.0010187104f, -0.0008753659f, 0.0007250868f,  0.0005901512f,  0.0004571248f,
    0.0003254497f,  0.0001951829f,  0.0000666175f,  -0.0000600275f, -0.0001845164f,
    -0.0003065709f, -0.0004259665f, -0.0005424777f, -0.0006558085f, -0.0007659104f,
    -0.0008724863f, -0.0009753527f, -0.0010743001f, -0.0011691442f, -0.0012597255f,
    -0.0013458347f, -0.0014273394f, -0.0015040794f, -0.0015758807f, -0.0016426332f,
    -0.0017042002f, -0.0017605145f, -0.0018114587f, -0.0018569818f, -0.0018970286f,
    -0.0019315863f, -0.0019606268f, -0.0019841781f, -0.0020022886f, -0.0020149164f,
    -0.0020221891f, -0.0020242548f, -0.0020211563f, -0.0020131115f, -0.0020002127f,
    -0.0019826870f, -0.0019606939f, -0.0019344082f, -0.0019041235f, -0.0018700724f,
    -0.0018325197f, -0.0017917566f, -0.0017479789f, -0.0017015412f, -0.0016526897f,
    -0.0016016904f, -0.0015489543f, -0.0014947094f, -0.0014391905f, -0.0013827635f,
    -0.0013256427f, -0.0012681838f, -0.0012105964f, -0.0011530248f, -0.0010959618f,
    -0.0010395534f, -0.0009838343f, -0.0009290278f, -0.0008749813f, -0.0008215802f,
    -0.0007706117f, -0.0007240456f, -0.0006849431f, -0.0006499495f, -0.0006169267f,
    -0.0005864026f, -0.0005585561f, -0.0005332623f, -0.0005106712f, -0.0004907669f,
    -0.0004734583f, -0.0004585870f, -0.0004460039f, -0.0004356373f, -0.0004273243f,
    -0.0004208330f, -0.0004159436f, -0.0004123962f, -0.0004100222f, -0.0004085470f,
    -0.0004077079f, -0.0004073251f, -0.0004070932f, -0.0004067607f, -0.0004061488f,
    -0.0004050555f, -0.0004033837f, -0.0004008813f, -0.0003973767f, -0.0003928188f,
    -0.0003870558f, -0.0003799992f, -0.0003715968f, -0.0003617546f, -0.0003505340f,
    -0.0003378810f, -0.0003237817f, -0.0003083795f, -0.0002916576f, -0.0002737129f,
    -0.0002546264f, -0.0002344782f, -0.0002134573f, -0.0001916261f, -0.0001692856f,
    -0.0001466954f, -0.0001236852f, -0.0001005735f, -0.0000775065f, -0.0000546696f,
    -0.0000325590f, -0.0000109682f, 0.0000098813f,  0.0000295145f,  0.0000481009f,
    0.0000651376f,  0.0000805138f,  0.0000942973f,  0.0001058290f,  0.0001155818f,
    0.0001229653f,  0.0001266878f,  0.0001279376f,  0.0001216913f,  0.0000938624f};
const WORD32 ixheaacd_ldmps_polyphase_filter_coeff_fix[1280] = {
    -853545,     -1322930,    -1719119,    -2126782,    -2574301,    -3048041,    -3559191,
    -4107257,    -4687213,    -5301343,    -5945718,    -6618804,    -7319246,    -8042436,
    -8787193,    -9550858,    -10329401,   -11120710,   -11921096,   -12727691,   -13537407,
    -14346057,   -15150853,   -15948462,   -16734813,   -17506682,   -18260204,   -18992030,
    -19698524,   -20375460,   -21019632,   -21627450,   -22194906,   -22718388,   -23194228,
    -23619058,   -23989208,   -24300612,   -24550210,   -24734604,   -24850088,   -24893120,
    -24860320,   -24748872,   -24555020,   -24275056,   -23906264,   -23445354,   -22888868,
    -22233058,   -21474636,   -20611186,   -19638052,   -18551164,   -17347894,   -16023834,
    -14575184,   -12996252,   -11282398,   -9433623,    -7438163,    -5292880,    -3006836,
    -503110,     2373307,     5565520,     8966779,     12521101,    16247504,    20156977,
    24254745,    28551455,    33050715,    37756963,    42677747,    47817031,    53178415,
    58766175,    64583803,    70635191,    76922335,    83447527,    90213583,    97222127,
    104473895,   111970231,   119711559,   127698423,   135930079,   144405983,   153125359,
    162086735,   171287967,   180727023,   190401311,   200307759,   210442895,   220802799,
    231383407,   242179839,   253187231,   264400207,   275813087,   287419775,   299213791,
    311188447,   323336671,   335651135,   348123967,   360747487,   373513343,   386413087,
    399438047,   412579327,   425827871,   439174303,   452609119,   466123039,   479705791,
    493347807,   507038783,   520768895,   534527807,   548304511,   562089407,   575871167,
    589638911,   603382783,   -616972224,  -630561280,  -644096832,  -657557376,  -670928128,
    -684199360,  -697358208,  -710392320,  -723291200,  -736042496,  -748634432,  -761055488,
    -773293824,  -785338560,  -797177600,  -808799744,  -820193728,  -831348672,  -842253312,
    -852897024,  -863268928,  -873359040,  -883156608,  -892651904,  -901834880,  -910696256,
    -919226432,  -927416576,  -935257728,  -942741568,  -949859712,  -956604288,  -962967872,
    -968943040,  -974523328,  -979702144,  -984473216,  -988830784,  -992769472,  -996284160,
    -999370432,  -1002023936, -1004241152, -1006018624, -1007353408, -1008243264, -1008686080,
    -1008680384, -1008225216, -1007319936, -1005964352, -1004159168, -1001904896, -999203008,
    -996055296,  -992463936,  -988431744,  -983961600,  -979057152,  -973723136,  -967963072,
    -961782272,  -955188096,  -948176576,  -940733120,  -932871616,  -924614144,  -915975232,
    -906960000,  -897575424,  -887829312,  -877729344,  -867284352,  -856503424,  -845395648,
    -833970624,  -822238464,  -810209472,  -797894080,  -785303104,  -772447680,  -759339008,
    -745988736,  -732408256,  -718609600,  -704604736,  -690405760,  -676025024,  -661474816,
    -646767680,  -631916032,  -616932352,  -601829440,  -586619776,  -571316096,  -555930880,
    -540476864,  -524966560,  -509412608,  -493827296,  -478223168,  -462612320,  -447007040,
    -431419360,  -415861152,  -400344320,  -384880608,  -369481088,  -354157280,  -338920384,
    -323781216,  -308750432,  -293838528,  -279055808,  -264412320,  -249917712,  -235581696,
    -221413296,  -207421712,  -193615632,  -180003216,  -166592928,  -153392432,  -140409152,
    -127650504,  -115123088,  -102833456,  -90787896,   78982231,    67436503,    56152287,
    45133459,    34384447,    23909225,    13711688,    3795326,     -5836509,    -15181175,
    -24235940,   -32998822,   -41467856,   -49641716,   -57519016,   -65099300,   -72381880,
    -79366616,   -86053888,   -92443992,   -98537928,   -104336768,  -109842056,  -115055288,
    -119978936,  -124614776,  -128966056,  -133035120,  -136825472,  -140340416,  -143583616,
    -146558944,  -149270608,  -151722976,  -153920640,  -155868256,  -157570976,  -159033728,
    -160262000,  -161261296,  -162037200,  -162595552,  -162942208,  -163083344,  -163025056,
    -162773648,  -162335456,  -161716896,  -160924480,  -159964672,  -158844224,  -157569664,
    -156147744,  -154585104,  -152888400,  -151064400,  -149119760,  -147060976,  -144894768,
    -142627696,  -140266240,  -137816960,  -135286336,  -132680216,  -130003904,  -127263872,
    -124466480,  -121617840,  -118723504,  -115789008,  -112819784,  -109821152,  -106798304,
    -103756416,  -100700392,  -97635024,   -94564992,   -91494696,   -88428680,   -85370960,
    -82325696,   -79296824,   -76287928,   -73302712,   -70344488,   -67416584,   -64522128,
    -61664132,   -58845164,   -56067984,   -53335052,   -50648652,   -48010904,   -45423984,
    -42889380,   -40408892,   -37984088,   -35616396,   -33307162,   -31057478,   -28868358,
    -26740700,   -24675216,   -22672550,   -20733178,   -18857476,   -17045774,   -15298145,
    -13614569,   -11995047,   -10439353,   -8947174,    -7518114,    -6151709,    -4847411,
    -3604494,    -2422200,    -1299721,    -236167,     769579,      1718459,     2611733,
    3450582,     4236234,     4969991,     5653225,     6287459,     6873702,     -7412089,
    -7907611,    -8360065,    -8771162,    -9142386,    -9475263,    -9771528,    -10032850,
    -10260773,   -10457096,   -10623310,   -10761275,   -10872361,   -10958351,   -11020777,
    -11061291,   -11081422,   -11082676,   -11066606,   -11034660,   -10988248,   -10928770,
    -10857626,   -10776101,   -10685411,   -10586810,   -10481535,   -10370559,   -10254778,
    -10135307,   -10012977,   -9888702,    -9763244,    -9637374,    -9511811,    -9387239,
    -9264156,    -9143165,    -9024623,    -8908885,    -8796288,    -8687171,    -8581710,
    -8480185,    -8382680,    -8289292,    -8200058,    -8115010,    -8034124,    -7957374,
    -7884576,    -7815679,    -7750490,    -7688897,    -7630654,    -7575516,    -7523270,
    -7473727,    -7426594,    -7381571,    -7338427,    -7296920,    -7256859,    -7217828,
    -7179189,    -7140628,    -7102109,    -7063418,    -7024274,    -6984400,    -6943556,
    -6901536,    -6858122,    -6813173,    -6766470,    -6717911,    -6667262,    -6614481,
    -6559384,    -6501888,    -6441886,    -6379327,    -6314134,    -6246263,    -6175665,
    -6102323,    -6026243,    -5947411,    -5865812,    -5781451,    -5694415,    -5604653,
    -5512186,    -5417077,    -5319326,    -5219017,    -5116080,    -5010583,    -4902647,
    -4792272,    -4679528,    -4564441,    -4447046,    -4327357,    -4205414,    -4081287,
    -3955075,    -3826724,    -3696345,    -3564024,    -3429800,    -3293731,    -3155876,
    -3016304,    -2875162,    -2732491,    -2588381,    -2442967,    -2296290,    -2148430,
    -1999480,    -1849897,    -1699739,    -1549018,    -1397728,    -1246111,    -1093832,
    -939917,     778556,      633670,      490834,      349449,      209576,      71530,
    -64454,      -198123,     -329178,     -457378,     -582481,     -704169,     -822390,
    -936825,     -1047277,    -1153521,    -1255359,    -1352620,    -1445079,    -1532594,
    -1614993,    -1692089,    -1763764,    -1829871,    -1890338,    -1945039,    -1993919,
    -2036919,    -2074025,    -2105207,    -2130495,    -2149941,    -2163500,    -2171309,
    -2173527,    -2170200,    -2161562,    -2147712,    -2128894,    -2105279,    -2077055,
    -2044537,    -2007975,    -1967653,    -1923884,    -1876878,    -1827016,    -1774562,
    -1719802,    -1663177,    -1604932,    -1545319,    -1484731,    -1423398,    -1361702,
    -1299868,    -1238051,    -1176780,    -1116212,    -1056384,    -997536,     -939504,
    -882165,     -827438,     -777438,     -735452,     -697878,     -662420,     -629645,
    -599745,     -572586,     -548329,     -526957,     -508372,     -492404,     -478893,
    -467762,     -458836,     -451866,     -446616,     -442807,     -440258,     -438674,
    -437773,     -437362,     -437113,     -436756,     -436099,     -434925,     -433130,
    -430443,     -426680,     -421786,     -415598,     -408021,     -398999,     -388431,
    -376383,     -362797,     -347658,     -331120,     -313165,     -293897,     -273403,
    -251769,     -229198,     -205757,     -181769,     -157513,     -132806,     -107990,
    -83222,      -58701,      -34960,      -11777,      10610,       31691,       51648,
    69941,       86451,       101251,      113633,      124105,      132033,      136030,
    137372,      130665,      100784,      -853545,     -1322930,    -1719119,    -2126782,
    -2574301,    -3048041,    -3559191,    -4107257,    -4687213,    -5301343,    -5945718,
    -6618804,    -7319246,    -8042436,    -8787193,    -9550858,    -10329401,   -11120710,
    -11921096,   -12727691,   -13537407,   -14346057,   -15150853,   -15948462,   -16734813,
    -17506682,   -18260204,   -18992030,   -19698524,   -20375460,   -21019632,   -21627450,
    -22194906,   -22718388,   -23194228,   -23619058,   -23989208,   -24300612,   -24550210,
    -24734604,   -24850088,   -24893120,   -24860320,   -24748872,   -24555020,   -24275056,
    -23906264,   -23445354,   -22888868,   -22233058,   -21474636,   -20611186,   -19638052,
    -18551164,   -17347894,   -16023834,   -14575184,   -12996252,   -11282398,   -9433623,
    -7438163,    -5292880,    -3006836,    -503110,     2373307,     5565520,     8966779,
    12521101,    16247504,    20156977,    24254745,    28551455,    33050715,    37756963,
    42677747,    47817031,    53178415,    58766175,    64583803,    70635191,    76922335,
    83447527,    90213583,    97222127,    104473895,   111970231,   119711559,   127698423,
    135930079,   144405983,   153125359,   162086735,   171287967,   180727023,   190401311,
    200307759,   210442895,   220802799,   231383407,   242179839,   253187231,   264400207,
    275813087,   287419775,   299213791,   311188447,   323336671,   335651135,   348123967,
    360747487,   373513343,   386413087,   399438047,   412579327,   425827871,   439174303,
    452609119,   466123039,   479705791,   493347807,   507038783,   520768895,   534527807,
    548304511,   562089407,   575871167,   589638911,   603382783,   -616972224,  -630561280,
    -644096832,  -657557376,  -670928128,  -684199360,  -697358208,  -710392320,  -723291200,
    -736042496,  -748634432,  -761055488,  -773293824,  -785338560,  -797177600,  -808799744,
    -820193728,  -831348672,  -842253312,  -852897024,  -863268928,  -873359040,  -883156608,
    -892651904,  -901834880,  -910696256,  -919226432,  -927416576,  -935257728,  -942741568,
    -949859712,  -956604288,  -962967872,  -968943040,  -974523328,  -979702144,  -984473216,
    -988830784,  -992769472,  -996284160,  -999370432,  -1002023936, -1004241152, -1006018624,
    -1007353408, -1008243264, -1008686080, -1008680384, -1008225216, -1007319936, -1005964352,
    -1004159168, -1001904896, -999203008,  -996055296,  -992463936,  -988431744,  -983961600,
    -979057152,  -973723136,  -967963072,  -961782272,  -955188096,  -948176576,  -940733120,
    -932871616,  -924614144,  -915975232,  -906960000,  -897575424,  -887829312,  -877729344,
    -867284352,  -856503424,  -845395648,  -833970624,  -822238464,  -810209472,  -797894080,
    -785303104,  -772447680,  -759339008,  -745988736,  -732408256,  -718609600,  -704604736,
    -690405760,  -676025024,  -661474816,  -646767680,  -631916032,  -616932352,  -601829440,
    -586619776,  -571316096,  -555930880,  -540476864,  -524966560,  -509412608,  -493827296,
    -478223168,  -462612320,  -447007040,  -431419360,  -415861152,  -400344320,  -384880608,
    -369481088,  -354157280,  -338920384,  -323781216,  -308750432,  -293838528,  -279055808,
    -264412320,  -249917712,  -235581696,  -221413296,  -207421712,  -193615632,  -180003216,
    -166592928,  -153392432,  -140409152,  -127650504,  -115123088,  -102833456,  -90787896,
    78982231,    67436503,    56152287,    45133459,    34384447,    23909225,    13711688,
    3795326,     -5836509,    -15181175,   -24235940,   -32998822,   -41467856,   -49641716,
    -57519016,   -65099300,   -72381880,   -79366616,   -86053888,   -92443992,   -98537928,
    -104336768,  -109842056,  -115055288,  -119978936,  -124614776,  -128966056,  -133035120,
    -136825472,  -140340416,  -143583616,  -146558944,  -149270608,  -151722976,  -153920640,
    -155868256,  -157570976,  -159033728,  -160262000,  -161261296,  -162037200,  -162595552,
    -162942208,  -163083344,  -163025056,  -162773648,  -162335456,  -161716896,  -160924480,
    -159964672,  -158844224,  -157569664,  -156147744,  -154585104,  -152888400,  -151064400,
    -149119760,  -147060976,  -144894768,  -142627696,  -140266240,  -137816960,  -135286336,
    -132680216,  -130003904,  -127263872,  -124466480,  -121617840,  -118723504,  -115789008,
    -112819784,  -109821152,  -106798304,  -103756416,  -100700392,  -97635024,   -94564992,
    -91494696,   -88428680,   -85370960,   -82325696,   -79296824,   -76287928,   -73302712,
    -70344488,   -67416584,   -64522128,   -61664132,   -58845164,   -56067984,   -53335052,
    -50648652,   -48010904,   -45423984,   -42889380,   -40408892,   -37984088,   -35616396,
    -33307162,   -31057478,   -28868358,   -26740700,   -24675216,   -22672550,   -20733178,
    -18857476,   -17045774,   -15298145,   -13614569,   -11995047,   -10439353,   -8947174,
    -7518114,    -6151709,    -4847411,    -3604494,    -2422200,    -1299721,    -236167,
    769579,      1718459,     2611733,     3450582,     4236234,     4969991,     5653225,
    6287459,     6873702,     -7412089,    -7907611,    -8360065,    -8771162,    -9142386,
    -9475263,    -9771528,    -10032850,   -10260773,   -10457096,   -10623310,   -10761275,
    -10872361,   -10958351,   -11020777,   -11061291,   -11081422,   -11082676,   -11066606,
    -11034660,   -10988248,   -10928770,   -10857626,   -10776101,   -10685411,   -10586810,
    -10481535,   -10370559,   -10254778,   -10135307,   -10012977,   -9888702,    -9763244,
    -9637374,    -9511811,    -9387239,    -9264156,    -9143165,    -9024623,    -8908885,
    -8796288,    -8687171,    -8581710,    -8480185,    -8382680,    -8289292,    -8200058,
    -8115010,    -8034124,    -7957374,    -7884576,    -7815679,    -7750490,    -7688897,
    -7630654,    -7575516,    -7523270,    -7473727,    -7426594,    -7381571,    -7338427,
    -7296920,    -7256859,    -7217828,    -7179189,    -7140628,    -7102109,    -7063418,
    -7024274,    -6984400,    -6943556,    -6901536,    -6858122,    -6813173,    -6766470,
    -6717911,    -6667262,    -6614481,    -6559384,    -6501888,    -6441886,    -6379327,
    -6314134,    -6246263,    -6175665,    -6102323,    -6026243,    -5947411,    -5865812,
    -5781451,    -5694415,    -5604653,    -5512186,    -5417077,    -5319326,    -5219017,
    -5116080,    -5010583,    -4902647,    -4792272,    -4679528,    -4564441,    -4447046,
    -4327357,    -4205414,    -4081287,    -3955075,    -3826724,    -3696345,    -3564024,
    -3429800,    -3293731,    -3155876,    -3016304,    -2875162,    -2732491,    -2588381,
    -2442967,    -2296290,    -2148430,    -1999480,    -1849897,    -1699739,    -1549018,
    -1397728,    -1246111,    -1093832,    -939917,     778556,      633670,      490834,
    349449,      209576,      71530,       -64454,      -198123,     -329178,     -457378,
    -582481,     -704169,     -822390,     -936825,     -1047277,    -1153521,    -1255359,
    -1352620,    -1445079,    -1532594,    -1614993,    -1692089,    -1763764,    -1829871,
    -1890338,    -1945039,    -1993919,    -2036919,    -2074025,    -2105207,    -2130495,
    -2149941,    -2163500,    -2171309,    -2173527,    -2170200,    -2161562,    -2147712,
    -2128894,    -2105279,    -2077055,    -2044537,    -2007975,    -1967653,    -1923884,
    -1876878,    -1827016,    -1774562,    -1719802,    -1663177,    -1604932,    -1545319,
    -1484731,    -1423398,    -1361702,    -1299868,    -1238051,    -1176780,    -1116212,
    -1056384,    -997536,     -939504,     -882165,     -827438,     -777438,     -735452,
    -697878,     -662420,     -629645,     -599745,     -572586,     -548329,     -526957,
    -508372,     -492404,     -478893,     -467762,     -458836,     -451866,     -446616,
    -442807,     -440258,     -438674,     -437773,     -437362,     -437113,     -436756,
    -436099,     -434925,     -433130,     -430443,     -426680,     -421786,     -415598,
    -408021,     -398999,     -388431,     -376383,     -362797,     -347658,     -331120,
    -313165,     -293897,     -273403,     -251769,     -229198,     -205757,     -181769,
    -157513,     -132806,     -107990,     -83222,      -58701,      -34960,      -11777,
    10610,       31691,       51648,       69941,       86451,       101251,      113633,
    124105,      132033,      136030,      137372,      130665,      100784};

const ia_mps_dec_res_huffmann_tables_struct ixheaacd_mps_dec_res_huffmann_tables = {
    {4,  4,  4,  4,  4,  4,  4,  4,  4,  4,  4,  4,  4,  4,  8,  8,  8,  8,  8,  12, 12,
     12, 12, 12, 16, 16, 24, 28, 36, 44, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, -1},
    {4, 4, 4, 4, 4, 4, 8, 8, 8, 16, 28, 36, -1},
    {4,  4,  4,  4,  4,  4,  4,  4,  4,  4,  4,  4,  4,  4,  8,  8,
     8,  8,  12, 12, 12, 16, 16, 16, 20, 24, 24, 28, 36, 40, 40, 40,
     40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 40, -1},
    {4,  4,  4,  4,  4,  4,  4,  4,  4,  4,  8,  8,  8,  8,  8,  8,  8,
     12, 12, 12, 12, 16, 16, 20, 20, 24, 24, 28, 28, 32, 32, 32, 32, 32,
     32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 96, -1},
    {4, 4, 4, 4, 4, 8, 8, 8, 12, 12, 12, 16, 16, 16, -1},
    {4,  4,  4,  4,  4,  4,  4,  4,  4,  4,  8,  8,  8,  8,  8,  8,  8,  12,
     12, 12, 12, 16, 16, 20, 20, 24, 24, 28, 28, 32, 32, 32, 32, 32, 32, 32,
     32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, -1},
    {4,  4,  4,  4,  4,  4,  4,  4,  4,  4,  4,  8,  8,  8,  8,  8,
     8,  8,  8,  8,  8,  12, 12, 12, 12, 16, 16, 16, 20, 20, 24, 24,
     28, 28, 32, 36, 36, 40, 44, 48, 52, 52, 64, 64, 64, 64, 64, -1},
    {4, 4, 4, 4, 4, 4, 4, 8, 8, 8, 12, 12, 16, 16, 20, -1},
    {8,  8,  8,  8,  8,  8,  8,  8,  8,  8,  8,  12, 12, 12, 12, 12, 12, 12, 12, 12, 16, 16,
     16, 16, 20, 20, 20, 24, 24, 28, 28, 32, 36, 40, 40, 44, 48, 52, 56, 60, 64, 64, 64, -1},
    {4, 4, 4, 4, 4, 4, 4, 4, 8, 8, 12, 12, 16, 20, 20, -1},
    {12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 16, 16, 16, 16, 16, 16, 16, 20,
     20, 20, 20, 24, 24, 24, 28, 28, 32, 36, 36, 40, 44, 48, 52, 56, 60, 64, 80, -1},
    {4, 4, 4, 4, 4, 4, 4, 8, 8, 8, 8, 12, 16, 20, 20, -1},
    {4,  4,  4,  4,  4,  4,  4,  4,  4,  4,  4,  4,  4,  4,  8,  8,  8,  8,  8,  12, 12,
     12, 12, 12, 16, 16, 24, 28, 36, 44, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, -1},
    {4, 4, 4, 4, 4, 4, 8, 8, 8, 16, 28, 28, -1},
    {4,  4,  4,  4,  4,  4,  4,  4,  4,  4,  4,  4,  4,  4,  8,  8,
     8,  8,  12, 12, 12, 16, 16, 16, 20, 24, 24, 28, 36, 40, 40, 40,
     40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 16, -1},
    {4,  4,  4,  4,  4,  4,  4,  4,  4,  4,  8,  8,  8,  8,  8,  8,  8,
     12, 12, 12, 12, 16, 16, 20, 20, 24, 24, 28, 28, 32, 32, 32, 32, 32,
     32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, -1},
    {4, 4, 4, 4, 4, 8, 8, 8, 12, 12, 12, 16, 16, 8, -1},
    {4,  4,  4,  4,  4,  4,  4,  4,  4,  4,  4,  8,  8,  8,  8,  8,
     8,  8,  8,  8,  8,  12, 12, 12, 12, 16, 16, 16, 20, 20, 24, 24,
     28, 28, 32, 36, 36, 40, 44, 48, 52, 52, 64, 64, 64, 64, -1},
    {4, 4, 4, 4, 4, 4, 4, 8, 8, 8, 12, 12, 16, 16, 12, -1},
    {8,  8,  8,  8,  8,  8,  8,  8,  8,  8,  8,  12, 12, 12, 12, 12, 12, 12, 12, 12, 16, 16,
     16, 16, 20, 20, 20, 24, 24, 28, 28, 32, 36, 40, 40, 44, 48, 52, 56, 60, 64, 64, -1},
    {4, 4, 4, 4, 4, 4, 4, 4, 8, 8, 12, 12, 16, 20, 12, -1},
    {12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 16, 16, 16, 16, 16, 16, 16, 20,
     20, 20, 20, 24, 24, 24, 28, 28, 32, 36, 36, 40, 44, 48, 52, 56, 60, 64, 16, -1},
    {4, 4, 4, 4, 4, 4, 4, 8, 8, 8, 8, 12, 16, 20, 12, -1},

    /* huffman_code_book_1 */
    {
        0x8800, 0x8800, 0x8800, 0x8800, 0x8800, 0x8800, 0x8800, 0x8800, 0x8800, 0x8800, 0x8800,
        0x8800, 0x8800, 0x8800, 0x8800, 0x8800, 0xa840, 0xa8c0, 0xa803, 0xa810, 0xa801, 0xa80c,
        0xa804, 0xa830, 0x1008, 0x100b, 0x100e, 0x1011, 0x1014, 0x1017, 0x201a, 0x1029, 0x9070,
        0x90d0, 0x900d, 0x901c, 0x9034, 0x9007, 0x9050, 0x900f, 0x90f0, 0x903c, 0x904c, 0x9013,
        0x90c4, 0x9005, 0x9044, 0x9031, 0x9014, 0x9011, 0x90cc, 0x9041, 0x90c3, 0x9043, 0x90c1,
        0x9033, 0xa05c, 0xa0dc, 0xa074, 0xa017, 0xa01d, 0xa035, 0xa037, 0xa07c, 0xa04d, 0xa01f,
        0xa0d4, 0xa0c7, 0xa0f4, 0xa03d, 0xa071, 0xa073, 0x1004, 0x1007, 0x180a, 0x2011, 0x90d3,
        0x90fc, 0x903f, 0x9015, 0x9047, 0x9051, 0x90d1, 0x9054, 0x98f1, 0x98cf, 0x9853, 0x984f,
        0x98cd, 0x98f3, 0x98c5, 0x9845, 0xa077, 0xa0dd, 0xa0d7, 0xa07d, 0xa055, 0xa0f5, 0xa05f,
        0xa0f7, 0xa0ff, 0xa05d, 0xa075, 0xa0d5, 0xa0df, 0xa0fd, 0xa07f, 0xa057,
    },
    /* huffman_code_book_2 */
    {
        0x9800, 0x9800, 0x9800, 0x9800, 0xa040, 0xa040, 0xa8c0, 0xa801, 0xa80c, 0xa803, 0xa830,
        0xa804, 0xa810, 0x0813, 0x0814, 0x0815, 0x0816, 0x0817, 0x0818, 0x0819, 0x081a, 0x081b,
        0x081c, 0x081d, 0x081e, 0x101f, 0x1022, 0x1025, 0x1028, 0x182d, 0x1834, 0x103b, 0x8834,
        0x88d0, 0x881c, 0x8807, 0x8813, 0x880d, 0x88c3, 0x8870, 0x884c, 0x88f0, 0x880f, 0x8844,
        0x8841, 0x8831, 0x88c4, 0x8811, 0x883c, 0x88c1, 0x8833, 0x88cc, 0x8850, 0x8814, 0x8805,
        0x8843, 0x901d, 0x904d, 0x90dc, 0x9037, 0x9074, 0x9053, 0x9045, 0x90d4, 0x903d, 0x9054,
        0x90c7, 0x90fc, 0x90cd, 0x907c, 0x905c, 0x0801, 0x8871, 0x88d3, 0x98f4, 0x98c5, 0x98f1,
        0x98f3, 0x983f, 0x9847, 0x984f, 0x981f, 0x9815, 0x98d1, 0x98cf, 0x9817, 0x9873, 0x9835,
        0x9851, 0x9877, 0x1004, 0x1007, 0x100a, 0x100d, 0x88dd, 0x88dd, 0x907d, 0x90ff, 0x90d7,
        0x90d5, 0x9055, 0x90f7, 0x9075, 0x90df, 0x90f5, 0x905f, 0x907f, 0x90fd, 0x905d, 0x9057,
    },
    /* huffman_code_book_3 */
    {
        0x8800, 0x8800, 0x8800, 0x8800, 0x8800, 0x8800, 0x8800, 0x8800, 0x8800, 0x8800, 0x8800,
        0x8800, 0x8800, 0x8800, 0x8800, 0x8800, 0xa040, 0xa040, 0xa001, 0xa001, 0xa010, 0xa010,
        0xa004, 0xa004, 0xa850, 0xa805, 0x0806, 0x0807, 0x0808, 0x1009, 0x100e, 0x101f, 0x8814,
        0x8811, 0x8844, 0x8815, 0x8841, 0x8854, 0x9055, 0x9045, 0x9051, 0x0801, 0x8880, 0x8802,
        0x0804, 0x1005, 0x1008, 0x100b, 0x8806, 0x8890, 0x8864, 0x8864, 0x9009, 0x9019, 0x9060,
        0x9016, 0x9094, 0x9008, 0x9024, 0x9018, 0x9020, 0x9012, 0x1004, 0x1007, 0x1810, 0x1017,
        0x9084, 0x9065, 0x9025, 0x9058, 0x9059, 0x0803, 0x0804, 0x0805, 0x8861, 0x8848, 0x8849,
        0x8821, 0x8895, 0x8856, 0x9891, 0x9846, 0x980a, 0x981a, 0x98a4, 0x9868, 0x9842, 0x9881,
        0x1004, 0x1007, 0x100a, 0x1011, 0x8829, 0x8829, 0x90a0, 0x9069, 0x9052, 0x9085, 0x905a,
        0x90a5, 0x9028, 0x9026, 0x0802, 0x0803, 0x884a, 0x88a1, 0x8898, 0x88a8, 0x0804, 0x0805,
        0x1006, 0x1009, 0x882a, 0x88a9, 0x8899, 0x8866, 0x886a, 0x886a, 0x9022, 0x9088, 0x9062,
        0x0803, 0x1004, 0x1007, 0x8889, 0x8896, 0x8892, 0x8892, 0x90aa, 0x90a6, 0x909a, 0x9086,
        0x9082, 0x0801, 0x88a2, 0x888a,
    },
    /* huffman_code_book_4 */
    {
        0xa055, 0xa055, 0xa015, 0xa015, 0xa051, 0xa051, 0xa054, 0xa054, 0xa045, 0xa045, 0xa040,
        0xa040, 0xa050, 0xa050, 0xa000, 0xa000, 0xa005, 0xa005, 0xa044, 0xa044, 0xa841, 0xa814,
        0xa801, 0xa811, 0xa804, 0xa810, 0x1006, 0x1009, 0x100c, 0x1815, 0x101c, 0x1029, 0x9095,
        0x9059, 0x9065, 0x9056, 0x9094, 0x9091, 0x9064, 0x9085, 0x9019, 0x0803, 0x0804, 0x0805,
        0x8816, 0x8858, 0x8825, 0x8846, 0x8861, 0x8852, 0x9849, 0x9890, 0x9884, 0x9860, 0x9881,
        0x9812, 0x9824, 0x9806, 0x0804, 0x0805, 0x0806, 0x1007, 0x8818, 0x8821, 0x8842, 0x8809,
        0x8848, 0x8880, 0x8802, 0x8802, 0x9020, 0x9008, 0x1004, 0x1007, 0x180e, 0x1015, 0x9069,
        0x90a5, 0x9099, 0x905a, 0x9066, 0x9096, 0x0802, 0x0803, 0x8868, 0x88a4, 0x8898, 0x8829,
        0x981a, 0x98a1, 0x9826, 0x9889, 0x984a, 0x98a9, 0x9862, 0x9886, 0x0804, 0x1005, 0x1008,
        0x100b, 0x8892, 0x886a, 0x909a, 0x90a6, 0x9028, 0x90a0, 0x900a, 0x9088, 0x9022, 0x9082,
        0x90aa, 0x902a, 0x90a8, 0x0801, 0x88a2, 0x888a,
    },
    /* huffman_code_book_5 */
    {
        0x8800, 0x8800, 0x8800, 0x8800, 0x8800, 0x8800, 0x8800, 0x8800, 0x8800, 0x8800, 0x8800,
        0x8800, 0x8800, 0x8800, 0x8800, 0x8800, 0xa0f0, 0xa0f0, 0xa010, 0xa010, 0xa001, 0xa001,
        0xa00f, 0xa00f, 0xa81f, 0xa8f1, 0xa8ff, 0xa811, 0x1004, 0x1807, 0x100e, 0x101d, 0x90e0,
        0x9002, 0x9020, 0x900e, 0x98ef, 0x9821, 0x98fe, 0x9812, 0x98e1, 0x982f, 0x98f2, 0x981e,
        0x0804, 0x0805, 0x1006, 0x1009, 0x88d0, 0x8830, 0x880d, 0x8803, 0x90df, 0x9013, 0x9031,
        0x90fd, 0x90d1, 0x903f, 0x901d, 0x90f3, 0x1004, 0x1807, 0x100e, 0x101d, 0x90e2, 0x9022,
        0x90ee, 0x902e, 0x98de, 0x983e, 0x98e3, 0x982d, 0x9832, 0x9823, 0x98d2, 0x98ed, 0x0804,
        0x0805, 0x1006, 0x1009, 0x880c, 0x88c0, 0x8841, 0x8840, 0x90cf, 0x9004, 0x904f, 0x90fc,
        0x9014, 0x90f4, 0x90c1, 0x901c, 0x1004, 0x1007, 0x100a, 0x1011, 0x903d, 0x90dd, 0x90d3,
        0x90e4, 0x90ce, 0x9042, 0x902c, 0x9024, 0x9033, 0x90c2, 0x0802, 0x0803, 0x88ec, 0x884e,
        0x883c, 0x88cd, 0x0804, 0x0805, 0x0806, 0x1007, 0x88c3, 0x8834, 0x88d4, 0x8843, 0x884d,
        0x88dc, 0x904c, 0x90c4, 0x9044, 0x90cc,
    },
    /* huffman_code_book_6 */
    {
        0xa000, 0xa000, 0xa010, 0xa010, 0xa00f, 0xa00f, 0xa001, 0xa001, 0xa0f0, 0xa0f0, 0xa011,
        0xa011, 0xa0f1, 0xa0f1, 0xa01f, 0xa01f, 0xa0ff, 0xa0ff, 0x080e, 0x080f, 0x0810, 0x0811,
        0x0812, 0x0813, 0x0814, 0x0815, 0x1016, 0x1019, 0x101c, 0x101f, 0x1028, 0x1039, 0x882f,
        0x8821, 0x88e1, 0x88ef, 0x88e0, 0x88f2, 0x8820, 0x881e, 0x8812, 0x880e, 0x88fe, 0x8802,
        0x882e, 0x88e2, 0x88ee, 0x8822, 0x90d1, 0x9031, 0x903f, 0x90f3, 0x90df, 0x9013, 0x901d,
        0x90fd, 0x9030, 0x90d0, 0x900d, 0x9003, 0x9032, 0x0803, 0x0804, 0x0805, 0x88de, 0x88e3,
        0x8823, 0x883e, 0x882d, 0x88ed, 0x0804, 0x1005, 0x1008, 0x100b, 0x88d2, 0x8833, 0x903d,
        0x90dd, 0x90d3, 0x901c, 0x90fc, 0x9041, 0x90c1, 0x90cf, 0x9014, 0x904f, 0x90f4, 0x900c,
        0x1004, 0x1007, 0x100a, 0x100f, 0x90c2, 0x90ce, 0x9024, 0x90ec, 0x90c0, 0x9042, 0x904e,
        0x90e4, 0x9040, 0x902c, 0x9004, 0x0801, 0x88dc, 0x88d4, 0x0804, 0x0805, 0x0806, 0x1007,
        0x883c, 0x884d, 0x8834, 0x8843, 0x88c3, 0x88cd, 0x9044, 0x90c4, 0x90cc, 0x904c,
    },
    /* huffman_code_book_7 */
    {
        0x8800, 0x8800, 0x8800, 0x8800, 0x8800, 0x8800, 0x8800, 0x8800, 0x8800, 0x8800, 0x8800,
        0x8800, 0x8800, 0x8800, 0x8800, 0x8800, 0x9810, 0x9810, 0x9810, 0x9810, 0x9801, 0x9801,
        0x9801, 0x9801, 0xa011, 0xa011, 0x0806, 0x0807, 0x1008, 0x100b, 0x1014, 0x1023, 0x8821,
        0x8812, 0x8820, 0x8802, 0x9031, 0x9013, 0x9022, 0x9030, 0x9003, 0x0803, 0x0804, 0x0805,
        0x8823, 0x8832, 0x8814, 0x8841, 0x8815, 0x8851, 0x0804, 0x0805, 0x1006, 0x1009, 0x8833,
        0x8824, 0x8804, 0x8840, 0x9042, 0x9025, 0x9052, 0x9005, 0x9061, 0x9050, 0x9016, 0x9043,
        0x1004, 0x1007, 0x180e, 0x1015, 0x9035, 0x9034, 0x9053, 0x9026, 0x9062, 0x9017, 0x0802,
        0x0803, 0x8836, 0x8806, 0x8860, 0x8844, 0x9871, 0x9845, 0x9872, 0x9854, 0x9863, 0x9827,
        0x9873, 0x9864, 0x0804, 0x1005, 0x1008, 0x100b, 0x8855, 0x8846, 0x8837, 0x8837, 0x9070,
        0x9007, 0x9065, 0x9056, 0x9074, 0x9047, 0x9057, 0x9075, 0x0802, 0x0803, 0x8876, 0x8866,
        0x8867, 0x8877,
    },
    /* huffman_code_book_8 */
    {
        0x9811, 0x9811, 0x9811, 0x9811, 0xa021, 0xa021, 0xa010, 0xa010, 0xa012, 0xa012, 0xa001,
        0xa001, 0xa022, 0xa022, 0xa800, 0xa820, 0xa802, 0xa831, 0xa813, 0xa832, 0xa823, 0x080b,
        0x080c, 0x080d, 0x080e, 0x080f, 0x1010, 0x1013, 0x1016, 0x1019, 0x1820, 0x1027, 0x8833,
        0x8841, 0x8814, 0x8842, 0x8824, 0x8830, 0x8803, 0x8843, 0x8834, 0x8852, 0x9051, 0x9025,
        0x9015, 0x9053, 0x9035, 0x9044, 0x9054, 0x9004, 0x9045, 0x9040, 0x9026, 0x9062, 0x9061,
        0x9016, 0x0802, 0x0803, 0x8836, 0x8863, 0x8855, 0x8850, 0x9864, 0x9805, 0x9846, 0x9871,
        0x9872, 0x9827, 0x9865, 0x9873, 0x0804, 0x1005, 0x1008, 0x100b, 0x8817, 0x8856, 0x8837,
        0x8837, 0x9066, 0x9074, 0x9060, 0x9047, 0x9006, 0x9075, 0x9076, 0x9067, 0x0802, 0x0803,
        0x8857, 0x8870, 0x8807, 0x8877,
    },
    /* huffman_code_book_9 */
    {
        0x8800, 0x8800, 0x8800, 0x8800, 0x8800, 0x8800, 0x8800, 0x8800, 0x8800, 0x8800, 0x8800,
        0x8800, 0x8800, 0x8800, 0x8800, 0x8800, 0x9810, 0x9810, 0x9810, 0x9810, 0x9801, 0x9801,
        0x9801, 0x9801, 0xa011, 0xa011, 0x0806, 0x0807, 0x1008, 0x100d, 0x101a, 0x1037, 0x8821,
        0x8812, 0x8820, 0x8802, 0x9031, 0x9022, 0x9013, 0x0801, 0x8830, 0x8803, 0x0804, 0x0805,
        0x0806, 0x1007, 0x8823, 0x8832, 0x8814, 0x8841, 0x8824, 0x8815, 0x9042, 0x9033, 0x9004,
        0x9040, 0x1004, 0x1007, 0x180c, 0x1813, 0x9051, 0x9025, 0x9016, 0x9034, 0x9052, 0x9061,
        0x9043, 0x0801, 0x8805, 0x8826, 0x9850, 0x9817, 0x9835, 0x9818, 0x9881, 0x9844, 0x9853,
        0x9862, 0x9871, 0x9806, 0x9882, 0x9828, 0x9836, 0x9827, 0x9845, 0x9891, 0x1004, 0x2015,
        0x1024, 0x1045, 0x0804, 0x1005, 0x1008, 0x100b, 0x8819, 0x8872, 0x9060, 0x9054, 0x9063,
        0x9083, 0x9007, 0x9092, 0x9038, 0x9046, 0x9037, 0x9008, 0x90a1, 0x9064, 0xa029, 0xa055,
        0xa080, 0xa070, 0xa073, 0xa0a2, 0xa093, 0xa084, 0xa01a, 0xa074, 0xa065, 0xa056, 0xa048,
        0xa047, 0xa039, 0xa0b1, 0x1004, 0x1809, 0x1810, 0x1817, 0x9058, 0x9090, 0x9085, 0x0801,
        0x88a3, 0x882a, 0x9809, 0x98b2, 0x9894, 0x9866, 0x98c1, 0x9849, 0x9886, 0x981b, 0x9895,
        0x98a4, 0x9857, 0x9875, 0x982b, 0x981c, 0x98c2, 0x98b3, 0x983a, 0x9859, 0x9867, 0x9887,
        0x98b4, 0x980a, 0x9876, 0x98c3, 0x1804, 0x100b, 0x201a, 0x1029, 0x98a0, 0x98a5, 0x984a,
        0x9868, 0x982c, 0x9896, 0x9897, 0x984b, 0x0804, 0x0805, 0x1006, 0x1009, 0x88b0, 0x8869,
        0x883b, 0x885a, 0x9088, 0x9078, 0x90c5, 0x903c, 0x90b5, 0x9077, 0x90c4, 0x90b6, 0xa0a6,
        0xa04c, 0xa079, 0xa05b, 0xa00b, 0xa0c6, 0xa06a, 0xa0c0, 0xa0a7, 0xa05c, 0xa07a, 0xa098,
        0xa00c, 0xa0b7, 0xa089, 0xa099, 0x1004, 0x1007, 0x180a, 0x1011, 0x90a8, 0x907b, 0x90c7,
        0x906b, 0x908b, 0x90b8, 0x907c, 0x906c, 0x988a, 0x98a9, 0x988c, 0x989a, 0x989b, 0x989c,
        0x98ab, 0x98c9, 0x0804, 0x0805, 0x0806, 0x1007, 0x88aa, 0x88b9, 0x88c8, 0x88ba, 0x88ca,
        0x88cb, 0x90ac, 0x90bb, 0x90bc, 0x90cc,
    },
    /* huffman_code_book_10 */
    {
        0xa011, 0xa011, 0xa012, 0xa012, 0xa021, 0xa021, 0xa822, 0xa810, 0xa801, 0xa813, 0xa832,
        0xa831, 0xa823, 0xa833, 0x0812, 0x0813, 0x0814, 0x0815, 0x0816, 0x0817, 0x0818, 0x1019,
        0x101c, 0x101f, 0x1022, 0x1025, 0x182e, 0x1835, 0x103c, 0x204d, 0x105c, 0x107d, 0x8820,
        0x8802, 0x8824, 0x8842, 0x8814, 0x8841, 0x8800, 0x8843, 0x8834, 0x8830, 0x8803, 0x8844,
        0x8825, 0x8852, 0x9015, 0x9051, 0x9053, 0x9035, 0x9054, 0x9045, 0x9062, 0x9026, 0x9063,
        0x9040, 0x9061, 0x9004, 0x9016, 0x9036, 0x9055, 0x9064, 0x9046, 0x0803, 0x0804, 0x0805,
        0x8865, 0x8872, 0x8837, 0x8827, 0x8856, 0x8882, 0x9873, 0x9850, 0x9871, 0x9805, 0x9881,
        0x9817, 0x9883, 0x9874, 0x9847, 0x9828, 0x9866, 0x9875, 0x9818, 0x9838, 0x9884, 0x9848,
        0x0804, 0x1005, 0x1008, 0x100b, 0x8857, 0x8885, 0x8858, 0x8858, 0x9076, 0x9067, 0x9092,
        0x9060, 0x9068, 0x9093, 0x9039, 0x9091, 0x9029, 0x9006, 0xa086, 0xa094, 0xa049, 0xa0a2,
        0xa019, 0xa077, 0xa087, 0xa095, 0xa078, 0xa0a3, 0xa059, 0xa0a4, 0xa02a, 0xa0a1, 0xa03a,
        0xa096, 0x1004, 0x1007, 0x1810, 0x1817, 0x9069, 0x9080, 0x904a, 0x9070, 0x90b2, 0x0803,
        0x0804, 0x0805, 0x8879, 0x88b3, 0x88a6, 0x881a, 0x88b1, 0x8897, 0x9807, 0x9888, 0x98a5,
        0x983b, 0x985a, 0x9889, 0x98b5, 0x9808, 0x98b4, 0x982b, 0x987a, 0x986a, 0x98a7, 0x984b,
        0x981b, 0x98c2, 0x1804, 0x180b, 0x1012, 0x1023, 0x9898, 0x98c3, 0x98b6, 0x985b, 0x98c4,
        0x98b7, 0x98c5, 0x983c, 0x986b, 0x9890, 0x98a8, 0x98a0, 0x98c1, 0x9809, 0x984c, 0x9899,
        0x0804, 0x1005, 0x1008, 0x100b, 0x88c6, 0x882c, 0x888a, 0x888a, 0x909a, 0x901c, 0x90b8,
        0x90c7, 0x907b, 0x905c, 0x906c, 0x90a9, 0x908b, 0x90c8, 0x1004, 0x1007, 0x100a, 0x180d,
        0x900a, 0x907c, 0x90b0, 0x90aa, 0x90b9, 0x90ba, 0x900b, 0x90bb, 0x909b, 0x90ab, 0x90c0,
        0x908c, 0x98c9, 0x98ac, 0x989c, 0x98bc, 0x98cb, 0x980c, 0x98ca, 0x98cc,
    },
    /* huffman_codebook_11[290] = */
    {
        0xa000, 0xa000, 0xa021, 0xa021, 0xaa10, 0xa820, 0xa801, 0xa841, 0xa822, 0xa842, 0x0816,
        0x0817, 0x0818, 0x1019, 0x101c, 0x101f, 0x1022, 0x1025, 0x182c, 0x1833, 0x183a, 0x1841,
        0x1848, 0x184f, 0x1056, 0x2063, 0x2072, 0x2081, 0x1090, 0x28b1, 0x28d0, 0x10ef, 0x8823,
        0x8861, 0x8862, 0x8840, 0x8843, 0x8802, 0x8863, 0x8863, 0x9081, 0x9024, 0x9082, 0x9044,
        0x9083, 0x9064, 0x9060, 0x9003, 0x90a1, 0x90a2, 0x9045, 0x9084, 0x9025, 0x90a3, 0x9065,
        0x90a4, 0x0802, 0x0803, 0x8885, 0x88c2, 0x8846, 0x88c1, 0x98c3, 0x9866, 0x9826, 0x9890,
        0x9870, 0x9a05, 0x9a03, 0x9a04, 0x98c4, 0x9a06, 0x9880, 0x9886, 0x9804, 0x9850, 0x98a5,
        0x98b0, 0x9a07, 0x9a02, 0x9a08, 0x9847, 0x98e2, 0x9867, 0x98c5, 0x98a6, 0x98d0, 0x9a0a,
        0x98e3, 0x98e1, 0x9a09, 0x98f0, 0x9830, 0x9827, 0x9887, 0x9a0b, 0x98e4, 0x9a0c, 0x9910,
        0x9a01, 0x98c6, 0x9930, 0x9848, 0x98a7, 0x9950, 0x9a0d, 0x9903, 0x9902, 0x9868, 0x98a0,
        0x0804, 0x0805, 0x0806, 0x1007, 0x8a0e, 0x8970, 0x88e5, 0x8888, 0x88c7, 0x88e6, 0x8805,
        0x8805, 0x9104, 0x920f, 0xa190, 0xa028, 0xa101, 0xa1d0, 0xa0a8, 0xa1b0, 0xa069, 0xa105,
        0xa0e7, 0xa049, 0xa106, 0xa122, 0xa123, 0xa1f0, 0xa089, 0xa0c8, 0xa0c0, 0xa124, 0xa0a9,
        0xa107, 0xa0e8, 0xa029, 0xa143, 0xa006, 0xa142, 0xa121, 0xa125, 0xa08a, 0xa04a, 0xa126,
        0xa06a, 0xa0c9, 0xa144, 0xa108, 0xa145, 0xa127, 0xa163, 0xa02a, 0xa0e0, 0xa146, 0xa0e9,
        0xa06b, 0xa0aa, 0xa141, 0xa08b, 0xa162, 0xa1a2, 0xa0ca, 0x1004, 0x1007, 0x1810, 0x1817,
        0x91a3, 0x904b, 0x9200, 0x90ab, 0x9165, 0x0803, 0x0804, 0x0805, 0x8964, 0x8928, 0x88ea,
        0x8909, 0x8810, 0x888d, 0x9807, 0x986d, 0x9966, 0x99a1, 0x99a4, 0x9983, 0x984d, 0x99a5,
        0x990a, 0x98cb, 0x9948, 0x9947, 0x99c2, 0x9984, 0x982b, 0x988c, 0xa961, 0xa86c, 0xa82d,
        0xa982, 0xa8eb, 0xa86e, 0xa8ac, 0xa8ad, 0xa9c4, 0xa88e, 0xa967, 0xa9c3, 0xa985, 0xa9a6,
        0xa986, 0xa900, 0xa968, 0xa84c, 0xa929, 0xa9c5, 0xa8cd, 0xa94a, 0xa9e2, 0xa90b, 0xa92a,
        0xa9c6, 0xa949, 0xa8ae, 0xa969, 0xa9c1, 0xa84e, 0xa8cc, 0xa82c, 0xa9a8, 0xa808, 0xa9a7,
        0xa8ec, 0xa987, 0xa8ed, 0xa9e3, 0xa981, 0xa8ce, 0xa84f, 0xa9e5, 0xa9e4, 0xa82e, 0xa92b,
        0xa88f, 0xa9c7, 0xa90d, 0xa9a9, 0xa90c, 0xa8af, 0xa86f, 0xa94b, 0xa96a, 0xa988, 0xa9e6,
        0xa9e7, 0xa90e, 0xa9e1, 0xa8ee, 0xa920, 0xa809, 0x1804, 0x100b, 0x201e, 0x102d, 0x992d,
        0x992c, 0x9989, 0x99c8, 0x994d, 0x99c9, 0x998a, 0x98cf, 0x1004, 0x1007, 0x100a, 0x100d,
        0x88ef, 0x88ef, 0x912e, 0x91e8, 0x916b, 0x916e, 0x902f, 0x914c, 0x914e, 0x91ab, 0x91aa,
        0x916d, 0x916c, 0x910f, 0x91cb, 0x91ac, 0xa18d, 0xa1e9, 0xa1ca, 0xa140, 0xa18b, 0xa12f,
        0xa00a, 0xa18c, 0xa160, 0xa18e, 0xa14f, 0xa1ad, 0xa00d, 0xa1cc, 0xa1ea, 0xa1eb, 0x1004,
        0x1007, 0x100a, 0x100d, 0x916f, 0x91cd, 0x91a0, 0x900b, 0x91ae, 0x91ec, 0x91ed, 0x918f,
        0x91c0, 0x91ce, 0x91af, 0x9180, 0x91cf, 0x0803, 0x0804, 0x0805, 0x880e, 0x880c, 0x89ee,
        0x89e0, 0x880f, 0x89ef,
    },
    /* huffman_code_book_scl */
    {
        7,      0x883c, 0x883c, 0x883c, 0x883c, 0x883c, 0x883c, 0x883c, 0x883c, 0x883c, 0x883c,
        0x883c, 0x883c, 0x883c, 0x883c, 0x883c, 0x883c, 0x883c, 0x883c, 0x883c, 0x883c, 0x883c,
        0x883c, 0x883c, 0x883c, 0x883c, 0x883c, 0x883c, 0x883c, 0x883c, 0x883c, 0x883c, 0x883c,
        0x883c, 0x883c, 0x883c, 0x883c, 0x883c, 0x883c, 0x883c, 0x883c, 0x883c, 0x883c, 0x883c,
        0x883c, 0x883c, 0x883c, 0x883c, 0x883c, 0x883c, 0x883c, 0x883c, 0x883c, 0x883c, 0x883c,
        0x883c, 0x883c, 0x883c, 0x883c, 0x883c, 0x883c, 0x883c, 0x883c, 0x883c, 0x883c, 0x983b,
        0x983b, 0x983b, 0x983b, 0x983b, 0x983b, 0x983b, 0x983b, 0x983b, 0x983b, 0x983b, 0x983b,
        0x983b, 0x983b, 0x983b, 0x983b, 0xa03d, 0xa03d, 0xa03d, 0xa03d, 0xa03d, 0xa03d, 0xa03d,
        0xa03d, 0xa03a, 0xa03a, 0xa03a, 0xa03a, 0xa03a, 0xa03a, 0xa03a, 0xa03a, 0xa03e, 0xa03e,
        0xa03e, 0xa03e, 0xa03e, 0xa03e, 0xa03e, 0xa03e, 0xa839, 0xa839, 0xa839, 0xa839, 0xa83f,
        0xa83f, 0xa83f, 0xa83f, 0xb038, 0xb038, 0xb040, 0xb040, 0xb037, 0xb037, 0xb041, 0xb041,
        0xb842, 0xb836, 0xb843, 0x0805, 0x0806, 0x1007, 0x100a, 0x1011, 0x8835, 0x8844, 0x8834,
        0x8845, 0x8833, 0x8833, 0x9046, 0x9032, 0x9031, 0x9047, 0x0802, 0x0803, 0x8848, 0x8830,
        0x8849, 0x882f, 0x0804, 0x1005, 0x1008, 0x100f, 0x884a, 0x882e, 0x904c, 0x904b, 0x904d,
        0x904e, 0x902d, 0x902b, 0x0802, 0x0803, 0x882c, 0x884f, 0x882a, 0x8829, 0x0804, 0x1005,
        0x1008, 0x1011, 0x8850, 0x8828, 0x9051, 0x9027, 0x9052, 0x9026, 0x9053, 0x0803, 0x0804,
        0x0805, 0x8825, 0x8823, 0x8855, 0x8821, 0x8824, 0x8822, 0x0804, 0x1005, 0x1008, 0x1015,
        0x8854, 0x8820, 0x9057, 0x9059, 0x901e, 0x901f, 0x0804, 0x0805, 0x0806, 0x1007, 0x8856,
        0x881d, 0x881a, 0x881b, 0x881c, 0x8818, 0x8858, 0x8858, 0x9019, 0x9016, 0x1004, 0x100d,
        0x2020, 0x202f, 0x9017, 0x0803, 0x0804, 0x0805, 0x885a, 0x8815, 0x8813, 0x8803, 0x8801,
        0x8802, 0x1004, 0x1007, 0x100a, 0x100d, 0x8800, 0x8800, 0x9062, 0x9063, 0x9064, 0x9065,
        0x9066, 0x9075, 0x9061, 0x905b, 0x905c, 0x905d, 0x905e, 0x905f, 0x9060, 0x9068, 0xa06f,
        0xa070, 0xa071, 0xa072, 0xa073, 0xa074, 0xa06e, 0xa069, 0xa06a, 0xa06b, 0xa06c, 0xa06d,
        0xa076, 0xa006, 0xa008, 0xa009, 0xa00a, 0xa005, 0xa067, 0xa078, 0xa077, 0xa004, 0xa007,
        0xa00f, 0xa010, 0xa012, 0xa014, 0xa011, 0xa00b, 0xa00c, 0xa00e, 0xa00d,

    }}; /* END OF ia_mps_dec_res_huffmann_tables_struct */

const ia_mps_dec_res_block_tables_struct ixheaacd_mps_dec_res_block_tables = {
    {0 >> 4,        131072 >> 4,   330281 >> 4,   567116 >> 4,   832256 >> 4,   1120650 >> 4,
     1429042 >> 4,  1755122 >> 4,  2097152 >> 4,  2453767 >> 4,  2823861 >> 4,  3206517 >> 4,
     3600960 >> 4,  4006524 >> 4,  4422631 >> 4,  4848770 >> 4,  5284492 >> 4,  5729392 >> 4,
     6183105 >> 4,  6645302 >> 4,  7115683 >> 4,  7593972 >> 4,  8079916 >> 4,  8573281 >> 4,
     9073850 >> 4,  9581422 >> 4,  10095808 >> 4, 10616832 >> 4, 11144330 >> 4, 11678147 >> 4,
     12218136 >> 4, 12764159 >> 4, 13316085 >> 4, 13873792 >> 4, 14437162 >> 4, 15006082 >> 4,
     15580448 >> 4, 16160157 >> 4, 16745112 >> 4, 17335222 >> 4, 17930398 >> 4, 18530554 >> 4,
     19135610 >> 4, 19745488 >> 4, 20360112 >> 4, 20979411 >> 4, 21603314 >> 4, 22231755 >> 4,
     22864669 >> 4, 23501994 >> 4, 24143669 >> 4, 24789637 >> 4, 25439841 >> 4, 26094226 >> 4,
     26752740 >> 4, 27415332 >> 4, 28081952 >> 4, 28752552 >> 4, 29427086 >> 4, 30105507 >> 4,
     30787772 >> 4, 31473838 >> 4, 32163664 >> 4, 32857208 >> 4, 33554432 >> 4, 34255297 >> 4,
     34959765 >> 4, 35667801 >> 4, 36379368 >> 4, 37094431 >> 4, 37812958 >> 4, 38534914 >> 4,
     39260268 >> 4, 39988988 >> 4, 40721043 >> 4, 41456403 >> 4, 42195038 >> 4, 42936921 >> 4,
     43682022 >> 4, 44430314 >> 4, 45181770 >> 4, 45936364 >> 4, 46694070 >> 4, 47454862 >> 4,
     48218716 >> 4, 48985607 >> 4, 49755512 >> 4, 50528406 >> 4, 51304267 >> 4, 52083073 >> 4,
     52864802 >> 4, 53649431 >> 4, 54436939 >> 4, 55227306 >> 4, 56020511 >> 4, 56816534 >> 4,
     57615355 >> 4, 58416954 >> 4, 59221313 >> 4, 60028412 >> 4, 60838233 >> 4, 61650759 >> 4,
     62465970 >> 4, 63283850 >> 4, 64104381 >> 4, 64927547 >> 4, 65753329 >> 4, 66581713 >> 4,
     67412681 >> 4, 68246218 >> 4, 69082308 >> 4, 69920936 >> 4, 70762086 >> 4, 71605743 >> 4,
     72451892 >> 4, 73300519 >> 4, 74151609 >> 4, 75005149 >> 4, 75861124 >> 4, 76719520 >> 4,
     77580324 >> 4, 78443523 >> 4, 79309103 >> 4, 80177051 >> 4, 81047354 >> 4, 81920000 >> 4,
     82794977 >> 4, 83672271 >> 4, 84551871 >> 4},
    {16384, 19484, 23171, 27555},
    {16385, 19486, 23172, 27557},

    /* conceal_n_tns_tables */
    {{31, 9},
     {31, 9},
     {34, 10},
     {40, 14},
     {42, 14},
     {51, 14},
     {46, 14},
     {46, 14},
     {42, 14},
     {42, 14},
     {42, 14},
     {39, 14}},
    {(WORD16)-0x7e0e, (WORD16)-0x6eda, (WORD16)-0x5247, (WORD16)-0x2bc7, (WORD16)0x0000,
     (WORD16)0x378a, (WORD16)0x6413, (WORD16)0x7cca},
    {(WORD16)-0x7f74, (WORD16)-0x7b1d, (WORD16)-0x7295, (WORD16)-0x6625, (WORD16)-0x563c,
     (WORD16)-0x4362, (WORD16)-0x2e3d, (WORD16)-0x1785, (WORD16)0x0000, (WORD16)0x1a9d,
     (WORD16)0x3410, (WORD16)0x4b3d, (WORD16)0x5f1f, (WORD16)0x6eda, (WORD16)0x79bc,
     (WORD16)0x7f4c},
}; /* END OF ia_mps_dec_res_block_tables_struct */

const ia_mps_dec_common_tables_struct ixheaacd_mps_dec_common_tables = {
    {1073741824, 1074789888, 1075836928, 1076882944, 1077927936, 1078971904, 1080014976,
     1081056896, 1082097920, 1083137920, 1084176896, 1085214848, 1086251904, 1087287808,
     1088322944, 1089356928, 1090390016, 1091422080, 1092453120, 1093483264, 1094512512,
     1095540608, 1096567936, 1097594112, 1098619392, 1099643776, 1100667264, 1101689600,
     1102711168, 1103731712, 1104751360, 1105769984, 1106787712, 1107804544, 1108820352,
     1109835392, 1110849408, 1111862400, 1112874624, 1113885824, 1114896128, 1115905536,
     1116914048, 1117921664, 1118928384, 1119934208, 1120939008, 1121943040, 1122946048,
     1123948288, 1124949504, 1125949952, 1126949504, 1127948032, 1128945792, 1129942656,
     1130938624, 1131933824, 1132928000, 1133921408, 1134913920, 1135905536, 1136896256,
     1137886208, 1138875136, 1139863424, 1140850688, 1141837184, 1142822784, 1143807488,
     1144791424, 1145774592, 1146756736, 1147738112, 1148718720, 1149698432, 1150677376,
     1151655424, 1152632576, 1153608960, 1154584576, 1155559296, 1156533248, 1157506304,
     1158478592, 1159450112, 1160420736, 1161390592, 1162359680, 1163327872, 1164295296,
     1165261952, 1166227712, 1167192704, 1168156928, 1169120384, 1170083072, 1171044864,
     1172005888, 1172966144, 1173925632, 1174884352, 1175842304, 1176799488, 1177755776,
     1178711424, 1179666176, 1180620160, 1181573504, 1182525952, 1183477760, 1184428672,
     1185378816, 1186328320, 1187277056, 1188224896, 1189172096, 1190118528, 1191064192,
     1192009088, 1192953216, 1193896704, 1194839296, 1195781248, 1196722432, 1197662976,
     1198602624, 1199541632, 1200479872, 1201417344, 1202354176, 1203290240, 1204225536,
     1205160064, 1206093952, 1207027072, 1207959552, 1208891264, 1209822208, 1210752512,
     1211682048, 1212610944, 1213539072, 1214466560, 1215393280, 1216319232, 1217244544,
     1218169088, 1219092992, 1220016256, 1220938752, 1221860608, 1222781696, 1223702144,
     1224621824, 1225540864, 1226459264, 1227376896, 1228293888, 1229210240, 1230125824,
     1231040768, 1231954944, 1232868608, 1233781504, 1234693632, 1235605248, 1236516096,
     1237426304, 1238335872, 1239244672, 1240152960, 1241060480, 1241967360, 1242873600,
     1243779072, 1244684032, 1245588224, 1246491776, 1247394816, 1248297088, 1249198592,
     1250099584, 1250999936, 1251899648, 1252798592, 1253697024, 1254594816, 1255491840,
     1256388352, 1257284224, 1258179328, 1259073920, 1259967744, 1260861056, 1261753728,
     1262645760, 1263537152, 1264427904, 1265318016, 1266207488, 1267096448, 1267984640,
     1268872320, 1269759232, 1270645632, 1271531520, 1272416640, 1273301120, 1274185088,
     1275068416, 1275951104, 1276833280, 1277714688, 1278595584, 1279475840, 1280355584,
     1281234560, 1282113024, 1282990848, 1283868160, 1284744832, 1285620864, 1286496384,
     1287371264, 1288245504, 1289119232, 1289992320, 1290864768, 1291736704, 1292608000,
     1293478784, 1294348928, 1295218432, 1296087424, 1296955904, 1297823616, 1298690944,
     1299557504, 1300423680, 1301289216, 1302154112, 1303018496, 1303882240, 1304745472,
     1305608064, 1306470144, 1307331712, 1308192640, 1309052928, 1309912704, 1310771968,
     1311630720, 1312488832, 1313346304, 1314203392, 1315059840, 1315915648, 1316770944,
     1317625728, 1318480000, 1319333632, 1320186752, 1321039360, 1321891328, 1322742784,
     1323593728, 1324444032, 1325293824, 1326143104, 1326991872, 1327840128, 1328687744,
     1329534848, 1330381440, 1331227392, 1332072960, 1332917888, 1333762304, 1334606208,
     1335449472, 1336292352, 1337134592, 1337976448, 1338817664, 1339658368, 1340498560,
     1341338112, 1342177280, 1343015936, 1343853952, 1344691456, 1345528576, 1346365056,
     1347201024, 1348036480, 1348871424, 1349705856, 1350539776, 1351373184, 1352206080,
     1353038464, 1353870336, 1354701696, 1355532544, 1356363008, 1357192832, 1358022144,
     1358850944, 1359679232, 1360507008, 1361334400, 1362161152, 1362987520, 1363813248,
     1364638592, 1365463424, 1366287744, 1367111552, 1367934848, 1368757632, 1369579904,
     1370401792, 1371223168, 1372043904, 1372864384, 1373684224, 1374503552, 1375322496,
     1376140800, 1376958720, 1377776256, 1378593152, 1379409536, 1380225536, 1381041024,
     1381856128, 1382670592, 1383484672, 1384298240, 1385111296, 1385923968, 1386736128,
     1387547776, 1388358912, 1389169664, 1389979904, 1390789760, 1391598976, 1392407808,
     1393216256, 1394024064, 1394831488, 1395638528, 1396445056, 1397251072, 1398056576,
     1398861696, 1399666304, 1400470528, 1401274240, 1402077440, 1402880256, 1403682560,
     1404484480, 1405285888, 1406086912, 1406887296, 1407687424, 1408487040, 1409286144,
     1410084864, 1410883072, 1411680896, 1412478208, 1413275136, 1414071552, 1414867456,
     1415662976, 1416458112, 1417252736, 1418046976, 1418840704, 1419634048, 1420426880,
     1421219328, 1422011392, 1422802816, 1423593984, 1424384640, 1425174912, 1425964672,
     1426754048, 1427542912, 1428331392, 1429119488, 1429907072, 1430694272, 1431480960,
     1432267264, 1433053184, 1433838592, 1434623616, 1435408256, 1436192384, 1436976128,
     1437759488, 1438542336, 1439324800, 1440106752, 1440888448, 1441669632, 1442450304,
     1443230720, 1444010624, 1444790144, 1445569152, 1446347776, 1447126016, 1447903872,
     1448681216, 1449458304, 1450234880, 1451010944, 1451786752, 1452562048, 1453336960,
     1454111360, 1454885504, 1455659136, 1456432384, 1457205248, 1457977728, 1458749696,
     1459521408, 1460292608, 1461063424, 1461833728, 1462603776, 1463373312, 1464142592,
     1464911360, 1465679744, 1466447744, 1467215232, 1467982464, 1468749184, 1469515520,
     1470281600, 1471047168, 1471812352, 1472577024, 1473341440, 1474105472, 1474868992,
     1475632256, 1476395008, 1477157376, 1477919360, 1478681088, 1479442304, 1480203136,
     1480963584, 1481723648, 1482483200, 1483242496, 1484001408, 1484759936, 1485518080,
     1486275712, 1487033088, 1487790080, 1488546560, 1489302784, 1490058624, 1490813952,
     1491569024, 1492323712, 1493078016, 1493831808, 1494585344, 1495338496, 1496091264,
     1496843648, 1497595648, 1498347264, 1499098496, 1499849344, 1500599808, 1501349888,
     1502099712, 1502849024, 1503598080, 1504346624, 1505094912, 1505842816, 1506590208,
     1507337344, 1508084096, 1508830592, 1509576576, 1510322176, 1511067520, 1511812480,
     1512556928, 1513301120, 1514044928, 1514788480, 1515531520, 1516274304, 1517016576,
     1517758592, 1518500249

    }}; /* END OF ia_mps_dec_common_tables_struct */

const ia_mps_dec_qmf_tables_struct ixheaacd_mps_dec_qmf_tables = {
    {
        0,          28501019,   775583039,  -775583039, -28501019,  0,          28501019,
        775583039,  -775583039, -28501019,  -1186546,   30903291,   799678975,  -751600831,
        -26167087,  -1186546,   30903291,   799678975,  -751600831, -26167087,  -1206390,
        33373087,   823849919,  -727722687, -23904831,  -1206390,   33373087,   823849919,
        -727722687, -23904831,  -1062471,   35932707,   848086783,  -703969535, -21721843,
        -1062471,   35932707,   848086783,  -703969535, -21721843,  -1046947,   38533023,
        872376063,  -680382719, -19611965,  -1046947,   38533023,   872376063,  -680382719,
        -19611965,  -1050933,   41204291,   896724095,  -656936447, -17566035,  -1050933,
        41204291,   896724095,  -656936447, -17566035,  -1082485,   43922867,   921081471,
        -633661567, -15594127,  -1082485,   43922867,   921081471,  -633661567, -15594127,
        -1122396,   46700799,   945441215,  -610575615, -13699290,  -1122396,   46700799,
        945441215,  -610575615, -13699290,  -1173935,   49538187,   969802879,  -587687679,
        -11883575,  -1173935,   49538187,   969802879,  -587687679, -11883575,  -1219298,
        52433171,   994136319,  -565014399, -10140974,  -1219298,   52433171,   994136319,
        -565014399, -10140974,  -1260772,   55378415,   1018434047, -542557503, -8461326,
        -1260772,   55378415,   1018434047, -542557503, -8461326,   -1316997,   58381367,
        1042657663, -520338911, -6857726,   -1316997,   58381367,   1042657663, -520338911,
        -6857726,   -1355597,   61433531,   1066807231, -498364575, -5331498,   -1355597,
        61433531,   1066807231, -498364575, -5331498,   -1404525,   64532455,   1090882559,
        -476666783, -3873947,   -1404525,   64532455,   1090882559, -476666783, -3873947,
        -1455497,   67649519,   1114809215, -455209823, -2484238,   -1455497,   67649519,
        1114809215, -455209823, -2484238,   -1490700,   70814151,   1138647551, -434060159,
        -1173445,   -1490700,   70814151,   1138647551, -434060159, -1173445,   -1537112,
        74006783,   1162337023, -413168703, 59280,      -1537112,   74006783,   1162337023,
        -413168703, 59280,      -1558008,   77244463,   1185851519, -392597055, 1252469,
        -1558008,   77244463,   1185851519, -392597055, 1252469,    -1597930,   80490447,
        1209202815, -372332479, 2341257,    -1597930,   80490447,   1209202815, -372332479,
        2341257,    -1608593,   83763391,   1232338687, -352393215, 3389734,    -1608593,
        83763391,   1232338687, -352393215, 3389734,    -1649561,   87048071,   1255290751,
        -332775583, 4353845,    -1649561,   87048071,   1255290751, -332775583, 4353845,
        -1658898,   90333703,   1277993983, -313482463, 5263168,    -1658898,   90333703,
        1277993983, -313482463, 5263168,    -1682409,   93651231,   1300469631, -294538495,
        6108894,    -1682409,   93651231,   1300469631, -294538495, 6108894,    -1670714,
        96956399,   1322658815, -275952255, 6891679,    -1670714,   96956399,   1322658815,
        -275952255, 6891679,    -1675824,   100253775,  1344591615, -257714783, 7602359,
        -1675824,   100253775,  1344591615, -257714783, 7602359,    -1675348,   103544295,
        1366224767, -239836751, 8258450,    -1675348,   103544295,  1366224767, -239836751,
        8258450,    -1666012,   106812775,  1387547135, -222335327, 8858722,    -1666012,
        106812775,  1387547135, -222335327, 8858722,    -1638700,   110070599,  1408537983,
        -205199231, 9406377,    -1638700,   110070599,  1408537983, -205199231, 9406377,
        -1617055,   113307839,  1429180415, -188451903, 9886913,    -1617055,   113307839,
        1429180415, -188451903, 9886913,    -1571819,   116490847,  1449479167, -172093519,
        10331429,   -1571819,   116490847,  1449479167, -172093519, 10331429,   -1549493,
        119652127,  1469384191, -156109887, 10702990,   -1549493,   119652127,  1469384191,
        -156109887, 10702990,   -1485615,   122753695,  1488911103, -140533439, 11034259,
        -1485615,   122753695,  1488911103, -140533439, 11034259,   -1428165,   125824431,
        1508046463, -125349767, 11320622,   -1428165,   125824431,  1508046463, -125349767,
        11320622,   -1361847,   128814119,  1526734207, -110553351, 11561831,   -1361847,
        128814119,  1526734207, -110553351, 11561831,   -1276919,   131738495,  1544999039,
        -96165783,  11758284,   -1276919,   131738495,  1544999039, -96165783,  11758284,
        -1194983,   134616687,  1562820223, -82200639,  11897996,   -1194983,   134616687,
        1562820223, -82200639,  11897996,   -1105003,   137377935,  1580163967, -68618815,
        12008111,   -1105003,   137377935,  1580163967, -68618815,  12008111,   -989200,
        140068991,  1597046655, -55453887,  12083055,   -989200,    140068991,  1597046655,
        -55453887,  12083055,   -879420,    142671839,  1613433983, -42699303,  12109487,
        -879420,    142671839,  1613433983, -42699303,  12109487,   -751871,    145186207,
        1629313151, -30341543,  12123660,   -751871,    145186207,  1629313151, -30341543,
        12123660,   -622121,    147541535,  1644687871, -18406457,  12073290,   -622121,
        147541535,  1644687871, -18406457,  12073290,   -450614,    149814959,  1659528319,
        -6890608,   12012598,   -450614,    149814959,  1659528319, -6890608,   12012598,
        -310607,    151962111,  1673810559, 4244630,    11913318,   -310607,    151962111,
        1673810559, 4244630,    11913318,   -132571,    153975151,  1687568511, 14954401,
        11784539,   -132571,    153975151,  1687568511, 14954401,   11784539,   28980,
        155839151,  1700750335, 25259525,   11638668,   28980,      155839151,  1700750335,
        25259525,   11638668,   235016,     157543743,  1713362559, 35154575,   11482955,
        235016,     157543743,  1713362559, 35154575,   11482955,   438734,     159129327,
        1725392639, 44667031,   11265949,   438734,     159129327,  1725392639, 44667031,
        11265949,   633406,     160514207,  1736819327, 53753139,   11039644,   633406,
        160514207,  1736819327, 53753139,   11039644,   864692,     161735007,  1747663231,
        62453979,   10821818,   864692,     161735007,  1747663231, 62453979,   10821818,
        1096803,    162781055,  1757881983, 70777607,   10552219,   1096803,    162781055,
        1757881983, 70777607,   10552219,   1339895,    163636639,  1767469183, 78687687,
        10293438,   1339895,    163636639,  1767469183, 78687687,   10293438,   1601598,
        164280815,  1776457599, 86212511,   10008660,   1601598,    164280815,  1776457599,
        86212511,   10008660,   1848649,    164732079,  1784781951, 93365887,   9708741,
        1848649,    164732079,  1784781951, 93365887,   9708741,    2122999,    164964111,
        1792491135, 100137871,  9391100,    2122999,    164964111,  1792491135, 100137871,
        9391100,    2415952,    164976143,  1799530623, 106510607,  9076182,    2415952,
        164976143,  1799530623, 106510607,  9076182,    2701080,    164755999,  1805935231,
        112548287,  8765974,    2701080,    164755999,  1805935231, 112548287,  8765974,
        2985537,    164293391,  1811668351, 118210391,  8419731,    2985537,    164293391,
        1811668351, 118210391,  8419731,    3316406,    163584207,  1816732159, 123513103,
        8075380,    3316406,    163584207,  1816732159, 123513103,  8075380,    3622393,
        162630175,  1821133951, 128455295,  7732716,    3622393,    162630175,  1821133951,
        128455295,  7732716,    3940259,    161399775,  1824889727, 133058679,  7391396,
        3940259,    161399775,  1824889727, 133058679,  7391396,    4260852,    159915455,
        1827931903, 137319727,  7030778,    4260852,    159915455,  1827931903, 137319727,
        7030778,    4608839,    158141983,  1830310399, 141237999,  6684132,    4608839,
        158141983,  1830310399, 141237999,  6684132,    4942917,    156073663,  1832022783,
        144853151,  6328515,    4942917,    156073663,  1832022783, 144853151,  6328515,
        5288310,    153722543,  1833032063, 148104223,  5985136,    5288310,    153722543,
        1833032063, 148104223,  5985136,    5626784,    151082575,  1833389567, 151082575,
        5626784,    5626784,    151082575,  1833389567, 151082575,  5626784,
    },
    {
        0x0000, 0x0648, 0x0c8c, 0x12c8, 0x18f9, 0x1f1a, 0x2528, 0x2b1f, 0x30fc, 0x36ba, 0x3c57,
        0x41ce, 0x471d, 0x4c40, 0x5134, 0x55f6, 0x5a82, 0x5ed7, 0x62f2, 0x66d0, 0x6a6e, 0x6dca,
        0x70e3, 0x73b6, 0x7642, 0x7885, 0x7a7d, 0x7c2a, 0x7d8a, 0x7e9d, 0x7f62, 0x7fd9, 0x7fff,
    },
    {
        0x7ffe, 0x7fc2, 0x7f38, 0x7e60, 0x7d3a, 0x7bc6, 0x7a06, 0x77fb, 0x75a6, 0x7308, 0x7023,
        0x6cf9, 0x698c, 0x65de, 0x61f1, 0x5dc8, 0x5964, 0x54ca, 0x4ffb, 0x4afb, 0x45cd, 0x4074,
        0x3af3, 0x354e, 0x2f87, 0x29a4, 0x23a7, 0x1d93, 0x176e, 0x113a, 0x0afb, 0x04b6,
    },
    {
        0x0192, 0x07d9, 0x0e1c, 0x1455, 0x1a83, 0x209f, 0x26a8, 0x2c99, 0x326e, 0x3825, 0x3db8,
        0x4326, 0x486a, 0x4d81, 0x5269, 0x571e, 0x5b9d, 0x5fe4, 0x63ef, 0x67bd, 0x6b4b, 0x6e97,
        0x719e, 0x7460, 0x76d9, 0x790a, 0x7aef, 0x7c89, 0x7dd6, 0x7ed6, 0x7f87, 0x7fea,
    },
    {
        0x7D89, 0x6a6d, 0x471c, 0x18f9,
    },
    {
        0x7FF5, 0x7FA6, 0x7F09, 0x7E1D, 0x7CE3, 0x7B5C, 0x7989, 0x776B, 0x7504, 0x7254, 0x6F5E,
        0x6C23, 0x68A6, 0x64E8, 0x60EB, 0x5CB3, 0x5842, 0x539B, 0x4EBF, 0x49B4, 0x447A, 0x3F17,
        0x398C, 0x33DF, 0x2E11, 0x2826, 0x2223, 0x1C0B, 0x15E2, 0xFAB,  0x096A, 0x0324,
    },
    {
        0x0324, 0x096A, 0x0FAB, 0x15E2, 0x1C0B, 0x2223, 0x2826, 0x2E11, 0x33DF, 0x398C, 0x3F17,
        0x447A, 0x49B4, 0x4EBF, 0x539B, 0x5842, 0x5CB3, 0x60EB, 0x64E8, 0x68A6, 0x6C23, 0x6F5E,
        0x7254, 0x7504, 0x776B, 0x7989, 0x7B5C, 0x7CE3, 0x7E1D, 0x7F09, 0x7FA6, 0x7FF5,

    },

}; /* END OF ia_mps_dec_qmf_tables_struct */

const ia_mps_dec_hybrid_tables_struct ixheaacd_mps_dec_hybrid_tables = {
    {
        -692, -2976, -5960, -9524, -9162, 15458, 16384, 15458, 9162, 9524,
        5960, 2976,  692,   14281, 5916,  -2749, -1404, 8799,  3645,

    },

    {
        1245, -4780, 20052, 20052, -4780, 1245,

    },

    {0,      101,    201,    302,    402,    503,    603,    704,    804,    905,    1005,
     1106,   1206,   1307,   1407,   1507,   1608,   1708,   1809,   1909,   2009,   2110,
     2210,   2310,   2411,   2511,   2611,   2711,   2811,   2912,   3012,   3112,   3212,
     3312,   3412,   3512,   3612,   3712,   3812,   3911,   4011,   4111,   4211,   4310,
     4410,   4510,   4609,   4709,   4808,   4907,   5007,   5106,   5205,   5305,   5404,
     5503,   5602,   5701,   5800,   5899,   5998,   6097,   6195,   6294,   6393,   6491,
     6590,   6688,   6787,   6885,   6983,   7081,   7180,   7278,   7376,   7473,   7571,
     7669,   7767,   7864,   7962,   8059,   8157,   8254,   8351,   8449,   8546,   8643,
     8740,   8836,   8933,   9030,   9127,   9223,   9319,   9416,   9512,   9608,   9704,
     9800,   9896,   9992,   10088,  10183,  10279,  10374,  10469,  10565,  10660,  10755,
     10850,  10945,  11039,  11134,  11228,  11323,  11417,  11511,  11605,  11699,  11793,
     11887,  11980,  12074,  12167,  12261,  12354,  12447,  12540,  12633,  12725,  12818,
     12910,  13003,  13095,  13187,  13279,  13371,  13463,  13554,  13646,  13737,  13828,
     13919,  14010,  14101,  14192,  14282,  14373,  14463,  14553,  14643,  14733,  14823,
     14912,  15002,  15091,  15180,  15269,  15358,  15447,  15535,  15624,  15712,  15800,
     15888,  15976,  16064,  16151,  16239,  16326,  16413,  16500,  16587,  16673,  16760,
     16846,  16932,  17018,  17104,  17190,  17275,  17361,  17446,  17531,  17616,  17700,
     17785,  17869,  17953,  18037,  18121,  18205,  18288,  18372,  18455,  18538,  18621,
     18703,  18786,  18868,  18950,  19032,  19114,  19195,  19277,  19358,  19439,  19520,
     19601,  19681,  19761,  19841,  19921,  20001,  20081,  20160,  20239,  20318,  20397,
     20475,  20554,  20632,  20710,  20788,  20865,  20943,  21020,  21097,  21174,  21251,
     21327,  21403,  21479,  21555,  21631,  21706,  21781,  21856,  21931,  22006,  22080,
     22154,  22228,  22302,  22375,  22449,  22522,  22595,  22668,  22740,  22812,  22884,
     22956,  23028,  23099,  23170,  23241,  23312,  23383,  23453,  23523,  23593,  23663,
     23732,  23801,  23870,  23939,  24008,  24076,  24144,  24212,  24279,  24347,  24414,
     24481,  24548,  24614,  24680,  24746,  24812,  24878,  24943,  25008,  25073,  25138,
     25202,  25266,  25330,  25394,  25457,  25520,  25583,  25646,  25708,  25771,  25833,
     25894,  25956,  26017,  26078,  26139,  26199,  26259,  26320,  26379,  26439,  26498,
     26557,  26616,  26674,  26733,  26791,  26848,  26906,  26963,  27020,  27077,  27133,
     27190,  27246,  27301,  27357,  27412,  27467,  27522,  27576,  27630,  27684,  27738,
     27791,  27844,  27897,  27950,  28002,  28054,  28106,  28158,  28209,  28260,  28311,
     28361,  28411,  28461,  28511,  28560,  28610,  28658,  28707,  28755,  28803,  28851,
     28899,  28946,  28993,  29040,  29086,  29132,  29178,  29224,  29269,  29314,  29359,
     29404,  29448,  29492,  29535,  29579,  29622,  29665,  29707,  29750,  29792,  29833,
     29875,  29916,  29957,  29997,  30038,  30078,  30118,  30157,  30196,  30235,  30274,
     30312,  30350,  30388,  30425,  30462,  30499,  30536,  30572,  30608,  30644,  30680,
     30715,  30750,  30784,  30819,  30853,  30886,  30920,  30953,  30986,  31018,  31050,
     31082,  31114,  31146,  31177,  31207,  31238,  31268,  31298,  31328,  31357,  31386,
     31415,  31443,  31471,  31499,  31527,  31554,  31581,  31608,  31634,  31660,  31686,
     31711,  31737,  31761,  31786,  31810,  31834,  31858,  31881,  31904,  31927,  31950,
     31972,  31994,  32015,  32037,  32058,  32078,  32099,  32119,  32138,  32158,  32177,
     32196,  32214,  32233,  32251,  32268,  32286,  32303,  32319,  32336,  32352,  32368,
     32383,  32398,  32413,  32428,  32442,  32456,  32470,  32483,  32496,  32509,  32522,
     32534,  32546,  32557,  32568,  32579,  32590,  32600,  32610,  32620,  32629,  32638,
     32647,  32656,  32664,  32672,  32679,  32686,  32693,  32700,  32706,  32712,  32718,
     32723,  32729,  32733,  32738,  32742,  32746,  32749,  32753,  32756,  32758,  32760,
     32762,  32764,  32766,  32767,  32767,  32767,  32767,  32767,  32767,  32767,  32766,
     32764,  32762,  32760,  32758,  32756,  32753,  32749,  32746,  32742,  32738,  32733,
     32729,  32723,  32718,  32712,  32706,  32700,  32693,  32686,  32679,  32672,  32664,
     32656,  32647,  32638,  32629,  32620,  32610,  32600,  32590,  32579,  32568,  32557,
     32546,  32534,  32522,  32509,  32496,  32483,  32470,  32456,  32442,  32428,  32413,
     32398,  32383,  32368,  32352,  32336,  32319,  32303,  32286,  32268,  32251,  32233,
     32214,  32196,  32177,  32158,  32138,  32119,  32099,  32078,  32058,  32037,  32015,
     31994,  31972,  31950,  31927,  31904,  31881,  31858,  31834,  31810,  31786,  31761,
     31737,  31711,  31686,  31660,  31634,  31608,  31581,  31554,  31527,  31499,  31471,
     31443,  31415,  31386,  31357,  31328,  31298,  31268,  31238,  31207,  31177,  31146,
     31114,  31082,  31050,  31018,  30986,  30953,  30920,  30886,  30853,  30819,  30784,
     30750,  30715,  30680,  30644,  30608,  30572,  30536,  30499,  30462,  30425,  30388,
     30350,  30312,  30274,  30235,  30196,  30157,  30118,  30078,  30038,  29997,  29957,
     29916,  29875,  29833,  29792,  29750,  29707,  29665,  29622,  29579,  29535,  29492,
     29448,  29404,  29359,  29314,  29269,  29224,  29178,  29132,  29086,  29040,  28993,
     28946,  28899,  28851,  28803,  28755,  28707,  28658,  28610,  28560,  28511,  28461,
     28411,  28361,  28311,  28260,  28209,  28158,  28106,  28054,  28002,  27950,  27897,
     27844,  27791,  27738,  27684,  27630,  27576,  27522,  27467,  27412,  27357,  27301,
     27246,  27190,  27133,  27077,  27020,  26963,  26906,  26848,  26791,  26733,  26674,
     26616,  26557,  26498,  26439,  26379,  26320,  26259,  26199,  26139,  26078,  26017,
     25956,  25894,  25833,  25771,  25708,  25646,  25583,  25520,  25457,  25394,  25330,
     25266,  25202,  25138,  25073,  25008,  24943,  24878,  24812,  24746,  24680,  24614,
     24548,  24481,  24414,  24347,  24279,  24212,  24144,  24076,  24008,  23939,  23870,
     23801,  23732,  23663,  23593,  23523,  23453,  23383,  23312,  23241,  23170,  23099,
     23028,  22956,  22884,  22812,  22740,  22668,  22595,  22522,  22449,  22375,  22302,
     22228,  22154,  22080,  22006,  21931,  21856,  21781,  21706,  21631,  21555,  21479,
     21403,  21327,  21251,  21174,  21097,  21020,  20943,  20865,  20788,  20710,  20632,
     20554,  20475,  20397,  20318,  20239,  20160,  20081,  20001,  19921,  19841,  19761,
     19681,  19601,  19520,  19439,  19358,  19277,  19195,  19114,  19032,  18950,  18868,
     18786,  18703,  18621,  18538,  18455,  18372,  18288,  18205,  18121,  18037,  17953,
     17869,  17785,  17700,  17616,  17531,  17446,  17361,  17275,  17190,  17104,  17018,
     16932,  16846,  16760,  16673,  16587,  16500,  16413,  16326,  16239,  16151,  16064,
     15976,  15888,  15800,  15712,  15624,  15535,  15447,  15358,  15269,  15180,  15091,
     15002,  14912,  14823,  14733,  14643,  14553,  14463,  14373,  14282,  14192,  14101,
     14010,  13919,  13828,  13737,  13646,  13554,  13463,  13371,  13279,  13187,  13095,
     13003,  12910,  12818,  12725,  12633,  12540,  12447,  12354,  12261,  12167,  12074,
     11980,  11887,  11793,  11699,  11605,  11511,  11417,  11323,  11228,  11134,  11039,
     10945,  10850,  10755,  10660,  10565,  10469,  10374,  10279,  10183,  10088,  9992,
     9896,   9800,   9704,   9608,   9512,   9416,   9319,   9223,   9127,   9030,   8933,
     8836,   8740,   8643,   8546,   8449,   8351,   8254,   8157,   8059,   7962,   7864,
     7767,   7669,   7571,   7473,   7376,   7278,   7180,   7081,   6983,   6885,   6787,
     6688,   6590,   6491,   6393,   6294,   6195,   6097,   5998,   5899,   5800,   5701,
     5602,   5503,   5404,   5305,   5205,   5106,   5007,   4907,   4808,   4709,   4609,
     4510,   4410,   4310,   4211,   4111,   4011,   3911,   3812,   3712,   3612,   3512,
     3412,   3312,   3212,   3112,   3012,   2912,   2811,   2711,   2611,   2511,   2411,
     2310,   2210,   2110,   2009,   1909,   1809,   1708,   1608,   1507,   1407,   1307,
     1206,   1106,   1005,   905,    804,    704,    603,    503,    402,    302,    201,
     101,    0,      -101,   -201,   -302,   -402,   -503,   -603,   -704,   -804,   -905,
     -1005,  -1106,  -1206,  -1307,  -1407,  -1507,  -1608,  -1708,  -1809,  -1909,  -2009,
     -2110,  -2210,  -2310,  -2411,  -2511,  -2611,  -2711,  -2811,  -2912,  -3012,  -3112,
     -3212,  -3312,  -3412,  -3512,  -3612,  -3712,  -3812,  -3911,  -4011,  -4111,  -4211,
     -4310,  -4410,  -4510,  -4609,  -4709,  -4808,  -4907,  -5007,  -5106,  -5205,  -5305,
     -5404,  -5503,  -5602,  -5701,  -5800,  -5899,  -5998,  -6097,  -6195,  -6294,  -6393,
     -6491,  -6590,  -6688,  -6787,  -6885,  -6983,  -7081,  -7180,  -7278,  -7376,  -7473,
     -7571,  -7669,  -7767,  -7864,  -7962,  -8059,  -8157,  -8254,  -8351,  -8449,  -8546,
     -8643,  -8740,  -8836,  -8933,  -9030,  -9127,  -9223,  -9319,  -9416,  -9512,  -9608,
     -9704,  -9800,  -9896,  -9992,  -10088, -10183, -10279, -10374, -10469, -10565, -10660,
     -10755, -10850, -10945, -11039, -11134, -11228, -11323, -11417, -11511, -11605, -11699,
     -11793, -11887, -11980, -12074, -12167, -12261, -12354, -12447, -12540, -12633, -12725,
     -12818, -12910, -13003, -13095, -13187, -13279, -13371, -13463, -13554, -13646, -13737,
     -13828, -13919, -14010, -14101, -14192, -14282, -14373, -14463, -14553, -14643, -14733,
     -14823, -14912, -15002, -15091, -15180, -15269, -15358, -15447, -15535, -15624, -15712,
     -15800, -15888, -15976, -16064, -16151, -16239, -16326, -16413, -16500, -16587, -16673,
     -16760, -16846, -16932, -17018, -17104, -17190, -17275, -17361, -17446, -17531, -17616,
     -17700, -17785, -17869, -17953, -18037, -18121, -18205, -18288, -18372, -18455, -18538,
     -18621, -18703, -18786, -18868, -18950, -19032, -19114, -19195, -19277, -19358, -19439,
     -19520, -19601, -19681, -19761, -19841, -19921, -20001, -20081, -20160, -20239, -20318,
     -20397, -20475, -20554, -20632, -20710, -20788, -20865, -20943, -21020, -21097, -21174,
     -21251, -21327, -21403, -21479, -21555, -21631, -21706, -21781, -21856, -21931, -22006,
     -22080, -22154, -22228, -22302, -22375, -22449, -22522, -22595, -22668, -22740, -22812,
     -22884, -22956, -23028, -23099, -23170, -23241, -23312, -23383, -23453, -23523, -23593,
     -23663, -23732, -23801, -23870, -23939, -24008, -24076, -24144, -24212, -24279, -24347,
     -24414, -24481, -24548, -24614, -24680, -24746, -24812, -24878, -24943, -25008, -25073,
     -25138, -25202, -25266, -25330, -25394, -25457, -25520, -25583, -25646, -25708, -25771,
     -25833, -25894, -25956, -26017, -26078, -26139, -26199, -26259, -26320, -26379, -26439,
     -26498, -26557, -26616, -26674, -26733, -26791, -26848, -26906, -26963, -27020, -27077,
     -27133, -27190, -27246, -27301, -27357, -27412, -27467, -27522, -27576, -27630, -27684,
     -27738, -27791, -27844, -27897, -27950, -28002, -28054, -28106, -28158, -28209, -28260,
     -28311, -28361, -28411, -28461, -28511, -28560, -28610, -28658, -28707, -28755, -28803,
     -28851, -28899, -28946, -28993, -29040, -29086, -29132, -29178, -29224, -29269, -29314,
     -29359, -29404, -29448, -29492, -29535, -29579, -29622, -29665, -29707, -29750, -29792,
     -29833, -29875, -29916, -29957, -29997, -30038, -30078, -30118, -30157, -30196, -30235,
     -30274, -30312, -30350, -30388, -30425, -30462, -30499, -30536, -30572, -30608, -30644,
     -30680, -30715, -30750, -30784, -30819, -30853, -30886, -30920, -30953, -30986, -31018,
     -31050, -31082, -31114, -31146, -31177, -31207, -31238, -31268, -31298, -31328, -31357,
     -31386, -31415, -31443, -31471, -31499, -31527, -31554, -31581, -31608, -31634, -31660,
     -31686, -31711, -31737, -31761, -31786, -31810, -31834, -31858, -31881, -31904, -31927,
     -31950, -31972, -31994, -32015, -32037, -32058, -32078, -32099, -32119, -32138, -32158,
     -32177, -32196, -32214, -32233, -32251, -32268, -32286, -32303, -32319, -32336, -32352,
     -32368, -32383, -32398, -32413, -32428, -32442, -32456, -32470, -32483, -32496, -32509,
     -32522, -32534, -32546, -32557, -32568, -32579, -32590, -32600, -32610, -32620, -32629,
     -32638, -32647, -32656, -32664, -32672, -32679, -32686, -32693, -32700, -32706, -32712,
     -32718, -32723, -32729, -32733, -32738, -32742, -32746, -32749, -32753, -32756, -32758,
     -32760, -32762, -32764, -32766, -32767, -32767, -32767, -32767, -32767, -32767, -32767,
     -32766, -32764, -32762, -32760, -32758, -32756, -32753, -32749, -32746, -32742, -32738,
     -32733, -32729, -32723, -32718, -32712, -32706, -32700, -32693, -32686, -32679, -32672,
     -32664, -32656, -32647, -32638, -32629, -32620, -32610, -32600, -32590, -32579, -32568,
     -32557, -32546, -32534, -32522, -32509, -32496, -32483, -32470, -32456, -32442, -32428,
     -32413, -32398, -32383, -32368, -32352, -32336, -32319, -32303, -32286, -32268, -32251,
     -32233, -32214, -32196, -32177, -32158, -32138, -32119, -32099, -32078, -32058, -32037,
     -32015, -31994, -31972, -31950, -31927, -31904, -31881, -31858, -31834, -31810, -31786,
     -31761, -31737, -31711, -31686, -31660, -31634, -31608, -31581, -31554, -31527, -31499,
     -31471, -31443, -31415, -31386, -31357, -31328, -31298, -31268, -31238, -31207, -31177,
     -31146, -31114, -31082, -31050, -31018, -30986, -30953, -30920, -30886, -30853, -30819,
     -30784, -30750, -30715, -30680, -30644, -30608, -30572, -30536, -30499, -30462, -30425,
     -30388, -30350, -30312, -30274, -30235, -30196, -30157, -30118, -30078, -30038, -29997,
     -29957, -29916, -29875, -29833, -29792, -29750, -29707, -29665, -29622, -29579, -29535,
     -29492, -29448, -29404, -29359, -29314, -29269, -29224, -29178, -29132, -29086, -29040,
     -28993, -28946, -28899, -28851, -28803, -28755, -28707, -28658, -28610, -28560, -28511,
     -28461, -28411, -28361, -28311, -28260, -28209, -28158, -28106, -28054, -28002, -27950,
     -27897, -27844, -27791, -27738, -27684, -27630, -27576, -27522, -27467, -27412, -27357,
     -27301, -27246, -27190, -27133, -27077, -27020, -26963, -26906, -26848, -26791, -26733,
     -26674, -26616, -26557, -26498, -26439, -26379, -26320, -26259, -26199, -26139, -26078,
     -26017, -25956, -25894, -25833, -25771, -25708, -25646, -25583, -25520, -25457, -25394,
     -25330, -25266, -25202, -25138, -25073, -25008, -24943, -24878, -24812, -24746, -24680,
     -24614, -24548, -24481, -24414, -24347, -24279, -24212, -24144, -24076, -24008, -23939,
     -23870, -23801, -23732, -23663, -23593, -23523, -23453, -23383, -23312, -23241, -23170,
     -23099, -23028, -22956, -22884, -22812, -22740, -22668, -22595, -22522, -22449, -22375,
     -22302, -22228, -22154, -22080, -22006, -21931, -21856, -21781, -21706, -21631, -21555,
     -21479, -21403, -21327, -21251, -21174, -21097, -21020, -20943, -20865, -20788, -20710,
     -20632, -20554, -20475, -20397, -20318, -20239, -20160, -20081, -20001, -19921, -19841,
     -19761, -19681, -19601, -19520, -19439, -19358, -19277, -19195, -19114, -19032, -18950,
     -18868, -18786, -18703, -18621, -18538, -18455, -18372, -18288, -18205, -18121, -18037,
     -17953, -17869, -17785, -17700, -17616, -17531, -17446, -17361, -17275, -17190, -17104,
     -17018, -16932, -16846, -16760, -16673, -16587, -16500, -16413, -16326, -16239, -16151,
     -16064, -15976, -15888, -15800, -15712, -15624, -15535, -15447, -15358, -15269, -15180,
     -15091, -15002, -14912, -14823, -14733, -14643, -14553, -14463, -14373, -14282, -14192,
     -14101, -14010, -13919, -13828, -13737, -13646, -13554, -13463, -13371, -13279, -13187,
     -13095, -13003, -12910, -12818, -12725, -12633, -12540, -12447, -12354, -12261, -12167,
     -12074, -11980, -11887, -11793, -11699, -11605, -11511, -11417, -11323, -11228, -11134,
     -11039, -10945, -10850, -10755, -10660, -10565, -10469, -10374, -10279, -10183, -10088,
     -9992,  -9896,  -9800,  -9704,  -9608,  -9512,  -9416,  -9319,  -9223,  -9127,  -9030,
     -8933,  -8836,  -8740,  -8643,  -8546,  -8449,  -8351,  -8254,  -8157,  -8059,  -7962,
     -7864,  -7767,  -7669,  -7571,  -7473,  -7376,  -7278,  -7180,  -7081,  -6983,  -6885,
     -6787,  -6688,  -6590,  -6491,  -6393,  -6294,  -6195,  -6097,  -5998,  -5899,  -5800,
     -5701,  -5602,  -5503,  -5404,  -5305,  -5205,  -5106,  -5007,  -4907,  -4808,  -4709,
     -4609,  -4510,  -4410,  -4310,  -4211,  -4111,  -4011,  -3911,  -3812,  -3712,  -3612,
     -3512,  -3412,  -3312,  -3212,  -3112,  -3012,  -2912,  -2811,  -2711,  -2611,  -2511,
     -2411,  -2310,  -2210,  -2110,  -2009,  -1909,  -1809,  -1708,  -1608,  -1507,  -1407,
     -1307,  -1206,  -1106,  -1005,  -905,   -804,   -704,   -603,   -503,   -402,   -302,
     -201,   -101},

    {32767,  32767,  32767,  32767,  32766,  32764,  32762,  32760,  32758,  32756,  32753,
     32749,  32746,  32742,  32738,  32733,  32729,  32723,  32718,  32712,  32706,  32700,
     32693,  32686,  32679,  32672,  32664,  32656,  32647,  32638,  32629,  32620,  32610,
     32600,  32590,  32579,  32568,  32557,  32546,  32534,  32522,  32509,  32496,  32483,
     32470,  32456,  32442,  32428,  32413,  32398,  32383,  32368,  32352,  32336,  32319,
     32303,  32286,  32268,  32251,  32233,  32214,  32196,  32177,  32158,  32138,  32119,
     32099,  32078,  32058,  32037,  32015,  31994,  31972,  31950,  31927,  31904,  31881,
     31858,  31834,  31810,  31786,  31761,  31737,  31711,  31686,  31660,  31634,  31608,
     31581,  31554,  31527,  31499,  31471,  31443,  31415,  31386,  31357,  31328,  31298,
     31268,  31238,  31207,  31177,  31146,  31114,  31082,  31050,  31018,  30986,  30953,
     30920,  30886,  30853,  30819,  30784,  30750,  30715,  30680,  30644,  30608,  30572,
     30536,  30499,  30462,  30425,  30388,  30350,  30312,  30274,  30235,  30196,  30157,
     30118,  30078,  30038,  29997,  29957,  29916,  29875,  29833,  29792,  29750,  29707,
     29665,  29622,  29579,  29535,  29492,  29448,  29404,  29359,  29314,  29269,  29224,
     29178,  29132,  29086,  29040,  28993,  28946,  28899,  28851,  28803,  28755,  28707,
     28658,  28610,  28560,  28511,  28461,  28411,  28361,  28311,  28260,  28209,  28158,
     28106,  28054,  28002,  27950,  27897,  27844,  27791,  27738,  27684,  27630,  27576,
     27522,  27467,  27412,  27357,  27301,  27246,  27190,  27133,  27077,  27020,  26963,
     26906,  26848,  26791,  26733,  26674,  26616,  26557,  26498,  26439,  26379,  26320,
     26259,  26199,  26139,  26078,  26017,  25956,  25894,  25833,  25771,  25708,  25646,
     25583,  25520,  25457,  25394,  25330,  25266,  25202,  25138,  25073,  25008,  24943,
     24878,  24812,  24746,  24680,  24614,  24548,  24481,  24414,  24347,  24279,  24212,
     24144,  24076,  24008,  23939,  23870,  23801,  23732,  23663,  23593,  23523,  23453,
     23383,  23312,  23241,  23170,  23099,  23028,  22956,  22884,  22812,  22740,  22668,
     22595,  22522,  22449,  22375,  22302,  22228,  22154,  22080,  22006,  21931,  21856,
     21781,  21706,  21631,  21555,  21479,  21403,  21327,  21251,  21174,  21097,  21020,
     20943,  20865,  20788,  20710,  20632,  20554,  20475,  20397,  20318,  20239,  20160,
     20081,  20001,  19921,  19841,  19761,  19681,  19601,  19520,  19439,  19358,  19277,
     19195,  19114,  19032,  18950,  18868,  18786,  18703,  18621,  18538,  18455,  18372,
     18288,  18205,  18121,  18037,  17953,  17869,  17785,  17700,  17616,  17531,  17446,
     17361,  17275,  17190,  17104,  17018,  16932,  16846,  16760,  16673,  16587,  16500,
     16413,  16326,  16239,  16151,  16064,  15976,  15888,  15800,  15712,  15624,  15535,
     15447,  15358,  15269,  15180,  15091,  15002,  14912,  14823,  14733,  14643,  14553,
     14463,  14373,  14282,  14192,  14101,  14010,  13919,  13828,  13737,  13646,  13554,
     13463,  13371,  13279,  13187,  13095,  13003,  12910,  12818,  12725,  12633,  12540,
     12447,  12354,  12261,  12167,  12074,  11980,  11887,  11793,  11699,  11605,  11511,
     11417,  11323,  11228,  11134,  11039,  10945,  10850,  10755,  10660,  10565,  10469,
     10374,  10279,  10183,  10088,  9992,   9896,   9800,   9704,   9608,   9512,   9416,
     9319,   9223,   9127,   9030,   8933,   8836,   8740,   8643,   8546,   8449,   8351,
     8254,   8157,   8059,   7962,   7864,   7767,   7669,   7571,   7473,   7376,   7278,
     7180,   7081,   6983,   6885,   6787,   6688,   6590,   6491,   6393,   6294,   6195,
     6097,   5998,   5899,   5800,   5701,   5602,   5503,   5404,   5305,   5205,   5106,
     5007,   4907,   4808,   4709,   4609,   4510,   4410,   4310,   4211,   4111,   4011,
     3911,   3812,   3712,   3612,   3512,   3412,   3312,   3212,   3112,   3012,   2912,
     2811,   2711,   2611,   2511,   2411,   2310,   2210,   2110,   2009,   1909,   1809,
     1708,   1608,   1507,   1407,   1307,   1206,   1106,   1005,   905,    804,    704,
     603,    503,    402,    302,    201,    101,    0,      -101,   -201,   -302,   -402,
     -503,   -603,   -704,   -804,   -905,   -1005,  -1106,  -1206,  -1307,  -1407,  -1507,
     -1608,  -1708,  -1809,  -1909,  -2009,  -2110,  -2210,  -2310,  -2411,  -2511,  -2611,
     -2711,  -2811,  -2912,  -3012,  -3112,  -3212,  -3312,  -3412,  -3512,  -3612,  -3712,
     -3812,  -3911,  -4011,  -4111,  -4211,  -4310,  -4410,  -4510,  -4609,  -4709,  -4808,
     -4907,  -5007,  -5106,  -5205,  -5305,  -5404,  -5503,  -5602,  -5701,  -5800,  -5899,
     -5998,  -6097,  -6195,  -6294,  -6393,  -6491,  -6590,  -6688,  -6787,  -6885,  -6983,
     -7081,  -7180,  -7278,  -7376,  -7473,  -7571,  -7669,  -7767,  -7864,  -7962,  -8059,
     -8157,  -8254,  -8351,  -8449,  -8546,  -8643,  -8740,  -8836,  -8933,  -9030,  -9127,
     -9223,  -9319,  -9416,  -9512,  -9608,  -9704,  -9800,  -9896,  -9992,  -10088, -10183,
     -10279, -10374, -10469, -10565, -10660, -10755, -10850, -10945, -11039, -11134, -11228,
     -11323, -11417, -11511, -11605, -11699, -11793, -11887, -11980, -12074, -12167, -12261,
     -12354, -12447, -12540, -12633, -12725, -12818, -12910, -13003, -13095, -13187, -13279,
     -13371, -13463, -13554, -13646, -13737, -13828, -13919, -14010, -14101, -14192, -14282,
     -14373, -14463, -14553, -14643, -14733, -14823, -14912, -15002, -15091, -15180, -15269,
     -15358, -15447, -15535, -15624, -15712, -15800, -15888, -15976, -16064, -16151, -16239,
     -16326, -16413, -16500, -16587, -16673, -16760, -16846, -16932, -17018, -17104, -17190,
     -17275, -17361, -17446, -17531, -17616, -17700, -17785, -17869, -17953, -18037, -18121,
     -18205, -18288, -18372, -18455, -18538, -18621, -18703, -18786, -18868, -18950, -19032,
     -19114, -19195, -19277, -19358, -19439, -19520, -19601, -19681, -19761, -19841, -19921,
     -20001, -20081, -20160, -20239, -20318, -20397, -20475, -20554, -20632, -20710, -20788,
     -20865, -20943, -21020, -21097, -21174, -21251, -21327, -21403, -21479, -21555, -21631,
     -21706, -21781, -21856, -21931, -22006, -22080, -22154, -22228, -22302, -22375, -22449,
     -22522, -22595, -22668, -22740, -22812, -22884, -22956, -23028, -23099, -23170, -23241,
     -23312, -23383, -23453, -23523, -23593, -23663, -23732, -23801, -23870, -23939, -24008,
     -24076, -24144, -24212, -24279, -24347, -24414, -24481, -24548, -24614, -24680, -24746,
     -24812, -24878, -24943, -25008, -25073, -25138, -25202, -25266, -25330, -25394, -25457,
     -25520, -25583, -25646, -25708, -25771, -25833, -25894, -25956, -26017, -26078, -26139,
     -26199, -26259, -26320, -26379, -26439, -26498, -26557, -26616, -26674, -26733, -26791,
     -26848, -26906, -26963, -27020, -27077, -27133, -27190, -27246, -27301, -27357, -27412,
     -27467, -27522, -27576, -27630, -27684, -27738, -27791, -27844, -27897, -27950, -28002,
     -28054, -28106, -28158, -28209, -28260, -28311, -28361, -28411, -28461, -28511, -28560,
     -28610, -28658, -28707, -28755, -28803, -28851, -28899, -28946, -28993, -29040, -29086,
     -29132, -29178, -29224, -29269, -29314, -29359, -29404, -29448, -29492, -29535, -29579,
     -29622, -29665, -29707, -29750, -29792, -29833, -29875, -29916, -29957, -29997, -30038,
     -30078, -30118, -30157, -30196, -30235, -30274, -30312, -30350, -30388, -30425, -30462,
     -30499, -30536, -30572, -30608, -30644, -30680, -30715, -30750, -30784, -30819, -30853,
     -30886, -30920, -30953, -30986, -31018, -31050, -31082, -31114, -31146, -31177, -31207,
     -31238, -31268, -31298, -31328, -31357, -31386, -31415, -31443, -31471, -31499, -31527,
     -31554, -31581, -31608, -31634, -31660, -31686, -31711, -31737, -31761, -31786, -31810,
     -31834, -31858, -31881, -31904, -31927, -31950, -31972, -31994, -32015, -32037, -32058,
     -32078, -32099, -32119, -32138, -32158, -32177, -32196, -32214, -32233, -32251, -32268,
     -32286, -32303, -32319, -32336, -32352, -32368, -32383, -32398, -32413, -32428, -32442,
     -32456, -32470, -32483, -32496, -32509, -32522, -32534, -32546, -32557, -32568, -32579,
     -32590, -32600, -32610, -32620, -32629, -32638, -32647, -32656, -32664, -32672, -32679,
     -32686, -32693, -32700, -32706, -32712, -32718, -32723, -32729, -32733, -32738, -32742,
     -32746, -32749, -32753, -32756, -32758, -32760, -32762, -32764, -32766, -32767, -32767,
     -32767, -32767, -32767, -32767, -32767, -32766, -32764, -32762, -32760, -32758, -32756,
     -32753, -32749, -32746, -32742, -32738, -32733, -32729, -32723, -32718, -32712, -32706,
     -32700, -32693, -32686, -32679, -32672, -32664, -32656, -32647, -32638, -32629, -32620,
     -32610, -32600, -32590, -32579, -32568, -32557, -32546, -32534, -32522, -32509, -32496,
     -32483, -32470, -32456, -32442, -32428, -32413, -32398, -32383, -32368, -32352, -32336,
     -32319, -32303, -32286, -32268, -32251, -32233, -32214, -32196, -32177, -32158, -32138,
     -32119, -32099, -32078, -32058, -32037, -32015, -31994, -31972, -31950, -31927, -31904,
     -31881, -31858, -31834, -31810, -31786, -31761, -31737, -31711, -31686, -31660, -31634,
     -31608, -31581, -31554, -31527, -31499, -31471, -31443, -31415, -31386, -31357, -31328,
     -31298, -31268, -31238, -31207, -31177, -31146, -31114, -31082, -31050, -31018, -30986,
     -30953, -30920, -30886, -30853, -30819, -30784, -30750, -30715, -30680, -30644, -30608,
     -30572, -30536, -30499, -30462, -30425, -30388, -30350, -30312, -30274, -30235, -30196,
     -30157, -30118, -30078, -30038, -29997, -29957, -29916, -29875, -29833, -29792, -29750,
     -29707, -29665, -29622, -29579, -29535, -29492, -29448, -29404, -29359, -29314, -29269,
     -29224, -29178, -29132, -29086, -29040, -28993, -28946, -28899, -28851, -28803, -28755,
     -28707, -28658, -28610, -28560, -28511, -28461, -28411, -28361, -28311, -28260, -28209,
     -28158, -28106, -28054, -28002, -27950, -27897, -27844, -27791, -27738, -27684, -27630,
     -27576, -27522, -27467, -27412, -27357, -27301, -27246, -27190, -27133, -27077, -27020,
     -26963, -26906, -26848, -26791, -26733, -26674, -26616, -26557, -26498, -26439, -26379,
     -26320, -26259, -26199, -26139, -26078, -26017, -25956, -25894, -25833, -25771, -25708,
     -25646, -25583, -25520, -25457, -25394, -25330, -25266, -25202, -25138, -25073, -25008,
     -24943, -24878, -24812, -24746, -24680, -24614, -24548, -24481, -24414, -24347, -24279,
     -24212, -24144, -24076, -24008, -23939, -23870, -23801, -23732, -23663, -23593, -23523,
     -23453, -23383, -23312, -23241, -23170, -23099, -23028, -22956, -22884, -22812, -22740,
     -22668, -22595, -22522, -22449, -22375, -22302, -22228, -22154, -22080, -22006, -21931,
     -21856, -21781, -21706, -21631, -21555, -21479, -21403, -21327, -21251, -21174, -21097,
     -21020, -20943, -20865, -20788, -20710, -20632, -20554, -20475, -20397, -20318, -20239,
     -20160, -20081, -20001, -19921, -19841, -19761, -19681, -19601, -19520, -19439, -19358,
     -19277, -19195, -19114, -19032, -18950, -18868, -18786, -18703, -18621, -18538, -18455,
     -18372, -18288, -18205, -18121, -18037, -17953, -17869, -17785, -17700, -17616, -17531,
     -17446, -17361, -17275, -17190, -17104, -17018, -16932, -16846, -16760, -16673, -16587,
     -16500, -16413, -16326, -16239, -16151, -16064, -15976, -15888, -15800, -15712, -15624,
     -15535, -15447, -15358, -15269, -15180, -15091, -15002, -14912, -14823, -14733, -14643,
     -14553, -14463, -14373, -14282, -14192, -14101, -14010, -13919, -13828, -13737, -13646,
     -13554, -13463, -13371, -13279, -13187, -13095, -13003, -12910, -12818, -12725, -12633,
     -12540, -12447, -12354, -12261, -12167, -12074, -11980, -11887, -11793, -11699, -11605,
     -11511, -11417, -11323, -11228, -11134, -11039, -10945, -10850, -10755, -10660, -10565,
     -10469, -10374, -10279, -10183, -10088, -9992,  -9896,  -9800,  -9704,  -9608,  -9512,
     -9416,  -9319,  -9223,  -9127,  -9030,  -8933,  -8836,  -8740,  -8643,  -8546,  -8449,
     -8351,  -8254,  -8157,  -8059,  -7962,  -7864,  -7767,  -7669,  -7571,  -7473,  -7376,
     -7278,  -7180,  -7081,  -6983,  -6885,  -6787,  -6688,  -6590,  -6491,  -6393,  -6294,
     -6195,  -6097,  -5998,  -5899,  -5800,  -5701,  -5602,  -5503,  -5404,  -5305,  -5205,
     -5106,  -5007,  -4907,  -4808,  -4709,  -4609,  -4510,  -4410,  -4310,  -4211,  -4111,
     -4011,  -3911,  -3812,  -3712,  -3612,  -3512,  -3412,  -3312,  -3212,  -3112,  -3012,
     -2912,  -2811,  -2711,  -2611,  -2511,  -2411,  -2310,  -2210,  -2110,  -2009,  -1909,
     -1809,  -1708,  -1608,  -1507,  -1407,  -1307,  -1206,  -1106,  -1005,  -905,   -804,
     -704,   -603,   -503,   -402,   -302,   -201,   -101,   0,      101,    201,    302,
     402,    503,    603,    704,    804,    905,    1005,   1106,   1206,   1307,   1407,
     1507,   1608,   1708,   1809,   1909,   2009,   2110,   2210,   2310,   2411,   2511,
     2611,   2711,   2811,   2912,   3012,   3112,   3212,   3312,   3412,   3512,   3612,
     3712,   3812,   3911,   4011,   4111,   4211,   4310,   4410,   4510,   4609,   4709,
     4808,   4907,   5007,   5106,   5205,   5305,   5404,   5503,   5602,   5701,   5800,
     5899,   5998,   6097,   6195,   6294,   6393,   6491,   6590,   6688,   6787,   6885,
     6983,   7081,   7180,   7278,   7376,   7473,   7571,   7669,   7767,   7864,   7962,
     8059,   8157,   8254,   8351,   8449,   8546,   8643,   8740,   8836,   8933,   9030,
     9127,   9223,   9319,   9416,   9512,   9608,   9704,   9800,   9896,   9992,   10088,
     10183,  10279,  10374,  10469,  10565,  10660,  10755,  10850,  10945,  11039,  11134,
     11228,  11323,  11417,  11511,  11605,  11699,  11793,  11887,  11980,  12074,  12167,
     12261,  12354,  12447,  12540,  12633,  12725,  12818,  12910,  13003,  13095,  13187,
     13279,  13371,  13463,  13554,  13646,  13737,  13828,  13919,  14010,  14101,  14192,
     14282,  14373,  14463,  14553,  14643,  14733,  14823,  14912,  15002,  15091,  15180,
     15269,  15358,  15447,  15535,  15624,  15712,  15800,  15888,  15976,  16064,  16151,
     16239,  16326,  16413,  16500,  16587,  16673,  16760,  16846,  16932,  17018,  17104,
     17190,  17275,  17361,  17446,  17531,  17616,  17700,  17785,  17869,  17953,  18037,
     18121,  18205,  18288,  18372,  18455,  18538,  18621,  18703,  18786,  18868,  18950,
     19032,  19114,  19195,  19277,  19358,  19439,  19520,  19601,  19681,  19761,  19841,
     19921,  20001,  20081,  20160,  20239,  20318,  20397,  20475,  20554,  20632,  20710,
     20788,  20865,  20943,  21020,  21097,  21174,  21251,  21327,  21403,  21479,  21555,
     21631,  21706,  21781,  21856,  21931,  22006,  22080,  22154,  22228,  22302,  22375,
     22449,  22522,  22595,  22668,  22740,  22812,  22884,  22956,  23028,  23099,  23170,
     23241,  23312,  23383,  23453,  23523,  23593,  23663,  23732,  23801,  23870,  23939,
     24008,  24076,  24144,  24212,  24279,  24347,  24414,  24481,  24548,  24614,  24680,
     24746,  24812,  24878,  24943,  25008,  25073,  25138,  25202,  25266,  25330,  25394,
     25457,  25520,  25583,  25646,  25708,  25771,  25833,  25894,  25956,  26017,  26078,
     26139,  26199,  26259,  26320,  26379,  26439,  26498,  26557,  26616,  26674,  26733,
     26791,  26848,  26906,  26963,  27020,  27077,  27133,  27190,  27246,  27301,  27357,
     27412,  27467,  27522,  27576,  27630,  27684,  27738,  27791,  27844,  27897,  27950,
     28002,  28054,  28106,  28158,  28209,  28260,  28311,  28361,  28411,  28461,  28511,
     28560,  28610,  28658,  28707,  28755,  28803,  28851,  28899,  28946,  28993,  29040,
     29086,  29132,  29178,  29224,  29269,  29314,  29359,  29404,  29448,  29492,  29535,
     29579,  29622,  29665,  29707,  29750,  29792,  29833,  29875,  29916,  29957,  29997,
     30038,  30078,  30118,  30157,  30196,  30235,  30274,  30312,  30350,  30388,  30425,
     30462,  30499,  30536,  30572,  30608,  30644,  30680,  30715,  30750,  30784,  30819,
     30853,  30886,  30920,  30953,  30986,  31018,  31050,  31082,  31114,  31146,  31177,
     31207,  31238,  31268,  31298,  31328,  31357,  31386,  31415,  31443,  31471,  31499,
     31527,  31554,  31581,  31608,  31634,  31660,  31686,  31711,  31737,  31761,  31786,
     31810,  31834,  31858,  31881,  31904,  31927,  31950,  31972,  31994,  32015,  32037,
     32058,  32078,  32099,  32119,  32138,  32158,  32177,  32196,  32214,  32233,  32251,
     32268,  32286,  32303,  32319,  32336,  32352,  32368,  32383,  32398,  32413,  32428,
     32442,  32456,  32470,  32483,  32496,  32509,  32522,  32534,  32546,  32557,  32568,
     32579,  32590,  32600,  32610,  32620,  32629,  32638,  32647,  32656,  32664,  32672,
     32679,  32686,  32693,  32700,  32706,  32712,  32718,  32723,  32729,  32733,  32738,
     32742,  32746,  32749,  32753,  32756,  32758,  32760,  32762,  32764,  32766,  32767,
     32767,  32767},

}; /* END OF ia_mps_dec_hybrid_tables_struct */

const ia_mps_dec_mdct2qmf_tables_struct ixheaacd_mps_dec_mdct2qmf_tables = {
    /* cos_table_long_32_00[32] */
    {-22594, -24811, 20160,  26791,  -17530, -28510, 14733,  29957,  -11792, -31113, 8740,
     31972,  -5601,  -32521, 2411,   32758,  804,    -32678, -4010,  32286,  7180,   -31580,
     -10278, 30572,  13279,  -29268, -16150, 27684,  18868,  -25832, -21402, 23732},
    /* cos_table_long_32_01[32] */
    {21403,  27684,  -13278, -31580, 4011,  32758,  5602,  -31113, -14732, 26791,  22595,
     -20159, -28510, 11793,  31972,  -2410, -32678, -7179, 30572,  16151,  -25832, -23731,
     18868,  29269,  -10278, -32285, 804,   32522,  8740,  -29956, -17530, 24812},
    /* cos_table_long_32_02[32] */
    {-20159, -29956, 5602,   32679,  10279,  -27683, -23731, 16151,  31581,  -803,   -31971,
     -14732, 24812,  26791,  -11792, -32521, -4010,  30572,  18868,  -21402, -29268, 7179,
     32758,  8740,   -28510, -22594, 17531,  31114,  -2410,  -32285, -13278, 25833},
    /* cos_table_long_32_03[32] */
    {18868, 31581,  2411,   -29956, -22594, 14733, 32522,  7180,   -27683, -25832, 10279,
     32758, 11793,  -24811, -28510, 5602,   32286, 16151,  -21402, -30571, 804,    31114,
     20160, -17530, -31971, -4010,  29269,  23732, -13278, -32678, -8739,  26791},
    /* cos_table_long_32_04[32] */
    {-17530, -32521, -10278, 23732, 30572, 2411,  -28510, -26790, 5602,  31581, 21403,
     -13278, -32757, -14732, 20160, 31972, 7180,  -25832, -29268, 804,   29957, 24812,
     -8739,  -32285, -18867, 16151, 32679, 11793, -22594, -31113, -4010, 27684},
    /* cos_table_long_32_05[32] */
    {16151,  32758,  17531, -14732, -32678, -18867, 13279,  32522,  20160, -11792, -32285,
     -21402, 10279,  31972, 22595,  -8739,  -31580, -23731, 7179,   31114, 24812,  -5601,
     -30571, -25832, 4011,  29957,  26791,  -2410,  -29268, -27683, 804,   28511},
    /* cos_table_long_32_06[32] */
    {-14732, -32285, -23731, 4011,   28511,  29957,  7180,   -21402, -32678, -17530, 11793,
     31581,  25833,  -803,   -26790, -31113, -10278, 18868,  32758,  20160,  -8739,  -30571,
     -27683, -2410,  24812,  31972,  13279,  -16150, -32521, -22594, 5602,   29269},
    /* cos_table_long_32_07[32] */
    {13279, 31114,  28511,  7180,   -18867, -32521, -24811, -803,   23732,  32679,  20160,
     -5601, -27683, -31580, -14732, 11793,  30572,  29269,  8740,   -17530, -32285, -25832,
     -2410, 22595,  32758,  21403,  -4010,  -26790, -31971, -16150, 10279,  29957},
    /* cos_table_long_32_08[32] */
    {-11792, -29268, -31580, -17530, 5602,   25833,  32679,  22595,  804,    -21402, -32521,
     -26790, -7179,  16151,  31114,  29957,  13279,  -10278, -28510, -31971, -18867, 4011,
     24812,  32758,  23732,  2411,   -20159, -32285, -27683, -8739,  14733,  30572},
    /* cos_table_long_32_09[32] */
    {10279, 26791, 32758, 25833,  8740,   -11792, -27683, -32678, -24811, -7179, 13279,
     28511, 32522, 23732, 5602,   -14732, -29268, -32285, -22594, -4010,  16151, 29957,
     31972, 21403, 2411,  -17530, -30571, -31580, -20159, -803,   18868,  31114},
    /* cos_table_long_32_10[32] */
    {-8739, -23731, -31971, -31113, -21402, -5601,  11793,  25833, 32522, 29957, 18868,
     2411,  -14732, -27683, -32757, -28510, -16150, 804,    17531, 29269, 32679, 26791,
     13279, -4010,  -20159, -30571, -32285, -24811, -10278, 7180,  22595, 31581},
    /* cos_table_long_32_11[32] */
    {7179,   20160,  29269,  32758,  29957,  21403,  8740,  -5601, -18867, -28510, -32678,
     -30571, -22594, -10278, 4011,   17531,  27684,  32522, 31114, 23732,  11793,  -2410,
     -16150, -26790, -32285, -31580, -24811, -13278, 804,   14733, 25833,  31972},
    /* cos_table_long_32_12[32] */
    {-5601,  -16150, -24811, -30571, -32757, -31113, -25832, -17530, -7179,  4011,   14733,
     23732,  29957,  32679,  31581,  26791,  18868,  8740,   -2410,  -13278, -22594, -29268,
     -32521, -31971, -27683, -20159, -10278, 804,    11793,  21403,  28511,  32286},
    /* cos_table_long_32_13[32] */
    {4011,   11793,  18868, 24812,  29269,  31972,  32758,  31581,  28511,  23732,  17531,
     10279,  2411,   -5601, -13278, -20159, -25832, -29956, -32285, -32678, -31113, -27683,
     -22594, -16150, -8739, -803,   7180,   14733,  21403,  26791,  30572,  32522},
    /* cos_table_long_32_14[32] */
    {-2410,  -7178,  -11792, -16150, -20159, -23731, -26790, -29268, -31113, -32285, -32757,
     -32521, -31580, -29956, -27683, -24811, -21402, -17530, -13278, -8739,  -4010,  804,
     5602,   10279,  14733,  18868,  22595,  25833,  28511,  30572,  31972,  32679},
    /* cos_table_long_32_15[32] */
    {804,   2411,  4011,  5602,  7180,  8740,  10279, 11793, 13279, 14733, 16151,
     17531, 18868, 20160, 21403, 22595, 23732, 24812, 25833, 26791, 27684, 28511,
     29269, 29957, 30572, 31114, 31581, 31972, 32286, 32522, 32679, 32758},
    /* cos_table_long_32_16[32] */
    {23732,  21403, -25831, -18867, 27684,  16151, -29268, -13278, 30572,  10279, -31580,
     -7179,  32286, 4011,   -32678, -803,   32758, -2410,  -32521, 5602,   31972, -8739,
     -31113, 11793, 29957,  -14732, -28510, 17531, 26791,  -20159, -24811, 22595},
    /* cos_table_long_32_17[32] */
    {-24811, -17530, 29957, 8740, -32521, 804,  32286, -10278, -29268, 18868, 23732,
     -25832, -16150, 30572, 7180, -32678, 2411, 31972, -11792, -28510, 20160, 22595,
     -26790, -14732, 31114, 5602, -32757, 4011, 31581, -13278, -27683, 21403},
    /* cos_table_long_32_18[32] */
    {25832, 13279,  -32285, 2411,  31114,  -17530, -22594, 28511, 8740,   -32757, 7180,
     29269, -21402, -18867, 30572, 4011,   -32521, 11793,  26791, -24811, -14732, 31972,
     -803,  -31580, 16151,  23732, -27683, -10278, 32679,  -5601, -29956, 20160},
    /* cos_table_long_32_19[32] */
    {-26790, -8739,  32679,  -13278, -23731, 29269,  4011,   -31971, 17531,  20160,  -31113,
     804,    30572,  -21402, -16150, 32286,  -5601,  -28510, 24812,  11793,  -32757, 10279,
     25833,  -27683, -7179,  32522,  -14732, -22594, 29957,  2411,   -31580, 18868},
    /* cos_table_long_32_20[32] */
    {27684,  4011,  -31113, 22595,  11793, -32678, 16151,  18868,  -32285, 8740,   24812,
     -29956, 804,   29269,  -25832, -7179, 31972,  -20159, -14732, 32758,  -13278, -21402,
     31581,  -5601, -26790, 28511,  2411,  -30571, 23732,  10279,  -32521, 17531},
    /* cos_table_long_32_21[32] */
    {-28510, 804,    27684,  -29268, 2411,   26791,  -29956, 4011,   25833,  -30571, 5602,
     24812,  -31113, 7180,   23732,  -31580, 8740,   22595,  -31971, 10279,  21403,  -32285,
     11793,  20160,  -32521, 13279,  18868,  -32678, 14733,  17531,  -32757, 16151},
    /* cos_table_long_32_22[32] */
    {29269,  -5601, -22594, 32522, -16150, -13278, 31972, -24811, -2410,  27684, -30571,
     8740,   20160, -32757, 18868, 10279,  -31113, 26791, -803,   -25832, 31581, -11792,
     -17530, 32679, -21402, -7179, 29957,  -28510, 4011,  23732,  -32285, 14733},
    /* cos_table_long_32_23[32] */
    {-29956, 10279, 16151, -31971, 26791, -4010,  -21402, 32758, -22594, -2410, 25833,
     -32285, 17531, 8740,  -29268, 30572, -11792, -14732, 31581, -27683, 5602,  20160,
     -32678, 23732, 804,   -24811, 32522, -18867, -7179,  28511, -31113, 13279},
    /* cos_table_long_32_24[32] */
    {30572,  -14732, -8739, 27684,  -32285, 20160, 2411,   -23731, 32758,  -24811, 4011,
     18868,  -31971, 28511, -10278, -13278, 29957, -31113, 16151,  7180,   -26790, 32522,
     -21402, -803,   22595, -32678, 25833,  -5601, -17530, 31581,  -29268, 11793},
    /* cos_table_long_32_25[32] */
    {-31113, 18868,  804,    -20159, 31581,  -30571, 17531,  2411,   -21402, 31972,  -29956,
     16151,  4011,   -22594, 32286,  -29268, 14733,  5602,   -23731, 32522,  -28510, 13279,
     7180,   -24811, 32679,  -27683, 11793,  8740,   -25832, 32758,  -26790, 10279},
    /* cos_table_long_32_26[32] */
    {31581,  -22594, 7179,   10279,  -24811, 32286,  -30571, 20160,  -4010,  -13278, 26791,
     -32678, 29269,  -17530, 804,    16151,  -28510, 32758,  -27683, 14733,  2411,   -18867,
     29957,  -32521, 25833,  -11792, -5601,  21403,  -31113, 31972,  -23731, 8740},
    /* cos_table_long_32_27[32] */
    {-31971, 25832,  -14732, 804,    13279,  -24811, 31581,  -32285, 26791,  -16150, 2411,
     11793,  -23731, 31114,  -32521, 27684,  -17530, 4011,   10279,  -22594, 30572,  -32678,
     28511,  -18867, 5602,   8740,   -21402, 29957,  -32757, 29269,  -20159, 7180},
    /* cos_table_long_32_28[32] */
    {32286, -28510, 21403,  -11792, 804,    10279, -20159, 27684, -31971, 32522, -29268,
     22595, -13278, 2411,   8740,   -18867, 26791, -31580, 32679, -29956, 23732, -14732,
     4011,  7180,   -17530, 25833,  -31113, 32758, -30571, 24812, -16150, 5602},
    /* cos_table_long_32_29[32] */
    {-32521, 30572, -26790, 21403, -14732, 7179,  804,    -8739, 16151,  -22594, 27684,
     -31113, 32679, -32285, 29957, -25831, 20160, -13278, 5602,  2411,   -10278, 17531,
     -23731, 28511, -31580, 32758, -31971, 29269, -24811, 18868, -11792, 4011},
    /* cos_table_long_32_30[32] */
    {32679,  -31971, 30572,  -28510, 25832,  -22594, 18868,  -14732, 10279, -5601,  804,
     4011,   -8739,  13279,  -17530, 21403,  -24811, 27684,  -29956, 31581, -32521, 32758,
     -32285, 31114,  -29268, 26791,  -23731, 20160,  -16150, 11793,  -7178, 2411},
    /* cos_table_long_32_31[32] */
    {-32757, 32679,  -32521, 32286,  -31971, 31581,  -31113, 30572,  -29956, 29269,  -28510,
     27684,  -26790, 25832,  -24811, 23732,  -22594, 21403,  -20159, 18868,  -17530, 16151,
     -14732, 13279,  -11792, 10279,  -8739,  7179,   -5601,  4011,   -2410,  804},

    /* cos_table_long_30_00[30] */
    {22556, 24917,  -19947, -27004, 17121,  28797,  -14106, -30273, 10938,  31419,
     -7649, -32218, 4277,   32667,  -857,   -32756, -2570,  32488,  5971,   -31862,
     -9306, 30888,  12540,  -29575, -15635, 27939,  18560,  -25996, -21280, 23769},
    /* cos_table_long_30_01[30] */
    {-21280, -27938, 12540,  31863,  -2570,  -32666, -7649, 30274,  17121,  -24916,
     -24916, 17121,  30274,  -7649,  -32666, -2570,  31863, 12540,  -27938, -21280,
     21281,  27939,  -12539, -31862, 2571,   32667,  7650,  -30273, -17120, 24917},
    /* cos_table_long_30_02[30] */
    {19948, 30274, -4276,  -32487, -12539, 25997, 25997, -12539, -32487, -4276,
     30274, 19948, -19947, -30273, 4277,   32488, 12540, -25996, -25996, 12540,
     32488, 4277,  -30273, -19947, 19948,  30274, -4276, -32487, -12539, 25997},
    /* cos_table_long_30_03[30] */
    {-18559, -31862, -4276,  28797, 24917, -10937, -32756, -12539, 23769, 29576,
     -2570,  -31418, -19947, 17121, 32219, 5971,   -27938, -25996, 9307,  32667,
     14107,  -22555, -30273, 858,   30888, 21281,  -15635, -32487, -7649, 27005},
    /* cos_table_long_30_04[30] */
    {17121,  32667,  12540,  -21280, -31862, -7649,  24917,  30274,  2571,  -27938,
     -27938, 2571,   30274,  24917,  -7649,  -31862, -21280, 12540,  32667, 17121,
     -17120, -32666, -12539, 21281,  31863,  7650,   -24916, -30273, -2570, 27939},
    /* cos_table_long_30_05[30] */
    {-15635, -32666, -19947, 10938,  31863,  23769, -5970,  -30273, -27004, 858,
     27939,  29576,  4277,   -24916, -31418, -9306, 21281,  32488,  14107,  -17120,
     -32756, -18559, 12540,  32219,  22556,  -7649, -30887, -25996, 2571,   28797},
    /* cos_table_long_30_06[30] */
    {14107,  31863,  25997,  858,    -24916, -32218, -15635, 12540,  31419,  27005,
     2571,   -23768, -32487, -17120, 10938,  30888,  27939,  4277,   -22555, -32666,
     -18559, 9307,   30274,  28797,  5971,   -21280, -32756, -19947, 7650,   29576},
    /* cos_table_long_30_07[30] */
    {-12539, -30273, -30273, -12539, 12540,  30274,  30274,  12540,  -12539, -30273,
     -30273, -12539, 12540,  30274,  30274,  12540,  -12539, -30273, -30273, -12539,
     12540,  30274,  30274,  12540,  -12539, -30273, -30273, -12539, 12540,  30274},
    /* cos_table_long_30_08[30] */
    {10938, 27939, 32488, 22556, 2571,   -18559, -31418, -30273, -15635, 5972,
     24917, 32757, 25997, 7650,  -14106, -29575, -31862, -19947, 858,    21281,
     32219, 28797, 12540, -9306, -27004, -32666, -23768, -4276,  17121,  30888},
    /* cos_table_long_30_09[30] */
    {-9306, -24916, -32487, -29575, -17120, 858,    18560,  30274, 32219, 23769,
     7650,  -10937, -25996, -32666, -28796, -15635, 2571,   19948, 30888, 31863,
     22556, 5971,   -12539, -27004, -32756, -27938, -14106, 4277,  21281, 31419},
    /* cos_table_long_30_10[30] */
    {7650,   21281,  30274,  32667,  27939,  17121,  2571,  -12539, -24916, -31862,
     -31862, -24916, -12539, 2571,   17121,  27939,  32667, 30274,  21281,  7650,
     -7649,  -21280, -30273, -32666, -27938, -17120, -2570, 12540,  24917,  31863},
    /* cos_table_long_30_11[30] */
    {-5970,  -17120, -25996, -31418, -32666, -29575, -22555, -12539, -857,   10938,
     21281,  28797,  32488,  31863,  27005,  18560,  7650,   -4276,  -15635, -24916,
     -30887, -32756, -30273, -23768, -14106, -2570,  9307,   19948,  27939,  32219},
    /* cos_table_long_30_12[30] */
    {4277,   12540,  19948,  25997,  30274,  32488,  32488,  30274,  25997,  19948,
     12540,  4277,   -4276,  -12539, -19947, -25996, -30273, -32487, -32487, -30273,
     -25996, -19947, -12539, -4276,  4277,   12540,  19948,  25997,  30274,  32488},
    /* cos_table_long_30_13[30] */
    {-2570,  -7649,  -12539, -17120, -21280, -24916, -27938, -30273, -31862, -32666,
     -32666, -31862, -30273, -27938, -24916, -21280, -17120, -12539, -7649,  -2570,
     2571,   7650,   12540,  17121,  21281,  24917,  27939,  30274,  31863,  32667},
    /* cos_table_long_30_14[30] */
    {858,   2571,  4277,  5971,  7650,  9307,  10938, 12540, 14107, 15636,
     17121, 18560, 19948, 21281, 22556, 23769, 24917, 25997, 27005, 27939,
     28797, 29576, 30274, 30888, 31419, 31863, 32219, 32488, 32667, 32757},
    /* cos_table_long_30_15[30] */
    {-23768, -21280, 25997,  18560,  -27938, -15635, 29576,  12540,  -30887, -9306,
     31863,  5972,   -32487, -2570,  32757,  -857,   -32666, 4277,   32219,  -7649,
     -31418, 10938,  30274,  -14106, -28796, 17121,  27005,  -19947, -24916, 22556},
    /* cos_table_long_30_16[30] */
    {24917,  17121,  -30273, -7648,  32667,  -2570, -31862, 12540,  27939,  -21280,
     -21280, 27939,  12540,  -31862, -2570,  32667, -7649,  -30273, 17121,  24917,
     -24916, -17120, 30274,  7650,   -32666, 2571,  31863,  -12539, -27938, 21281},
    /* cos_table_long_30_17[30] */
    {-25996, -12539, 32488, -4276, -30273, 19948,  19948, -30273, -4276,  32488,
     -12539, -25996, 25997, 12540, -32487, 4277,   30274, -19947, -19947, 30274,
     4277,   -32487, 12540, 25997, -25996, -12539, 32488, -4276,  -30273, 19948},
    /* cos_table_long_30_18[30] */
    {27005, 7650,   -32487, 15635, 21281,  -30887, 858,   30274, -22555, -14106,
     32667, -9306,  -25996, 27939, 5972,   -32218, 17121, 19948, -31418, 2571,
     29576, -23768, -12539, 32757, -10937, -24916, 28797, 4277,  -31862, 18560},
    /* cos_table_long_30_19[30] */
    {-27938, -2570, 30274,  -24916, -7649, 31863,  -21280, -12539, 32667,  -17120,
     -17120, 32667, -12539, -21280, 31863, -7649,  -24916, 30274,  -2570,  -27938,
     27939,  2571,  -30273, 24917,  7650,  -31862, 21281,  12540,  -32666, 17121},
    /* cos_table_long_30_20[30] */
    {28797,  -2570,  -25996, 30888,  -7649, -22555, 32219,  -12539, -18559, 32757,
     -17120, -14106, 32488,  -21280, -9306, 31419,  -24916, -4276,  29576,  -27938,
     858,    27005,  -30273, 5972,   23769, -31862, 10938,  19948,  -32666, 15636},
    /* cos_table_long_30_21[30] */
    {-29575, 7650,   19948,  -32756, 21281,  5972,   -28796, 30274,  -9305,  -18559,
     32667,  -22555, -4276,  27939,  -30887, 10938,  17121,  -32487, 23769,  2571,
     -27004, 31419,  -12539, -15635, 32219,  -24916, -857,   25997,  -31862, 14107},
    /* cos_table_long_30_22[30] */
    {30274,  -12539, -12539, 30274,  -30273, 12540,  12540,  -30273, 30274,  -12539,
     -12539, 30274,  -30273, 12540,  12540,  -30273, 30274,  -12539, -12539, 30274,
     -30273, 12540,  12540,  -30273, 30274,  -12539, -12539, 30274,  -30273, 12540},
    /* cos_table_long_30_23[30] */
    {-30887, 17121,  4277,  -23768, 32667, -27004, 9307,   12540, -28796, 32219,
     -21280, 858,    19948, -31862, 29576, -14106, -7649,  25997, -32756, 24917,
     -5970,  -15635, 30274, -31418, 18560, 2571,   -22555, 32488, -27938, 10938},
    /* cos_table_long_30_24[30] */
    {31419, -21280, 4277,  14107,  -27938, 32757, -27004, 12540, 5972,   -22555,
     31863, -30887, 19948, -2570,  -15635, 28797, -32666, 25997, -10937, -7649,
     23769, -32218, 30274, -18559, 858,    17121, -29575, 32488, -24916, 9307},
    /* cos_table_long_30_25[30] */
    {-31862, 24917,  -12539, -2570, 17121,  -27938, 32667,  -30273, 21281,  -7649,
     -7649,  21281,  -30273, 32667, -27938, 17121,  -2570,  -12539, 24917,  -31862,
     31863,  -24916, 12540,  2571,  -17120, 27939,  -32666, 30274,  -21280, 7650},
    /* cos_table_long_30_26[30] */
    {32219,  -27938, 19948,  -9306, -2570,  14107,  -23768, 30274,  -32756, 30888,
     -24916, 15635,  -4276,  -7648, 18560,  -27004, 31863,  -32487, 28797,  -21280,
     10938,  858,    -12539, 22556, -29575, 32667,  -31418, 25997,  -17120, 5971},
    /* cos_table_long_30_27[30] */
    {-32487, 30274,  -25995, 19948,  -12539, 4277,   4277,   -12539, 19948,  -25996,
     30274,  -32487, 32488,  -30273, 25997,  -19947, 12540,  -4276,  -4276,  12540,
     -19947, 25997,  -30273, 32488,  -32487, 30274,  -25996, 19948,  -12539, 4277},
    /* cos_table_long_30_28[30] */
    {32667,  -31862, 30274,  -27938, 24917,  -21280, 17121,  -12539, 7650,   -2570,
     -2570,  7650,   -12539, 17121,  -21280, 24917,  -27938, 30274,  -31862, 32667,
     -32666, 31863,  -30273, 27939,  -24916, 21281,  -17120, 12540,  -7649,  2571},
    /* cos_table_long_30_29[30] */
    {-32756, 32667, -32487, 32219, -31862, 31419, -30887, 30274, -29575, 28797,
     -27938, 27005, -25996, 24917, -23768, 22556, -21280, 19948, -18559, 17121,
     -15635, 14107, -12539, 10938, -9306,  7650,  -5970,  4277,  -2570,  858},

    /* cos_table_long_24_00[24] */
    {-22399, -25329, 19087, 27827, -15446, -29846, 11542,  31357, -7440, -32329, 3212,   32750,
     1072,   -32609, -5337, 31912, 9512,   -30667, -13523, 28899, 17304, -26634, -20787, 23916},
    /* cos_table_long_24_01[24] */
    {20788,  28899, -9511, -32609, -3211,  31357,  15447, -25329, -25329, 15447,  31357,  -3211,
     -32609, -9511, 28899, 20788,  -20787, -28898, 9512,  32610,  3212,   -31356, -15446, 25330},
    /* cos_table_long_24_02[24] */
    {-19086, -31356, -1071, 30668,  20788,  -17303, -31911, -3211, 29847,  22400,  -15446, -32329,
     -5337,  28899,  23916, -13523, -32609, -7440,  27827,  25330, -11542, -32749, -9511,  26635},
    /* cos_table_long_24_03[24] */
    {17304, 32610, 11543,  -22399, -31356, -5337, 26635, 28899, -1071,  -29846, -25329, 7441,
     31912, 20788, -13523, -32749, -15446, 19087, 32330, 9512,  -23915, -30667, -3211,  27827},
    /* cos_table_long_24_04[24] */
    {-15446, -32609, -20787, 9512,   31357, 25330, -3211, -28898, -28898, -3211,  25330, 31357,
     9512,   -20787, -32609, -15446, 15447, 32610, 20788, -9511,  -31356, -25329, 3212,  28899},
    /* cos_table_long_24_05[24] */
    {13524,  31357,  27827, 5338,  -20787, -32749, -22399, 3212,   26635,  31912,  15447, -11542,
     -30667, -28898, -7440, 19087, 32610,  23916,  -1071,  -25329, -32329, -17303, 9512,  29847},
    /* cos_table_long_24_06[24] */
    {-11541, -28898, -31911, -19086, 3212,  23916, 32750,  25330,  5338,   -17303, -31356, -29846,
     -13523, 9512,   27827,  32330,  20788, -1071, -22399, -32609, -26634, -7440,  15447,  30668},
    /* cos_table_long_24_07[24] */
    {9512,  25330, 32610, 28899, 15447, -3211,  -20787, -31356, -31356, -20787, -3211, 15447,
     28899, 32610, 25330, 9512,  -9511, -25329, -32609, -28898, -15446, 3212,   20788, 31357},
    /* cos_table_long_24_08[24] */
    {-7440, -20787, -29846, -32749, -28898, -19086, -5337,  9512,   22400, 30668, 32610, 27827,
     17304, 3212,   -11542, -23915, -31356, -32329, -26634, -15446, -1071, 13524, 25330, 31912},
    /* cos_table_long_24_09[24] */
    {5338,   15447,  23916,  29847,  32610,  31912,  27827, 20788, 11543, 1072,  -9511, -19086,
     -26634, -31356, -32749, -30667, -25329, -17303, -7440, 3212,  13524, 22400, 28899, 32330},
    /* cos_table_long_24_10[24] */
    {-3211,  -9511,  -15446, -20787, -25329, -28898, -31356, -32609,
     -32609, -31356, -28898, -25329, -20787, -15446, -9511,  -3211,
     3212,   9512,   15447,  20788,  25330,  28899,  31357,  32610},
    /* cos_table_long_24_11[24] */
    {1072,  3212,  5338,  7441,  9512,  11543, 13524, 15447, 17304, 19087, 20788, 22400,
     23916, 25330, 26635, 27827, 28899, 29847, 30668, 31357, 31912, 32330, 32610, 32750},
    /* cos_table_long_24_12[24] */
    {23916, 20788, -26634, -17303, 28899, 13524,  -30667, -9511, 31912, 5338,   -32609, -1071,
     32750, -3211, -32329, 7441,   31357, -11542, -29846, 15447, 27827, -19086, -25329, 22400},
    /* cos_table_long_24_13[24] */
    {-25329, -15446, 31357,  3212,   -32609, 9512,  28899,  -20787, -20787, 28899, 9512,   -32609,
     3212,   31357,  -15446, -25329, 25330,  15447, -31356, -3211,  32610,  -9511, -28898, 20788},
    /* cos_table_long_24_14[24] */
    {26635,  9512,  -32749, 11542,  25330, -27826, -7440,  32610,  -13523, -23915, 28899,  5338,
     -32329, 15447, 22400,  -29846, -3211, 31912,  -17303, -20787, 30668,  1072,   -31356, 19087},
    /* cos_table_long_24_15[24] */
    {-27826, -3211,  30668, -23915, -9511,  32330, -19086, -15446, 32750, -13523, -20787, 31912,
     -7440,  -25329, 29847, -1071,  -28898, 26635, 5338,   -31356, 22400, 11543,  -32609, 17304},
    /* cos_table_long_24_16[24] */
    {28899, -3211,  -25329, 31357, -9511,  -20787, 32610, -15446, -15446, 32610, -20787, -9511,
     31357, -25329, -3211,  28899, -28898, 3212,   25330, -31356, 9512,   20788, -32609, 15447},
    /* cos_table_long_24_17[24] */
    {-29846, 9512,  17304,  -32329, 25330, -1071,  -23915, 32610,  -19086, -7440, 28899,  -30667,
     11542,  15447, -31911, 26635,  -3211, -22399, 32750,  -20787, -5337,  27827, -31356, 13524},
    /* cos_table_long_24_18[24] */
    {30668,  -15446, -7440,  26635, -32609, 22400,  -1071, -20787, 32330,  -27826, 9512,   13524,
     -29846, 31357,  -17303, -5337, 25330,  -32749, 23916, -3211,  -19086, 31912,  -28898, 11543},
    /* cos_table_long_24_19[24] */
    {-31356, 20788, -3211, -15446, 28899, -32609, 25330, -9511, -9511,  25330, -32609, 28899,
     -15446, -3211, 20788, -31356, 31357, -20787, 3212,  15447, -28898, 32610, -25329, 9512},
    /* cos_table_long_24_20[24] */
    {31912, -25329, 13524, 1072,   -15446, 26635, -32329, 31357, -23915, 11542, 3212,   -17303,
     27827, -32609, 30668, -22399, 9512,   5338,  -19086, 28899, -32749, 29847, -20787, 7441},
    /* cos_table_long_24_21[24] */
    {-32329, 28899, -22399, 13524, -3211,  -7440, 17304,  -25329, 30668,  -32749, 31357,  -26634,
     19087,  -9511, -1071,  11543, -20787, 27827, -31911, 32610,  -29846, 23916,  -15446, 5338},
    /* cos_table_long_24_22[24] */
    {32610,  -31356, 28899,  -25329, 20788,  -15446, 9512,   -3211, -3211,  9512,  -15446, 20788,
     -25329, 28899,  -31356, 32610,  -32609, 31357,  -28898, 25330, -20787, 15447, -9511,  3212},
    /* cos_table_long_24_23[24] */
    {-32749, 32610, -32329, 31912, -31356, 30668, -29846, 28899, -27826, 26635, -25329, 23916,
     -22399, 20788, -19086, 17304, -15446, 13524, -11541, 9512,  -7440,  5338,  -3211,  1072},

    /* cos_table_long_18_00[18] */
    {22138, 25997, -17605, -29065, 12540, 31251, -7091, -32487, 1429, 32737, 4277, -31990, -9853,
     30274, 15131, -27635, -19947, 24159},
    /* cos_table_long_18_01[18] */
    {-19947, -30273, 4277, 32488, 12540, -25996, -25996, 12540, 32488, 4277, -30273, -19947,
     19948, 30274, -4276, -32487, -12539, 25997},
    /* cos_table_long_18_02[18] */
    {17606, 32488, 9854, -24158, -30273, -1428, 29066, 25997, -7091, -31990, -19947, 15131, 32737,
     12540, -22137, -31250, -4276, 27636},
    /* cos_table_long_18_03[18] */
    {-15130, -32487, -22137, 7092, 30274, 27636, 1429, -25996, -31250, -9853, 19948, 32737, 17606,
     -12539, -31990, -24158, 4277, 29066},
    /* cos_table_long_18_04[18] */
    {12540, 30274, 30274, 12540, -12539, -30273, -30273, -12539, 12540, 30274, 30274, 12540,
     -12539, -30273, -30273, -12539, 12540, 30274},
    /* cos_table_long_18_05[18] */
    {-9852, -25996, -32736, -27635, -12539, 7092, 24159, 32488, 29066, 15131, -4276, -22137,
     -31990, -30273, -17605, 1429, 19948, 31251},
    /* cos_table_long_18_06[18] */
    {7092, 19948, 29066, 32737, 30274, 22138, 9854, -4276, -17605, -27635, -32487, -31250, -24158,
     -12539, 1429, 15131, 25997, 31991},
    /* cos_table_long_18_07[18] */
    {-4276, -12539, -19947, -25996, -30273, -32487, -32487, -30273, -25996, -19947, -12539, -4276,
     4277, 12540, 19948, 25997, 30274, 32488},
    /* cos_table_long_18_08[18] */
    {1429, 4277, 7092, 9854, 12540, 15131, 17606, 19948, 22138, 24159, 25997, 27636, 29066, 30274,
     31251, 31991, 32488, 32737},
    /* cos_table_long_18_09[18] */
    {-24158, -19947, 27636, 15131, -30273, -9853, 31991, 4277, -32736, 1429, 32488, -7091, -31250,
     12540, 29066, -17605, -25996, 22138},
    /* cos_table_long_18_10[18] */
    {25997, 12540, -32487, 4277, 30274, -19947, -19947, 30274, 4277, -32487, 12540, 25997, -25996,
     -12539, 32488, -4276, -30273, 19948},
    /* cos_table_long_18_11[18] */
    {-27635, -4276, 31251, -22137, -12539, 32737, -15130, -19947, 31991, -7091, -25996, 29066,
     1429, -30273, 24159, 9854, -32487, 17606},
    /* cos_table_long_18_12[18] */
    {29066, -4276, -24158, 31991, -12539, -17605, 32737, -19947, -9853, 31251, -25996, -1428,
     27636, -30273, 7092, 22138, -32487, 15131},
    /* cos_table_long_18_13[18] */
    {-30273, 12540, 12540, -30273, 30274, -12539, -12539, 30274, -30273, 12540, 12540, -30273,
     30274, -12539, -12539, 30274, -30273, 12540},
    /* cos_table_long_18_14[18] */
    {31251, -19947, 1429, 17606, -30273, 31991, -22137, 4277, 15131, -29065, 32488, -24158, 7092,
     12540, -27635, 32737, -25996, 9854},
    /* cos_table_long_18_15[18] */
    {-31990, 25997, -15130, 1429, 12540, -24158, 31251, -32487, 27636, -17605, 4277, 9854, -22137,
     30274, -32736, 29066, -19947, 7092},
    /* cos_table_long_18_16[18] */
    {32488, -30273, 25997, -19947, 12540, -4276, -4276, 12540, -19947, 25997, -30273, 32488,
     -32487, 30274, -25996, 19948, -12539, 4277},
    /* cos_table_long_18_17[18] */
    {-32736, 32488, -31990, 31251, -30273, 29066, -27635, 25997, -24158, 22138, -19947, 17606,
     -15130, 12540, -9852, 7092, -4276, 1429},

    /* cos_table_long_16_00[16] */
    {-22005, -26319, 16846, 29622, -11038, -31785, 4808, 32729, 1608, -32412, -7961, 30853, 14010,
     -28105, -19519, 24279},
    /* cos_table_long_16_01[16] */
    {19520, 30853, -1607, -31785, -16845, 22006, 29622, -4807, -32412, -14009, 24279, 28106,
     -7961, -32728, -11038, 26320},
    /* cos_table_long_16_02[16] */
    {-16845, -32728, -14009, 19520, 32413, 11039, -22005, -31785, -7961, 24279, 30853, 4808,
     -26319, -29621, -1607, 28106},
    /* cos_table_long_16_03[16] */
    {14010, 31786, 26320, 1608, -24278, -32412, -16845, 11039, 30853, 28106, 4808, -22005, -32728,
     -19519, 7962, 29622},
    /* cos_table_long_16_04[16] */
    {-11038, -28105, -32412, -22005, -1607, 19520, 31786, 29622, 14010, -7961, -26319, -32728,
     -24278, -4807, 16846, 30853},
    /* cos_table_long_16_05[16] */
    {7962, 22006, 30853, 32413, 26320, 14010, -1607, -16845, -28105, -32728, -29621, -19519,
     -4807, 11039, 24279, 31786},
    /* cos_table_long_16_06[16] */
    {-4807, -14009, -22005, -28105, -31785, -32728, -30852, -26319, -19519, -11038, -1607, 7962,
     16846, 24279, 29622, 32413},
    /* cos_table_long_16_07[16] */
    {1608, 4808, 7962, 11039, 14010, 16846, 19520, 22006, 24279, 26320, 28106, 29622, 30853,
     31786, 32413, 32729},
    /* cos_table_long_16_08[16] */
    {24279, 19520, -28105, -14009, 30853, 7962, -32412, -1607, 32729, -4807, -31785, 11039, 29622,
     -16845, -26319, 22006},
    /* cos_table_long_16_09[16] */
    {-26319, -11038, 32729, -7961, -28105, 24279, 14010, -32412, 4808, 29622, -22005, -16845,
     31786, -1607, -30852, 19520},
    /* cos_table_long_16_10[16] */
    {28106, 1608, -29621, 26319, 4808, -30852, 24279, 7962, -31785, 22006, 11039, -32412, 19520,
     14010, -32728, 16846},
    /* cos_table_long_16_11[16] */
    {-29621, 7962, 19520, -32728, 22006, 4808, -28105, 30853, -11038, -16845, 32413, -24278,
     -1607, 26320, -31785, 14010},
    /* cos_table_long_16_12[16] */
    {30853, -16845, -4807, 24280, -32728, 26319, -7961, -14009, 29622, -31785, 19520, 1608,
     -22005, 32413, -28105, 11039},
    /* cos_table_long_16_13[16] */
    {-31785, 24279, -11038, -4807, 19520, -29621, 32729, -28105, 16846, -1607, -14009, 26320,
     -32412, 30853, -22005, 7962},
    /* cos_table_long_16_14[16] */
    {32413, -29621, 24279, -16845, 7962, 1608, -11038, 19520, -26319, 30853, -32728, 31786,
     -28105, 22006, -14009, 4808},
    /* cos_table_long_16_15[16] */
    {-32728, 32413, -31785, 30853, -29621, 28106, -26319, 24279, -22005, 19520, -16845, 14010,
     -11038, 7962, -4807, 1608},

    /* cos_table_long_15_00[15] */
    {20622, 29197, -8480, -32722, -5125, 30592, 17847, -23169, -27481, 11743, 32365, 1715, -31650,
     -14875, 25466},
    /* cos_table_long_15_01[15] */
    {-17846, -32364, -8480, 25466, 29197, -1714, -30591, -23169, 11743, 32723, 14876, -20621,
     -31650, -5125, 27482},
    /* cos_table_long_15_02[15] */
    {14876, 32365, 23170, -5125, -29195, -29195, -5125, 23170, 32365, 14876, -14875, -32364,
     -23169, 5126, 29197},
    /* cos_table_long_15_03[15] */
    {-11742, -29195, -31650, -17846, 5126, 25466, 32723, 23170, 1715, -20621, -32364, -27481,
     -8480, 14876, 30592},
    /* cos_table_long_15_04[15] */
    {8481, 23170, 31651, 31651, 23170, 8481, -8480, -23169, -31650, -31650, -23169, -8480, 8481,
     23170, 31651},
    /* cos_table_long_15_05[15] */
    {-5125, -14875, -23169, -29196, -32364, -32364, -29196, -23169, -14875, -5125, 5126, 14876,
     23170, 29197, 32365},
    /* cos_table_long_15_06[15] */
    {1715, 5126, 8481, 11743, 14876, 17847, 20622, 23170, 25466, 27482, 29197, 30592, 31651,
     32365, 32723},
    /* cos_table_long_15_07[15] */
    {-23169, -23169, 23170, 23170, -23169, -23169, 23170, 23170, -23169, -23169, 23170, 23170,
     -23169, -23169, 23170},
    /* cos_table_long_15_08[15] */
    {25466, 14876, -31650, -1714, 32365, -11742, -27481, 23170, 17847, -30591, -5125, 32723,
     -8480, -29196, 20622},
    /* cos_table_long_15_09[15] */
    {-27481, -5125, 31651, -20621, -14875, 32723, -11742, -23169, 30592, -1714, -29195, 25466,
     8481, -32364, 17847},
    /* cos_table_long_15_10[15] */
    {29196, -5125, -23169, 32365, -14875, -14875, 32365, -23169, -5125, 29197, -29195, 5126,
     23170, -32364, 14876},
    /* cos_table_long_15_11[15] */
    {-30591, 14876, 8481, -27481, 32365, -20621, -1714, 23170, -32722, 25466, -5125, -17846,
     31651, -29196, 11743},
    /* cos_table_long_15_12[15] */
    {31651, -23169, 8481, 8481, -23169, 31651, -31650, 23170, -8480, -8480, 23170, -31650, 31651,
     -23169, 8481},
    /* cos_table_long_15_13[15] */
    {-32364, 29196, -23169, 14876, -5125, -5125, 14876, -23169, 29197, -32364, 32365, -29195,
     23170, -14875, 5126},
    /* cos_table_long_15_14[15] */
    {32723, -32364, 31651, -30591, 29196, -27481, 25466, -23169, 20622, -17846, 14876, -11742,
     8481, -5125, 1715},

    /* cos_table_short_4_00[4] */
    {-18204, -32137, -6392, 27246},
    /* cos_table_short_4_01[4] */
    {6393, 18205, 27246, 32138},
    /* cos_table_short_4_02[4] */
    {27246, 6393, -32137, 18205},
    /* cos_table_short_4_03[4] */
    {-32137, 27246, -18204, 6393},

    /* cos_table_short_3_00[3] */
    {8481, 23170, 31651},
    /* cos_table_short_3_01[3] */
    {-23169, -23169, 23170},
    /* cos_table_short_3_02[3] */
    {31651, -23169, 8481},

    /* cos_table_short_2_00[2] */
    {12540, 30274},
    /* cos_table_short_2_01[2] */
    {-30273, 12540}}; /* END OF ia_mps_dec_mdct2qmf_tables_struct */

const ia_mps_dec_m1_m2_tables_struct ixheaacd_mps_dec_m1_m2_tables = {
    {{/* row_2_channel_stp[7][8] */
      {0, 1, 2, -1, 3, 4, -1, -1},
      {0, 3, 1, 4, 2, -1, -1, -1},
      {0, 2, 1, 3, -1, -1, -1, -1},
      {0, 4, 2, 1, 5, 3, -1, -1},
      {0, 4, 2, 1, 5, 3, -1, -1},
      {0, 2, -1, 1, 3, -1, -1, -1},
      {-1, 2, 0, -1, 3, 1, -1, -1}},
     {/* row_2_channel_ges[7][8] */
      {0, 1, 2, -1, 3, 4, -1, -1},
      {0, 3, 1, 4, 2, -1, -1, -1},
      {0, 3, 1, 4, 2, -1, -1, -1},
      {0, 5, 3, 1, 6, 4, 2, -1},
      {0, 5, 3, 1, 6, 4, 2, -1},
      {0, 2, -1, 1, 3, -1, -1, -1},
      {-1, 2, 0, -1, 3, 1, -1, -1}},
     {/* row_2_residual[7][8] */
      {-1, 0, 1, 3, 2, 4},
      {-1, 0, 1, 3, 4, 2},
      {-1, -1, -1, 1, 2, 0},
      {-1, -1, -1, 1, 2, 0, 3, 4},
      {-1, -1, -1, 1, 2, 0, 3, 4},
      {-1, -1, -1, -1, -1, -1, 0, 1},
      {-1, -1, -1, -1, -1, -1, 0, 1}}},
    {/* hybrid_2_param_28[71] */
     1,  0,  0,  1,  2,  3,  4,  5,  6,  7,  8,  9,  10, 11, 12, 13, 14, 15,
     16, 17, 17, 18, 18, 19, 19, 20, 20, 21, 21, 21, 22, 22, 22, 23, 23, 23,
     23, 24, 24, 24, 24, 24, 25, 25, 25, 25, 25, 25, 26, 26, 26, 26, 26, 26,
     26, 27, 27, 27, 27, 27, 27, 27, 27, 27, 27, 27, 27, 27, 27, 27, 27},
    {/* r1_matrix_l[31] */
     0,     184,   328,   583,   1036,  1840,  2595,  3654,  5129,  7159,  9880,
     12120, 14682, 17486, 20381, 23170, 25658, 27713, 29295, 30444, 31243, 31976,
     32364, 32564, 32665, 32716, 32752, 32763, 32766, 32767, 32768},
    {/* ten_cld_by_10[31] q15 */
     0,       1,        3,        10,        33,        104,        207,       413,
     823,     1642,     3277,     5193,      8231,      13045,      20675,     32767,
     51932,   82307,    130448,   206746,    327670,    653788,     1304478,   2602775,
     5193220, 10361835, 32767000, 103618352, 327670000, 1036183521, 0x7FFFFFFF},
    {/* w00_cld2_15[31] */
     0,     184,   328,   583,   1036,  1840,  2595,  3654,  5129,  7158,  9880,
     12120, 14682, 17485, 20381, 23170, 25658, 27712, 29294, 30443, 31242, 31976,
     32363, 32563, 32664, 32715, 32751, 32762, 32765, 32766, 32767},
    {/* table_kappa[8] */
     0, 6609, 10230, 15121, 17593, 18918, 15288, 2669},
    {/* dec_pow[31] q15 */
     0,      184,    327,     582,     1036,    1842,    2602,      3676,
     5193,   7335,   10362,   13045,   16422,   20675,   26028,     32768,
     41252,  51933,  65380,   82309,   103621,  146369,  206752,    292045,
     412524, 582706, 1036215, 1842680, 3276800, 5827066, 2147483647},
    {/* cld_tab_1[31] */
     0,     1,     3,     10,    32,    103,   205,   407,   802,   1563,  2978,
     4482,  6578,  9330,  12676, 16384, 20091, 23437, 26189, 28285, 29789, 31204,
     31965, 32360, 32562, 32664, 32735, 32757, 32764, 32766, 32768},
    {/* cld_tab_2[31] */
     2147483647, 5827066, 3276800, 1842680, 1036215, 582706, 412524, 292045,
     206752,     146369,  103621,  82309,   65380,   51933,  41252,  32768,
     26028,      20675,   16422,   13045,   10362,   7335,   5193,   3676,
     2602,       1842,    1036,    582,     327,     184,    0},
    {/* cld_tab_3[31] */
     0,       1,        3,        10,        32,        103,        206,       412,
     823,     1642,     3276,     5193,      8230,      13045,      20675,     32768,
     51933,   82309,    130451,   206752,    327680,    653807,     1304517,   2602854,
     5193378, 10362151, 32768000, 103621512, 327680000, 1036215168, 2147483647},
    {/* reciprocal[576] q28 */
     268435456, 134217728, 89478488, 67108864, 53687092, 44739244, 38347924, 33554432, 29826162,
     26843546,  24403224,  22369622, 20648882, 19173962, 17895698, 16777216, 15790321, 14913081,
     14128182,  13421773,  12782641, 12201612, 11671107, 11184811, 10737418, 10324441, 9942054,
     9586981,   9256395,   8947849,  8659208,  8388608,  8134408,  7895161,  7669585,  7456541,
     7255013,   7064091,   6882961,  6710887,  6547206,  6391321,  6242685,  6100806,  5965233,
     5835554,   5711393,   5592406,  5478275,  5368709,  5263441,  5162221,  5064820,  4971027,
     4880645,   4793491,   4709394,  4628198,  4549754,  4473925,  4400581,  4329604,  4260881,
     4194304,   4129776,   4067204,  4006499,  3947580,  3890369,  3834792,  3780781,  3728270,
     3677198,   3627506,   3579140,  3532046,  3486175,  3441480,  3397917,  3355443,  3314018,
     3273603,   3234162,   3195660,  3158064,  3121343,  3085465,  3050403,  3016129,  2982616,
     2949840,   2917777,   2886403,  2855696,  2825637,  2796203,  2767376,  2739137,  2711469,
     2684355,   2657777,   2631720,  2606170,  2581110,  2556528,  2532410,  2508743,  2485514,
     2462711,   2440322,   2418338,  2396745,  2375535,  2354697,  2334221,  2314099,  2294320,
     2274877,   2255760,   2236962,  2218475,  2200291,  2182402,  2164802,  2147484,  2130440,
     2113665,   2097152,   2080895,  2064888,  2049126,  2033602,  2018312,  2003250,  1988411,
     1973790,   1959383,   1945185,  1931190,  1917396,  1903798,  1890391,  1877171,  1864135,
     1851279,   1838599,   1826092,  1813753,  1801580,  1789570,  1777718,  1766023,  1754480,
     1743087,   1731842,   1720740,  1709780,  1698959,  1688273,  1677722,  1667301,  1657009,
     1646843,   1636802,   1626882,  1617081,  1607398,  1597830,  1588376,  1579032,  1569798,
     1560671,   1551650,   1542733,  1533917,  1525202,  1516585,  1508064,  1499639,  1491308,
     1483069,   1474920,   1466860,  1458888,  1451003,  1443201,  1435484,  1427848,  1420293,
     1412818,   1405421,   1398101,  1390857,  1383688,  1376592,  1369569,  1362617,  1355735,
     1348922,   1342177,   1335500,  1328888,  1322342,  1315860,  1309441,  1303085,  1296790,
     1290555,   1284380,   1278264,  1272206,  1266205,  1260260,  1254371,  1248537,  1242757,
     1237030,   1231355,   1225733,  1220161,  1214640,  1209169,  1203747,  1198373,  1193047,
     1187768,   1182535,   1177349,  1172207,  1167111,  1162058,  1157049,  1152084,  1147160,
     1142279,   1137438,   1132639,  1127880,  1123161,  1118481,  1113840,  1109237,  1104673,
     1100145,   1095655,   1091201,  1086783,  1082401,  1078054,  1073742,  1069464,  1065220,
     1061010,   1056833,   1052688,  1048576,  1044496,  1040448,  1036430,  1032444,  1028488,
     1024563,   1020667,   1016801,  1012964,  1009156,  1005376,  1001625,  997901,   994205,
     990537,    986895,    983280,   979691,   976129,   972592,   969081,   965595,   962134,
     958698,    955286,    951899,   948535,   945195,   941879,   938586,   935315,   932068,
     928842,    925640,    922459,   919300,   916162,   913046,   909951,   906877,   903823,
     900790,    897777,    894785,   891812,   888859,   885926,   883011,   880116,   877240,
     874383,    871544,    868723,   865921,   863137,   860370,   857621,   854890,   852176,
     849479,    846800,    844137,   841490,   838861,   836248,   833651,   831070,   828505,
     825955,    823422,    820904,   818401,   815913,   813441,   810983,   808541,   806113,
     803699,    801300,    798915,   796544,   794188,   791845,   789516,   787201,   784899,
     782611,    780336,    778074,   775825,   773589,   771366,   769156,   766958,   764773,
     762601,    760440,    758292,   756156,   754032,   751920,   749820,   747731,   745654,
     743589,    741534,    739492,   737460,   735440,   733430,   731432,   729444,   727467,
     725501,    723546,    721601,   719666,   717742,   715828,   713924,   712030,   710147,
     708273,    706409,    704555,   702711,   700876,   699051,   697235,   695429,   693632,
     691844,    690065,    688296,   686536,   684784,   683042,   681308,   679583,   677867,
     676160,    674461,    672771,   671089,   669415,   667750,   666093,   664444,   662804,
     661171,    659547,    657930,   656321,   654721,   653128,   651542,   649965,   648395,
     646832,    645278,    643730,   642190,   640657,   639132,   637614,   636103,   634599,
     633103,    631613,    630130,   628654,   627186,   625724,   624269,   622820,   621378,
     619943,    618515,    617093,   615678,   614269,   612866,   611470,   610081,   608697,
     607320,    605949,    604584,   603226,   601873,   600527,   599186,   597852,   596523,
     595201,    593884,    592573,   591268,   589968,   588674,   587386,   586104,   584827,
     583555,    582290,    581029,   579774,   578525,   577281,   576042,   574808,   573580,
     572357,    571139,    569927,   568719,   567517,   566320,   565127,   563940,   562758,
     561580,    560408,    559241,   558078,   556920,   555767,   554619,   553475,   552336,
     551202,    550073,    548948,   547827,   546712,   545601,   544494,   543392,   542294,
     541201,    540112,    539027,   537947,   536871,   535799,   534732,   533669,   532610,
     531555,    530505,    529459,   528416,   527378,   526344,   525314,   524288,   523266,
     522248,    521234,    520224,   519218,   518215,   517217,   516222,   515231,   514244,
     513261,    512281,    511306,   510334,   509365,   508401,   507439,   506482,   505528,
     504578,    503631,    502688,   501749,   500812,   499880,   498951,   498025,   497103,
     496184,    495268,    494356,   493448,   492542,   491640,   490741,   489846,   488953,
     488064,    487179,    486296,   485417,   484541,   483668,   482798,   481931,   481067,
     480207,    479349,    478495,   477643,   476795,   475949,   475107,   474268,   473431,
     472598,    471767,    470939,   470115,   469293,   468474,   467658,   466844,   466034},
    {/* c_l_table[31] */
     0,     184,   328,   583,   1036,  1840,  2595,  3654,  5129,  7159,  9880,
     12120, 14682, 17486, 20381, 23170, 25658, 27713, 29295, 30444, 31243, 31976,
     32364, 32564, 32665, 32716, 32752, 32763, 32766, 32767, 32767},
    {/* cos_table[16][31] */
     {32768, 32768, 32768, 32768, 32768, 32768, 32768, 32768, 32768, 32768, 32768,
      32768, 32768, 32768, 32768, 32768, 32768, 32768, 32768, 32768, 32768, 32768,
      32768, 32768, 32768, 32768, 32768, 32768, 32768, 32768, 32768},
     {30704, 30726, 30743, 30773, 30825, 30912, 30989, 31090, 31219, 31378, 31565,
      31701, 31842, 31984, 32121, 32248, 32361, 32458, 32538, 32601, 32650, 32700,
      32730, 32747, 32757, 32762, 32766, 32767, 32768, 32768, 32768},
     {27564, 27617, 27658, 27730, 27855, 28066, 28254, 28502, 28821, 29218, 29688,
      30033, 30395, 30759, 31112, 31440, 31733, 31983, 32188, 32350, 32473, 32599,
      32675, 32718, 32741, 32754, 32763, 32767, 32768, 32768, 32768},
     {19691, 19808, 19898, 20057, 20334, 20810, 21239, 21815, 22570, 23531, 24703,
      25586, 26526, 27489, 28433, 29317, 30105, 30775, 31317, 31738, 32053, 32368,
      32551, 32653, 32708, 32737, 32758, 32765, 32767, 32768, 32768},
     {12047, 12206, 12329, 12546, 12927, 13590, 14197, 15025, 16135, 17586, 19413,
      20829, 22370, 23980, 25583, 27097, 28447, 29584, 30491, 31182, 31687, 32178,
      32455, 32605, 32684, 32725, 32754, 32764, 32767, 32768, 32768},
     {0,     184,   328,   583,   1036,  1840,  2595,  3654,  5129,  7159,  9880,
      12120, 14682, 17486, 20381, 23170, 25658, 27713, 29295, 30444, 31243, 31976,
      32364, 32564, 32665, 32716, 32752, 32763, 32766, 32767, 32768},
     {-19300, -19179, -19084, -18914, -18604, -18036, -17477, -16651, -15406, -13492, -10479,
      -7533,  -3540,  1699,   8069,   14854,  20913,  25445,  28411,  30209,  31263,  32079,
      32446,  32615,  32694,  32732,  32757,  32765,  32767,  32768,  32768},
     {
         -32440, -32437, -32434, -32428, -32419, -32400, -32382, -32353, -32306, -32226, -32073,
         -31875, -31483, -30498, -26581, 2317,   29018,  31884,  32450,  32628,  32699,  32741,
         32756,  32763,  32766,  32767,  32768,  32768,  32768,  32768,  32768,
     },
     {
         -32381, -32376, -32373, -32366, -32355, -32333, -32311, -32277, -32222, -32128, -31947,
         -31715, -31256, -30112, -25701, 2520,   28513,  31737,  32395,  32603,  32687,  32736,
         32754,  32762,  32765,  32767,  32768,  32768,  32768,  32768,  32768,
     },
     {
         -23483, -23393, -23322, -23194, -22961, -22530, -22102, -21460, -20474, -18908, -16315,
         -13613, -9671,  -3995,  3628,   12334,  20114,  25547,  28767,  30544,  31512,  32216,
         32516,  32650,  32712,  32741,  32760,  32765,  32767,  32768,  32768,
     },
     {
         -17414, -17281, -17177, -16990, -16652, -16032, -15426, -14535, -13204, -11183, -8069,
         -5095,  -1169,  3823,   9712,   15861,  21349,  25536,  28361,  30128,  31191,  32034,
         32421,  32602,  32687,  32729,  32756,  32764,  32767,  32768,  32768,
     },
     {
         -14568, -14420, -14303, -14095, -13719, -13034, -12370, -11400, -9970, -7840, -4648,
         -1698,  2067,   6675,   11918,  17268,  22043,  25769,  28374,  30067, 31121, 31984,
         32392,  32586,  32679,  32724,  32754,  32764,  32767,  32768,  32768,
     },
     {
         -12498, -12340, -12216, -11995, -11596, -10873, -10175, -9162, -7682, -5505, -2305,
         592,    4211,   8540,   13364,  18224,  22560,  25987,  28434, 30060, 31095, 31960,
         32377,  32577,  32674,  32722,  32754,  32764,  32767,  32768, 32768,
     },
     {
         -11093, -10929, -10801, -10573, -10161, -9416, -8699, -7663, -6158, -3964, -777,
         2070,   5582,   9725,   14285,  18845,  22913, 26152, 28493, 30071, 31087, 31949,
         32369,  32572,  32672,  32720,  32753,  32763, 32767, 32768, 32768,
     },
     {
         -10279, -10112, -9982, -9749, -9331, -8575, -7849, -6802, -5286, -3086, 88,
         2902,   6348,   10384, 14799, 19195, 23118, 26253, 28533, 30082, 31086, 31944,
         32365,  32570,  32670, 32720, 32753, 32763, 32767, 32768, 32768,
     },
     {
         -10012, -9845, -9714, -9480, -9060, -8300, -7571, -6521, -5002, -2801, 367,
         3170,   6595,  10597, 14964, 19309, 23185, 26287, 28547, 30086, 31087, 31942,
         32364,  32569, 32670, 32719, 32753, 32763, 32767, 32768, 32768,
     }},
    {/* sin_table[8][31] */
     {
         0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
         0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
     },
     {
         11447, 11387, 11340, 11259, 11117, 10872, 10650, 10351, 9955, 9442, 8798,
         8294,  7734,  7126,  6481,  5816,  5148,  4496,  3876,  3302, 2782, 2114,
         1578,  1161,  846,   611,   352,   200,   113,   64,    0,
     },
     {
         17719, 17636, 17571, 17458, 17258, 16912, 16596, 16166, 15591, 14835, 13870,
         13105, 12244, 11298, 10287, 9234,  8171,  7129,  6137,  5217,  4386,  3321,
         2471,  1814,  1318,  951,   546,   310,   176,   99,    0,
     },
     {
         26192, 26103, 26034, 25912, 25695, 25312, 24953, 24451, 23756, 22804, 21529,
         20471, 19238, 17836, 16289, 14637, 12938, 11254, 9642,  8150,  6808,  5105,
         3765,  2743,  1982,  1423,  813,   461,   260,   147,   0,
     },
     {
         30473, 30410, 30360, 30271, 30110, 29817, 29533, 29120, 28520, 27649, 26399,
         25296, 23944, 22332, 20475, 18425, 16264, 14090, 12001, 10071, 8348,  6190,
         4520,  3267,  2346,  1677,  952,   538,   304,   171,   0,
     },
     {
         32768, 32767, 32766, 32763, 32752, 32716, 32665, 32564, 32364, 31976, 31243,
         30444, 29295, 27713, 25658, 23170, 20381, 17486, 14682, 12120, 9880,  7159,
         5129,  3654,  2595,  1840,  1036,  583,   328,   184,   0,
     },
     {
         26481, 26569, 26637, 26758, 26974, 27358, 27718, 28222, 28920, 29862, 31047,
         31890, 32576, 32724, 31759, 29208, 25227, 20647, 16327, 12696, 9818,  6685,
         4584,  3167,  2202,  1538,  853,   476,   266,   149,   0,
     },
     {
         4622, 4648, 4669,  4705,  4772,  4895,  5017, 5199, 5481, 5934, 6715,
         7597, 9086, 11983, 19163, 32686, 15222, 7561, 4554, 3024, 2123, 1328,
         869,  583,  398,   275,   151,   84,    47,   26,   0,
     }}}; /* END OF ia_mps_dec_m1_m2_tables_struct */

const ia_mps_dec_decorr_tables_struct ixheaacd_mps_dec_decorr_tables = {
    { /* rev_table */
     {/* rev_delay[4][10] */
      {8, 8, 8, 8, 8, 8, 8, 8, 8, 8},
      {7, 7, 7, 7, 7, 7, 7, 7, 7, 7},
      {2, 2, 2, 2, 2, 2, 2, 2, 2, 2},
      {1, 1, 1, 1, 1, 1, 1, 1, 1, 1}},
     /* rev_split_freq_0[4] */
     {3, 15, 24, 65},
     /* rev_split_freq_1[4] */
     {3, 50, 65, 65},
     /* rev_split_freq_2[4] */
     {0, 15, 65, 65}},
    {/* lattice_coeff_0[10][20] */
     {8110,  14854, -721, -10099, -184, 12432,  -11331, 12465, -10682, 16043,
      -7497, 11629, 6354, -4591,  1265, -13287, -9988,  -8176, 1288,   8058},
     {12950,  -13910, -940,  14139, 2363,  -3795, 2241, -416,  -8408,  6344,
      -13153, -8369,  -1937, 11085, -6200, -2395, 6891, 14742, -11911, -6236},
     {-3093, -6822, -3280, -14320, -13615, 12472, -4846, -14818, 13379, 2005,
      15988, 5390,  -5426, 5669,   655,    -8588, 11459, -7471,  10286, -10476},
     {2366,  6049, -13756, 2913,  -8625, -8723, -8985, -15342, 9227,   10155,
      -7468, 2831, 891,    -6691, 7556,  400,   -7569, -8657,  -12966, -11367},
     {-11282, -14428, 7268, -4787, -3090, -3437, -4548, 14585, -2585, 15548,
      -4660,  -2907,  2025, 5685,  5069,  780,   -3444, -3559, 15594, -4122},
     {2169, -4335, -11393, -12544, -2497, 10335,  -14241, -8978, 12124,  -3916,
      557,  12809, -14038, -1488,  -8897, -16158, 3775,   10115, -12445, -11236},
     {-15480, 11128, 5679,  -12829, 9162,  9552, -79,   -5695, 9434, 2943,
      9378,   -7576, 14333, -14831, 12429, 8710, 15670, -5983, 5400, 6747},
     {5168,   12943, 14877, 9817,  -16381, 12904, 6187, 15637, 12085, -1642,
      -15797, 242,   1645,  -7468, -13622, 5289,  4378, 9352,  11459, 10266},
     {-5177, -6344, -4778, -9231, -10040, 3244,  15611, -8235, 14035,  -12101,
      8575,  12016, 5492,  4961,  246,    -3192, 531,   -3660, -13481, 11426},
     {865,   7376,   15113,  -6272, -11954, 7887, 1638,  10122,  10106, -15381,
      11793, -14248, -13045, 13582, -6134,  5941, -5476, -10197, 3195,  -13189}},
    {/* lattice_coeff_1[10][15] */
     {9696, -12373, -11407, 10066, 13058, 11521, 5531, -4610, -49, 1681, 8736, -9739, -6380,
      15594, -6622},
     {1376, -4994, 11167, 16030, 5823, -1304, -1278, -2317, -12586, 15073, 5790, 8575, 2323,
      -5659, 2654},
     {13281, 7124, -15263, 1579, 1697, 2363, -12757, -1897, 2969, -14818, -10751, 6213, -2081, 39,
      2107},
     {12796, 3251, -5400, 6370, -2051, 12812, -13110, 10125, 2949, -3775, -10020, -15283, -12875,
      -9293, -8962},
     {-8592, 7700, 5780, -9899, 5774, 9568, 15758, -3939, -9159, -6187, 6111, 197, 11534, -3634,
      -9660},
     {-15817, 7006, -8592, -15994, 15539, 12272, 4165, 15784, -7111, -197, 5993, -5482, -154,
      12979, -14257},
     {-12724, 1042, -9418, -1776, -9028, -6613, 15286, 13897, 14887, 11620, 2048, 682, -475, 8821,
      -7943},
     {-10519, -14595, 5675, 5089, -9067, 1769, -5990, 8015, 4771, 3827, -11692, 8172, -8962,
      12855, 918},
     {-12970, -6629, 8929, -3883, 11213, -8192, 3883, 11993, -3418, -16024, -1153, -9670, -3831,
      -6013, 15643},
     {1602, 15018, 14483, 3660, -9136, -7540, -6331, -15099, 770, -11600, 14267, -331, 4361,
      12737, -16161}},
    {/* lattice_coeff_2[10][6] */
     {-5741, 5420, -2454, -6603, 826, -151},
     {16289, -6898, -13556, -6062, 7278, 12629},
     {15185, 11541, 13314, 14909, -14762, -14841},
     {10093, 10335, 3205, 2372, 3480, 12583},
     {-4797, -5043, 3903, -9916, 8392, 12167},
     {5725, 8788, -7678, 16246, -15509, 13949},
     {-16187, 3467, -9067, -3156, -14382, 3362},
     {986, -1101, -1511, 15906, 10053, -15152},
     {4037, -1655, 2697, 6111, 4755, 15670},
     {-9470, 6619, 13471, -13690, -8235, 15801}},
    {/* lattice_coeff_3[10][3] */
     {4450, -1222, 1170},
     {-14510, -7491, -15368},
     {13242, -6698, 15204},
     {-14379, 12465, -15699},
     {9844, 7782, 14418},
     {14202, 10882, -5259},
     {-4951, 832, -5243},
     {-12255, 4083, 8087},
     {-16194, -9958, 15663},
     {12504, -12783, -14529}},
    {/* den_coef_0 q14 */
     {16384, -2677, 11144, -8152, -2917, 537,   -2150, -1288, 5735, -6796, 8752,
      -2647, 2786,  5973,  -3923, 1093,  -8123, -5322, -1199, -53,  4029},

     {16384, 2448,   -15662, 1190,  16636, -5357, -10438, 4364, 1939,  -4316, 5345,
      -3394, -11208, 3891,   13793, -7985, -9467, 8668,   8686, -6206, -3118},

     {16384, -6990, -772, 3794, -12779, 2933, 4793, -14032, 6966, -2876, -4518,
      14259, -6262, 1196, 5414, -6895,  2755, 3281, -4283,  6852, -5238},

     {16384, 5512, 4926, -2017, -4276, -2849, -5766, -6567, -5863, -627, 3326,
      1558,  5098, 5629, 1356,  5286,  2457,  -3334, -6056, -7615, -5684},

     {16384, -8857, -4068, 3305, -3044, 5892, -5781, -2649, 2947, -264, 5595,
      540,   -3428, -2919, 4814, -107,  2970, -3338, -4532, 8788, -2061},

     {16384, 1190,  -10978, 2490,  -3098, -2264, 12235, -9936, -7287, 12175, -7420,
      -1698, 15077, -5154,  -3386, -94,   -7800, 3804,  7900,  -5899, -5618},

     {16384, -17384, 12468, -751,  3681, -7469, 10649, 3130,  -5704, 2373, 6351,
      5340,  -12595, 16555, -7389, 5115, -5671, 12027, -3051, -994,  3373},

     {16384, 13384, 10432, 5829,  3526,  -7134, 3086, -115,  -1605, -4068, -1825,
      -7607, -653,  -1349, -4475, -4514, 6441,  8150, 10624, 9360,  5133},

     {16384, -5813, 362,  -1267, -8112, -2160, 4043, 1620, -3873, 8207, -12183,
      5524,  1972,  1327, 4976,  2631,  -3570, -50,  42,   -7948, 5713},

     {16384, -7682,  2829, 12031, -22053, 12224, 2498,  -12336, 26658, -10308, -9897,
      18060, -22112, 2326, 9035,  -12851, 12792, -5163, -5946,  4431,  -6595}},
    {/* den_coef_1 q14 */
     {16384, 5086, -12829, -8464, 6791, 10492, 2538, -4199, -3432, 5908, 6533, -3531, -8738, 3267,
      6451, -3311},

     {16384, 3356, -2917, 2732, 4176, 1387, 1216, 2488, -1363, -3535, 5979, 3249, 5099, 268,
      -2539, 1327},

     {16384, 6526, -2521, -4879, 6157, 850, -4836, -3599, 2838, -2512, -8878, -3331, 2352, -1190,
      439, 1053},

     {16384, 10349, 9342, 1987, 4461, 1128, 3510, -5025, 2031, -153, -2101, -6694, -10307, -10414,
      -7129, -4481},

     {16384, -3388, -2228, -58, -2878, 2872, 5455, 6756, -2217, -5804, -3514, 3112, -905, 6255,
      -660, -4830},

     {16384, -12573, 2440, 7208, -21776, 11349, 9605, -15665, 18521, -4353, -12453, 14610, -4744,
      -4245, 10731, -7129},

     {16384, 1438, 3894, -4945, -4577, -5649, -8998, 1275, 2533, 7551, 5513, 831, 2478, -516,
      3803, -3971},

     {16384, -9557, -4016, 1148, 3067, -2322, 4368, -9160, 4040, 2668, 1543, -3710, 3583, -7718,
      6155, 459},

     {16384, -8302, -3137, 3782, -3003, 1583, -2785, -119, 6186, -659, -3700, -576, -718, -1954,
      -6285, 7822},

     {16384, 2798, 10568, 5005, -7412, -7699, -13818, -6523, -6133, 5936, 1861, 11433, 1574,
      -2064, 3440, -8081}},
    {/* den_coef_2 q14 */
     {16384, -3386, 2367, -451, -3395, 428, -75},

     {16384, 9840, -7195, -12936, -3631, 6891, 6314},

     {16384, 15624, 8696, 3216, -3613, -12943, -7420},

     {16384, 8053, 7214, 3850, 4439, 4576, 6291},

     {16384, -2632, -3365, 2966, -6169, 2640, 6083},

     {16384, -6449, 9825, -7212, 10563, -9094, 6975},

     {16384, -9038, 5639, -5838, 2923, -8043, 1681},

     {16384, 251, -4704, -415, 8460, 3836, -7576},

     {16384, 3680, 1058, 2332, 3098, 3594, 7835},

     {16384, -7410, -4018, 12455, -5813, -6733, 7900}},
    {/* den_coef_3 q14 */
     {16384, 2120, -535, 585},

     {16384, -3840, -1121, -7684},

     {16384, 3714, -905, 7602},

     {16384, -12910, 10987, -7850},

     {16384, 7803, 6571, 7209},

     {16384, 8586, 3923, -2630},

     {16384, -2605, 822, -2621},

     {16384, -6387, 341, 4044},

     {16384, -8016, -7673, 7832},

     {16384, 6647, -8082, -7265}},
    {/* lattice_delta_phi[10][20] */
     {58687, 14277, 37483, 30019, 55054, 47071, 28194, 1144,  50735, 27466,
      38014, 48916, 56938, 45597, 10889, 25058, 57780, 56633, 25339, 55198},
     {3575, 21794, 50227, 609,   8579,  12524, 12275, 37293, 16813, 12281,
      944,  46128, 27492, 57554, 28783, 25857, 52268, 32437, 12517, 41514},
     {51767, 1212,  42081, 23439, 51377, 31058, 43821, 26490, 18815, 11715,
      11947, 42140, 18701, 33456, 9319,  43106, 23370, 53120, 52727, 36661},
     {30671, 55575, 50748, 39833, 50522, 40780, 21122, 17895, 21073, 32988,
      44912, 19104, 51790, 35088, 22879, 43404, 33761, 27479, 42900, 38375},
     {49093, 59100, 32280, 54362, 10682, 60516, 16767, 15584, 54090, 45541,
      8431,  727,   55214, 12301, 18452, 40855, 17567, 28983, 4001,  61047},
     {35996, 26159, 31841, 20627, 26739, 13956, 35812, 46966, 32725, 39564,
      12914, 23459, 48382, 42054, 28479, 35072, 49057, 3657,  37238, 3106},
     {25657, 18838, 54005, 927,   47435, 59965, 61155, 48726, 27096, 30779,
      13215, 39748, 19769, 59300, 44882, 25444, 45990, 16551, 27171, 57652},
     {42208, 13130, 51836, 38837, 8264, 12793, 37503, 38905, 22882, 35524,
      27882, 2710,  1678,  19313, 793,  23717, 42192, 5734,  2182,  37824},
     {37588, 973,   1009,  11741, 36251, 3555,  22702, 39004, 44325, 42785,
      5194,  28063, 27289, 21820, 9486,  41733, 43188, 44935, 29547, 34272},
     {7478,  27843, 44217, 55149, 16869, 15735, 53464, 14352, 49712, 56109,
      14323, 14782, 3074,  4843,  39580, 11790, 52124, 10741, 10548, 61414}

    }}; /* END OF ia_mps_dec_decorr_tables_struct */

const ia_mps_dec_tp_process_tables_struct ixheaacd_mps_dec_tp_process_tables = {
    {/* WORD32 bp[25] */
     0,          536871,     9878425,    63028645,   277025391,  793709956,  1051300620,
     1072990205, 1073741824, 1073741824, 1073741824, 1073741824, 1073634450, 1072023837,
     1063863399, 1034979744, 961213681,  827962321,  657881616,  494887607,  364105853,
     267683837,  198427489,  148927991,  113065014},
    {/* WORD32 bpxgf[25] */
     0,      0,      0,      0,      0,      0,      11,     869,    3876,
     9030,   17180,  29034,  42613,  60301,  78683,  101438, 118431, 129369,
     130793, 123544, 116663, 110310, 106802, 105375, 106563},
    {/* WORD32 bp2xgf2[25] */
     0,          0,          0,          0,          0,          0,          14,
     94422,      1878124,    10192994,   36893488,   105371488,  226978688,  454531424,
     773883456,  1286217856, 1753241984, 2092045696, 2138365312, 1907882112, 1701286528,
     1521032576, 1425823104, 1387998976, 1419449728},
    {/* ia_mps_dec_qmf_64_640 */

     -593273,    -603195,    -531235,    -523473,    -525466,    -541242,    -561198,
     -586968,    -609649,    -630386,    -658498,    -677798,    -702262,    -727749,
     -745350,    -768556,    -779004,    -798965,    -804296,    -824781,    -829449,
     -841205,    -835357,    -837912,    -837674,    -833006,    -819350,    -808527,
     -785910,    -774746,    -742807,    -714082,    -680923,    -638459,    -597491,
     -552501,    -494600,    -439710,    -375935,    -311061,    -225307,    -155303,
     -66285,     14490,      117508,     219367,     316703,     432346,     548401,
     669947,     800799,     924324,     1061499,    1207976,    1350540,    1492769,
     1658203,    1811196,    1970130,    2130426,    2304420,    2471459,    2644155,
     2813392,    -14250510,  15451646,   16686544,   17966354,   19266512,   20602146,
     21961434,   23350400,   24769094,   26216586,   27689208,   29190684,   30716766,
     32266228,   33824760,   35407076,   37003392,   38622232,   40245224,   41881696,
     43524036,   45166852,   46825616,   48478200,   50126888,   51772148,   53406388,
     55035300,   56653920,   58245424,   59826064,   61376848,   62912216,   64407060,
     65869248,   67308344,   68688968,   70034496,   71335920,   72593104,   73770768,
     74907480,   75981056,   76987576,   77919576,   78771872,   79564664,   80257104,
     80867504,   81390528,   81818320,   82140408,   82366040,   82482056,   82488072,
     82378000,   82146696,   81792104,   81315088,   80699888,   79957728,   79070992,
     78036832,   76861272,   75541288,   -387791520, 399839488,  411924960,  424043392,
     436188032,  448362048,  460540736,  472720608,  484901440,  497068160,  509217024,
     521328832,  533403616,  545441280,  557404608,  569323776,  581168512,  592925760,
     604601408,  616169344,  627645376,  638996992,  650234816,  661329408,  672295808,
     683112384,  693773568,  704268992,  714590208,  724739584,  734692096,  744455552,
     754023232,  763367104,  772499520,  781410112,  790081984,  798523328,  806716992,
     814656576,  822343936,  829764160,  836905280,  843784256,  850375168,  856681280,
     862696320,  868409664,  873831616,  878940992,  883734592,  888228800,  892390976,
     896245568,  899765312,  902967616,  905834176,  908366080,  910566976,  912444864,
     913965952,  915155200,  916011392,  916516032,  916694784,  387791520,  -375800416,
     -363861344, -351984768, -340191360, -328468224, -316830784, -305287808, -293843840,
     -282507200, -271278752, -260169456, -249182288, -238333392, -227604912, -217030080,
     -206584352, -196298528, -186166240, -176196608, -166387792, -156741232, -147269248,
     -137976128, -128857392, -119918376, -111167664, -102599616, -94225952,  -86046760,
     -78054944,  -70266720,  -62674884,  -55276676,  -48082892,  -41100320,  -34309408,
     -27726944,  -21349652,  -15170772,  -9203229,   -3445304,   2122315,    7477201,
     12629763,   17577288,   22333516,   26876570,   31226990,   35388804,   39343844,
     43106256,   46682944,   50068936,   53255304,   56274144,   59105196,   61756552,
     64227648,   66529340,   68659864,   70619000,   72426576,   74052112,   75541288,
     14250510,   -13083544,  -11952416,  -10860922,  -9805983,   -8783018,   -7797064,
     -6849645,   -5941788,   -5070487,   -4230663,   -3428863,   -2665749,   -1936973,
     -1242119,   -586722,    29640,      626234,     1170628,    1694867,    2176923,
     2631584,    3054447,    3445840,    3801180,    4129225,    4429361,    4703189,
     4943457,    5165715,    5351495,    5517130,    5660311,    5780916,    5879142,
     5948998,    6004056,    6041528,    6054744,    6061830,    6036645,    6006299,
     5956659,    5892270,    5819334,    5741478,    5632975,    5519822,    5410909,
     5276110,    5146719,    5004330,    4854371,    4695550,    4538091,    4382987,
     4209866,    4037690,    3866358,    3695698,    3515389,    3342066,    3164257,
     2992568,    2813392,    0

    },

    {/* time_out_idx_5xxx */
     0, 4, 1, 5, 2, 3},
    {                          /* time_out_idx_7xxx */
     0, 6, 4, 1, 7, 5, 2, 3}}; /* END OF ia_mps_dec_tp_process_tables_struct */

const ia_mps_dec_wf_tables_struct ixheaacd_mps_dec_wf_tables = {
    {/* wf_02[02] */
     241763088, 1047220608},
    {/* wf_03[03] */
     405508672, 994288128, 1073741824},
    {/* wf_04[04] */
     74786520, 495910976, 952295808, 1072442752},
    {/* wf_15[15] */
     33378420, 82512488, 161958320, 271833312, 405508672, 550893760, 693520960, 820157440,
     921652736, 994288128, 1039588224, 1063000768, 1071959744, 1073777408, 1073741824},
    {/* wf_16[16] */
     17767756, 49954848, 106257792, 189948048, 299393344, 427811456, 564606912, 697780672,
     816546368, 913347264, 984834112, 1031783360, 1058213184, 1070029568, 1073496768, 1073778048},
    {/* wf_18[18] */
     16564868, 43063124, 87930072, 154132432, 241763088, 347599968, 465479488, 587373440,
     704843840, 810472832, 898935168, 967540544, 1016242176, 1047220608, 1064192000, 1071578112,
     1073653504, 1073771776},
    {/* wf_24[24] */
     14317799,   31203742,   57523900,   95005720,   144655552,  206523232,
     279593792,  361828608,  450350208,  541736896,  632377216,  718827712,
     798123008,  868004096,  927046656,  974691008,  1011186368, 1037469120,
     1054995264, 1065546944, 1071026944, 1073256768, 1073790592, 1073759872},
    {/* wf_30[30] */
     13067639,   25239604,   43063124,   67534224,   99414240,   139133360,
     186719680,  241763088,  303418944,  370451168,  441309952,  514235072,
     587373440,  658898880,  727122624,  790586112,  848129856,  898935168,
     942540224,  978831680,  1008016576, 1030578048, 1047220608, 1058807040,
     1066291840, 1070653760, 1072829696, 1073653504, 1073802496, 1073753728},
    {/* wf_32[32] */
     12766251,   23875188,   39863096,   61569988,   89667248,   124584992,  166455168,
     215076864,  269907904,  330083936,  394462912,  461690592,  530280480,  598700672,
     665459648,  729184768,  788687296,  843011328,  891463872,  933627840,  969357504,
     998760960,  1022170432, 1040104512, 1053224448, 1062286912, 1068094656, 1071448256,
     1073099136, 1073706624, 1073800704, 1073752448}}; /* END OF ia_mps_dec_wf_tables_struct */

const ia_mps_dec_mdct2qmf_table_struct ixheaacd_mps_dec_mdct2qmf_table = {
    {/* twi_post_cos[64] */
     13,   -38,  63,   -88,   113,  -138,  163,  -187,  212,  -237,  261,  -285, 309,
     -333, 357,  -380, 403,   -426, 449,   -472, 494,   -516, 537,   -558, 579,  -600,
     620,  -640, 659,  -678,  697,  -715,  733,  -750,  767,  -784,  799,  -815, 830,
     -844, 858,  -872, 885,   -897, 909,   -920, 931,   -941, 951,   -960, 968,  -976,
     983,  -990, 996,  -1002, 1007, -1011, 1015, -1018, 1020, -1022, 1023, -1024

    },
    {/* twi_post_sin[64] */

     1024, -1023, 1022, -1020, 1018, -1015, 1011, -1007, 1002, -996, 990,  -983, 976,
     -968, 960,   -951, 941,   -931, 920,   -909, 897,   -885, 872,  -858, 844,  -830,
     815,  -799,  784,  -767,  750,  -733,  715,  -697,  678,  -659, 640,  -620, 600,
     -579, 558,   -537, 516,   -494, 472,   -449, 426,   -403, 380,  -357, 333,  -309,
     285,  -261,  237,  -212,  187,  -163,  138,  -113,  88,   -63,  38,   -13},
    {/* hybrid_2_qmf[71] */
     0,  0,  0,  0,  0,  0,  1,  1,  2,  2,  3,  4,  5,  6,  7,  8,  9,  10,
     11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28,
     29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46,
     47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63},
    {/* local_sin_4 */
     6393, 18205, 27246, 32138},
    {/* local_sin_15 */
     0, 3425, 6813, 10126, 13328, 16384, 19261, 21926, 24351, 26510, 28378, 29935, 31164, 32052,
     32588, 32768},
    {/* local_sin_16 */
     1608, 4808, 7962, 11039, 14010, 16846, 19520, 22006, 24279, 26320, 28106, 29622, 30853,
     31786, 32413, 32729},
    {/* local_sin_18 */
     1429, 4277, 7092, 9854, 12540, 15131, 17606, 19948, 22138, 24159, 25997, 27636, 29066, 30274,
     31251, 31991, 32488, 32737},
    {/* local_sin_24 */
     1072,  3212,  5338,  7441,  9512,  11543, 13524, 15447, 17304, 19087, 20788, 22400,
     23916, 25330, 26635, 27827, 28899, 29847, 30668, 31357, 31912, 32330, 32610, 32750},
    {/* local_sin_30 */
     858,   2571,  4277,  5971,  7650,  9307,  10938, 12540, 14107, 15636,
     17121, 18560, 19948, 21281, 22556, 23769, 24917, 25997, 27005, 27939,
     28797, 29576, 30274, 30888, 31419, 31863, 32219, 32488, 32667, 32757},
    {/* local_sin_32 */
     804,   2411,  4011,  5602,  7180,  8740,  10279, 11793, 13279, 14733, 16151,
     17531, 18868, 20160, 21403, 22595, 23732, 24812, 25833, 26791, 27684, 28511,
     29269, 29957, 30572, 31114, 31581, 31972, 32286, 32522, 32679, 32758}

}; /* END OF ia_mps_dec_mdct2qmf_table_struct */

const ia_mps_dec_tonality_tables_struct ixheaacd_mps_dec_tonality_tables = {
    {/* gmax_fix[72] */
     1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 2, 2, 2, 2, 2, 2, 2,
     2, 2, 2, 2, 2, 2, 2, 2, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
     4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 5, 5, 5, 5, 5, 5, 5, 5},
    {/* dwin_fix[72] */
     32768,  65536,  98304,  131072, 163840, 196608, 229376, 262144, 294912, 327680, 360448,
     393216, 425984, 458752, 491520, 524288, 278528, 294912, 311296, 327680, 344064, 360448,
     376832, 393216, 409600, 425984, 442368, 458752, 475136, 491520, 507904, 524288, 360448,
     371371, 382293, 393216, 404139, 415061, 425984, 436907, 447829, 458752, 469675, 480597,
     491520, 502443, 513365, 524288, 401408, 409600, 417792, 425984, 434176, 442368, 450560,
     458752, 466944, 475136, 483328, 491520, 499712, 507904, 516096, 524288, 425984, 432538,
     439091, 445645, 452198, 458752, 465306, 471859},
    {/* nstart_fix[5][72] */
     {

         -15, -14, -13, -12, -11, -10, -9, -8, -7, -6, -5, -4, -3, -2, -1, 0,  -7, -7,
         -6,  -6,  -5,  -5,  -4,  -4,  -3, -3, -2, -2, -1, -1, 0,  0,  -5, -5, -4, -4,
         -4,  -3,  -3,  -3,  -2,  -2,  -2, -1, -1, -1, 0,  0,  -4, -3, -3, -3, -3, -2,
         -2,  -2,  -2,  -1,  -1,  -1,  -1, 0,  0,  0,  -3, -3, -3, -2, -2, -2, -2, -2},
     {

         -14, -12, -10, -8, -6, -4, -2, 0,  2,  4,  6,  8,  10, 12, 14, 16, 1,  2,
         3,   4,   5,   6,  7,  8,  9,  10, 11, 12, 13, 14, 15, 16, 6,  7,  7,  8,
         9,   9,   10,  11, 11, 12, 13, 13, 14, 15, 15, 16, 9,  9,  10, 10, 11, 11,
         12,  12,  13,  13, 14, 14, 15, 15, 16, 16, 10, 10, 11, 11, 12, 12, 12, 13},
     {

         -13, -10, -7, -4, -1, 2,  5,  8,  11, 14, 17, 20, 23, 26, 29, 32, 10, 11,
         13,  14,  16, 17, 19, 20, 22, 23, 25, 26, 28, 29, 31, 32, 17, 18, 19, 20,
         21,  22,  23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 21, 22, 22, 23, 24, 25,
         25,  26,  27, 28, 28, 29, 30, 31, 31, 32, 23, 24, 24, 25, 25, 26, 27, 27},
     {

         -12, -8, -4, 0,  4,  8,  12, 16, 20, 24, 28, 32, 36, 40, 44, 48, 18, 20,
         22,  24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 28, 29, 31, 32,
         33,  35, 36, 37, 39, 40, 41, 43, 44, 45, 47, 48, 33, 34, 35, 36, 37, 38,
         39,  40, 41, 42, 43, 44, 45, 46, 47, 48, 36, 37, 38, 38, 39, 40, 41, 42},
     {

         -11, -6, -1, 4,  9,  14, 19, 24, 29, 34, 39, 44, 49, 54, 59, 64, 27, 29,
         32,  34, 37, 39, 42, 44, 47, 49, 52, 54, 57, 59, 62, 64, 39, 41, 42, 44,
         46,  47, 49, 51, 52, 54, 56, 57, 59, 61, 62, 64, 45, 47, 48, 49, 50, 52,
         53,  54, 55, 57, 58, 59, 60, 62, 63, 64, 49, 50, 51, 52, 53, 54, 55, 56}},
    {/* dfrac_fix[5][56] */
     {16384, 0,     16384,  0,     16384, 0,      16384, 0,     16384,  0,     16384, 0,
      16384, 0,     16384,  0,     0,     -10923, 10923, 0,     -10923, 10923, 0,     -10923,
      10923, 0,     -10923, 10923, 0,     -10923, 10923, 0,     -8192,  16384, 8192,  0,
      -8192, 16384, 8192,   0,     -8192, 16384,  8192,  0,     -8192,  16384, 8192,  0,
      0,     -6554, -13107, 13107, 6554,  0,      -6554, -13107},
     {0,      0,      0,     0,      0,     0,     0,      0,   0,     0,      0,     0,
      0,      0,      0,     0,      0,     10923, -10923, 0,   10923, -10923, 0,     10923,
      -10923, 0,      10923, -10923, 0,     10923, -10923, 0,   16384, 0,      16384, 0,
      16384,  0,      16384, 0,      16384, 0,     16384,  0,   16384, 0,      16384, 0,
      0,      -13107, 6554,  -6554,  13107, 0,     -13107, 6554},
     {16384, 0, 16384, 0,     16384, 0,     16384, 0,     16384, 0,     16384,  0, 16384, 0,
      16384, 0, 0,     0,     0,     0,     0,     0,     0,     0,     0,      0, 0,     0,
      0,     0, 0,     0,     8192,  16384, -8192, 0,     8192,  16384, -8192,  0, 8192,  16384,
      -8192, 0, 8192,  16384, -8192, 0,     0,     13107, -6554, 6554,  -13107, 0, 13107, -6554},
     {0, 0,      0,     0,      0,     0, 0,      0,     0,     0,      0,     0, 0,      0,
      0, 0,      0,     -10923, 10923, 0, -10923, 10923, 0,     -10923, 10923, 0, -10923, 10923,
      0, -10923, 10923, 0,      0,     0, 0,      0,     0,     0,      0,     0, 0,      0,
      0, 0,      0,     0,      0,     0, 0,      6554,  13107, -13107, -6554, 0, 6554,   13107},
     {16384,  0,     16384, 0,      16384, 0,     16384,  0, 16384, 0,      16384, 0,
      16384,  0,     16384, 0,      0,     10923, -10923, 0, 10923, -10923, 0,     10923,
      -10923, 0,     10923, -10923, 0,     10923, -10923, 0, -8192, 16384,  8192,  0,
      -8192,  16384, 8192,  0,      -8192, 16384, 8192,   0, -8192, 16384,  8192,  0,
      0,      0,     0,     0,      0,     0,     0,      0}

    },
    {/* part4[4] */
     65536, 131072, 557056, 1343488},
    {/* part5[5] */
     32768, 65536, 196608, 458752, 1343488},
    {/* part7[7] */
     32768, 32768, 65536, 131072, 196608, 294912, 1343488},
    {/* part10[10] */
     16384, 16384, 32768, 32768, 65536, 65536, 65536, 163840, 294912, 1343488},
    {/* part14[14] */
     16384, 16384, 16384, 16384, 32768, 32768, 65536, 65536, 98304, 98304, 131072, 163840, 393216,
     950272},
    {/* part20[20] */
     8192,  8192,  8192,  8192,  16384, 16384, 16384,  16384,  32768,  32768,
     32768, 32768, 32768, 32768, 65536, 98304, 131072, 163840, 393216, 950272},
    {/* part28[28] */
     8192,  8192,  8192,  8192,  8192,   8192,   8192,   8192,  16384, 16384,
     16384, 16384, 32768, 32768, 32768,  32768,  65536,  65536, 65536, 65536,
     65536, 65536, 98304, 98304, 131072, 163840, 196608, 753664},
    {/* part40[40] */
     4096,  4096,  4096,  4096,  4096,  4096,   4096,   4096,   8192,   8192,
     8192,  8192,  8192,  8192,  8192,  8192,   16384,  16384,  16384,  16384,
     16384, 16384, 16384, 16384, 32768, 32768,  32768,  32768,  32768,  65536,
     65536, 65536, 65536, 98304, 98304, 131072, 163840, 196608, 229376, 524288},
    {/* w_real[16] */
     1073741824, 1053109888, 992008576, 892784128, 759250368, 596538752, 410902752, 209476288, 0,
     -209476288, -410902752, -596538752, -759250368, -892784128, -992008576, -1053109888},
    {/* w_imag[16] */
     0, -209476288, -410902752, -596538752, -759250368, -892784128, -992008576, -1053109888,
     -1073741824, -1053109888, -992008576, -892784128, -759250368, -596538752, -410902752,
     -209476288},
    {/* bitrev[16] */
     0, 8, 4, 12, 2, 10, 6, 14, 1, 9, 5, 13, 3, 11, 7, 15}

}; /* END OF ia_mps_dec_tonality_tables_struct */

const ia_mps_dec_bitdec_tables_struct ixheaacd_mps_dec_bitdec_tables = {
    { /* kernel_table */
     {/* kernels_4_to_71[71] */
      0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
      2, 2, 2, 2, 2, 2, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
      3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3},
     {/* kernels_5_to_71[71] */
      0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 2, 2, 2, 2, 2, 2, 3, 3, 3, 3, 3, 3, 3, 3,
      3, 3, 3, 3, 3, 3, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
      4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4},
     {/* kernels_7_to_71[71] */
      0, 0, 0, 0, 0, 0, 1, 1, 2, 2, 2, 3, 3, 3, 3, 4, 4, 4, 4, 4, 4, 5, 5, 5,
      5, 5, 5, 5, 5, 5, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6,
      6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6},
     {/* kernels_10_to_71[71] */
      0, 0, 0, 0, 1, 1, 2, 2, 3, 3, 4, 4, 5, 5, 6, 6, 7, 7, 7, 7, 7, 8, 8, 8,
      8, 8, 8, 8, 8, 8, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9,
      9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9},
     {/* kernels_14_to_71[71] */
      0,  0,  0,  0,  1,  1,  2,  3,  4,  4,  5,  6,  6,  7,  7,  8,  8,  8,
      9,  9,  9,  10, 10, 10, 10, 11, 11, 11, 11, 11, 12, 12, 12, 12, 12, 12,
      12, 12, 12, 12, 12, 12, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13,
      13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13},
     {/* kernels_20_to_71[71] */
      1,  0,  0,  1,  2,  3,  4,  5,  6,  7,  8,  9,  10, 11, 12, 13, 14, 14,
      15, 15, 15, 16, 16, 16, 16, 17, 17, 17, 17, 17, 18, 18, 18, 18, 18, 18,
      18, 18, 18, 18, 18, 18, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19,
      19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19},
     {/* kernels_28_to_71[71] */
      1,  0,  0,  1,  2,  3,  4,  5,  6,  7,  8,  9,  10, 11, 12, 13, 14, 15,
      16, 17, 17, 18, 18, 19, 19, 20, 20, 21, 21, 21, 22, 22, 22, 23, 23, 23,
      23, 24, 24, 24, 24, 24, 25, 25, 25, 25, 25, 25, 26, 26, 26, 26, 26, 26,
      26, 27, 27, 27, 27, 27, 27, 27, 27, 27, 27, 27, 27, 27, 27, 27, 27},
     {/* bb_env_kernels[71] */
      1,  0,  0,  1,  2,  3,  4,  5,  6,  7,  8,  9,  10, 11, 12, 13, 14, 14,
      15, 15, 15, 16, 16, 16, 16, 17, 17, 17, 17, 17, 18, 18, 18, 18, 18, 18,
      18, 18, 18, 18, 18, 18, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19,
      19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19}},
    { /* map_table */
     {/* mapping_4_to_28[28] */
      0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 3, 3, 3, 3, 3, 3},
     {/* mapping_5_to_28[28] */
      0, 0, 0, 0, 1, 1, 1, 1, 2, 2, 2, 2, 2, 2, 3, 3, 3, 3, 3, 3, 3, 3, 4, 4, 4, 4, 4, 4},
     {/* mapping_7_to_28[28] */
      0, 0, 0, 0, 1, 1, 2, 2, 2, 3, 3, 3, 3, 4, 4, 4, 4, 4, 5, 5, 5, 5, 6, 6, 6, 6, 6, 6},
     {/* mapping_10_to_28[28] */
      0, 0, 1, 1, 2, 2, 3, 3, 4, 4, 5, 5, 6, 6, 7, 7, 7, 7, 8, 8, 8, 8, 9, 9, 9, 9, 9, 9},
     {/* mapping_14_to_28[28] */
      0, 0, 1, 1, 2,  3,  4,  4,  5,  6,  6,  7,  7,  8,
      8, 8, 9, 9, 10, 10, 11, 11, 12, 12, 12, 13, 13, 13},
     {/* mapping_20_to_28[28] */
      0,  1,  2,  3,  4,  5,  6,  7,  8,  9,  10, 11, 12, 13,
      14, 14, 15, 15, 16, 16, 17, 17, 18, 18, 18, 19, 19, 19}

    },

    {/* tree_property_table[7] */
     {1, 6, 5, 0, {0, 0, 0, 0, 1}},
     {1, 6, 5, 0, {0, 0, 1, 0, 0}},
     {2, 6, 3, 1, {1, 0, 0, 0, 0}},
     {2, 8, 5, 1, {1, 0, 0, 0, 0}},
     {2, 8, 5, 1, {1, 0, 0, 0, 0}},
     {6, 8, 2, 0, {0, 0, 0, 0, 0}},
     {6, 8, 2, 0, {0, 0, 0, 0, 0}}},

    {/* sampling_freq_table[13] */
     96000, 88200, 64000, 48000, 44100, 32000, 24000, 22050, 16000, 12000, 11025, 8000, 7350},
    {/* freq_res_table[8] */
     0, 28, 20, 14, 10, 7, 5, 4},
    {/* temp_shape_chan_table[2][7] */
     {5, 5, 4, 6, 6, 4, 4},
     {5, 5, 5, 7, 7, 4, 4}},
    {/* surround_gain_table[5] */
     32768, 38968, 46341, 55109, 65536},
    {/* lfe_gain_table[5] */
     32768, 103621, 327680, 1036215, 3276800},
    {/* clip_gain_table[8] */
     32768, 38968, 46341, 55109, 65536, 77936, 92682, 131072},
    {/* pb_stride_table[4] */
     1, 2, 5, 28},
    {/* smg_time_table[4] */
     64, 128, 256, 512},
    {/* dequant_cld[31] */
     -4915200, -1474560, -1310720, -1146880, -983040, -819200, -720896, -622592,
     -524288,  -425984,  -327680,  -262144,  -196608, -131072, -65536,  0,
     65536,    131072,   196608,   262144,   327680,  425984,  524288,  622592,
     720896,   819200,   983040,   1146880,  1310720, 1474560, 4915200},
    {/* dequant_cld_coarse[15] */
     -4915200, -1146880, -819200, -622592, -425984, -262144, -131072, 0, 131072, 262144, 425984,
     622592, 819200, 1146880, 4915200},
    {/* dequant_cpc[52] */
     -65536, -62259, -58982, -55705, -52428, -49152, -45875, -42598, -39321, -36044, -32768,
     -29491, -26214, -22937, -19660, -16384, -13107, -9830,  -6553,  -3276,  0,      3276,
     6553,   9830,   13107,  16384,  19660,  22937,  26214,  29491,  32768,  36044,  39321,
     42598,  45875,  49152,  52428,  55705,  58982,  62259,  65536,  68812,  72089,  75366,
     78643,  81920,  85196,  88473,  91750,  95027,  98304},
    {/* dequant_cpc_coarse[26] */
     -65536, -58982, -52428, -45875, -39321, -32768, -26214, -19660, -13107,
     -6553,  0,      6553,   13107,  19660,  26214,  32768,  39321,  45875,
     52428,  58982,  65536,  72089,  78643,  85196,  91750,  98304},
    {/* dequant_icc[8] */
     32768, 30704, 27564, 19691, 12047, 0, -19300, -32440},
    {/* factor_cld_tab_1[31] */
     -4915200, -1474564, -1310734, -1146925, -983182, -819649, -721791, -624372,
     -527818,  -432943,  -341243,  -283080,  -228498, -178762, -135149, -98641,
     -69613,   -47690,   -31890,   -20936,   -13563,  -6959,   -3530,   -1780,
     -895,     -449,     -142,     -44,      -14,     -4,      0},
    {/* hrtf_power[64] */
     5193,    5827,    6538,    7336,    8231,    9235,    10362,   11627,   13045,   14637,
     16423,   18427,   20675,   23198,   26029,   29205,   32768,   36766,   41252,   46286,
     51934,   58271,   65381,   73358,   82309,   92353,   103622,  116265,  130452,  146369,
     164229,  184268,  206752,  231980,  260285,  292045,  327680,  367663,  412525,  462860,
     519338,  582707,  653808,  733584,  823095,  923528,  1036215, 1162652, 1304518, 1463693,
     1642291, 1842680, 2067521, 2319797, 2602855, 2920452, 3276800, 3676630, 4125246, 4628604,
     5193379, 5827066, 6538075, 7335840},
    {/* envshape_data[2][5] */
     {16384, 23170, 32768, 46341, 65536},
     {16384, 20643, 26008, 32768, 41285}},
    {/* pcm_chnksz_level_3[5] */
     2, 4, 5, 7, 8},

    /* pcm_chnksz_level_4 */
    2,
    {/* pcm_chnksz_level_7[6] */
     3, 6, 9, 12, 15, 17},
    /* pcm_chnksz_level_8 */
    3,
    {/* pcm_chnksz_level_11[2] */
     4, 7},
    {/* pcm_chnksz_level_13[4] */
     4, 8, 12, 15},
    /* pcm_chnksz_level_15 */
    4,
    {/* pcm_chnksz_level_19[4] */
     5, 9, 13, 17},
    {/* pcm_chnksz_level_25[3] */
     5, 10, 14},
    /* pcm_chnksz_level_26 */
    5,
    /* pcm_chnksz_level_31 */
    5,
    {                 /* pcm_chnksz_level_51[4] */
     6, 12, 18, 23}}; /* END OF ia_mps_dec_bitdec_tables_struct */

const ia_mps_dec_blind_tables_struct ixheaacd_mps_dec_blind_tables = {
    {{/* blind_cld_mesh[31][21] */
      {-9, -9, -7, -3, -2, -1, 0, 0, 1, 1, 2, 2, 2, 3, 3, 3, 3, 3, 3, 3, 1},
      {-10, -8, -6, -3, -2, -1, 0, 1, 1, 2, 2, 2, 3, 3, 3, 4, 4, 4, 5, 5, 7},
      {-10, -6, -5, -2, -1, 0, 1, 1, 2, 2, 2, 3, 3, 4, 4, 4, 5, 5, 6, 6, 9},
      {-7, -5, -4, -2, 0, 1, 1, 2, 2, 3, 3, 4, 4, 4, 5, 5, 5, 5, 6, 7, 10},
      {-8, -5, -3, 0, 1, 2, 2, 3, 3, 3, 4, 4, 5, 5, 5, 5, 6, 6, 6, 7, 10},
      {-10, -4, -4, 1, 2, 2, 3, 4, 4, 4, 4, 5, 5, 6, 6, 6, 6, 6, 7, 8, 10},
      {1, 1, 1, 2, 3, 2, 2, 3, 4, 5, 5, 5, 6, 6, 6, 6, 6, 7, 7, 9, 11},
      {3, 3, 2, 4, 2, 2, 3, 3, 4, 5, 6, 6, 7, 7, 7, 7, 7, 8, 8, 9, 11},
      {4, 4, 4, 1, 3, 2, 3, 4, 5, 6, 6, 6, 7, 7, 8, 8, 8, 8, 8, 9, 11},
      {5, 5, 5, 3, 2, 3, 3, 4, 5, 6, 7, 7, 7, 7, 7, 7, 7, 8, 8, 9, 10},
      {5, 5, 4, 4, 5, 3, 3, 5, 5, 6, 7, 7, 8, 8, 8, 8, 8, 8, 9, 9, 11},
      {5, 5, 5, 5, 6, 5, 4, 5, 5, 7, 7, 8, 8, 8, 8, 9, 8, 8, 8, 10, 11},
      {5, 5, 5, 5, 5, 4, 4, 6, 6, 7, 8, 9, 8, 8, 8, 8, 8, 9, 9, 10, 11},
      {5, 5, 5, 5, 5, 4, 4, 6, 6, 9, 8, 8, 8, 9, 9, 9, 9, 9, 9, 10, 11},
      {5, 5, 5, 5, 5, 5, 5, 6, 7, 8, 8, 8, 10, 10, 9, 9, 10, 10, 10, 11, 11},
      {5, 5, 5, 5, 5, 5, 5, 5, 8, 8, 9, 9, 9, 10, 10, 10, 9, 9, 10, 11, 11},
      {5, 5, 5, 5, 5, 5, 6, 7, 8, 8, 9, 10, 10, 10, 10, 10, 10, 10, 11, 11, 11},
      {5, 5, 5, 5, 5, 5, 6, 7, 7, 8, 10, 10, 10, 10, 10, 10, 10, 10, 11, 11, 11},
      {5, 5, 5, 5, 5, 6, 6, 6, 6, 9, 10, 10, 10, 10, 10, 10, 10, 10, 11, 11, 11},
      {5, 5, 5, 5, 6, 6, 6, 7, 8, 9, 10, 10, 10, 10, 10, 10, 10, 10, 11, 11, 11},
      {5, 5, 5, 5, 6, 6, 7, 7, 8, 9, 10, 10, 10, 10, 10, 10, 10, 10, 10, 11, 11},
      {5, 5, 5, 6, 6, 6, 7, 7, 7, 9, 9, 10, 10, 10, 10, 10, 10, 10, 10, 11, 11},
      {5, 5, 5, 6, 6, 6, 7, 7, 8, 9, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10},
      {5, 5, 6, 6, 6, 7, 7, 8, 9, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10},
      {6, 6, 6, 6, 6, 7, 7, 8, 9, 9, 11, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10},
      {6, 6, 6, 6, 7, 7, 8, 8, 9, 10, 11, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10},
      {6, 6, 6, 6, 7, 7, 8, 9, 10, 10, 11, 11, 10, 10, 10, 10, 10, 10, 10, 10, 10},
      {6, 6, 6, 7, 7, 8, 8, 9, 10, 10, 11, 11, 10, 10, 10, 10, 10, 10, 10, 10, 10},
      {6, 6, 6, 7, 7, 8, 8, 9, 10, 10, 11, 11, 11, 10, 10, 10, 10, 10, 10, 10, 10},
      {9, 9, 8, 7, 8, 8, 10, 10, 11, 11, 11, 11, 11, 11, 10, 10, 10, 10, 10, 10, 10},
      {11, 11, 8, 7, 8, 8, 10, 11, 11, 11, 11, 11, 11, 11, 10, 10, 10, 10, 10, 10, 10}},
     {/* blind_icc_mesh[31][21] */
      {4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 5},
      {4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4},
      {4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4},
      {4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4},
      {4, 4, 4, 3, 3, 3, 3, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4},
      {5, 4, 4, 3, 3, 3, 3, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4},
      {3, 3, 3, 3, 3, 3, 3, 3, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4},
      {3, 3, 3, 4, 3, 3, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4},
      {3, 3, 2, 2, 4, 3, 4, 3, 3, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4},
      {2, 2, 2, 3, 2, 3, 4, 3, 3, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4},
      {2, 2, 2, 3, 3, 2, 3, 3, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4},
      {2, 2, 2, 3, 3, 3, 3, 4, 4, 4, 4, 4, 4, 4, 4, 4, 3, 3, 3, 4, 4},
      {2, 2, 3, 3, 3, 2, 2, 4, 4, 4, 4, 4, 4, 4, 4, 4, 3, 4, 4, 4, 4},
      {2, 2, 3, 3, 2, 2, 2, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4},
      {3, 3, 3, 2, 2, 2, 3, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4},
      {3, 3, 2, 2, 2, 3, 3, 2, 4, 4, 5, 4, 4, 4, 4, 4, 4, 4, 4, 5, 5},
      {3, 3, 2, 3, 3, 3, 3, 4, 4, 4, 4, 5, 4, 4, 4, 4, 4, 4, 5, 4, 4},
      {3, 3, 3, 3, 3, 3, 3, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 5, 4},
      {3, 3, 3, 3, 3, 3, 3, 3, 2, 5, 4, 4, 4, 4, 4, 4, 4, 4, 4, 5, 4},
      {3, 3, 3, 3, 3, 3, 3, 3, 4, 4, 5, 5, 4, 4, 4, 4, 4, 4, 4, 4, 4},
      {3, 3, 3, 3, 3, 3, 3, 3, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4},
      {3, 3, 3, 3, 3, 3, 3, 3, 2, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4},
      {3, 3, 3, 3, 3, 3, 3, 3, 3, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4},
      {3, 3, 3, 3, 3, 3, 3, 3, 3, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4},
      {3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 5, 5, 4, 4, 4, 4, 4, 4, 4, 4, 4},
      {3, 3, 3, 3, 3, 3, 3, 3, 3, 4, 5, 5, 4, 4, 4, 4, 4, 4, 4, 4, 4},
      {3, 3, 3, 3, 3, 3, 3, 3, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4},
      {3, 3, 3, 3, 3, 3, 3, 3, 4, 3, 5, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4},
      {3, 3, 3, 3, 3, 3, 3, 3, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4},
      {4, 4, 3, 3, 3, 3, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4},
      {4, 5, 3, 3, 3, 3, 4, 5, 5, 4, 5, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4}},
     {/* blind_cpc_1_mesh[31][21] */
      {8, 9, 8, 7, 7, 6, 6, 6, 6, 6, 5, 4, 4, 3, 3, 2, 1, 0, -1, -1, -5},
      {10, 9, 8, 7, 7, 7, 7, 6, 6, 6, 5, 5, 4, 4, 3, 3, 2, 2, 1, 1, 1},
      {9, 9, 8, 8, 7, 7, 7, 7, 7, 6, 6, 5, 5, 4, 4, 4, 3, 2, 2, 2, 0},
      {9, 7, 6, 6, 7, 7, 7, 7, 7, 7, 6, 6, 5, 5, 4, 4, 3, 3, 3, 3, 2},
      {8, 6, 7, 7, 6, 7, 7, 7, 7, 7, 6, 6, 6, 5, 5, 4, 3, 3, 3, 3, 3},
      {10, 7, 8, 7, 6, 7, 7, 7, 7, 7, 7, 6, 6, 6, 5, 4, 4, 3, 3, 4, 4},
      {7, 7, 7, 6, 7, 7, 7, 8, 7, 7, 7, 6, 6, 6, 5, 4, 4, 4, 4, 5, 4},
      {6, 6, 8, 6, 8, 8, 8, 8, 8, 7, 7, 8, 7, 7, 6, 5, 5, 4, 5, 5, 4},
      {4, 4, 5, 9, 8, 9, 9, 8, 8, 8, 8, 7, 7, 7, 6, 6, 5, 4, 5, 5, 4},
      {3, 3, 7, 6, 9, 9, 9, 9, 8, 8, 8, 8, 7, 7, 5, 5, 5, 5, 5, 5, 5},
      {2, 2, 5, 7, 8, 10, 9, 9, 8, 8, 8, 8, 8, 7, 7, 6, 5, 5, 5, 5, 5},
      {4, 4, 5, 7, 7, 9, 9, 9, 8, 9, 8, 9, 8, 8, 7, 7, 6, 7, 6, 5, 6},
      {5, 5, 6, 7, 8, 9, 10, 8, 9, 9, 9, 9, 7, 7, 7, 6, 6, 6, 6, 5, 6},
      {6, 6, 6, 7, 8, 9, 10, 9, 9, 9, 8, 9, 8, 8, 9, 7, 7, 6, 6, 6, 7},
      {6, 6, 7, 8, 8, 9, 9, 9, 9, 9, 9, 8, 9, 8, 8, 9, 8, 8, 5, 7, 7},
      {7, 7, 7, 8, 9, 9, 9, 10, 9, 9, 10, 9, 9, 9, 8, 8, 8, 8, 8, 8, 7},
      {7, 7, 7, 8, 9, 9, 10, 10, 10, 9, 10, 9, 8, 8, 8, 8, 9, 8, 8, 8, 8},
      {7, 7, 8, 8, 9, 9, 10, 10, 10, 10, 9, 10, 9, 7, 8, 8, 8, 8, 8, 8, 8},
      {8, 8, 8, 8, 9, 9, 10, 10, 10, 10, 10, 9, 9, 8, 8, 8, 8, 8, 9, 9, 8},
      {8, 8, 8, 9, 9, 9, 10, 10, 10, 10, 10, 9, 9, 9, 8, 8, 8, 8, 9, 8, 8},
      {8, 8, 8, 9, 9, 9, 10, 10, 10, 10, 10, 10, 9, 9, 8, 8, 8, 8, 8, 8, 8},
      {8, 8, 8, 9, 9, 9, 10, 10, 10, 10, 10, 10, 9, 9, 9, 8, 8, 8, 8, 8, 8},
      {8, 8, 9, 9, 9, 10, 10, 10, 10, 10, 10, 10, 9, 9, 9, 9, 8, 8, 8, 8, 8},
      {9, 9, 9, 9, 9, 10, 10, 10, 10, 10, 10, 10, 9, 9, 9, 9, 9, 8, 8, 8, 8},
      {9, 9, 9, 9, 9, 10, 10, 10, 10, 10, 10, 10, 10, 9, 9, 9, 9, 8, 8, 8, 8},
      {9, 9, 9, 9, 9, 10, 10, 10, 10, 10, 10, 10, 10, 9, 9, 9, 9, 9, 8, 8, 8},
      {9, 9, 9, 9, 9, 10, 10, 10, 10, 10, 10, 10, 10, 9, 9, 9, 9, 9, 9, 8, 8},
      {9, 9, 9, 9, 10, 10, 10, 10, 10, 10, 10, 10, 10, 9, 9, 9, 9, 9, 9, 9, 9},
      {9, 9, 9, 9, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 9, 9, 9, 9, 9, 9, 9},
      {10, 10, 9, 9, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 9, 9, 9, 9, 9, 9, 9},
      {10, 10, 9, 9, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 9, 9, 9, 9, 9, 9, 9}},
     {/* blind_cpc_2_mesh[31][21] */
      {8, 9, 8, 7, 7, 6, 6, 6, 6, 6, 5, 4, 4, 3, 3, 2, 1, 0, -1, -1, -5},
      {7, 7, 7, 6, 6, 6, 6, 6, 5, 5, 4, 4, 3, 3, 2, 2, 0, 0, 0, 0, 0},
      {10, 6, 6, 6, 5, 5, 5, 5, 5, 5, 4, 4, 3, 3, 2, 2, 2, 1, 1, 0, -3},
      {7, 3, 5, 5, 5, 5, 4, 5, 5, 4, 4, 4, 3, 3, 2, 2, 2, 2, 1, 0, -2},
      {2, 0, 3, 4, 5, 4, 4, 3, 4, 4, 3, 3, 3, 2, 2, 2, 2, 2, 2, 0, -5},
      {0, 2, 2, 3, 2, 4, 3, 1, 2, 2, 3, 2, 2, 2, 2, 2, 2, 2, 1, 0, -6},
      {1, 1, 1, 1, 2, 2, 1, 1, 0, 0, -1, 0, 0, 1, 2, 2, 2, 1, 0, -2, -8},
      {0, 0, 0, -2, -2, 1, 2, 0, 0, -1, -1, -2, -3, -3, -1, 0, 0, 0, -2, -5, -5},
      {2, 2, 5, 3, -1, -1, 0, 0, 0, -1, -2, -2, -1, -1, -3, -2, -3, -1, -1, -3, -5},
      {1, 1, 5, 4, 3, 0, -1, 1, 0, -1, -1, -2, -1, 0, 0, 0, 1, 0, 0, -3, -3},
      {1, 1, 3, 4, 5, 2, -1, -1, 1, 2, 1, 0, 0, 0, 1, 1, 0, 1, -1, -2, -5},
      {2, 2, 3, 4, 4, 1, -1, 2, 3, 3, 2, 1, 1, 0, 2, -1, 0, 3, -1, -3, -5},
      {3, 3, 3, 3, 3, 2, 2, 3, 4, 1, 2, 1, 3, -1, 1, 3, -2, -4, 1, -3, -5},
      {3, 3, 3, 3, 3, 2, 2, 0, 3, 3, 1, 1, -3, 0, -1, -1, -1, 1, 0, -3, -5},
      {3, 3, 3, 3, 3, 2, 2, 2, 0, 7, 2, 3, 0, -3, -4, -4, -4, -6, -5, -6, -5},
      {3, 3, 3, 3, 2, 2, 2, 3, 4, 5, 3, 3, 1, -1, -3, -6, 0, -2, -5, -6, -7},
      {3, 3, 3, 3, 2, 2, 3, 3, 2, 6, 3, 2, 2, 0, -2, -3, -1, -4, -4, -6, -6},
      {3, 3, 3, 3, 2, 3, 3, 3, 3, 0, 0, 0, 1, 3, 0, -2, -2, -3, -6, -7, -6},
      {3, 3, 3, 3, 3, 3, 3, 3, 3, 0, -2, 0, 1, 1, 1, -1, -2, -3, -5, -9, -6},
      {3, 3, 3, 3, 3, 3, 3, 2, 1, -1, 2, 0, 1, 1, 0, 0, -2, -3, -5, -6, -6},
      {3, 3, 3, 3, 3, 3, 2, 2, 1, 1, 1, 1, 1, 1, 0, 0, -1, -3, -4, -6, -6},
      {3, 3, 3, 3, 3, 2, 2, 2, 4, 1, 1, 1, 1, 1, 0, 0, -1, -2, -4, -5, -5},
      {3, 3, 3, 3, 3, 2, 2, 3, 2, 2, 1, 1, 1, 1, 0, 0, -1, -2, -3, -4, -4},
      {3, 3, 3, 3, 3, 2, 2, 2, 2, 2, 2, 2, 1, 1, 0, 0, -1, -2, -3, -3, -3},
      {3, 3, 3, 3, 2, 2, 2, 2, 2, 3, 4, 2, 1, 1, 0, 0, -1, -2, -2, -3, -3},
      {3, 3, 3, 3, 2, 2, 2, 2, 2, 2, 1, 2, 2, 1, 1, 0, -1, -1, -2, -2, -2},
      {3, 3, 3, 3, 2, 2, 2, 2, 2, 2, 1, 1, 2, 1, 1, 0, 0, -1, -2, -2, -2},
      {3, 3, 3, 2, 2, 2, 2, 2, 2, 2, 0, 1, 1, 1, 1, 0, 0, -1, -1, -2, -2},
      {3, 3, 3, 2, 2, 2, 2, 2, 2, 2, 1, 1, 1, 1, 1, 0, 0, -1, -1, -1, -1},
      {5, 5, 4, 2, 2, 2, 2, 2, 2, 2, 2, 1, 1, 1, 1, 1, 0, 0, -1, -1, -1},
      {8, 8, 4, 2, 2, 2, 2, 3, 3, 4, -3, 3, -1, 1, 1, 1, 0, 0, -1, -1, -1}}},
    {/* exp_1[13] */
     32762, 32762, 32759, 32757, 32756, 32751, 32745, 32743, 32734, 32723, 32719, 32700, 32694},
    {/* exp_2[13] */
     32757, 32756, 32751, 32745, 32743, 32734, 32723, 32719, 32700, 32677, 32669, 32632, 32620},
    {/* exp_4[13] */
     32745, 32743, 32734, 32723, 32719, 32700, 32677, 32669, 32632, 32586, 32570, 32496, 32472},
    {/* exp_8[13] */
     32723, 32719, 32700, 32677, 32669, 32632, 32586, 32570, 32496, 32406, 32374, 32226, 32179},
    {/* exp_16[13] */
     32677, 32669, 32632, 32586, 32570, 32496, 32406, 32374, 32226, 32048, 31985, 31694, 31600},
    {/* exp_32[13] */
     32586, 32570, 32496, 32406, 32374, 32226, 32048, 31985, 31694, 31344, 31221, 30655, 30474},
    {/* exp_64[13] */
     32406, 32374, 32226, 32048, 31985, 31694, 31344, 31221, 30655, 29981, 29746, 28678, 28342},
    {/* exp_128[13] */
     32048, 31985, 31694, 31344, 31221, 30655, 29981, 29746, 28678, 27431, 27003, 25098,
     24513}}; /* END OF ia_mps_dec_blind_tables_struct */

const ia_huff_cpc_nodes_struct ixheaacd_huff_cpc_nodes =
    {
        /* ia_huff_cpc_nodes_struct huff_cpc_nodes */
        {{{{2, 1},    {-1, -2},   {-3, 3},   {-4, 4},   {6, 5},    {-5, 7},   {-6, 8},
           {-7, 9},   {-8, 10},   {-9, 11},  {-10, 12}, {-11, 13}, {-12, 14}, {-13, 15},
           {-14, 16}, {-15, 17},  {-16, 18}, {-17, 19}, {-18, 20}, {-19, 21}, {-20, 22},
           {-21, 23}, {-22, -26}, {-23, 24}, {-24, -25}}},
         {{{-1, 1},   {-2, 2},    {-3, 3},   {-4, 4},   {-5, 5},   {-6, 6},   {-7, 7},
           {9, 8},    {-8, 10},   {-9, 11},  {-10, 12}, {-11, 13}, {15, 14},  {-12, -14},
           {-13, 16}, {-15, 17},  {-16, 18}, {-17, 19}, {-18, 20}, {-19, 21}, {-20, 22},
           {-26, 23}, {-21, -22}, {-23, 24}, {-24, -25}}},
         {{{-1, 1},   {-2, 2},    {-3, 3},   {-4, 4},   {-5, 5},   {-6, 6},   {-7, 7},
           {9, 8},    {-8, 10},   {-9, 11},  {-10, 12}, {-11, 13}, {15, 14},  {-12, -14},
           {-13, 16}, {-15, 17},  {-16, 18}, {-17, 19}, {-18, 20}, {-19, 21}, {-20, 22},
           {-26, 23}, {-21, -22}, {-23, 24}, {-24, -25}}}},
        {{{{{2, 1},
            {-1, -52},
            {4, 3},
            {-2, 5},
            {-51, 6},
            {-18, 7},
            {-17, 8},
            {10, 9},
            {-3, -36},
            {-19, -50},
            {-35, 11},
            {-34, 12},
            {-4, 13},
            {-33, 14},
            {-20, -49}},
           {{2, 1},     {4, 3},     {-103, 5}, {-1, 6},    {8, 7},    {-2, 9},   {-102, 10},
            {-18, 11},  {13, 12},   {-17, 14}, {-87, 15},  {-19, 16}, {18, 17},  {-86, -101},
            {-3, 19},   {21, 20},   {23, 22},  {-34, -85}, {-20, 24}, {-35, 25}, {-100, 26},
            {28, 27},   {-4, 29},   {-33, 30}, {-70, -71}, {-84, 31}, {-36, 32}, {-21, 33},
            {-69, 34},  {-99, 35},  {-5, 36},  {-50, 37},  {-51, 38}, {-83, 39}, {-37, -68},
            {-22, -52}, {-98, 40},  {-6, -49}, {-54, -55}, {-53, 41}, {-7, 42},  {-66, 43},
            {-67, 44},  {-39, -65}, {-38, 45}, {-82, 46},  {-81, 47}, {-23, -97}},
           {{2, 1},      {4, 3},      {6, 5},      {-154, 7},    {9, 8},       {11, 10},
            {-1, 12},    {14, 13},    {-2, -153},  {-18, 15},    {17, 16},     {19, 18},
            {-17, 20},   {-138, 21},  {23, 22},    {-19, 24},    {-137, 25},   {-152, 26},
            {-3, 27},    {29, 28},    {31, 30},    {-34, 32},    {34, 33},     {-136, 35},
            {-20, 36},   {-35, 37},   {-151, 38},  {40, 39},     {-122, 41},   {-4, -33},
            {-121, 42},  {44, 43},    {-36, 45},   {-135, 46},   {48, 47},     {-120, 49},
            {-21, 50},   {52, 51},    {-150, 53},  {55, 54},     {-50, -51},   {-5, 56},
            {58, 57},    {-37, -119}, {-52, 59},   {-134, 60},   {-38, 61},    {-103, 62},
            {-22, -118}, {-53, 63},   {-133, 64},  {-23, 65},    {-106, -149}, {-105, 66},
            {-104, 67},  {-49, -148}, {69, 68},    {-6, 70},     {-68, 71},    {73, 72},
            {-117, 74},  {-39, -54},  {-69, 75},   {-102, -132}, {-66, 76},    {-24, -67},
            {78, 77},    {-147, 79},  {-7, -88},   {-86, 80},    {-87, -90},   {-55, -101},
            {-116, 81},  {-8, -89},   {-40, -70},  {-65, -131},  {-25, 82},    {-83, 83},
            {-84, -146}, {-85, 84},   {-82, 85},   {-9, 86},     {-73, 87},    {-72, 88},
            {-71, -74},  {-81, 89},   {-10, 90},   {-98, -99},   {-100, 91},   {93, 92},
            {-57, -58},  {-56, 94},   {-97, -115}, {-114, 95},   {-42, 96},    {-41, -113},
            {-130, 97},  {-26, 98},   {-129, -145}},
           {{2, 1},       {4, 3},      {6, 5},       {8, 7},       {-205, 9},    {11, 10},
            {13, 12},     {-1, 14},    {16, 15},     {-204, 17},   {-18, 18},    {-2, 19},
            {21, 20},     {23, 22},    {-189, 24},   {-17, 25},    {27, 26},     {-19, 28},
            {-188, 29},   {-203, 30},  {32, 31},     {-3, 33},     {35, 34},     {-34, 36},
            {38, 37},     {40, 39},    {-187, 41},   {-35, 42},    {-20, 43},    {45, 44},
            {-202, 46},   {-173, 47},  {49, 48},     {51, 50},     {-172, 52},   {54, 53},
            {-4, -33},    {-36, 55},   {-186, 56},   {-171, 57},   {59, 58},     {-21, 60},
            {62, 61},     {-201, 63},  {65, 64},     {-50, 66},    {-51, 67},    {69, 68},
            {-52, 70},    {72, 71},    {-37, -170},  {74, 73},     {-185, 75},   {-5, 76},
            {78, 77},     {-22, 79},   {-157, 80},   {82, 81},     {-156, 83},   {85, 84},
            {-155, 86},   {-200, 87},  {89, 88},     {-154, 90},   {-53, 91},    {-49, 92},
            {-169, 93},   {-38, 94},   {96, 95},     {98, 97},     {-184, 99},   {-6, 100},
            {-66, 101},   {-86, 102},  {-23, -67},   {-69, 103},   {-68, 104},   {106, 105},
            {108, 107},   {-199, 109}, {-54, 110},   {-153, 111},  {-56, -136},  {-71, 112},
            {-151, -168}, {-166, 113}, {-41, 114},   {-39, -137},  {-181, 115},  {-138, -141},
            {-183, 116},  {-139, 117}, {-140, 118},  {-24, 119},   {-7, 120},    {-26, -120},
            {-121, 121},  {-70, 122},  {-152, 123},  {-65, 124},   {-196, 125},  {-55, -198},
            {-87, 126},   {-135, 127}, {-150, -167}, {-72, 128},   {-40, -82},   {-57, -84},
            {-85, 129},   {-83, -182}, {-165, 130},  {-42, 131},   {-27, -103},  {-8, 132},
            {-25, -180},  {-102, 133}, {-195, -197}, {-101, 134},  {-119, -124}, {-123, 135},
            {-125, 136},  {-73, -122}, {-88, 137},   {-58, -149},  {-43, -134},  {-28, -179},
            {-164, 138},  {-11, -194}, {-81, 139},   {-9, -106},   {-99, -105},  {-100, -104},
            {-98, 140},   {-12, 141},  {143, 142},   {-10, -107},  {-116, 144},  {-109, 145},
            {-117, -118}, {-108, 146}, {-13, 147},   {-97, 148},   {-90, 149},   {-91, -114},
            {-89, 150},   {-115, 151}, {-93, 152},   {-131, 153},  {-92, -133},  {-132, 154},
            {-113, 155},  {-74, 156},  {158, 157},   {-76, -130},  {-75, 159},   {-129, 160},
            {-77, -148},  {-147, 161}, {-61, -146},  {163, 162},   {-59, -60},   {-163, 164},
            {-44, -162},  {-145, 165}, {-45, 166},   {-161, -178}, {-29, 167},   {-177, 0}}},
          {{{2, 1},
            {-1, -52},
            {-17, 3},
            {5, 4},
            {-36, 6},
            {-18, 7},
            {-2, 8},
            {-33, 9},
            {-20, 10},
            {-34, -51},
            {-35, 11},
            {-49, 12},
            {-19, 13},
            {-3, 14},
            {-4, -50}},
           {{2, 1},      {4, 3},     {-103, 5},  {-1, 6},    {-17, 7},  {-87, 8},  {10, 9},
            {-18, 11},   {13, 12},   {-2, -33},  {-71, 14},  {16, 15},  {-34, 17}, {-102, 18},
            {-86, 19},   {-55, 20},  {-49, -50}, {22, 21},   {24, 23},  {-70, 25}, {-19, 26},
            {-39, 27},   {-65, -66}, {-35, 28},  {30, 29},   {-54, 31}, {-3, 32},  {-51, 33},
            {-85, -101}, {-23, -81}, {-82, 34},  {-38, 35},  {-69, 36}, {-67, 37}, {-20, -53},
            {-36, 38},   {-97, 39},  {-52, 40},  {-4, -100}, {-84, 41}, {-68, 42}, {-21, 43},
            {-37, 44},   {-5, 45},   {-83, -99}, {-22, 46},  {-98, 47}, {-6, -7}},
           {{2, 1},      {4, 3},      {-154, 5},   {7, 6},      {-1, 8},     {-17, 9},
            {-138, 10},  {12, 11},    {14, 13},    {-18, 15},   {17, 16},    {-122, 18},
            {-33, 19},   {21, 20},    {-2, -34},   {23, 22},    {-153, 24},  {-106, 25},
            {-137, 26},  {28, 27},    {-49, 29},   {-50, 30},   {32, 31},    {-121, 33},
            {-90, 34},   {36, 35},    {-19, -66},  {38, 37},    {-65, 39},   {41, 40},
            {-35, 42},   {-105, 43},  {45, 44},    {-51, -74},  {-82, 46},   {-3, 47},
            {49, 48},    {-81, -152}, {-58, 50},   {-89, -98},  {-136, 51},  {53, 52},
            {-73, 54},   {-67, -120}, {56, 55},    {-83, 57},   {-97, 58},   {-104, 59},
            {-42, 60},   {-88, 61},   {-114, 62},  {-20, 63},   {-57, -113}, {-36, 64},
            {-99, 65},   {-52, -68},  {67, 66},    {-72, 68},   {-130, 69},  {-26, 70},
            {-41, -103}, {-4, -151},  {-135, 71},  {-84, -129}, {-119, 72},  {-115, 73},
            {-56, 74},   {-87, 75},   {-53, -145}, {-100, 76},  {-21, 77},   {-37, 78},
            {-69, -71},  {-118, 79},  {81, 80},    {-85, -150}, {-5, -102},  {-134, 82},
            {-86, 83},   {-38, 84},   {-22, 85},   {-54, 86},   {-133, 87},  {-70, 88},
            {-149, 89},  {-6, -117},  {-101, 90},  {-23, 91},   {-39, 92},   {-55, -148},
            {-132, 93},  {-116, 94},  {-7, 95},    {-24, -40},  {-147, 96},  {-8, -131},
            {-25, 97},   {-9, 98},    {-10, -146}},
           {{2, 1},       {4, 3},       {6, 5},       {8, 7},       {-205, 9},    {-1, 10},
            {-17, 11},    {13, 12},     {-189, 14},   {16, 15},     {-18, 17},    {19, 18},
            {-173, 20},   {22, 21},     {-33, 23},    {-34, 24},    {-2, 25},     {27, 26},
            {-204, 28},   {-157, 29},   {31, 30},     {-188, 32},   {-49, -50},   {34, 33},
            {36, 35},     {-172, 37},   {-141, 38},   {40, 39},     {42, 41},     {-65, -66},
            {44, 43},     {-19, 45},    {47, 46},     {-156, 48},   {-35, 49},    {51, 50},
            {-125, 52},   {54, 53},     {-82, 55},    {-81, 56},    {-51, 57},    {59, 58},
            {-140, 60},   {-3, 61},     {-203, 62},   {64, 63},     {-109, -187}, {66, 65},
            {-98, 67},    {-67, 68},    {-171, 69},   {-97, 70},    {72, 71},     {-124, 73},
            {75, 74},     {-93, 76},    {-155, 77},   {79, 78},     {-61, -83},   {-114, 80},
            {82, 81},     {84, 83},     {-113, -146}, {-20, 85},    {-36, -108},  {-76, 86},
            {88, 87},     {-77, -139},  {-52, 89},    {-99, 90},    {-131, 91},   {-130, 92},
            {-45, 93},    {95, 94},     {-91, -129},  {-68, 96},    {-92, -161},  {-123, 97},
            {-162, 98},   {-202, 99},   {-170, 100},  {-60, 101},   {-116, 102},  {-4, -145},
            {-115, -186}, {104, 103},   {-107, -154}, {-84, 105},   {-29, -147},  {107, 106},
            {-106, 108},  {-75, -177},  {-178, 109},  {111, 110},   {-132, -138}, {-100, 112},
            {-21, 113},   {-37, 114},   {-44, -101},  {-193, 115},  {-90, 116},   {-53, -69},
            {-122, -163}, {118, 117},   {-121, 119},  {-59, -117},  {-148, 120},  {-201, 121},
            {-85, -185},  {123, 122},   {-74, 124},   {-153, -169}, {-5, 125},    {-86, -105},
            {127, 126},   {-133, -137}, {129, 128},   {-22, -136},  {-102, 130},  {-38, 131},
            {-54, 132},   {-89, -120},  {-118, 133},  {-70, -71},   {135, 134},   {-104, 136},
            {-168, -200}, {-6, 137},    {-152, -184}, {-87, 138},   {140, 139},   {-103, 141},
            {-39, 142},   {-135, 143},  {-151, 144},  {-55, 145},   {-23, 146},   {-119, 147},
            {-56, -72},   {-88, 148},   {-167, -183}, {-7, -199},   {150, 149},   {-166, 151},
            {-24, -150},  {-40, 152},   {154, 153},   {-134, 155},  {-41, 156},   {-198, 157},
            {-57, -182},  {-8, 158},    {-73, -197},  {-9, -181},   {-165, 159},  {-149, 160},
            {-25, 161},   {-26, -180},  {-164, 162},  {-58, 163},   {-42, -196},  {165, 164},
            {-10, -195},  {-27, -43},   {-179, 166},  {-28, -194},  {-11, 167},   {-12, -13}}}},
         {{{{-1, 1},
            {-52, 2},
            {4, 3},
            {-17, 5},
            {-2, 6},
            {-18, -36},
            {8, 7},
            {-51, 9},
            {11, 10},
            {-33, -34},
            {-20, -35},
            {-19, 12},
            {-3, 13},
            {-49, 14},
            {-4, -50}},
           {{2, 1},    {-103, 3},   {-1, 4},    {6, 5},    {-17, 7},  {9, 8},     {-2, -87},
            {-18, 10}, {12, 11},    {-102, 13}, {15, 14},  {-34, 16}, {-33, -86}, {18, 17},
            {-71, 19}, {21, 20},    {-19, 22},  {-70, 23}, {-35, 24}, {-50, 25},  {-3, 26},
            {-55, 27}, {-85, -101}, {-49, 28},  {30, 29},  {-51, 31}, {-69, 32},  {-54, 33},
            {-20, 34}, {-66, 35},   {-36, 36},  {-39, 37}, {-65, 38}, {-52, -53}, {-67, 39},
            {-4, 40},  {-84, -100}, {-38, -68}, {-82, 41}, {-81, 42}, {-21, -23}, {-37, 43},
            {-5, 44},  {-83, -97},  {-99, 45},  {-22, 46}, {-6, 47},  {-7, -98}},
           {{2, 1},       {-154, 3},   {5, 4},      {-1, 6},     {8, 7},       {-17, 9},
            {-18, 10},    {-138, 11},  {-2, 12},    {14, 13},    {-153, 15},   {17, 16},
            {-34, 18},    {-137, 19},  {21, 20},    {-33, -122}, {23, 22},     {-19, 24},
            {26, 25},     {28, 27},    {-121, 29},  {-35, 30},   {32, 31},     {-50, 33},
            {-3, 34},     {-152, 35},  {-106, 36},  {-136, 37},  {-49, 38},    {40, 39},
            {-120, 41},   {-51, 42},   {44, 43},    {-105, 45},  {47, 46},     {49, 48},
            {-66, 50},    {-20, 51},   {-36, 52},   {54, 53},    {-68, -90},   {56, 55},
            {-103, 57},   {-52, -104}, {-65, -88},  {-67, 58},   {60, 59},     {62, 61},
            {-4, -89},    {-83, -151}, {64, 63},    {-53, -135}, {-119, 65},   {-82, 66},
            {-73, -87},   {-74, 67},   {-69, -98},  {-84, 68},   {-58, 69},    {-81, 70},
            {72, 71},     {-72, 73},   {-21, 74},   {-37, 75},   {-102, -118}, {-85, 76},
            {-86, -99},   {-57, 77},   {-71, 78},   {-150, 79},  {-97, 80},    {-100, -114},
            {-54, 81},    {-5, -134},  {-38, 82},   {-56, -70},  {-42, 83},    {-113, 84},
            {-115, 85},   {-130, 86},  {-41, -101}, {-22, -133}, {-117, 87},   {-129, 88},
            {-26, 89},    {-39, 90},   {-23, -149}, {-6, 91},    {-55, 92},    {-132, 93},
            {-145, -148}, {-116, 94},  {-24, -40},  {-7, 95},    {-147, 96},   {-8, -131},
            {-25, 97},    {-146, 98},  {-9, -10}},
           {{2, 1},       {4, 3},      {-205, 5},    {-1, 6},      {8, 7},      {10, 9},
            {-17, 11},    {-18, 12},   {-2, -189},   {14, 13},     {-204, 15},  {17, 16},
            {19, 18},     {-34, 20},   {-188, 21},   {23, 22},     {-33, -173}, {25, 24},
            {-19, 26},    {28, 27},    {30, 29},     {32, 31},     {-35, -172}, {34, 33},
            {36, 35},     {-3, -50},   {38, 37},     {-203, 39},   {-187, 40},  {-157, 41},
            {-49, 42},    {44, 43},    {-171, 45},   {-51, 46},    {48, 47},    {-156, 49},
            {51, 50},     {53, 52},    {-20, 54},    {-66, 55},    {-36, 56},   {58, 57},
            {60, 59},     {-141, 61},  {-52, 62},    {-155, 63},   {65, 64},    {-67, 66},
            {68, 67},     {-65, 69},   {71, 70},     {-140, 72},   {-202, 73},  {-186, 74},
            {-4, 75},     {-170, 76},  {-82, 77},    {-68, 78},    {80, 79},    {-154, 81},
            {83, 82},     {85, 84},    {-125, -139}, {87, 86},     {-86, 88},   {-121, 89},
            {91, 90},     {93, 92},    {-53, 94},    {-37, -101},  {-21, -83},  {96, 95},
            {-81, -124},  {98, 97},    {100, 99},    {-69, -98},   {102, 101},  {-106, -138},
            {104, 103},   {-136, 105}, {-109, 106},  {-84, 107},   {109, 108},  {-102, -120},
            {111, 110},   {-116, 112}, {-105, 113},  {-123, 114},  {-91, 115},  {-99, 116},
            {-169, -185}, {-97, -153}, {-108, 117},  {-85, -137},  {-131, 118}, {-201, 119},
            {-87, -114},  {-5, -76},   {-122, 120},  {-104, -117}, {-93, 121},  {-61, -71},
            {-146, 122},  {-103, 123}, {-100, 124},  {-90, 125},   {-118, 126}, {-115, 127},
            {-70, -113},  {-132, 128}, {-38, -130},  {-75, 129},   {-22, -107}, {-89, 130},
            {-54, 131},   {-92, -119}, {-147, 132},  {-133, 133},  {-77, -151}, {-162, 134},
            {136, 135},   {-45, -152}, {-135, -200}, {-168, 137},  {-60, -148}, {-88, -161},
            {-184, 138},  {-59, -74},  {-129, 139},  {-72, 140},   {-6, 141},   {-163, 142},
            {-44, -56},   {-55, 143},  {-145, -178}, {-23, 144},   {146, 145},  {-29, 147},
            {-39, -166},  {-150, 148}, {-167, -177}, {-7, -41},    {-134, 149}, {-183, 150},
            {-199, 151},  {-40, 152},  {-165, 153},  {-24, -73},   {-57, 154},  {-149, -193},
            {-181, 155},  {157, 156},  {-182, 158},  {-42, 159},   {-8, 160},   {-26, 161},
            {-164, 162},  {-25, -198}, {-27, -180},  {-58, 163},   {-196, 164}, {-195, 165},
            {-10, -197},  {-11, -43},  {-12, 166},   {-9, -179},   {-13, 167},  {-28, -194}}},
          {{{-1, 1},
            {-52, 2},
            {4, 3},
            {-2, 5},
            {-17, 6},
            {-18, 7},
            {-36, -51},
            {9, 8},
            {11, 10},
            {-34, -35},
            {-19, 12},
            {-3, -33},
            {-20, 13},
            {-50, 14},
            {-4, -49}},
           {{2, 1},    {-103, 3},  {-1, 4},     {6, 5},     {8, 7},     {-2, 9},     {-17, -18},
            {-87, 10}, {-102, 11}, {13, 12},    {15, 14},   {-86, 16},  {-34, 17},   {19, 18},
            {-19, 20}, {-33, 21},  {-35, 22},   {-71, 23},  {-3, 24},   {-70, -101}, {-85, 25},
            {27, 26},  {-50, 28},  {30, 29},    {-20, 31},  {-69, 32},  {-51, 33},   {-36, -55},
            {35, 34},  {-49, 36},  {-54, -100}, {-4, 37},   {-52, -84}, {39, 38},    {-53, -68},
            {-66, 40}, {-21, 41},  {-67, 42},   {-37, -39}, {-65, 43},  {-38, -99},  {-5, 44},
            {-83, 45}, {-22, -82}, {-98, 46},   {-23, -81}, {-6, 47},   {-7, -97}},
           {{2, 1},      {4, 3},       {-154, 5},   {7, 6},     {-1, 8},     {10, 9},
            {-18, 11},   {-2, -17},    {13, 12},    {-138, 14}, {-153, 15},  {17, 16},
            {19, 18},    {-137, 20},   {-34, 21},   {23, 22},   {-19, 24},   {26, 25},
            {28, 27},    {-33, -122},  {-35, 29},   {-3, 30},   {-152, 31},  {-121, 32},
            {-136, 33},  {35, 34},     {37, 36},    {39, 38},   {-50, -120}, {41, 40},
            {43, 42},    {-20, -51},   {45, 44},    {-36, 46},  {48, 47},    {-106, 49},
            {-52, 50},   {-105, 51},   {-49, -103}, {53, 52},   {-151, 54},  {-104, -135},
            {-4, 55},    {-68, 56},    {-119, 57},  {-53, 58},  {60, 59},    {-66, 61},
            {-67, 62},   {-88, 63},    {-69, 64},   {-21, 65},  {-37, 66},   {-118, 67},
            {-87, 68},   {-90, 69},    {-83, 70},   {-89, 71},  {-86, -102}, {-65, 72},
            {-150, 73},  {-38, 74},    {-84, -134}, {76, 75},   {-5, 77},    {-54, -73},
            {79, 78},    {-82, -85},   {-133, 80},  {-72, 81},  {-70, 82},   {-22, -71},
            {-98, 83},   {-117, 84},   {-74, 85},   {-23, -99}, {-101, 86},  {-39, -149},
            {-81, -100}, {-148, 87},   {-6, -58},   {-55, 88},  {-57, 89},   {91, 90},
            {-56, -132}, {-116, 92},   {-24, 93},   {-114, 94}, {-40, -115}, {-97, 95},
            {-7, -42},   {-131, -147}, {-41, 96},   {-8, -113}, {-25, 97},   {-26, -130},
            {-9, -146},  {-129, 98},   {-10, -145}},
           {{2, 1},       {4, 3},       {-205, 5},    {7, 6},       {9, 8},       {-1, 10},
            {12, 11},     {-18, 13},    {-17, 14},    {-2, 15},     {-189, 16},   {-204, 17},
            {19, 18},     {-188, 20},   {22, 21},     {24, 23},     {-34, 25},    {27, 26},
            {-19, 28},    {30, 29},     {-35, 31},    {-173, 32},   {-33, 33},    {35, 34},
            {-172, 36},   {-203, 37},   {-3, 38},     {-187, 39},   {41, 40},     {-171, 42},
            {44, 43},     {-50, 45},    {47, 46},     {-51, 48},    {-20, 49},    {51, 50},
            {-36, 52},    {-52, 53},    {55, 54},     {57, 56},     {-157, 58},   {60, 59},
            {-156, 61},   {-155, 62},   {-49, 63},    {-202, 64},   {-154, 65},   {-170, 66},
            {-186, 67},   {69, 68},     {-4, 70},     {-86, 71},    {73, 72},     {-66, 74},
            {-67, 75},    {-68, 76},    {-69, 77},    {79, 78},     {-53, 80},    {82, 81},
            {-21, -37},   {84, 83},     {-120, 85},   {-137, 86},   {-141, 87},   {-121, 88},
            {-140, 89},   {-138, 90},   {-136, -139}, {92, 91},     {-153, 93},   {95, 94},
            {-65, -201},  {-169, 96},   {-101, 97},   {-103, -185}, {99, 98},     {101, 100},
            {-82, 102},   {-102, 103},  {-5, 104},    {-85, 105},   {-83, -84},   {-71, 106},
            {108, 107},   {-70, -87},   {-106, 109},  {-22, 110},   {-38, 111},   {-54, 112},
            {114, 113},   {-105, 115},  {-123, 116},  {-124, -151}, {-125, 117},  {-104, 118},
            {-122, -135}, {120, 119},   {-119, 121},  {-116, 122},  {-152, 123},  {-184, -200},
            {-168, 124},  {-81, 125},   {-117, 126},  {128, 127},   {-56, -98},   {-118, 129},
            {-100, 130},  {-99, 131},   {-6, -91},    {-72, 132},   {-90, 133},   {-23, -39},
            {-166, 134},  {-88, 135},   {137, 136},   {-55, 138},   {-89, -150},  {-107, 139},
            {-109, 140},  {142, 141},   {-108, -131}, {-199, 143},  {-41, -132},  {-134, 144},
            {-97, 145},   {-57, -183},  {147, 146},   {-76, -167},  {-114, -133}, {-73, 148},
            {150, 149},   {-115, 151},  {-40, -75},   {-24, 152},   {-7, -165},   {-74, -181},
            {-92, 153},   {-93, 154},   {-146, -182}, {-26, -147},  {-198, 155},  {-149, 156},
            {-42, -58},   {158, 157},   {-130, -148}, {-61, -113},  {-196, 159},  {-60, -180},
            {-164, 160},  {-8, -25},    {-27, 161},   {-59, -77},   {-163, 162},  {-162, 163},
            {-195, -197}, {-43, 164},   {-44, -179},  {-11, -45},   {-9, -129},   {-28, 165},
            {-178, 166},  {-145, -194}, {-29, -161},  {-10, -12},   {-177, 167},  {-13, -193}}}},
         {{{{2, 1},
            {-1, -52},
            {-17, 3},
            {5, 4},
            {-36, 6},
            {-18, 7},
            {-2, 8},
            {-33, 9},
            {-20, 10},
            {-34, -51},
            {-35, 11},
            {-49, 12},
            {-19, 13},
            {-3, 14},
            {-4, -50}},
           {{2, 1},      {4, 3},     {-103, 5},  {-1, 6},    {-17, 7},  {-87, 8},  {10, 9},
            {-18, 11},   {13, 12},   {-2, -33},  {-71, 14},  {16, 15},  {-34, 17}, {-102, 18},
            {-86, 19},   {-55, 20},  {-49, -50}, {22, 21},   {24, 23},  {-70, 25}, {-19, 26},
            {-39, 27},   {-65, -66}, {-35, 28},  {30, 29},   {-54, 31}, {-3, 32},  {-51, 33},
            {-85, -101}, {-23, -81}, {-82, 34},  {-38, 35},  {-69, 36}, {-67, 37}, {-20, -53},
            {-36, 38},   {-97, 39},  {-52, 40},  {-4, -100}, {-84, 41}, {-68, 42}, {-21, 43},
            {-37, 44},   {-5, 45},   {-83, -99}, {-22, 46},  {-98, 47}, {-6, -7}},
           {{2, 1},      {4, 3},      {-154, 5},   {7, 6},      {-1, 8},     {-17, 9},
            {-138, 10},  {12, 11},    {14, 13},    {-18, 15},   {17, 16},    {-122, 18},
            {-33, 19},   {21, 20},    {-2, -34},   {23, 22},    {-153, 24},  {-106, 25},
            {-137, 26},  {28, 27},    {-49, 29},   {-50, 30},   {32, 31},    {-121, 33},
            {-90, 34},   {36, 35},    {-19, -66},  {38, 37},    {-65, 39},   {41, 40},
            {-35, 42},   {-105, 43},  {45, 44},    {-51, -74},  {-82, 46},   {-3, 47},
            {49, 48},    {-81, -152}, {-58, 50},   {-89, -98},  {-136, 51},  {53, 52},
            {-73, 54},   {-67, -120}, {56, 55},    {-83, 57},   {-97, 58},   {-104, 59},
            {-42, 60},   {-88, 61},   {-114, 62},  {-20, 63},   {-57, -113}, {-36, 64},
            {-99, 65},   {-52, -68},  {67, 66},    {-72, 68},   {-130, 69},  {-26, 70},
            {-41, -103}, {-4, -151},  {-135, 71},  {-84, -129}, {-119, 72},  {-115, 73},
            {-56, 74},   {-87, 75},   {-53, -145}, {-100, 76},  {-21, 77},   {-37, 78},
            {-69, -71},  {-118, 79},  {81, 80},    {-85, -150}, {-5, -102},  {-134, 82},
            {-86, 83},   {-38, 84},   {-22, 85},   {-54, 86},   {-133, 87},  {-70, 88},
            {-149, 89},  {-6, -117},  {-101, 90},  {-23, 91},   {-39, 92},   {-55, -148},
            {-132, 93},  {-116, 94},  {-7, 95},    {-24, -40},  {-147, 96},  {-8, -131},
            {-25, 97},   {-9, 98},    {-10, -146}},
           {{2, 1},       {4, 3},       {6, 5},       {8, 7},       {-205, 9},    {-1, 10},
            {-17, 11},    {13, 12},     {-189, 14},   {16, 15},     {-18, 17},    {19, 18},
            {-173, 20},   {22, 21},     {-33, 23},    {-34, 24},    {-2, 25},     {27, 26},
            {-204, 28},   {-157, 29},   {31, 30},     {-188, 32},   {-49, -50},   {34, 33},
            {36, 35},     {-172, 37},   {-141, 38},   {40, 39},     {42, 41},     {-65, -66},
            {44, 43},     {-19, 45},    {47, 46},     {-156, 48},   {-35, 49},    {51, 50},
            {-125, 52},   {54, 53},     {-82, 55},    {-81, 56},    {-51, 57},    {59, 58},
            {-140, 60},   {-3, 61},     {-203, 62},   {64, 63},     {-109, -187}, {66, 65},
            {-98, 67},    {-67, 68},    {-171, 69},   {-97, 70},    {72, 71},     {-124, 73},
            {75, 74},     {-93, 76},    {-155, 77},   {79, 78},     {-61, -83},   {-114, 80},
            {82, 81},     {84, 83},     {-113, -146}, {-20, 85},    {-36, -108},  {-76, 86},
            {88, 87},     {-77, -139},  {-52, 89},    {-99, 90},    {-131, 91},   {-130, 92},
            {-45, 93},    {95, 94},     {-91, -129},  {-68, 96},    {-92, -161},  {-123, 97},
            {-162, 98},   {-202, 99},   {-170, 100},  {-60, 101},   {-116, 102},  {-4, -145},
            {-115, -186}, {104, 103},   {-107, -154}, {-84, 105},   {-29, -147},  {107, 106},
            {-106, 108},  {-75, -177},  {-178, 109},  {111, 110},   {-132, -138}, {-100, 112},
            {-21, 113},   {-37, 114},   {-44, -101},  {-193, 115},  {-90, 116},   {-53, -69},
            {-122, -163}, {118, 117},   {-121, 119},  {-59, -117},  {-148, 120},  {-201, 121},
            {-85, -185},  {123, 122},   {-74, 124},   {-153, -169}, {-5, 125},    {-86, -105},
            {127, 126},   {-133, -137}, {129, 128},   {-22, -136},  {-102, 130},  {-38, 131},
            {-54, 132},   {-89, -120},  {-118, 133},  {-70, -71},   {135, 134},   {-104, 136},
            {-168, -200}, {-6, 137},    {-152, -184}, {-87, 138},   {140, 139},   {-103, 141},
            {-39, 142},   {-135, 143},  {-151, 144},  {-55, 145},   {-23, 146},   {-119, 147},
            {-56, -72},   {-88, 148},   {-167, -183}, {-7, -199},   {150, 149},   {-166, 151},
            {-24, -150},  {-40, 152},   {154, 153},   {-134, 155},  {-41, 156},   {-198, 157},
            {-57, -182},  {-8, 158},    {-73, -197},  {-9, -181},   {-165, 159},  {-149, 160},
            {-25, 161},   {-26, -180},  {-164, 162},  {-58, 163},   {-42, -196},  {165, 164},
            {-10, -195},  {-27, -43},   {-179, 166},  {-28, -194},  {-11, 167},   {-12, -13}}},
          {{{2, 1},
            {-1, -52},
            {-17, 3},
            {5, 4},
            {-36, 6},
            {-18, 7},
            {-2, 8},
            {-33, 9},
            {-20, 10},
            {-34, -51},
            {-35, 11},
            {-49, 12},
            {-19, 13},
            {-3, 14},
            {-4, -50}},
           {{2, 1},      {4, 3},     {-103, 5},  {-1, 6},    {-17, 7},  {-87, 8},  {10, 9},
            {-18, 11},   {13, 12},   {-2, -33},  {-71, 14},  {16, 15},  {-34, 17}, {-102, 18},
            {-86, 19},   {-55, 20},  {-49, -50}, {22, 21},   {24, 23},  {-70, 25}, {-19, 26},
            {-39, 27},   {-65, -66}, {-35, 28},  {30, 29},   {-54, 31}, {-3, 32},  {-51, 33},
            {-85, -101}, {-23, -81}, {-82, 34},  {-38, 35},  {-69, 36}, {-67, 37}, {-20, -53},
            {-36, 38},   {-97, 39},  {-52, 40},  {-4, -100}, {-84, 41}, {-68, 42}, {-21, 43},
            {-37, 44},   {-5, 45},   {-83, -99}, {-22, 46},  {-98, 47}, {-6, -7}},
           {{2, 1},      {4, 3},      {-154, 5},   {7, 6},      {-1, 8},     {-17, 9},
            {-138, 10},  {12, 11},    {14, 13},    {-18, 15},   {17, 16},    {-122, 18},
            {-33, 19},   {21, 20},    {-2, -34},   {23, 22},    {-153, 24},  {-106, 25},
            {-137, 26},  {28, 27},    {-49, 29},   {-50, 30},   {32, 31},    {-121, 33},
            {-90, 34},   {36, 35},    {-19, -66},  {38, 37},    {-65, 39},   {41, 40},
            {-35, 42},   {-105, 43},  {45, 44},    {-51, -74},  {-82, 46},   {-3, 47},
            {49, 48},    {-81, -152}, {-58, 50},   {-89, -98},  {-136, 51},  {53, 52},
            {-73, 54},   {-67, -120}, {56, 55},    {-83, 57},   {-97, 58},   {-104, 59},
            {-42, 60},   {-88, 61},   {-114, 62},  {-20, 63},   {-57, -113}, {-36, 64},
            {-99, 65},   {-52, -68},  {67, 66},    {-72, 68},   {-130, 69},  {-26, 70},
            {-41, -103}, {-4, -151},  {-135, 71},  {-84, -129}, {-119, 72},  {-115, 73},
            {-56, 74},   {-87, 75},   {-53, -145}, {-100, 76},  {-21, 77},   {-37, 78},
            {-69, -71},  {-118, 79},  {81, 80},    {-85, -150}, {-5, -102},  {-134, 82},
            {-86, 83},   {-38, 84},   {-22, 85},   {-54, 86},   {-133, 87},  {-70, 88},
            {-149, 89},  {-6, -117},  {-101, 90},  {-23, 91},   {-39, 92},   {-55, -148},
            {-132, 93},  {-116, 94},  {-7, 95},    {-24, -40},  {-147, 96},  {-8, -131},
            {-25, 97},   {-9, 98},    {-10, -146}},
           {{2, 1},       {4, 3},       {6, 5},       {8, 7},       {-205, 9},
            {-1, 10},     {-17, 11},    {13, 12},     {-189, 14},   {16, 15},
            {-18, 17},    {19, 18},     {-173, 20},   {22, 21},     {-33, 23},
            {-34, 24},    {-2, 25},     {27, 26},     {-204, 28},   {-157, 29},
            {31, 30},     {-188, 32},   {-49, -50},   {34, 33},     {36, 35},
            {-172, 37},   {-141, 38},   {40, 39},     {42, 41},     {-65, -66},
            {44, 43},     {-19, 45},    {47, 46},     {-156, 48},   {-35, 49},
            {51, 50},     {-125, 52},   {54, 53},     {-82, 55},    {-81, 56},
            {-51, 57},    {59, 58},     {-140, 60},   {-3, 61},     {-203, 62},
            {64, 63},     {-109, -187}, {66, 65},     {-98, 67},    {-67, 68},
            {-171, 69},   {-97, 70},    {72, 71},     {-124, 73},   {75, 74},
            {-93, 76},    {-155, 77},   {79, 78},     {-61, -83},   {-114, 80},
            {82, 81},     {84, 83},     {-113, -146}, {-20, 85},    {-36, -108},
            {-76, 86},    {88, 87},     {-77, -139},  {-52, 89},    {-99, 90},
            {-131, 91},   {-130, 92},   {-45, 93},    {95, 94},     {-91, -129},
            {-68, 96},    {-92, -161},  {-123, 97},   {-162, 98},   {-202, 99},
            {-170, 100},  {-60, 101},   {-116, 102},  {-4, -145},   {-115, -186},
            {104, 103},   {-107, -154}, {-84, 105},   {-29, -147},  {107, 106},
            {-106, 108},  {-75, -177},  {-178, 109},  {111, 110},   {-132, -138},
            {-100, 112},  {-21, 113},   {-37, 114},   {-44, -101},  {-193, 115},
            {-90, 116},   {-53, -69},   {-122, -163}, {118, 117},   {-121, 119},
            {-59, -117},  {-148, 120},  {-201, 121},  {-85, -185},  {123, 122},
            {-74, 124},   {-153, -169}, {-5, 125},    {-86, -105},  {127, 126},
            {-133, -137}, {129, 128},   {-22, -136},  {-102, 130},  {-38, 131},
            {-54, 132},   {-89, -120},  {-118, 133},  {-70, -71},   {135, 134},
            {-104, 136},  {-168, -200}, {-6, 137},    {-152, -184}, {-87, 138},
            {140, 139},   {-103, 141},  {-39, 142},   {-135, 143},  {-151, 144},
            {-55, 145},   {-23, 146},   {-119, 147},  {-56, -72},   {-88, 148},
            {-167, -183}, {-7, -199},   {150, 149},   {-166, 151},  {-24, -150},
            {-40, 152},   {154, 153},   {-134, 155},  {-41, 156},   {-198, 157},
            {-57, -182},  {-8, 158},    {-73, -197},  {-9, -181},   {-165, 159},
            {-149, 160},  {-25, 161},   {-26, -180},  {-164, 162},  {-58, 163},
            {-42, -196},  {165, 164},   {-10, -195},  {-27, -43},   {-179, 166},
            {-28, -194},  {-11, 167},   {-12, -13}}}}}}; /* END OF
                                                            ia_mps_dec_huff_nodes_table_struct */
